<?php
namespace Aws\LookoutforVision\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Lookout for Vision** service.
 */
class LookoutforVisionException extends AwsException {}
