OC.L10N.register(
    "password_policy",
    {
    "Password is among the 1,000,000 most common ones. Please make it unique." : "La contraseña ta ente'l 1000000 más frecuente. Crea una contraseña única.",
    "Password needs to contain at least one numeric character." : "La contraseña tien de contener polo menos un caráuter numbéricu.",
    "Password needs to contain at least one special character." : "La contraseña tien de contener polo menos un caráuter especial.",
    "Password needs to contain at least one lower and one upper case character." : "La contraseña tien de contener polo menos un caráuter en minúscula y otru en mayúscula.",
    "Unknown error" : "Error desconocíu",
    "Error while saving settings" : "Hebo un error mentanto se guardaba la configuración",
    "Error while saving" : "Hebo un error mentanto se guardaba"
},
"nplurals=2; plural=(n != 1);");
