OC.L10N.register(
    "support",
    {
    "Link:" : "Ligilo:",
    "Forum" : "Forumo",
    "News" : "Novaĵo",
    "Like our Facebook page" : "Ŝatu nian Facebook-paĝon",
    "Follow us on Twitter" : "Sekvu nin per Twitter",
    "Check out our blog" : "Vizitu nian blogon",
    "Subscribe to our newsletter" : "Aboni nian retan bultenon"
},
"nplurals=2; plural=(n != 1);");
