OC.L10N.register(
    "photos",
    {
    "Public link" : "Δημόσιος σύνδεσμος",
    "Photos" : "Φωτογραφίες",
    "Your memories under your control" : "Οι αναμνήσεις υπό τον έλεγχό σας",
    "All media" : "Όλα τα media",
    "Videos" : "Βίντεο",
    "Albums" : "Άλμπουμ",
    "Collaborative albums" : "Συνεργατικά άλμπουμ",
    "People" : "Άτομα",
    "Folders" : "Φάκελοι",
    "Favorites" : "Αγαπημένα",
    "On this day" : "Αυτή τη μέρα",
    "Shared with you" : "Διαμοιρασμένα μαζί σας",
    "Tags" : "Ετικέτες",
    "Places" : "Τοποθεσίες",
    "Map" : "Χάρτης",
    "Photos settings" : "Ρυθμίσεις φωτογραφιών",
    "Mark selection as favorite" : "Επισήμανση ως αγαπημένο",
    "Add selection to favorites" : "Προσθήκη στα αγαπημένα",
    "Remove selection from favorites" : "Αφαίρεση από τα αγαπημένα",
    "Name of the album" : "Όνομα του άλμπουμ",
    "Location of the album" : "Τοποθεσία του άλμπουμ",
    "Back" : "Πίσω",
    "Save" : "Αποθήκευση",
    "Create album" : "Δημιουργία άλμπουμ",
    "Shared by" : "Διαμοιράστηκε από",
    "Create a new album." : "Δημιουργήστε ένα νέο άλμπουμ.",
    "Create new album" : "Δημιουργία νέου άλμπουμ. ",
    "New album" : "Νέο άλμπουμ",
    "No recommendations. Start typing." : "Δεν υπάρχουν συστάσεις. Αρχίστε να πληκτρολογείτε.",
    "Group" : "Ομάδα",
    "Copy public link" : "Αντιγραφή δημόσιου συνδέσμου",
    "An error occurred" : "Παρουσιάστηκε σφάλμα",
    "Select image {imageName}" : "Επιλογή εικόνας {imageName}",
    "The file is in the favorites" : "Το αρχείο είναι στα αγαπημένα",
    "Open the full size \"{name}\" image" : "Άνοιγμα εικόνας «{name}» σε πλήρη μέγεθος",
    "There are no photos or videos yet!" : "Δεν υπάρχουν φωτογραφίες ή βίντεο ακόμη!",
    "Open the \"{name}\" sub-directory" : "Άνοιγμα υπό-κατάλογου του «{name}»",
    "Back to {folder}" : "Πίσω στο {folder}",
    "Share this folder" : "Διαμοιρασμός αυτού του φακέλου",
    "_{years} year ago_::_{years} years ago_" : ["{years} χρόνο πριν","{years} χρόνια πριν"],
    "Enable squared photos view" : "Ενεργοποίηση προβολής τετραγωνικών φωτογραφιών",
    "Select the default location for your media" : "Επιλέξτε την προεπιλεγμένη τοποθεσία για τα πολυμέσα σας",
    "Invalid location selected" : "Επιλέχθηκε μη έγκυρη τοποθεσία",
    "View" : "Προβολή",
    "Unselect all" : "Αποεπιλογή όλων",
    "Delete album" : "Διαγραφή άλμπουμ",
    "Download selected files" : "Λήψη επιλεγμένων αρχείων",
    "Remove selection from album" : "Αφαίρεση από το άλμπουμ",
    "This album does not have any photos or videos yet!" : "Αυτό το άλμπουμ δεν έχει φωτογραφίες ή βίντεο ακόμη!",
    "Add photos to this album" : "Προσθήκη φωτογραφιών σε αυτό το άλμπουμ",
    "There is no album yet!" : "Δεν υπάρχει άλμπουμ ακόμη!",
    "This person could not be found" : "Δεν ήταν δυνατή η εύρεση του ατόμου",
    "Rename person" : "Μετονομασία ατόμου",
    "Download selected photos" : "Λήψη επιλεγμένων φωτογραφιών",
    "Favorite" : "Αγαπημένο",
    "Remove from favorites" : "Αφαίρεση από τα αγαπημένα",
    "Remove person" : "Αφαίρεση ατόμου",
    "Save." : "Αποθηκεύστε.",
    "This folder does not exist" : "Αυτός ο φάκελος δεν υπάρχει",
    "Loading folders …" : "Φόρτωση φακέλων...",
    "No photos in here" : "Δεν υπάρχουν φωτογραφίες εδώ",
    "No photos with this tag yet" : "Δεν υπάρχουν φωτογραφίες με αυτή την ετικέτα ακόμη",
    "No tags yet" : "Χωρίς ετικέτες ακόμη",
    "Photos with tags will show up here" : "Φωτογραφίες με ετικέτες εμφανίζονται εδώ πάνω",
    "Popular tags" : "Δημοφιλείς ετικέτες",
    "Add" : "Προσθήκη",
    "Add to album" : "Προσθήκη στο άλμπουμ",
    "Delete selection" : "Διαγραφή επιλογής",
    "No photos or videos in here" : "Δεν υπάρχουν φωτογραφίες ή βίντεο εδώ",
    "All your media" : "Όλα τα media σας",
    "Tagged photos" : "Φωτογραφίες με ετικέτα",
    "Failed to rename {oldName} to {faceName}." : "Απέτυχε η μετονομασία του {oldName} σε {faceName}.",
    "Failed to delete {faceName}." : "Απέτυχε η διαγραφή {faceName}.",
    "Failed to delete {fileId}." : "Απέτυχε η διαγραφή {fileId}.",
    "Failed to delete {fileName}." : "Απέτυχε η διαγραφή {fileName}.",
    "Locations" : "Τοποθεσίες",
    "No collaborators available" : "Δεν υπάρχουν διαθέσιμοι συνεργάτες",
    "Add photos to the album" : "Προσθήκη φωτογραφιών στο άλμπουμ",
    "Shared albums" : "Κοινόχρηστα άλμπουμ",
    "Create a new album" : "Δημιουργία ενός νέου άλμπουμ",
    "Add selection to an album" : "Προσθήκη σε ένα άλμπουμ",
    "Failed to create {albumName}." : "Απέτυχε η δημιουργία {albumName}",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Απέτυχε η μετονομασία του {currentAlbumName} σε {newAlbumName}."
},
"nplurals=2; plural=(n != 1);");
