OC.L10N.register(
    "core",
    {
    "Please select a file." : "لطفا فایل مورد نظر را انتخاب کنید ",
    "File is too big" : "فایل خیلی بزرگ است",
    "The selected file is not an image." : "فایل انتخاب شده عکس نمی باشد.",
    "The selected file cannot be read." : "فایل انتخاب شده خوانده نمی شود.",
    "The file was uploaded" : "پرونده، بارگذاری شد",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "حجم پرونده بارگذاری شده بیشتر از تنظیمات upload_max_filesize در پرونده php.ini است",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "حجم پرونده بازگذاری شده بیشتر از تنظیمات MAX_FILE_SIZE مشخص شده در فرم HTML است",
    "The file was only partially uploaded" : "پرونده به صورت ناقص بارگذاری شد",
    "No file was uploaded" : "پرونده‌ای بارگذاری نشد",
    "Missing a temporary folder" : "پوشه موقت موجود نیست",
    "Could not write file to disk" : "ناتوانی در نوشتن پرونده روی حافظه",
    "A PHP extension stopped the file upload" : "یک افزونه پی‌اچ‌پی مانع بارگذاری پرونده شد",
    "Invalid file provided" : "فایل داده‌شده نا معتبر است",
    "No image or file provided" : "هیچ فایل یا تصویری وارد نشده است",
    "Unknown filetype" : "نوع فایل ناشناخته",
    "An error occurred. Please contact your admin." : "یک خطا رخ داده است. لطفا با مدیر سیستم تماس بگیرید.",
    "Invalid image" : "عکس نامعتبر",
    "No temporary profile picture available, try again" : "تصویر پروفایل موقت در حال حاضر در دسترس نیست ، دوباره تلاش کنید ",
    "No crop data provided" : "هیچ داده برش داده شده ارائه نشده است",
    "No valid crop data provided" : "هیچ داده برش داده شده معتبر ارائه نشده است",
    "Crop is not square" : "بخش بریده شده مربع نیست",
    "State token does not match" : "State token مطابقت ندارد",
    "Invalid app password" : "کلمه عبور اپلیکیشن اشتباه است",
    "Could not complete login" : "فرایند ورود شما به سیستم کامل نشد",
    "State token missing" : "State token missing",
    "Your login token is invalid or has expired" : "اطلاعات توکن ورود شما اشتباه یا منقضی است",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "This community release of Nextcloud is unsupported and push notifications are limited.",
    "Login" : "ورود",
    "Please try again" : "Please try again",
    "Password reset is disabled" : "تنظیم مجدد رمز عبور فعال نیست",
    "Could not reset password because the token is expired" : "رمز عبور بازنشانی نشد زیرا رمز منقضی شده است",
    "Could not reset password because the token is invalid" : "رمز عبور بازنشانی نشد زیرا رمز نامعتبر است",
    "Password is too long. Maximum allowed length is 469 characters." : "رمز عبور خیلی طولانی است. حداکثر طول مجاز 469 کاراکتر است.",
    "%s password reset" : "%s رمزعبور تغییر کرد",
    "Password reset" : "تنظیم مجدد رمز عبور",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "برای بازنشانی رمز عبور خود، روی دکمه زیر کلیک کنید. اگر شما تنظیم مجدد رمز عبور را درخواست نکردید، این ایمیل را نادیده بگیرید.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "برای بازنشانی رمز عبور خود، روی لینک زیر کلیک کنید. اگر شما تنظیم مجدد رمز عبور را درخواست نکردید، این ایمیل را نادیده بگیرید.",
    "Reset your password" : "تنظیم مجدد رمز عبور",
    "Requested task type does not exist" : "Requested task type does not exist",
    "Necessary language model provider is not available" : "Necessary language model provider is not available",
    "Task not found" : "Task not found",
    "Internal error" : "Internal error",
    "No translation provider available" : "No translation provider available",
    "Could not detect language" : "Could not detect language",
    "Unable to translate" : "Unable to translate",
    "Nextcloud Server" : "کارساز نکست‌کلود",
    "Some of your link shares have been removed" : "برخی از لینک های اشتراک گذاری شده شما حذف شده است",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Due to a security bug we had to remove some of your link shares. Please see the link for more information.",
    "The user limit of this instance is reached." : "The user limit of this instance is reached.",
    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies.",
    "Learn more ↗" : "بیشتر بدانید ↗",
    "Preparing update" : "آماده‌سازی به روز‌ رسانی",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Repair step:",
    "Repair info:" : "Repair info:",
    "Repair warning:" : "Repair warning:",
    "Repair error:" : "Repair error:",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Please use the command line updater because updating via browser is disabled in your config.php.",
    "Turned on maintenance mode" : "حالت \" در دست تعمیر \" فعال شد .",
    "Turned off maintenance mode" : "حالت \" در دست تعمیر \" غیرفعال شد .",
    "Maintenance mode is kept active" : "حالت تعمیرات فعال نگه‌داشته شده است",
    "Updating database schema" : "به روز رسانی طرح پایگاه داده",
    "Updated database" : "بروز رسانی پایگاه داده انجام شد .",
    "Update app \"%s\" from App Store" : "Update app \"%s\" from App Store",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "بررسی اینکه آیا طرح پایگاه داده %s می تواند به روز شود (این ممکن است بسته به اندازه پایگاه داده طولانی باشد)",
    "Updated \"%1$s\" to %2$s" : "Updated \"%1$s\" to %2$s",
    "Set log level to debug" : "Set log level to debug",
    "Reset log level" : "Reset log level",
    "Starting code integrity check" : "Starting code integrity check",
    "Finished code integrity check" : "Finished code integrity check",
    "%s (incompatible)" : "%s (incompatible)",
    "The following apps have been disabled: %s" : "The following apps have been disabled: %s",
    "Already up to date" : "در حال حاضر بروز است",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update.",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response.",
    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update.",
    "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information.",
    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available. See the {linkstart}documentation ↗{linkend} for more information." : "The database is used for transactional file locking. To enhance performance, please configure memcache, if available. See the {linkstart}documentation ↗{linkend} for more information.",
    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "It was not possible to execute the cron job via CLI. The following technical errors have appeared:",
    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}.",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}.",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}.",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})",
    "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Missing index \"{indexName}\" in table \"{tableName}\".",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster.",
    "Missing primary key on table \"{tableName}\"." : "Missing primary key on table \"{tableName}\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running.",
    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Missing optional column \"{columnName}\" in table \"{tableName}\".",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them.",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module.",
    "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required.",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page ↗{linkend} about this." : "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page ↗{linkend} about this.",
    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it.",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "This is particularly recommended when using the desktop client for file synchronisation.",
    "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}.",
    "The PHP memory limit is below the recommended value of 512MB." : "The PHP memory limit is below the recommended value of 512MB.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}.",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path.",
    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "The temporary directory of this instance points to an either non-existing or non-writable directory.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}.",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "This instance is running in debug mode. Only enable this for local development and not in production environments.",
    "Error occurred while checking server setup" : "خطا در هنگام چک کردن راه‌اندازی سرور رخ داده است",
    "For more details see the {linkstart}documentation ↗{linkend}." : "For more details see the {linkstart}documentation ↗{linkend}.",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly.",
    "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly.",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}.",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}.",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!",
    "unknown text" : "متن نامعلوم",
    "Hello world!" : "سلام دنیا!",
    "sunny" : "آفتابی",
    "Hello {name}, the weather is {weather}" : "سلام {name}, هوا  {weather} است",
    "Hello {name}" : "سلام {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>این نتایج جستجوی شماست <script>alert(1)</script> </strong>",
    "new" : "جدید",
    "_download %n file_::_download %n files_" : ["دانلود %n فایل","دانلود %n فایل"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "به روز رسانی در حال انجام است، این صفحه ممکن است روند در برخی از محیط ها را قطع کند.",
    "Update to {version}" : "بروزرسانی به  {version}",
    "An error occurred." : "یک خطا رخ‌داده است.",
    "Please reload the page." : "لطفا صفحه را دوباره بارگیری کنید.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "به روزرسانی ناموفق بود. برای اطلاعات بیشتر <a href=\"{url}\">فروم ما را بررسی کنید</a>",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "به روزرسانی ناموفق بود. لطفا این مسئله را در <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">جامعه Nextcloud</a> گزارش دهید",
    "Continue to {productName}" : "Continue to {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["The update was successful. Redirecting you to {productName} in %n second.","The update was successful. Redirecting you to {productName} in %n seconds."],
    "More apps" : "برنامه های بیشتر",
    "Currently open" : "Currently open",
    "_{count} notification_::_{count} notifications_" : ["{count} notification","{count} notifications"],
    "Log in" : "ورود",
    "Logging in …" : "ورود به سیستم ...",
    "Server side authentication failed!" : "تأیید هویت از سوی سرور انجام نشد!",
    "Please contact your administrator." : "لطفا با مدیر وب‌سایت تماس بگیرید.",
    "An internal error occurred." : "یک اشتباه داخلی رخ داد.",
    "Please try again or contact your administrator." : "لطفا مجددا تلاش کنید یا با مدیر سیستم تماس بگیرید.",
    "Account name or email" : "Account name or email",
    "Password" : "گذرواژه",
    "Log in to {productName}" : "Log in to {productName}",
    "Wrong username or password." : "شناسه کاربری و کلمه عبور اشتباه است",
    "User disabled" : "کاربر غیرفعال",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "از این آی پی چندین بار تلاش ناموفق برای ورود انجام شده است فلذا برای ورود مجدد حداقل ۳۰ ثانیه باید صبر کنید.",
    "Log in with a device" : "Log in with a device",
    "Username or email" : "نام کاربری یا ایمیل",
    "Your account is not setup for passwordless login." : "Your account is not setup for passwordless login.",
    "Browser not supported" : "Browser not supported",
    "Passwordless authentication is not supported in your browser." : "Passwordless authentication is not supported in your browser.",
    "Your connection is not secure" : "Your connection is not secure",
    "Passwordless authentication is only available over a secure connection." : "Passwordless authentication is only available over a secure connection.",
    "Reset password" : "تنظیم مجدد رمز عبور",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help.",
    "Couldn't send reset email. Please contact your administrator." : "ارسال ایمیل مجدد با مشکل مواجه شد . لطفا با مدیر سیستم تماس بگیرید .",
    "Password cannot be changed. Please contact your administrator." : "Password cannot be changed. Please contact your administrator.",
    "Back to login" : "Back to login",
    "New password" : "گذرواژه جدید",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?",
    "I know what I'm doing" : "اطلاع از انجام این کار دارم",
    "Resetting password" : "در حال ریست کردن کلمه عبور...",
    "Recommended apps" : "Recommended apps",
    "Loading apps …" : "Loading apps …",
    "Could not fetch list of apps from the App Store." : "Could not fetch list of apps from the App Store.",
    "Installing apps …" : "در حال نصب برنامه",
    "App download or installation failed" : "App download or installation failed",
    "Cannot install this app because it is not compatible" : "Cannot install this app because it is not compatible",
    "Cannot install this app" : "Cannot install this app",
    "Skip" : "پرش",
    "Install recommended apps" : "نصب کاره‌های پیشنهادی",
    "Schedule work & meetings, synced with all your devices." : "برنامه کار و جلسات ، همگام سازی با تمام دستگاه های شما",
    "Keep your colleagues and friends in one place without leaking their private info." : "همکاران و دوستان خود را در یک مکان نگه دارید بدون اینکه اطلاعات خصوصی آنها را بشناسید.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "برنامه ایمیل ساده با پرونده ها ، مخاطبین و تقویم یکپارچه شده است.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Collaborative documents, spreadsheets and presentations, built on Collabora Online.",
    "Distraction free note taking app." : "Distraction free note taking app.",
    "Search contacts" : "Search contacts",
    "Search contacts …" : "جستجو مخاطبین ...",
    "Could not load your contacts" : "Could not load your contacts",
    "No contacts found" : "مخاطبین یافت نشد",
    "Show all contacts …" : "نمایش همه مخاطبین ...",
    "Install the Contacts app" : "Install the Contacts app",
    "Loading your contacts …" : "بارگیری مخاطبین شما ...",
    "Looking for {term} …" : "به دنبال {term} …",
    "Forgot password?" : "رمز فراموش شده؟",
    "Back to login form" : "Back to login form",
    "Back" : "بازگشت",
    "Login form is disabled." : "Login form is disabled.",
    "Edit Profile" : "Edit Profile",
    "The headline and about sections will show up here" : "The headline and about sections will show up here",
    "You have not added any info yet" : "You have not added any info yet",
    "{user} has not added any info yet" : "{user} has not added any info yet",
    "Error opening the user status modal, try hard refreshing the page" : "Error opening the user status modal, try hard refreshing the page",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Search starts once you start typing and results may be reached with the arrow keys",
    "Reset search" : "Reset search",
    "Start search" : "Start search",
    "Search for {name} only" : "Search for {name} only",
    "Start typing to search" : "Start typing to search",
    "Loading more results …" : "Loading more results …",
    "Load more results" : "بار کردن نتیحه‌های بیش‌تر",
    "Search" : "جست‌و‌جو",
    "No results for {query}" : "No results for {query}",
    "Press Enter to start searching" : "Press Enter to start searching",
    "An error occurred while searching for {type}" : "An error occurred while searching for {type}",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Please enter {minSearchLength} character or more to search","Please enter {minSearchLength} characters or more to search"],
    "This browser is not supported" : "This browser is not supported",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Your browser is not supported. Please upgrade to a newer version or a supported one.",
    "Continue with this unsupported browser" : "Continue with this unsupported browser",
    "Supported versions" : "Supported versions",
    "{name} version {version} and above" : "{name} version {version} and above",
    "Settings menu" : "فهرست تنظیمات",
    "Search {types} …" : "Search {types} …",
    "No" : "نه",
    "Yes" : "بله",
    "Choose" : "انتخاب کردن",
    "Copy" : "کپی",
    "Move" : "انتقال",
    "OK" : "تایید",
    "Error loading message template: {error}" : "خطا در بارگذاری قالب پیام : {error}",
    "read-only" : "فقط-خواندنی",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count}  تضاد در فایل","{count}  تضاد در فایل"],
    "One file conflict" : "یک فایل متضاد",
    "New Files" : "فایل های جدید",
    "Already existing files" : "فایل های موجود در حال حاضر ",
    "Which files do you want to keep?" : "کدام فایل ها را می خواهید نگه دارید ؟",
    "If you select both versions, the copied file will have a number added to its name." : "اگر هر دو نسخه را انتخاب کنید، فایل کپی شده یک شماره به نام آن اضافه خواهد شد.",
    "Cancel" : "منصرف شدن",
    "Continue" : "ادامه",
    "(all selected)" : "(همه انتخاب شده اند)",
    "({count} selected)" : "({count} انتخاب شده)",
    "Error loading file exists template" : "خطا در بارگزاری فایل قالب",
    "Saving …" : "ذخیره کردن …",
    "seconds ago" : "ثانیه‌ها پیش",
    "Connection to server lost" : "اتصال به سرور از دست رفته است",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["%nمشکل بارگذاری صفحه، بارگیری مجدد در  ثانیه","%nمشکل بارگذاری صفحه، بارگیری مجدد در  ثانیه"],
    "Add to a project" : "Add to a project",
    "Show details" : "Show details",
    "Hide details" : "مخفی کردن جزئیات",
    "Rename project" : "Rename project",
    "Failed to rename the project" : "Failed to rename the project",
    "Failed to create a project" : "Failed to create a project",
    "Failed to add the item to the project" : "Failed to add the item to the project",
    "Connect items to a project to make them easier to find" : "Connect items to a project to make them easier to find",
    "Type to search for existing projects" : "Type to search for existing projects",
    "New in" : "جدید در",
    "View changelog" : "مشاهده تغییرات",
    "Very weak password" : "رمز عبور بسیار ضعیف",
    "Weak password" : "رمز عبور ضعیف",
    "So-so password" : "رمز عبور متوسط",
    "Good password" : "رمز عبور خوب",
    "Strong password" : "رمز عبور قوی",
    "No action available" : "هیچ عملی قابل انجام نیست",
    "Error fetching contact actions" : "خطا در دریافت فعالیتهای تماس",
    "Close \"{dialogTitle}\" dialog" : "Close \"{dialogTitle}\" dialog",
    "Non-existing tag #{tag}" : "برچسب غیر موجود #{tag}",
    "Restricted" : "Restricted",
    "Invisible" : "غیر قابل مشاهده",
    "Delete" : "حذف",
    "Rename" : "تغییرنام",
    "Collaborative tags" : "برچسب های همکاری",
    "No tags found" : "هیچ برچسبی یافت نشد",
    "Personal" : "شخصی",
    "Users" : "کاربران",
    "Apps" : "  برنامه ها",
    "Admin" : "مدیر",
    "Help" : "راه‌نما",
    "Access forbidden" : "اجازه دسترسی به مناطق ممنوعه را ندارید",
    "Profile not found" : "Profile not found",
    "The profile does not exist." : "The profile does not exist.",
    "Back to %s" : "Back to %s",
    "Page not found" : "صفحه یافت نشد",
    "The page could not be found on the server or you may not be allowed to view it." : "The page could not be found on the server or you may not be allowed to view it.",
    "Too many requests" : "Too many requests",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "There were too many requests from your network. Retry later or contact your administrator if this is an error.",
    "Error" : "خطا",
    "Previous" : "قبلی",
    "Internal Server Error" : "خطای داخلی سرور",
    "The server was unable to complete your request." : "سرور قادر به تکمیل درخواست شما نبود.",
    "If this happens again, please send the technical details below to the server administrator." : "اگر این اتفاق دوباره افتاد، لطفا جزئیات فنی زیر را به مدیر سرور ارسال کنید.",
    "More details can be found in the server log." : "جزئیات بیشتر در لاگ سرور قابل مشاهده خواهد بود.",
    "Technical details" : "جزئیات فنی",
    "Remote Address: %s" : "آدرس راه‌دور: %s",
    "Request ID: %s" : "ID درخواست: %s",
    "Type: %s" : "نوع: %s",
    "Code: %s" : "کد: %s",
    "Message: %s" : "پیام: %s",
    "File: %s" : "فایل : %s",
    "Line: %s" : "خط: %s",
    "Trace" : "ردیابی",
    "Security warning" : "اخطار امنیتی",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "فایلها و فهرست های داده های شما قابل از اینترنت قابل دسترسی هستند، چونکه فایل htacces. کار نمی کند.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>.",
    "Create an <strong>admin account</strong>" : "لطفا یک <strong> شناسه برای مدیر</strong> بسازید",
    "Username" : "نام کاربری",
    "Show password" : "نمایش گذرواژه",
    "Toggle password visibility" : "Toggle password visibility",
    "Storage & database" : "انبارش و پایگاه داده",
    "Data folder" : "پوشه اطلاعاتی",
    "Configure the database" : "پایگاه داده برنامه ریزی شدند",
    "Only %s is available." : "تنها %s موجود است.",
    "Install and activate additional PHP modules to choose other database types." : "جهت انتخاب انواع دیگر پایگاه‌داده‌،ماژول‌های اضافی PHP را نصب و فعال‌سازی کنید.",
    "For more details check out the documentation." : "برای جزئیات بیشتر به مستندات مراجعه کنید.",
    "Database user" : "شناسه پایگاه داده",
    "Database password" : "پسورد پایگاه داده",
    "Database name" : "نام پایگاه داده",
    "Database tablespace" : "جدول پایگاه داده",
    "Database host" : "هاست پایگاه داده",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Please specify the port number along with the host name (e.g., localhost:5432).",
    "Performance warning" : "اخطار کارایی",
    "You chose SQLite as database." : "شما SQLite را به عنوان پایگاه داده انتخاب کردید.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite should only be used for minimal and development instances. For production we recommend a different database backend.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "If you use clients for file syncing, the use of SQLite is highly discouraged.",
    "Install" : "نصب",
    "Installing …" : "Installing …",
    "Need help?" : "کمک لازم دارید ؟",
    "See the documentation" : "مشاهده‌ی مستندات",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Could not remove CAN_INSTALL from the config folder. Please remove this file manually.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page.",
    "Skip to main content" : "Skip to main content",
    "Skip to navigation of app" : "Skip to navigation of app",
    "Go to %s" : "برو به %s",
    "Get your own free account" : "Get your own free account",
    "This action requires you to confirm your password" : "این اقدام نیاز به تایید رمز عبور شما دارد",
    "Confirm your password" : "گذرواژه خود را تأیید کنید",
    "Confirm" : "تایید",
    "Connect to your account" : "Connect to your account",
    "Please log in before granting %1$s access to your %2$s account." : "Please log in before granting %1$s access to your %2$s account.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator.",
    "App token" : "App token",
    "Grant access" : " مجوز اعطا دسترسی",
    "Alternative log in using app token" : "Alternative log in using app token",
    "Account access" : "دسترسی به حساب",
    "Currently logged in as %1$s (%2$s)." : "Currently logged in as %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "You are about to grant %1$s access to your %2$s account.",
    "Account connected" : "Account connected",
    "Your client should now be connected!" : "Your client should now be connected!",
    "You can close this window." : "You can close this window.",
    "This share is password-protected" : "این اشتراک توسط رمز عبور محافظت می شود",
    "The password is wrong or expired. Please try again or request a new one." : "The password is wrong or expired. Please try again or request a new one.",
    "Please type in your email address to request a temporary password" : "Please type in your email address to request a temporary password",
    "Email address" : "آدرس ایمیل",
    "Password sent!" : "Password sent!",
    "You are not authorized to request a password for this share" : "You are not authorized to request a password for this share",
    "Two-factor authentication" : "Two-factor authentication",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Enhanced security is enabled for your account. Choose a second factor for authentication:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Could not load at least one of your enabled two-factor auth methods. Please contact your admin.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication.",
    "Set up two-factor authentication" : "Set up two-factor authentication",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance.",
    "Use backup code" : "از کد پشتیبان استفاده شود",
    "Cancel login" : "Cancel login",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Enhanced security is enforced for your account. Choose which provider to set up:",
    "Error while validating your second factor" : "Error while validating your second factor",
    "Access through untrusted domain" : "Access through untrusted domain",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Further information how to configure this can be found in the %1$sdocumentation%2$s.",
    "App update required" : "نیاز به بروزرسانی برنامه وجود دارد",
    "%1$s will be updated to version %2$s" : "%1$s will be updated to version %2$s",
    "The following apps will be updated:" : "The following apps will be updated:",
    "These incompatible apps will be disabled:" : "این برنامه های ناسازگار غیر فعال می شوند:",
    "The theme %s has been disabled." : "قالب %s غیر فعال شد.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Please make sure that the database, the config folder and the data folder have been backed up before proceeding.",
    "Start update" : "اغاز به روز رسانی",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "برای جلوگیری از وقفه در نصب های طولانی تر، شما می توانید دستورات زیر را از مسیر نصبتان اجرا کنید:",
    "Detailed logs" : "Detailed logs",
    "Update needed" : "نیاز به روز رسانی دارد",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Please use the command line updater because you have a big instance with more than 50 users.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure.",
    "Upgrade via web on my own risk" : "Upgrade via web on my own risk",
    "Maintenance mode" : "Maintenance mode",
    "This %s instance is currently in maintenance mode, which may take a while." : "This %s instance is currently in maintenance mode, which may take a while.",
    "This page will refresh itself when the instance is available again." : "This page will refresh itself when the instance is available again.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "اگر این پیغام همچنان وجود داشت یا به صورت غیر منتظره ظاهر شد با مدیر سیستم تماس بگیرید.",
    "Please use the command line updater because updating via the browser is disabled in your config.php." : "Please use the command line updater because updating via the browser is disabled in your config.php.",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it.",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}.",
    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help.",
    "If it is not there ask your local administrator." : "If it is not there ask your local administrator.",
    "Press enter to start searching" : "Press enter to start searching",
    "Open settings menu" : "Open settings menu",
    "Settings" : "تنظیمات",
    "Avatar of {fullName}" : "Avatar of {fullName}",
    "No files in here" : "هیچ فایلی اینجا وجود ندارد",
    "New folder" : "پوشه جدید",
    "No more subfolders in here" : "No more subfolders in here",
    "Name" : "نام",
    "Size" : "اندازه",
    "Modified" : "تغییر یافته",
    "\"{name}\" is an invalid file name." : "\"{name}\" نامی نامعتبر برای فایل است.",
    "File name cannot be empty." : "نام پرونده نمی تواند خالی باشد.",
    "\"/\" is not allowed inside a file name." : "\"/\" در داخل نام فایل مجاز نیست.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" یک نوع پرونده مجاز نیست",
    "{newName} already exists" : "{newName} قبلاً موجود است",
    "Error loading file picker template: {error}" : "خطا در بارگذاری قالب انتخاب فایل : {error}",
    "Show list view" : "نمایش فهرستی",
    "Show grid view" : "نمایش شبکه‌ای",
    "Pending" : "در انتظار",
    "Home" : "خانه ",
    "Copy to {folder}" : "کپی به {folder}",
    "Move to {folder}" : "انتقال به {folder}",
    "Authentication required" : "احراز هویت مورد نیاز است",
    "Failed to authenticate, try again" : "تأیید هویت نشد، دوباره امتحان کنید",
    "File not found" : "فایل یافت نشد",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "The document could not be found on the server. Maybe the share was deleted or has expired?",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Please use the command line updater because automatic updating is disabled in the config.php.",
    "The page could not be found on the server." : "The page could not be found on the server.",
    "PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to {linkstart}one of the officially supported PHP versions provided by the PHP Group ↗{linkend} as soon as possible." : "PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to {linkstart}one of the officially supported PHP versions provided by the PHP Group ↗{linkend} as soon as possible."
},
"nplurals=2; plural=(n > 1);");
