OC.L10N.register(
    "support",
    {
    "Link:" : "Ligòngiu:",
    "Password:" : "Crae:",
    "Generating system report failed." : "Generatzione de sa relata de sistema faddida.",
    "Could not create folder \"System information\" to store generated report." : "No at fatu a creare sa cartella \"Informatziones de sistema\" pro archiviare sa relata de ghennàrgiu.",
    "Could not create file \"%s\" to store generated report." : "No at fatu a creare \"%s\" pro archiviare sa relata generada.",
    "Could not share file \"%s\". Nevertheless, you can find it in the folder \"System information\"." : "No at fatu a cumpartzire s'archìviu \"%s\". Nointames, ddu podes agatare in sa cartella \"Informatziones de sistema\".",
    "Subscription notifications" : "Notìficas de sutaiscritzione",
    "Nextcloud Subscription" : "Sutaiscritziones de Nextcloud",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Su serbidore tuo non tenet una sutaiscritzione de Nextloud o sa sutaiscritzione nch'est iscàdida.",
    "Your Nextcloud server subscription does not cover your number of users." : "Sa sutaiscritzione de su serbidore tuo Nextcloud non coberit su nùmeru de utentes.",
    "Your Nextcloud Subscription has expired!" : "Sa sutaiscritzione tua de Nextcloud nch'est iscàdida!",
    "Your server has no Nextcloud Subscription" : "Su serbidore tuo non tenet peruna sutaiscritzione de Nextcloud",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Su serbidore Nextcloud no est suportadu dae una sutaiscritzione aziendale de Nextcloud.",
    "If your server setup breaks and employees can't work anymore, you don't have to rely on searching online forums for a solution. You have direct access to our experienced engineers!" : "Si su serbidore tuo non funtzionat prus e is impiegados tuos non bi podent traballare prus, non ti depes dare a is chircas in is forum pro una solutzione. Podes dimandare deretu a is ingegneris nostros!",
    "You have a contract with the vendor providing early security information, mitigations, patches and updates." : "Tenes unu cuntratu cun su bendidore chi frunit informatziones de seguresa de cunfiàntzia, abbrandos, patch e agiornamentos.",
    "If you need to stay longer on your current version without disruptions, you don't have to run software without security updates." : "Si cheres abarrare un pagu cun sa versione atuale sena interrutziones, non depes aviare su programa sena is agiornamentos de seguresa.",
    "You have the best expertise at hand to deal with performance and scalability issues." : "Tenes a disponimentu is mègius espertos pro isòrvere problemas de esecutzione e iscalabilidade.",
    "You have access to the right documentation and expertise to quickly answer compliance questions or deliver on GDPR, HIPAA and other regulation requirements." : "Podes atzèdere a sa documentatzione giusta e a is cumpetèntzias netzessàrias pro rispòndere a sa lestra a dimandas de cunformidade o dispensare informatziones subra de GDPR, HIPAA e àteros rechisitos normativos.",
    "We can also provide Outlook integration, Online Office, scalable integrated audio-video and chat communication and other features only available in a limited form for free or develop further integrations and capabilities to your needs." : "Podimus fintzas frunire integratzione cun Outlook, Office Online, comunicatzione aùdiu-vìdeu integrada e iscalàbile, tzarrada e àteras funtziones a disponimentu in donu isceti in forma limitada, opuru agiùnghere àteras integratziones e funtzionalidades cunforma a is bisòngios tuos. ",
    "A subscription helps you get the most out of Nextcloud!" : "Una sutaiscritzione t'agiudat a lograre su màssimu dae Nextcloud!",
    "Learn more now" : "Iscoberi àteru deretu",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %1$s because you have over %2$s registered users." : "Custu messàgiu est istadu inviadu a totu is amministradores dae s'aplicatzione de suportu de s'istàntzia Nextcloud subra de %1$s ca nch'as superadu is %2$s utentes registrados.",
    "Your Nextcloud server Subscription is over limit" : "Sa sutaiscritzione tua a su serbidore Nextcloud at superadu su lìmite",
    "Dear admin," : "Istimadu amministradore,",
    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact your Nextcloud account manager to get your subscription updated!" : "Sa sutaiscritzione tua Nextcloud non coberit su nùmeru de utentes chi sunt ativos immoe in custu serbidore. Pro praghere, cuntata s'amministradore de Nextcloud pro agiornare sa sutaiscritzione tua!",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "%1$s est s'amministradore tuo e podet èssere cuntatadu tràmite posta eletrònica cun %2$s o tràmite tèlefonu a su %3$s.",
    "Thank you," : "Gràtzias,",
    "Your Nextcloud team" : "S'iscuadra tua de Nextcloud",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because you have more users than your subscription covers." : "Custu messàgiu est istadu inviadu a totu is amministradores dae s'aplicatzione de suportu de s'istàntzia tua de Nextcloud in %s ca tenes prus utentes de cantu nde pighet sa sutaiscritzione tua.",
    "Your Nextcloud server Subscription is expired" : "Sa sutaiscritzione tua de su serbidore Nextcloud nch'est iscàdida.",
    "Your Nextcloud server Subscription is expired!" : "Sa sutaiscritzione de su serbidore tuo Nextcloud est iscàdida!",
    "Your Nextcloud Subscription has expired! Please contact your Nextcloud account manager to get your subscription updated!" : "Sa sutaiscritzione tua de Nextcloud nch'est iscàdida! Cuntata a s'amministradore tuo de Nextcloud pro agiornare sa sutaiscritzione tua!",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because your subscription expired." : "Custu messàgiu est istadu inviadu a totu is amministradores de s'aplicatzione de suportu de s'istàntzia tua de Nextcloud in %sca sa sutaiscritzione est iscàdida.",
    "Support" : "Suportu",
    "Getting support and help for your Nextcloud" : "Otène suportu e agiudu pro su Nextcloud tuo",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "S'aplicatzione de suportu ti permitet de intrare deretu a is risursas de consultatzione, sèberos de cuntatu dedicadas cun s'amministradore tuo e unu resumu de sa sutaiscritzione aziendale tua.",
    "Basic subscription" : "Sutaiscritzione de base",
    "Standard subscription" : "Sutaiscritzione istandard",
    "Premium subscription" : "Sutaiscritzione premium",
    "Géant subscription" : "Sutaiscritzione gigante",
    "Silver partner subscription" : "Sutaiscritzione cumpàngiu/a prata",
    "Gold partner subscription" : "Sutaiscritzione cumpàngiu/a oro",
    "Subscription" : "Sutaiscritzione",
    "Over subscription limit" : "Superat su lìmite de sa sutaiscritzione",
    "Valid subscription" : "Sutaiscritzione bàlida",
    "Expired subscription" : "Sutaiscritzione iscàdida",
    "Subscription key:" : "Crae de sutaiscritzione:",
    "Expires in: " : "Iscadet intro de:",
    "_%n year_::_%n years_" : ["%n annu","%n annos"],
    "_%n month_::_%n months_" : ["%n meses","%n mesi"],
    "_%n week_::_%n weeks_" : ["%n chidas","%n chidas"],
    "_%n day_::_%n days_" : ["%n dies","%n dies"],
    "For an unlimited amount of users" : "Pro una cantidade illacanada de utentes",
    "_For %n active users_::_For %n active users_" : ["Pro %n utentes attivi","Per %n utentes ativos"],
    "_For %n users_::_For %n users_" : ["Pro %n utentes","Per %n utentes"],
    "_currently at %n user_::_currently at %n users_" : ["immoe a %n utente","immoe a %n utentes"],
    "Includes support for %s" : "Includet su suportu pro %s",
    "Includes support for %1$s & %2$s" : "Includet su suportu pro %1$s e %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Includet su suportu pro %1$s, %2$s e %3$s",
    "Extended maintenance life cycle" : "Tziclu de vida de mantenidura crèschidu",
    "Update subscription key" : "Agiorna sa crae de sutaiscritzione",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s est s'amministradore tuo. Non timas a ddu cuntatare si tenes pregontas subra de sa sutaiscritzione.",
    "You can find answers to common question in our portal and also file support requests there." : "Podes agatare rispostas a is pregontas fitianas in su portale nostru e creare archìvios de rechestas de suportu.",
    "Access Nextcloud portal" : "Intra a su portale de Nextcloud",
    "System information" : "Informatziones de sistema",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Regolli is informatziones de su sistema pro sas rechestas de suportu. Su butone in fatu generat un'archìviu de testu in sa cartella \"Informatziones de sistema\" e ddu cumpartzit comente collegamentu pùblicu amparadu dae crae. Su ligòngiu est bàlidu pro 2 chidas.",
    "Generate system report" : "Gènera sa relata de sistema",
    "Enterprise subscription recommended" : "Sutaiscritzione aziendale racumandada",
    "No active enterprise subscription" : "Peruna sutaiscritzione aziendale ativa",
    "Unsupported" : "Non suportadu",
    "This Nextcloud server has no Enterprise Subscription." : "Custu serbidore Nextcloud non tenet peruna sutaiscritzione aziendale.",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "Una sutaiscritzione aziendale de Nextcloud t'agiudat a òtennere su màssimu dae Nextcloud, a mantènnere in seguresa is datos tuos e a fàghere funtzionare in manera fidada su serbidore tuo in cada momentu.",
    "Advantages" : "Profetos",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "Intrada a s'esperièntzia tècnica de is isvilupadores de Nextcloud tràmite sa documentatzione e su suportu",
    "Access to additional capabilities like Outlook integration, online office and more" : "Intrada a capatzidades agiuntas comente a s'integratzione de Outlook, ufìtziu in lìnia e àteru",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "Intrada a esperièntzias e capatzidades de iscalabilidade pro Archìvios e Talk",
    "Optional branding, consulting, architecture advice" : "Gestione a praghere de su marcu, consulèntzia, cunsìgios pro s'architetura",
    "Confidential security notification service, mitigations, patches and advice" : "Servìtziu de notìfica de cunfiàntzia pro sa seguresa, abbrandu, patch e consulèntzia",
    "Compliance certification, advice and documentation" : "Tzertificatzione de cunformidade, consulèntzia e documentatzione",
    "Get a quote" : "Otène unu preventivu",
    "More information" : "Àteras informatziones",
    "Subscription benefits" : "Benefìtzios",
    "Pricing" : "Prètzios",
    "Community support" : "Suportu de sa comunidade",
    "Forum" : "Forum",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcoud est unu programma lìberu chi est suportadu dae una comunidade ativa meda. Registra·ti a su forum pro fàghere pregontas e chistionare cun is àteros.",
    "Nextcloud forum" : "Forum de Nextcloud",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud impreat GitHub comente prataforma pro traballare in collaboratzione. Podes sinnalare is bug in cue etotu.",
    "Nextcloud at GitHub" : "Nextcloud in GitHub",
    "Subscription key" : "Crae de sutaiscritzione",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Si tenes una sutaiscritzione de Nextcloud ativa, iscrie inoghe sa crae tua de sutaiscritzione.",
    "Learn more about an enterprise subscription." : "Iscoberi àteru in contu de sa sutaiscritzione aziendale.",
    "Set subscription key" : "Imposta crae de sutaiscritzione",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "Is informatziones de sutaiscritzione immoe non podent èssere recuperadas in manera curreta. Est disposta torra una proa. Controlla tra unu pagu.",
    "The subscription key was invalid." : "Sa crae de sutaiscritzione non fiat bàlida.",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "Sa crae de sutaiscritzione non podet èssere verificada, ca custu serbidore non tenet una connessione a Ìnternet. Cuntata s'iscuadra nostra de suportu pro isòrvere su problema.",
    "The subscription key had an invalid format." : "Su formadu de sa crae de sutaiscritzione non fiat bàlidu.",
    "While fetching the subscription information an error happened." : "S'est verificadu un'errore recuperende is infomatzione de sutaiscritzione.",
    "The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Su butone in fatu gènerat unu'archìviu de testu in sa cartella \"Informatziones de sistema\" e ddu cumpartzit comente unu ligòngiu pùblicu amparadu cun sa crae. Su ligòngiu abarrat bàlidu pro 2 chidas.",
    "News" : "Noas",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "Pro abarrare agiornados cun is noas de Nextcloud, iscrie·ti a sa lista de messàgios nostra e sighi·nos in is àteras retes sotziales.",
    "Like our Facebook page" : "Bìsita sa pàgina nostra in Facebook",
    "Follow us on Twitter" : "Sighi·nos",
    "Check out our blog" : "Leghe·ti su blog nostru",
    "Subscribe to our newsletter" : "Iscrie·ti a sa lista de messàgios nostra"
},
"nplurals=2; plural=(n != 1);");
