OC.L10N.register(
    "support",
    {
    "Link:" : "קישור:",
    "Password:" : "ססמה:",
    "Generating system report failed." : "יצירת דוח המערכת נכשלה.",
    "Could not create folder \"System information\" to store generated report." : "לא ניתן ליצור את התיקייה „System Information” כדי לאחסן את הדוח שנוצר.",
    "Could not create file \"%s\" to store generated report." : "לא ניתן ליצור את הקובץ „%s” כדי לאחסן את הדוח שנוצר.",
    "Could not share file \"%s\". Nevertheless, you can find it in the folder \"System information\"." : "לא ניתן לשתף את הקובץ „%s”. עם זאת, ניתן למצוא אותו בתיקייה „System information” (פרטי המערכת).",
    "Subscription notifications" : "התראות מינוי",
    "Nextcloud Subscription" : "מינוי ל־Nextcloud",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "לשרת שלך אין מינוי ל־Nextcloud או שתוקף המינוי שלך פג.",
    "Your Nextcloud server subscription does not cover your number of users." : "מינוי שרת ה־Nextcloud שלך אינו מכסה את מספר המשתמשים שלך.",
    "Your Nextcloud Subscription has expired!" : "תוקף מינוי ה־Nextcloud שלך פג!",
    "Your server has no Nextcloud Subscription" : "לשרת שלך אין מינוי של Nextcloud",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "שרת ה־Nextcloud שלך אינו מגובה על ידי מינוי ל־Nextcloud Enterprise.",
    "Learn more now" : "מידע נוסף כעת",
    "Your Nextcloud server Subscription is over limit" : "המינוי של שרת ה־Nextcloud שלך עובר את המכסה",
    "Dear admin," : "מנהל/ת יקר/ה,",
    "Thank you," : "תודה לך,",
    "Your Nextcloud team" : "צוות ה־Nextcloud שלך",
    "Your Nextcloud server Subscription is expired" : "תוקף מינוי שרת ה־Nextcloud שלך פג",
    "Your Nextcloud server Subscription is expired!" : "תוקף מינוי שרת ה־Nextcloud שלך פג!",
    "Support" : "תמיכה",
    "Getting support and help for your Nextcloud" : "קבלת תמיכה ועזרה עבור ה־Nextcloud שלך",
    "Basic subscription" : "מינוי בסיסי",
    "Standard subscription" : "מינוי רגיל",
    "Premium subscription" : "מינוי פרימיום",
    "Géant subscription" : "מינוי Géant",
    "Silver partner subscription" : "מינוי שותף כסף",
    "Gold partner subscription" : "מינוי שותף זהב",
    "Subscription" : "מינוי",
    "Over subscription limit" : "מעבר לתקופת המינוי",
    "Valid subscription" : "מינוי תקף",
    "Expired subscription" : "מינוי שתוקפו פג",
    "Subscription key:" : "מפתח מינוי:",
    "Expires in: " : "יפוג בעוד:",
    "_%n year_::_%n years_" : ["שנה","שנתיים","%n שנים","%n שנים"],
    "_%n month_::_%n months_" : ["חודש","חודשיים","%n חודשים","%n חודשים"],
    "_%n week_::_%n weeks_" : ["שבוע","שבועיים","%n שבועות","%n שבועות"],
    "_%n day_::_%n days_" : ["יום","יומיים","%n ימים","%n ימים"],
    "For an unlimited amount of users" : "למספר בלתי מוגבל של משתמשים",
    "System information" : "פרטי מערכת",
    "Generate system report" : "יצירת דוח מערכת",
    "Enterprise subscription recommended" : "מומלץ מינוי Enterprise",
    "No active enterprise subscription" : "אין מינוי Enterprise פעיל",
    "Unsupported" : "ללא תמיכה",
    "This Nextcloud server has no Enterprise Subscription." : "לשרת Nextcloud זה אין מינוי Enterprise.",
    "Advantages" : "יתרונות",
    "Get a quote" : "קבלת הצעה",
    "More information" : "מידע נוסף",
    "Subscription benefits" : "יתרונות של מינוי",
    "Pricing" : "מחיר",
    "Community support" : "תמיכה קהילתית",
    "Forum" : "פורום",
    "Nextcloud forum" : "הפורום של Nextcloud",
    "GitHub" : "GitHub",
    "Nextcloud at GitHub" : "Nextcloud ב־GitHub",
    "Subscription key" : "מפתח מינוי",
    "Learn more about an enterprise subscription." : "מידע נוסף על מינוי ארגוני.",
    "Set subscription key" : "הגדרת מפתח מינוי",
    "News" : "חדשות",
    "Like our Facebook page" : "לייק לעמוד הפייסבוק שלנו",
    "Follow us on Twitter" : "לעקוב אחרינו בטוויטר",
    "Check out our blog" : "לעיין בבלוג שלנו",
    "Subscribe to our newsletter" : "הרשמה לרשימת הדיוור שלנו"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
