OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Nouvel emplacement de connexion détecté",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Une nouvelle connexion à votre compte a été détectée. L'adresse IP %s a été considérée comme suspecte. S'il s'agissait de vous, vous pouvez ignorer ce message. Sinon, vous devriez changer votre mot de passe.",
    "Suspicious Login" : "Connexion suspecte",
    "More information ↗" : "Plus d'information ↗",
    "You can get more info by pressing the button which will open %s and show info about the suspicious IP-address." : "Vous pouvez obtenir plus d'informations en pressant le bouton qui ouvrira %s et montrera des détails à propos de l'adresse IP suspecte.",
    "New login detected" : "Nouvelle connexion détectée",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Détecte et avertit des IPs suspectes se connectant à Nextcloud",
    "Suspicious login detection" : "Détection d'une connexion suspecte",
    "The suspicious login app is enabled on this instance. It will keep track of IP addresses users successfully log in from and build a classifier that warns if a new login comes from a suspicious IP address." : "L'application connexion suspecte est activée sur cette instance. Elle gardera une trace des adresses IP à partir desquelles les utilisateurs se connectent et crée un classificateur qui avertit si une nouvelle connexion provient d'une adresse IP suspecte.",
    "Training data statistics" : "Statistiques d'entraînement",
    "So far the app has captured {total} logins (including client connections), of which {distinct} are distinct (IP, UID) tuples." : "Jusqu'à présent, l'application a capturé {total} connexions (y compris les connexions client), dont {distinct} sont des tuples distincts (IP, UID).",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Classifier model statistics" : "Statistiques du modèle de classificateur",
    "No classifier model has been trained yet. This most likely means that you just enabled the app recently. Because the training of a model requires good data, the app waits until logins of at least {days} days have been captured." : "Aucun modèle de classificateur n'a encore été formé. Cela signifie très probablement que vous venez d'activer l'application récemment. Parce que la formation d'un modèle nécessite de bonnes données, l'application attend que des connexions d'au moins {days} jours aient été capturées.",
    "During evaluation, the latest model (trained {time}) has shown to capture {recall}% of all suspicious logins (recall), whereas {precision}% of the logins classified as suspicious are indeed suspicious (precision). Below you see a visualization of historic model performance." : "Lors de l'évaluation, le dernier modèle (formé {time}) a montré qu'il capturait {recall}% de toutes les connexions suspectes (rappel), alors que {precision}% des connexions classifiées comme suspectes étaient effectivement suspectes (précision). Ci-dessous, vous voyez une visualisation de la performance d'un modèle historique.",
    "Precision" : "Précision",
    "Recall" : "Rappeler"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
