OC.L10N.register(
    "nextcloud_announcements",
    {
    "Nextcloud announcements" : "Соопштенија ",
    "Nextcloud announcement" : "Соопштениe",
    "Read more" : "Прочитај повеќе",
    "Disable announcements" : "Оневозможи ги соопштенијата",
    "(These announcements are only shown to administrators)" : "(Овие објави се прикажуваат само на администраторите)",
    "Nextcloud announcements brings the latest news of Nextcloud into your notifications" : "Соопштенијата ве известуваат за најновите вести и случувања во Nextcloud",
    "Shows the latest news of Nextcloud in your notifications." : "Прикажи ги последните соопштенија во вашите известувања.",
    "These groups will be notified about the announcements." : "Овие групи на челнови ќе бидат известени за нови соопштенија."
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
