<?php
namespace Aws\MediaConnect\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS MediaConnect** service.
 */
class MediaConnectException extends AwsException {}
