OC.L10N.register(
    "viewer",
    {
    "Edit" : "Golygu",
    "Open sidebar" : "Agor y bar ochr",
    "Download" : "Llwytho i lawr",
    "Delete" : "Dileu",
    "View" : "Golwg",
    "Name" : "Enw",
    "Save" : "Cadw",
    "Back" : "Nôl",
    "Loading …" : "Yn llwytho …",
    "Cancel" : "Diddymu",
    "Undo" : "Dadwneud",
    "Custom" : "Cyfaddas",
    "Size" : "Maint"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
