OC.L10N.register(
    "photos",
    {
    "Public link" : "Viešoji nuoroda",
    "Photos" : "Nuotraukos",
    "Your memories under your control" : "Jūsų prisiminimai jūsų rankose",
    "All media" : "Visa medija",
    "Videos" : "Vaizdo įrašai",
    "Albums" : "Albumai",
    "People" : "Žmonės",
    "Folders" : "Aplankai",
    "Favorites" : "Mėgstamos",
    "On this day" : "Šią dieną",
    "Shared with you" : "Bendrinama su jumis",
    "Tags" : "Žymės",
    "Map" : "Žemėlapis",
    "Photos settings" : "Nuotraukų nustatymai",
    "Name of the album" : "Albumo pavadinimas",
    "Location of the album" : "Albumo vieta",
    "Back" : "Atgal",
    "Save" : "Įrašyti",
    "Create album" : "Sukurti albumą",
    "Add to Album" : "Pridėti į albumą",
    "Shared by" : "Bendrina",
    "Create a new album." : "Sukurti naują albumą.",
    "Create new album" : "Sukurti naują albumą",
    "New album" : "Naujas albumas",
    "Add people or groups who can edit your album" : "Pridėti žmonių ar grupių, kurie galėtų taisyti jūsų albumą",
    "Search people or groups" : "Ieškoti žmonių ar grupių",
    "No recommendations. Start typing." : "Rekomendacijų nėra. Pradėkite rašyti.",
    "Copy the public link" : "Kopijuoti viešąją nuorodą",
    "Public link copied!" : "Viešoji nuoroda nukopijuota!",
    "Copy public link" : "Kopijuoti viešąją nuorodą",
    "Delete the public link" : "Ištrinti viešąją nuorodą",
    "Share via public link" : "Bendrinti per viešąją nuorodą",
    "Failed to update album." : "Nepavyko atnaujinti albumo.",
    "This collection does not exist" : "Šios kolekcijos nėra",
    "An error occurred" : "Įvyko klaida",
    "Open the full size \"{name}\" image" : "Atverti viso dydžio „{name}“ paveikslą",
    "There are no photos or videos yet!" : "Kol kas nėra jokių nuotraukų ar vaizdo įrašų!",
    "Add to {destination}" : "Pridėti į {destination}",
    "Open the \"{name}\" sub-directory" : "Atverti „{name}“ pakatalogį",
    "Back to {folder}" : "Atgal į {folder}",
    "Share this folder" : "Bendrinti šį aplanką",
    "_{years} year ago_::_{years} years ago_" : ["Prieš {years} metus","Prieš {years} metus","Prieš {years} metų","Prieš {years} metus"],
    "Enable squared photos view" : "Įjungti kvadratinį nuotraukų rodinį",
    "Invalid location selected" : "Pasirinkta neteisinga vieta",
    "View" : "Rodyti",
    "Photos directory" : "Nuotraukų katalogas",
    "_%n photo_::_%n photos_" : ["%n nuotrauka","%n nuotraukos","%n nuotraukų","%n nuotrauka"],
    "Open actions menu" : "Atverti veiksmų meniu",
    "Edit album details" : "Taisyti išsamesnę albumo informaciją",
    "Download all files in album" : "Atsisiųsti visus failus šiame albume",
    "Delete album" : "Ištrinti albumą",
    "Download selected files" : "Atsisiųsti pažymėtus failus",
    "Remove selection from album" : "Šalinti žymėjimą iš albumo",
    "This album does not have any photos or videos yet!" : "Šiame albume kol kas nėra jokių nuotraukų ar vaizdo įrašų!",
    "Add photos to this album" : "Pridėti į šį albumą nuotraukų",
    "There is no album yet!" : "Kol kas nėra jokių albumų!",
    "This person could not be found" : "Nepavyko rasti šio žmogaus",
    "Rename person" : "Pervadinti žmogų",
    "Merge with different person" : "Sulieti su kitu žmogumi",
    "Download selected photos" : "Atsisiųsti pažymėtas nuotraukas",
    "Favorite" : "Mėgstamas",
    "Remove from favorites" : "Šalinti iš mėgstamų",
    "Remove person" : "Šalinti žmogų",
    "Name of this person" : "Šio žmogaus vardas",
    "Save." : "Įrašyti.",
    "This might take some time depending on the size of your photo library." : "Tai, priklausomai nuo jūsų nuotraukų bibliotekos dydžio, gali šiek tiek užtrukti.",
    "Recognized people will show up here" : "Čia bus rodomi atpažinti žmonės",
    "This folder does not exist" : "Šio aplanko nėra",
    "Loading folders …" : "Įkeliami aplankai…",
    "No photos in here" : "Čia nuotraukų nėra",
    "Cover photo for shared album {albumName}." : "Viršelio nuotrauka, skirta bendrinamam albumui {albumName}.",
    "Back to tags overview" : "Atgal į žymių apžvalgą",
    "No photos with this tag yet" : "Kol kas nėra nuotraukų su šia žyme",
    "No tags yet" : "Kol kas žymių nėra",
    "Photos with tags will show up here" : "Čia bus rodomos nuotraukos su žymėmis",
    "Popular tags" : "Populiarios žymės",
    "Add" : "Pridėti",
    "Add to album" : "Pridėti į albumą",
    "Delete selection" : "Ištrinti žymėjimą",
    "_%n photos_::_%n photos_" : ["%n nuotrauka","%n nuotraukos","%n nuotraukų","%n nuotrauka"],
    "Failed to fetch faces list." : "Nepavyko gauti veidų sąrašo.",
    "All your media" : "Visa jūsų medija",
    "Tagged photos" : "Pažymėtos nuotraukos",
    "{startDate} to {endDate}" : "Nuo {startDate} iki {endDate}",
    "Failed to rename {oldName} to {faceName}." : "Nepavyko pervadinti {oldName} į {faceName}.",
    "Failed to delete {faceName}." : "Nepavyko ištrinti {faceName}.",
    "Failed to delete {fileId}." : "Nepavyko ištrinti {fileId}.",
    "Failed to delete {fileName}." : "Nepavyko ištrinti {fileName}.",
    "Locations" : "Vietos",
    "Go back to the previous view." : "Grįžti į ankstesnį rodinį.",
    "Create the album." : "Sukurti albumą.",
    "Back to the new album form." : "Atgal į naujo albumo formą.",
    "_Share with %n user_::_Share with %n users_" : ["Bendrinti su %n naudotoju","Bendrinti su %n naudotojais","Bendrinti su %n naudotojų","Bendrinti su %n naudotoju"],
    "Failed to fetch album." : "Nepavyko gauti albumo.",
    "Add photos to the album" : "Pridėti nuotraukų į albumą",
    "Failed to fetch albums list." : "Nepavyko gauti albumų sąrašo.",
    "Shared albums" : "Bendrinami albumai",
    "Create a new album" : "Sukurti naują albumą",
    "Add selection to an album" : "Pridėti žymėjimą į albumą",
    "Failed to create {albumName}." : "Nepavyko sukurti {albumName}.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Nepavyko pervadinti {currentAlbumName} į {newAlbumName}."
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
