OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Bạn đã bật xác thực hai yếu tố TOTP cho tài khoản của mình",
    "You disabled TOTP two-factor authentication for your account" : "Bạn đã tắt xác thực hai yếu tố TOTP cho tài khoản của mình",
    "TOTP (Authenticator app)" : "TOTP (Ứng dụng xác thực)",
    "Authenticate with a TOTP app" : "Xác thực bằng ứng dụng TOTP",
    "Enable TOTP" : "Bật TOTP",
    "Authentication code" : "Mã xác thực",
    "Verify" : "Xác minh",
    "Get the authentication code from the two-factor authentication app on your device." : "Nhận mã xác thực từ ứng dụng xác thực hai yếu tố trên thiết bị của bạn.",
    "Submit" : "Gửi"
},
"nplurals=1; plural=0;");
