OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Tên quá dài",
    "The given web address is too long" : "Địa chỉ web quá dài",
    "The given web address is not a valid URL" : "Địa chỉ web được cấp không phải là một đường dân URL khả dụng",
    "The given legal notice address is too long" : "Địa chỉ thông cáo pháp lý được cấp quá dài",
    "The given legal notice address is not a valid URL" : "Địa chỉ thông cáo pháp lý được cấp không phải là một đường dẫn URL khả dụng",
    "The given privacy policy address is too long" : "Địa chỉ chính sách riêng tư quá dài",
    "The given privacy policy address is not a valid URL" : "Địa chỉ chính sách riêng tư được cấp không phải là một đường dẫn URL khả dụng",
    "The given slogan is too long" : "Khẩu hiệu quá dài",
    "The given color is invalid" : "Màu không hợp lệ",
    "Saved" : "Đã lưu",
    "The file was uploaded" : "Tập tin đã được tải lên",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Tập tin tải lên đã vượt quá upload_max_filesize giới hạn trong hệ thống",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Tập được tải lên vượt quá MAX_FILE_SIZE đã được giới hạn trong biểu mẫu HTML",
    "The file was only partially uploaded" : "Tệp chỉ được tải lên một phần",
    "No file was uploaded" : "Chưa có tệp nào dược tải lên",
    "Missing a temporary folder" : "Thiếu một thư mục tạm thời",
    "Could not write file to disk" : "Không thể ghi tệp lên ổ đĩa",
    "A PHP extension stopped the file upload" : "Một phần mở rộng của PHP đã dừng tải tệp lên",
    "No file uploaded" : "Không có tệp nào được tải lên",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Bạn đang sử dụng 1 chủ đề riêng. Các thiết lập của ứng dụng Chủ đề có thể bị ghi đè bởi nó.",
    "Theming" : "Điều chỉnh giao diện",
    "Dark theme" : "Chế độ ban đêm",
    "Enable dark theme" : "Bật chế độ ban đêm",
    "Dyslexia font" : "Chứng khó đọc",
    "Enable dyslexia font" : "Bật chế độ dành cho người gặp chứng khó đọc",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic là một kiểu chữ / phông chữ miễn phí được thiết kế để giảm thiểu một số lỗi đọc phổ biến do chứng khó đọc gây ra.",
    "High contrast mode" : "Chế độ tương phản cao",
    "Enable high contrast mode" : "Bật chế độ tương phản cao",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Chế độ tương phản cao giúp bạn dễ dàng điều hướng và phân biệt vị trí các mục chính xác hơn. Chất lượng hình ảnh sẽ giảm nhưng độ rõ sẽ được tăng lên.",
    "Legal notice" : "Thông cáo pháp lý",
    "Privacy policy" : "Chính sách riêng tư",
    "Adjust the Nextcloud theme" : "Tinh chỉnh chủ đề Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Điều chỉnh giao diện cho phép bạn có thể dễ dàng tùy biến bố cục trình bày của hệ thống. Khi thực hiện nó sẽ hiện hữu đối với tất cả người dùng",
    "Advanced options" : "Tùy chọn nâng cao",
    "Name" : "Tên",
    "Web link" : "Liên kết web",
    "a safe home for all your data" : "một ngôi nhà an toàn cho tất cả dữ liệu của bạn",
    "Slogan" : "Khẩu hiệu",
    "Color" : "Màu sắc",
    "Logo" : "Logo",
    "Upload new logo" : "Tải lên logo mới",
    "Legal notice link" : "Liên kết Thông cáo pháp lý",
    "Privacy policy link" : "Liên kết Chính sách riêng tư",
    "Header logo" : "Logo đầu trang",
    "Upload new header logo" : "Tải lên logo đầu trang mới",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Tải lên bộ Favicon mới",
    "Keyboard shortcuts" : "Phím tắt",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Sự truy cập đa dạng là rất quan trọng với chúng tôi. Chúng tôi tuân theo các tiêu chuẩn mạng và kiểm tra để khiến mọi thứ đều có thể sử dụng được ngay cả khi không có chuột, và hỗ trợ những phần mềm hỗ trợ như đọc màn hình. Chúng tôi hướng đến sự tương thích với {guidelines}Nguyên Tắc Truy Cập Cho Nội Dung Mạng{linkend} 2.1  ở cấp độ AA, với chế độ tương phản cao là AAA",
    "Move up" : "Di chuyển lên",
    "Move down" : "Di chuyển xuống",
    "Reset to default" : "Đặt lại về mặc định",
    "Upload" : "Tải lên",
    "Remove background image" : "Xóa bỏ ảnh nền",
    "Loading preview…" : "Đang tải mục xem trước...",
    "Admin" : "Quản trị viên",
    "Name cannot be empty" : "Tên không thể trống",
    "Custom color" : "Tùy chỉnh màu",
    "Open documentation" : "Mở tài liệu",
    "https://…" : "https://…",
    "Upload new login background" : "Tải lên ảnh nền trang đăng nhập mới",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Cài đặt phần mở rộng PHP Imagemagick với hỗ trợ cho hình ảnh SVG để tự động tạo bộ favicon dựa trên màu và logo được tải lên"
},
"nplurals=1; plural=0;");
