OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Habilitaste la autenticación TOTP de dos factores en tu cuenta",
    "You disabled TOTP two-factor authentication for your account" : "Deshabilitaste la autenticación de dos factores TOTP para tu cuenta.",
    "TOTP (Authenticator app)" : "TOTP (aplicación de autenticador)",
    "Authenticate with a TOTP app" : "Autenticar con una aplicación TOTP",
    "Enable TOTP" : "Habilitar TOTP",
    "Could not verify your key. Please try again" : "No fue posible verificar tu llave. Por favor vuelve a intentarlo",
    "Authentication code" : "Código de autenticación",
    "Verify" : "Verificar",
    "Get the authentication code from the two-factor authentication app on your device." : "Obten el código de autenticación de la aplicación de autenticación de dos factores en tu dispositivo.",
    "Submit" : "Enviar"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
