OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Dosya anımsatıcıları",
    "Reminder for {name}" : "{name} anımsatıcısı",
    "View file" : "Dosyayı görüntüle",
    "View folder" : "Klasörü görüntüle",
    "Set file reminders" : "Dosya anımsatıcıları ayarla",
    "**📣 File reminders**\n\nSet file reminders." : "**📣 Dosya anımsatıcıları**\n\nDosya anımsatıcıları ayarla.",
    "Back" : "Geri",
    "Clear reminder" : "Anımsatıcıyı temizle",
    "Set custom reminder" : "Özel anımsatıcı ayarla",
    "Later today" : "Bugün daha sonra",
    "Set reminder for later today" : "Bugün daha sonrası için anımsatıcı ayarla",
    "Tomorrow" : "Yarın",
    "Set reminder for tomorrow" : "Yarın için anımsatıcı ayarla",
    "This weekend" : "Bu hafta sonu",
    "Set reminder for this weekend" : "Bu hafta sonu için anımsatıcı ayarla",
    "Next week" : "Sonraki hafta",
    "Set reminder for next week" : "Gelecek hafta için anımsatıcı ayarla",
    "Set reminder at custom date & time" : "Özel bir tarih ve saat için anımsatıcı ayarla",
    "Reminder set for \"{fileName}\"" : "\"{fileName}\" için anımsatıcı ayarlandı",
    "Failed to set reminder" : "Anımsatıcı ayarlanamadı",
    "Please choose a valid date & time" : "Lütfen geçerli bir tarih ve saat seçin",
    "Reminder cleared" : "Anımsatıcı temizlendi",
    "Failed to clear reminder" : "Anımsatıcı temizlenemedi",
    "Failed to load reminder" : "Anımsatıcı yüklenemedi"
},
"nplurals=2; plural=(n > 1);");
