OC.L10N.register(
    "text",
    {
    "New text file" : "Новий текстовий файл",
    "Create new text file" : "Створіть новий текстовий файл",
    "The file was uploaded" : "Файл завантажено",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Файл для завантаження перевищує параметр upload_max_filesize у php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Розмір завантаженого файлу перевищує директиву MAX_FILE_SIZE, зазначену у HTML-формі",
    "The file was only partially uploaded" : "Файл завантажено частково",
    "No file was uploaded" : "Не вивантажено жодного файлу",
    "Missing a temporary folder" : "Відсутній каталог тимчасових файлів",
    "Could not write file to disk" : "Неможливо записати файл на диск",
    "A PHP extension stopped the file upload" : "Розширення PHP призупинило завантаження файлу",
    "No file uploaded or file size exceeds maximum of %s" : "Немає завантажених файлів або розмір файлу перевищує максимум %s",
    "Nextcloud Text" : "Nextcloud Text",
    "text document" : "текстовий документ",
    "{user} has mentioned you in the text document {node}" : "{user} згадав вас у текстовому документі {node}",
    "This file cannot be displayed as download is disabled by the share" : "Файл неможливо показати, оскільки звантаження заборонено для цього спільного ресурсу",
    "Readme" : "Readme",
    "Text" : "Текст",
    "📝 Collaborative document editing" : "Спільне редагування документів",
    "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "** 📝 Спільне редагування документів!**\n\n- **📝 Цілеспрямоване письмо: ** Ніяких відволікань, лише необхідне форматування. \n- **🙋 Працюйте разом: ** Діліться та співпрацюйте з друзями та колегами, незалежно від того, використовують вони Nextcloud чи ні! \n- **💾 Відкритий формат:** Файли зберігаються як [Markdown](https://en.wikipedia.org/wiki/Markdown), тож ви також можете редагувати їх із будь-якої іншої текстової програми. - **✊ Міцна основа:** Ми використовуємо [🐈 tiptap](https://tiptap.scrumpy.io), який базується на [🦉 ProseMirror](https://prosemirror.net) – величезне спасибі їм!",
    "Nextcloud Assistant" : "Асистент Nextcloud",
    "Translate" : "Перекласти",
    "Show assistant results" : "Показати результати роботи асистента",
    "Insert result" : "Вставити результат",
    "Show result" : "Показати результат",
    "Delete task" : "Вилучити завдання",
    "Nextcloud Assistant result copied" : "Результат роботи асистента Nextcloud скопійовано",
    "Could not copy result to clipboard" : "Не вдалося скопіювати результат",
    "Use current version" : "Використовувати поточну версію",
    "Use the saved version" : "Використовувати збережену версію",
    "Failed to load file" : "Не вдалося завантажити файл",
    "Document idle for {timeout} minutes, click to continue editing" : "Документ неактивний протягом {timeout} хвилин, натисніть, щоб продовжити редагування",
    "Reconnect" : "Повторне підключення",
    "The document has been changed outside of the editor. The changes cannot be applied." : "Документ було змінено за межами редактора. Неможливо застосувати зміни.",
    "File could not be loaded. Please check your internet connection." : "Неможливо завантажити файл. Перевірте з'єднання з інтернетом",
    "This file is opened read-only as it is currently locked by {user}." : "Цей файл відкрито лише для читання, оскільки він наразі заблокований {user}.",
    "Close outline view" : "Закрити вивід змісту",
    "Outline" : "Зміст",
    "Enter your name so other people can see who is editing" : "Введіть своє ім’я, щоб інші люди могли бачити, хто редагує",
    "Edit guest name" : "Редагувати ім'я гостя",
    "Guest" : "Гість",
    "Save guest name" : "Зберегти ім'я гостя",
    "Insert an attachment" : "Вставте вкладення",
    "guest" : "гість",
    "Show author colors" : "Показати кольори автора",
    "Author colors are only shown until everyone has closed the document." : "Кольори автора відображаються, лише доки всі не закриють документ.",
    "Active people" : "Зараз редагують",
    "Save document" : "Зберегти документ",
    "Last saved" : "Востаннє збережено",
    "Offline" : "Офлайн",
    "Offline, changes will be saved when online" : "В офлайні, зміни буде збережено після повернення в онлайн",
    "Saving …" : "Збереження …",
    "Saved" : "Збережено",
    "Last saved {lastSave}" : "Востаннє збережено {lastSave}",
    "Unsaved changes" : "Незбережені зміни",
    "Formatting help" : "Допомога",
    "Speed up your writing with simple shortcuts." : "Прискоріть написання за допомогою простих комбінацій клавіш.",
    "Just type the Markdown syntax or use keyboard shortcuts from below." : "Просто введіть синтаксис Markdown або скористайтеся комбінаціями клавіш нижче.",
    "Just type the Markdown syntax from below." : "Просто введіть синтаксис Markdown знизу.",
    "Style" : "Стиль",
    "Syntax" : "Синтаксис",
    "Keyboard shortcuts" : "Скорочення",
    "New paragraph" : "Новий параграф",
    "Enter" : "Ввід",
    "Hard line break" : "Жорсткий розрив",
    "followed by" : "слідом за",
    "Backspace" : "Повернутися",
    "Shift" : "Shift",
    "Bold" : "Грубий",
    "Bold text" : "Грубий текст",
    "Ctrl" : "Ctrl",
    "Italic" : "Курсив",
    "Italicized text" : "Текст курсивом",
    "Strikethrough" : "Перекреслений",
    "Mistaken text" : "Помилковий текст",
    "Underline" : "Підкреслений",
    "Underlined text" : "Підкреслений текст",
    "Heading 1" : "Заголовок 1",
    "Heading level 1" : "Рівень заголовка 1",
    "Heading 6" : "Заголовок 6",
    "Heading level 6" : "Рівень заголовка 6",
    "Unordered list" : "Невпорядкований список",
    "An item" : "Предмет",
    "Ordered list" : "Впорядкований список",
    "First item" : "Перший пункт",
    "Checklist" : "Контрольний список",
    "To-Do item" : "Елемент To-Do",
    "Blockquote" : "Цитата",
    "Quoted text" : "Процитований текст",
    "Code block" : "Код",
    "Some code" : "Якийсь код",
    "Upload from computer" : "Завантажити з комп'ютера",
    "Insert from Files" : "Вставити з файлів",
    "Remove link" : "Вилучити посилання",
    "Link to file or folder" : "Посилання на файл або каталог",
    "Link to website" : "Посилання на вебсайт",
    "Update link" : "Оновити посилання",
    "Open the Smart Picker" : "Відкрийте асистент вибору",
    "Select file or folder to link to" : "Виберіть файл або каталог, до якого потрібно застосувати посилання",
    "_%n word_::_%n words_" : ["%n слово","%n слова","%n слів","%n слів"],
    "_%n char_::_%n chars_" : ["%n символ","%n символи","%n символів","%n символів"],
    "Editor actions" : "Дії редактора",
    "Formatting menu bar" : "Форматування панелі меню",
    "Remaining actions" : "Решта дій",
    "To translate individual parts of the text, select it before using the translate function." : "Щоби перекласти окремі частини тексту, виділіть його, перед тим як перекладати.",
    "Translate from" : "Перекласти з",
    "Select language" : "Виберіть мову",
    "to" : "до",
    "Replace" : "Замінити",
    "Insert" : "Вставити",
    "Detect language" : "Визначити мову",
    "Translate from {language}" : "Перекласти з {language}",
    "Translate to {language}" : "Перекласти на {language}",
    "Translation failed" : "Не вдалося перекласти",
    "No emoji found" : "Емоційки не знайдено",
    "No command found" : "Відсутня команда",
    "No user found" : "Жодного користувача не знайдено",
    "No suggestion found" : "Відсутні пропозиції",
    "Code block options" : "Налаштування блоку коду",
    "Code block language" : "Мова блоку коду",
    "Source code" : "Вихідний код",
    "Diagram" : "Діаграма",
    "Both" : "Обидва",
    "Mermaid documentation" : "Документація Mermaid",
    "Link to this section" : "Посилання на цей розділ",
    "Delete this attachment" : "Вилучити цей вкладений файл",
    "Delete this image" : "Вилучити це зображення",
    "Failed to load" : "Не вдалося завантажити",
    "Unsupported image type" : "Цей тип зображення не підтримується",
    "Add row before" : "Додати рядок перед",
    "Add row after" : "Додати рядок після",
    "Delete this row" : "Вилучити цей рядок",
    "Left align column" : "Вирівняти по лівій стороні",
    "Center align column" : "Вирівняти по центру",
    "Right align column" : "Вирівняти по правій стороні",
    "Add column before" : "Додайте стовпець перед",
    "Add column after" : "Додайте стовпець після",
    "Delete this column" : "Вилучити цей стовпець",
    "Delete this table" : "Вилучити цю таблицю",
    "Hide outline" : "Сховати зміст",
    "Show outline" : "Показати зміст",
    "Undo" : "Скасувати",
    "Redo" : "Повторити",
    "Headings" : "Заголовок",
    "Heading 2" : "Заголовок 2",
    "Heading 3" : "Заголовок 3",
    "Heading 4" : "Заголовок 4",
    "Heading 5" : "Заголовок 5",
    "To-Do list" : "Список справ",
    "Insert link" : "Вставити посилання",
    "Callouts" : "Виноска",
    "Info" : "Info",
    "Success" : "Успіх",
    "Warning" : "Увага",
    "Danger" : "Небезпека",
    "Table" : "Таблиця",
    "Insert emoji" : "Емоційки",
    "Insert attachment" : "Вставте вкладення",
    "Command" : "Команда",
    "Control" : "Контроль",
    "Option" : "Варіант",
    "Formatting" : "Форматування",
    "Smart picker" : "Асистент розумного вибору",
    "Add notes, lists or links …" : "Додавайте примітки, створюйте списки та посилання...",
    "Edit" : "Редагувати",
    "Add description" : "Додати опис",
    "Front matter" : "Передня справа",
    "Document save status" : "Статус збереження документа",
    "Update Link" : "Оновити посилання",
    "Add Link" : "Додати посилання",
    "Link file" : "Файл посилання",
    "Remove Link" : "Вилучити посилання",
    "Select file to link to" : "Виберіть файл для посилання",
    "Show rich workspaces" : "Показувати опис каталогу",
    "Source language" : "Мова оригіналу",
    "Target language" : "Цільова мова",
    "e.g. php, javascript, json, ..." : "напр., PHP, JavaScript, JSON ..."
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
