OC.L10N.register(
    "files_versions",
    {
    "Versions" : "Верзии",
    "This application automatically maintains older versions of files that are changed." : "Оваа апликација автоматски ги менаџира постарите верзии на датотеките кој се изменети.",
    "This application automatically maintains older versions of files that are changed. When enabled, a hidden versions folder is provisioned in every user's directory and is used to store old file versions. A user can revert to an older version through the web interface at any time, with the replaced file becoming a version. The app automatically manages the versions folder to ensure the user does not run out of Quota because of versions.\n\t\tIn addition to the expiry of versions, the versions app makes certain never to use more than 50% of the user's currently available free space. If stored versions exceed this limit, the app will delete the oldest versions first until it meets this limit. More information is available in the Versions documentation." : "Оваа апликација автоматски ги менаџира постарите верзии на датотеките кој се изменети. Кога е овозможена, скриена папка се креира во секој кориснички директориум и се користи за зачувување на постарите верзии на датотеките. Корисникот има можност да врати стара верзија од датотеката во секое време преку веб-интерфејсот, со што се преклопува постоечката верзија на датотеката. Апликацијата автоматски се грижи за верзиите за да не дојде случај да се искористи просторот за складирање на корисникот.\n\t\tПокрај истекот на верзиите, апликацијата за верзии нема да користи повеќе од 50% од тековно достапната квота за верзии. Ако зачуваните верзии ја надминат оваа граница, апликацијата ги брише најстарите верзии на датотеки сè додека не се дојде под ова ограничување. Повеќе информации се достапни во документацијата за верзии на датотеки.",
    "Name this version" : "Додај име на оваа верзијата",
    "Edit version name" : "Промени име на верзијата",
    "Compare to current version" : "Спореди со моменталната верзија",
    "Restore version" : "Врати ја оваа верзија",
    "Download version" : "Преземи верзија",
    "Delete version" : "Избриши верзија",
    "Version name" : "Име на верзијата",
    "Named versions are persisted, and excluded from automatic cleanups when your storage quota is full." : "Именуваните верзии опстојуваат и се исклучени од автоматско чистење кога вашата квота за складирање е полна.",
    "Remove version name" : "Избриши име на верзијата",
    "Save version name" : "Зачувај име на верзија",
    "Current version" : "Моментална верзија",
    "Initial version" : "Првична верзија",
    "Initial version restored" : "Почетната верзијата е вратена",
    "Version restored" : "Верзијата е вратена",
    "Could not restore version" : "Неможе да се врати верзијата",
    "Could not set version name" : "Неможе да се постави име на верзијата",
    "Could not delete version" : "Неможе да се избрише верзијата",
    "${version.label} restored" : "${version.label} вратена",
    "Failed to revert {file} to revision {timestamp}." : "Не успеав да го вратам {file} на ревизијата {timestamp}.",
    "_%n byte_::_%n bytes_" : ["1 бајт","%n бајти"],
    "Restore" : "Врати",
    "No other versions available" : "Не постојат други верзии"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
