OC.L10N.register(
    "files_trashbin",
    {
    "restored" : "Gendannet",
    "Deleted files" : "Slettede filer",
    "Deleted files and folders in the trash bin (may expire during export if you are low on storage space)" : "Slettede filer og mapper i skraldespanden (kan udløbe under eksport, hvis du mangler lagerplads)",
    "This application enables users to restore files that were deleted from the system." : "Denne app giver brugere mulighed for at gendanne filer som var slettet fra systemet.",
    "This application enables users to restore files that were deleted from the system. It displays a list of deleted files in the web interface, and has options to restore those deleted files back to the users file directories or remove them permanently from the system. Restoring a file also restores related file versions, if the versions application is enabled. When a file is deleted from a share, it can be restored in the same manner, though it is no longer shared. By default, these files remain in the trash bin for 30 days.\nTo prevent a user from running out of disk space, the Deleted files app will not utilize more than 50% of the currently available free quota for deleted files. If the deleted files exceed this limit, the app deletes the oldest files until it gets below this limit. More information is available in the Deleted Files documentation." : "Denne applikation giver brugerne mulighed for at gendanne filer, der blev slettet fra systemet. Det viser en liste over slettede filer i webgrænsefladen og har muligheder for at gendanne de slettede filer tilbage til brugerens filmapper eller fjerne dem permanent fra systemet. Gendannelse af en fil gendanner også relaterede filversioner, hvis versionsprogrammet er aktiveret. Når en fil slettes fra en deling, kan den gendannes på samme måde, selvom den ikke længere deles. Som standard forbliver disse filer i papirkurven i 30 dage. \nFor at forhindre en bruger i at løbe tør for diskplads, bruger appen Slettede filer ikke mere end 50% af den aktuelt tilgængelige gratis kvote for slettede filer. Hvis de slettede filer overskrider denne grænse, sletter appen de ældste filer, indtil den kommer under denne grænse. Flere oplysninger findes i dokumentationen til slettede filer.",
    "Restore" : "Gendan",
    "No deleted files" : "Ingen slettede filer",
    "Deleted" : "Slettet",
    "You will be able to recover deleted files from here" : "Du vil kunne gendanne slettede filer herfra",
    "No entries found in this folder" : "Der blev ikke fundet poster i denne mappe",
    "Select all" : "Vælg alle",
    "Name" : "Navn",
    "Actions" : "Handlinger",
    "Delete permanently" : "Slet permanent",
    "Error while restoring file from trash bin" : "Fejl under gendannelse af fil fra papirkurven",
    "Error while removing file from trash bin" : "Fejl under fjernelse af fil fra papirkurven",
    "Error while restoring files from trash bin" : "Fejl under gendannelse af filer fra papirkurven",
    "Error while emptying trash bin" : "Fejl under tømning af skraldespand",
    "Error while removing files from trash bin" : "Fejl under fjernelse af filer fra papirkurven",
    "This operation is forbidden" : "Denne operation er forbudt",
    "This directory is unavailable, please check the logs or contact the administrator" : "Denne mappe er utilgængelig, tjek venligst loggene eller kontakt administratoren",
    "Delete" : "Slet"
},
"nplurals=2; plural=(n != 1);");
