OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Ai activat autentificarea în doi pași TOTP pentru contul tău",
    "You disabled TOTP two-factor authentication for your account" : "Ai dezactivat autentificarea în doi pași TOTP pentru contul tău",
    "TOTP two-factor authentication disabled by an admin" : "TOTO autentificarea în doi pași a fost dezacticată de admin",
    "TOTP (Authenticator app)" : "TOTP (Authenticator app)",
    "Authenticate with a TOTP app" : "Autentifică-te cu o aplicație TOTP",
    "Two-Factor TOTP Provider" : "Furnizorul de autentificare în doi pași TOTP",
    "TOTP two-factor provider" : "Furnizorul de autentificare în doi pași TOTP",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "Un furnizor de autentificare în doi pași TOTP (RFC6238",
    "Enable TOTP" : "Activează TOTP",
    "Could not enable TOTP" : "Nu s-a putut activa autentificarea TOTP",
    "Could not verify your key. Please try again" : "Nu s-a putut verifica cheia. Vă rugăm să încercați din nou",
    "Your new TOTP secret is:" : "Noul dumneavoastră secret TOTP este:",
    "For quick setup, scan this QR code with your TOTP app:" : "Pentru a seta rapid, scanați acest cod QR cu aplicația dumneavoastră TOTP:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "După ce a-ți configurat aplicația, introuceți un cod de test mai jos pentru a ne asigura că totul funcționează corect:",
    "Authentication code" : "Cod autentificare",
    "Verify" : "Verifică",
    "Get the authentication code from the two-factor authentication app on your device." : "Obțineți codul de autentificare din aplicația de autentificare two-factor de pe dispozitiv.",
    "Submit" : "Trimite"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
