OC.L10N.register(
    "support",
    {
    "Link:" : "Link:",
    "Password:" : "Passwort:",
    "Generating system report failed." : "Erstellung des System-Berichts fehlgeschlagen.",
    "Could not create folder \"System information\" to store generated report." : "Ordner \"System information\" konnte nicht erstellt werden, um den erstellten Bericht zu speichern.",
    "Could not create file \"%s\" to store generated report." : "Die Datei \"%s\" konnte nicht erstellt werden, um in ihr den erstellten Bericht zu speichern.",
    "Could not share file \"%s\". Nevertheless, you can find it in the folder \"System information\"." : "Konnte Datei \"%s\" nicht teilen. Nichtsdestotrotz kannst du die Datei im Ordner \"Systeminformation\" finden.",
    "Subscription notifications" : "Abonnements-Benachrichtigungen",
    "Nextcloud Subscription" : "Nextcloud-Abonnement",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Dein Server hat kein Nextcloud-Abonnement oder dein Abonnement ist abgelaufen.",
    "Your Nextcloud server subscription does not cover your number of users." : "Dein Nexcloud-Abonnement umfasst nicht die Anzahl deiner Benutzer.",
    "Your Nextcloud Subscription has expired!" : "Dein Nextcloud-Abonnement ist abgelaufen!",
    "Your server has no Nextcloud Subscription" : "Dein Server hat kein Nextcloud-Abonnement",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Dein Server wird nicht von einem Nextcloud-Enterprise-Abonnement umfasst.",
    "If your server setup breaks and employees can't work anymore, you don't have to rely on searching online forums for a solution. You have direct access to our experienced engineers!" : "Wenn deine Serverkonfiguration gestört ist und Mitarbeiter nicht mehr arbeiten können, must du dich nicht darauf verlassen, dass du in Online-Foren nach einer Lösung suchst. Du hast direkten Zugang zu unseren erfahrenen Ingenieuren!",
    "You have a contract with the vendor providing early security information, mitigations, patches and updates." : "Du hast einen Vertrag mit dem Anbieter, der frühzeitige Sicherheitsinformationen, Maßnahmen, Patches und Updates bereitstellt.",
    "If you need to stay longer on your current version without disruptions, you don't have to run software without security updates." : "Wenn du länger und ohne Unterbrechungen auf deiner aktuellen Version bleiben musst, so musst du keine Software ohne Sicherheitsupdates betreiben.",
    "You have the best expertise at hand to deal with performance and scalability issues." : "Du hast Zugriff auf das beste Know-how, um Probleme bezüglich Leistung und Skalierbarkeit zu lösen.",
    "You have access to the right documentation and expertise to quickly answer compliance questions or deliver on GDPR, HIPAA and other regulation requirements." : "Du hast Zugriff auf die richtige Dokumentation und das richtige Fachwissen, um Fragen zur Compliance, GDPR, HIPAA und andere Vorschriften schnell beantworten zu können.",
    "We can also provide Outlook integration, Online Office, scalable integrated audio-video and chat communication and other features only available in a limited form for free or develop further integrations and capabilities to your needs." : "Wir können auch Outlook-Integration, Online Office, skalierbare integrierte Audio-Video- und Chat-Kommunikation und andere Funktionen, die nur in eingeschränkter Form verfügbar sind, kostenlos zur Verfügung stellen oder weitere Integrationen und Funktionen nach deinen Bedürfnissen entwickeln.",
    "A subscription helps you get the most out of Nextcloud!" : "Ein Abonnement hilft Dir, das meiste aus Nexcloud herauszuholen!",
    "Learn more now" : "Erfahre jetzt mehr",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %1$s because you have over %2$s registered users." : "Diese E-Mail wurde von der Support-App deiner Nextcloud-Instanz unter %1$s an alle Administratoren verschickt, weil über %2$s registrierte Benutzer vorhanden sind.",
    "Your Nextcloud server Subscription is over limit" : "Dein Nextcloud-Server-Abonnement ist über dem Limit",
    "Dear admin," : "Lieber Administrator,",
    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact your Nextcloud account manager to get your subscription updated!" : "Dein Nextcloud-Abonnement umfasst nicht die Anzahl der aktuell auf diesem Server aktiven Benutzer. Bitte kontaktiere deinen Accountmanager, um dein Abonnement aktualisieren zu lassen!",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "%1$s ist dein Accountmanager und ist per E-Mail über  %2$s oder telefonisch unter %3$s erreichbar.",
    "Thank you," : "Danke schön,",
    "Your Nextcloud team" : "Dein Nextcloud-Team",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because you have more users than your subscription covers." : "Diese E-Mail wurde von der Support-App deiner Nextcloud-Instanz unter %s an alle Administratoren verschickt, weil mehr Benutzer registriert sind als das Nextcloud-Abonnement abdeckt.",
    "Your Nextcloud server Subscription is expired" : "Dein Nextcloud-Server-Abonnement ist abgelaufen",
    "Your Nextcloud server Subscription is expired!" : "Dein Nextcloud-Server-Abonnement ist abgelaufen!",
    "Your Nextcloud Subscription has expired! Please contact your Nextcloud account manager to get your subscription updated!" : "Dein Nextcloud Abonnement ist abgelaufen! Bitte kontaktiere deinen Accountmanager, um das Abonnement verlängert zu bekommen.",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because your subscription expired." : "Diese E-Mail wurde von der Support-App deiner Nextcloud-Instanz unter %s an alle Administratoren verschickt, weil dein Nextcloud-Abonnement abgelaufen ist.",
    "Support" : "Support",
    "Getting support and help for your Nextcloud" : "Erhalte Support und Hilfe für deine Nextcloud",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "Die Support-App bietet direkten Zugriff auf Hilfe- und Vertriebsquellen, direkte Kontaktmöglichkeiten zum Konten-Verwalter sowie einen Überblick über das Enterprise-Abonnement.",
    "Basic subscription" : "Basis Abonnement",
    "Standard subscription" : "Standard Abonnement",
    "Premium subscription" : "Premium Abonnement",
    "Géant subscription" : "Géant Abonnement",
    "Silver partner subscription" : "Silber-Partner Abonnement",
    "Gold partner subscription" : "Gold-Partner Abonnement",
    "Subscription" : "Abonnement",
    "Over subscription limit" : "Abonnements-Limit überschritten",
    "Valid subscription" : "Gültiges Abonnement",
    "Expired subscription" : "Abgelaufenes Abonnement",
    "Subscription key:" : "Abonnements-Schlüssel:",
    "Expires in: " : "Läuft ab in: ",
    "_%n year_::_%n years_" : ["%n Jahr","%n Jahre"],
    "_%n month_::_%n months_" : ["%n Monat","%n Monate"],
    "_%n week_::_%n weeks_" : ["%n Woche","%n Wochen"],
    "_%n day_::_%n days_" : ["%n Tag","%n Tage"],
    "For an unlimited amount of users" : "Für eine unbegrenzte Anzahl an Nutzern",
    "_For %n active users_::_For %n active users_" : ["Für %n aktiven Benutzer","Für %n aktive Benutzer"],
    "_For %n users_::_For %n users_" : ["Für %n Benutzer","Für %n Benutzer"],
    "_currently at %n user_::_currently at %n users_" : ["aktuell mit %n Benutzer","aktuell mit %n Benutzern"],
    "Includes support for %s" : "Beinhaltet Support für %s",
    "Includes support for %1$s & %2$s" : "Beinhaltet Support für %1$s & %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Beinhaltet Support für %1$s, %2$s & %3$s",
    "Extended maintenance life cycle" : "Erweiterter Wartungslebenszyklus",
    "Update subscription key" : "Abonnements-Schlüssel aktualisieren",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s ist dein Accountmanager. Zögere nicht, uns bezüglich Fragen zu deinem Abonnement anzusprechen.",
    "You can find answers to common question in our portal and also file support requests there." : "In unserem Portal findest du Antworten auf häufige Fragen und kannst auch Unterstützung anfordern.",
    "Access Nextcloud portal" : "Zum Nextcloud-Portal",
    "System information" : "Systeminformation",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Erstellen von Systeminformationen für Supportfälle. Nach Betätigung der Schaltfläche wird eine Textdatei im Ordner \"System Information\" erstellt und über eine passwortgeschütze, öffentliche Freigabe geteilt. Der Link ist 2 Wochen lang aktiv.",
    "Generate system report" : "System-Bericht erstellen",
    "Enterprise subscription recommended" : "Enterprise-Abonnement empfohlen",
    "No active enterprise subscription" : "Kein aktives Enterprise-Abonnement",
    "Unsupported" : "Nicht unterstützt",
    "This Nextcloud server has no Enterprise Subscription." : "Dieser Nextcloud-Server verfügt über kein Enterprise-Abonnement.",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "Ein Nextcloud Enterprise-Abonnenment hilft Dir, das meiste aus deiner Nextcloud herauszuholen, deine Daten abzusichern und deinen Server jederzeit zuverlässig zu betreiben.",
    "Advantages" : "Vorteile",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "Zugriff auf die technische Erfahrung der Nextcloud-Entwickler über die Dokumentation und den Support",
    "Access to additional capabilities like Outlook integration, online office and more" : "Zugriff auf weitere Funktionen wie Outlook-Integration, Online-Office, usw.",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "Zugriff auf Skalierbarkeits-Sachverstand und Skalierbarkeits-Fähigkeiten für Dateien und Talk",
    "Optional branding, consulting, architecture advice" : "Optionale Unterstützung bezüglich Branding, Beratung und Architektur",
    "Confidential security notification service, mitigations, patches and advice" : "Vertraulicher Sicherheitsbenachrichtigungsdienst, Risikominderung, Patches und Hilfestellungen",
    "Compliance certification, advice and documentation" : "Compliance-Zertifizierung, Beratung und Dokumentation",
    "Get a quote" : "Erhalte ein Angebot",
    "More information" : "Mehr Informationen",
    "Subscription benefits" : "Vorteile eines Abonnements",
    "Pricing" : "Preisgestaltung",
    "Community support" : "Community-Unterstützung",
    "Forum" : "Forum",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud ist eine freie Software, die von einer sehr aktive Community unterstützt wird. Bitte melde dich im Forum an, um Fragen zu stellen oder mit anderen zu diskutieren.",
    "Nextcloud forum" : "Nextcloud Forum",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud verwendet GitHub als Plattform für die Zusammenarbeit. Du kannst dort Fehler direkt melden.",
    "Nextcloud at GitHub" : "Nextcloud auf GitHub",
    "Subscription key" : "Abonnements-Schlüssel",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Wenn du über ein aktives Nextcloud-Abonnement verfügst, gib bitte hier deinen Abonnements-Schlüssel ein.",
    "Learn more about an enterprise subscription." : "Erfahre mehr über das Enterprise-Abonnement.",
    "Set subscription key" : "Abonnements-Schlüssel eingeben",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "Die Abonnenments-Informationen konnten soeben nicht abgerufen werden. Eine Wiederholung ist geplant. Bitte später noch einmal überprüfen.",
    "The subscription key was invalid." : "Der Abonnements-Schlüssel ist ungültig.",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "Der Abonnements-Schlüssel konnte nicht überprüft werden, da dieser Server nicht mit dem Internet verbunden ist. Bitte wende dich zur Fehlerbehebung an das Support-Team.",
    "The subscription key had an invalid format." : "Der Abonnements-Schlüssel hat ein ungültiges Format.",
    "While fetching the subscription information an error happened." : "Beim Abruf der Abonnements-Informationen ist ein Fehler aufgetreten",
    "The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Nach Betätigung der Schaltfläche wird eine Textdatei im Ordner \"System Information\" erstellt und über eine passwortgeschützte, öffentliche Freigabe geteilt. Der Link ist 2 Wochen lang aktiv.",
    "News" : "Neuigkeiten",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "Abonniere unseren Newsletter und folge uns auf unseren Social-Media-Kanälen, um bezüglich der Nexcloud-Entwicklung immer auf dem Laufenden zu sein.",
    "Like our Facebook page" : "Like uns auf unserer Facebook-Seite",
    "Follow us on Twitter" : "Folge uns auf Twitter",
    "Check out our blog" : "Sieh dir unseren Blog an",
    "Subscribe to our newsletter" : "Abonniere unseren Newsletter"
},
"nplurals=2; plural=(n != 1);");
