<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  9712 => 'Abu dhabi',
  9713 => 'Al Ain',
  97142 => 'Dubai',
  97143 => 'Dubai',
  97144 => 'Dubai',
  97145 => 'Dubai',
  97146 => 'Dubai',
  97147 => 'Dubai',
  97148 => 'Dubai',
  97162 => 'Sharjah, Ajman, Umm Al-Qaiwain',
  97163 => 'Sharjah, Ajman, Umm Al-Qaiwain',
  97164 => 'Sharjah, Ajman, Umm Al-Qaiwain',
  97165 => 'Sharjah, Ajman, Umm Al-Qaiwain',
  97166 => 'Sharjah, Ajman, Umm Al-Qaiwain',
  97167 => 'Sharjah, Ajman, Umm Al-Qaiwain',
  97168 => 'Sharjah, Ajman, Umm Al-Qaiwain',
  97172 => 'Ras Alkhaimah',
  97173 => 'Ras Alkhaimah',
  97174 => 'Ras Alkhaimah',
  97175 => 'Ras Alkhaimah',
  97176 => 'Ras Alkhaimah',
  97177 => 'Ras Alkhaimah',
  97178 => 'Ras Alkhaimah',
  97192 => 'Fujairah',
  97193 => 'Fujairah',
  97194 => 'Fujairah',
  97195 => 'Fujairah',
  97196 => 'Fujairah',
  97197 => 'Fujairah',
  97198 => 'Fujairah',
);
