OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Lembretes de ficheiros",
    "Reminder for {name}" : "Lembrete para {name}",
    "View file" : "Ver ficheiro",
    "View folder" : "Ver cartafol",
    "Set file reminders" : "Definir lembretes de ficheiros",
    "**📣 File reminders**\n\nSet file reminders." : "**📣 Lembretes de ficheiros**\n\nDefinir lembretes de ficheiros.",
    "Back" : "Atras",
    "Clear reminder" : "Limpar o lembrete",
    "Set custom reminder" : "Definir un lembrete personalizado",
    "Later today" : "Hoxe máis tarde",
    "Set reminder for later today" : "Definir un lembrete para hoxe máis tarde",
    "Tomorrow" : "Mañá",
    "Set reminder for tomorrow" : "Definir un lembrete para mañá",
    "This weekend" : "Este fin de semana",
    "Set reminder for this weekend" : "Definir un lembrete para este fin de semana",
    "Next week" : "Semana seguinte",
    "Set reminder for next week" : "Definir un lembrete para a semana seguinte",
    "Set reminder at custom date & time" : "Definir lembrete na data e hora personalizadas",
    "Reminder set for \"{fileName}\"" : "Lembrete definido para «{fileName}»",
    "Failed to set reminder" : "Produciuse un fallo ao definir o lembrete",
    "Please choose a valid date & time" : "Escolla unha data e hora válidas",
    "Reminder cleared" : "Limpouse o lembrete",
    "Failed to clear reminder" : "Produciuse un fallo ao limpar o lembrete",
    "Failed to load reminder" : "Produciuse un fallo ao cargar o lembrete"
},
"nplurals=2; plural=(n != 1);");
