<?php
namespace Aws\FinSpaceData\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **FinSpace Public API** service.
 */
class FinSpaceDataException extends AwsException {}
