OC.L10N.register(
    "files",
    {
    "File could not be found" : "Tệp tin không tồn tại",
    "Move or copy" : "Di chuyển hoặc sao chép",
    "Download" : "Tải về",
    "Delete" : "Xóa",
    "Tags" : "Nhãn",
    "Show list view" : "Hiển thị chế độ xem danh sách",
    "Show grid view" : "Hiển thị chế độ xem lưới",
    "Home" : "Nhà",
    "Close" : "Đóng",
    "Could not create folder \"{dir}\"" : "Không thể tạo thư mục “{dir}”",
    "This will stop your current uploads." : "Hành động này sẽ dừng các tải lên hiện hành.",
    "Upload cancelled." : "Hủy tải lên",
    "Processing files …" : "Đang xử lý các tệp tin...",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "không thể tải {filename} lên do nó là một thư mục hoặc có kích thước bằng 0 byte",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Không đủ dung lượng trống, bạn đang tải {size1} nhưng chỉ còn {size2} trống",
    "Target folder \"{dir}\" does not exist any more" : "Thư mục đích \"{dir}\" không còn tồn tại",
    "Not enough free space" : "Không đủ dung lượng trống",
    "An unknown error has occurred" : "Một lỗi không rõ đã xảy ra",
    "File could not be uploaded" : "Không thể tải lên tập tin",
    "Uploading …" : "Đang tải lên …",
    "{remainingTime} ({currentNumber}/{total})" : "{thời gian còn lại} ({số lượng hiện tại}/{tổng số})",
    "Uploading … ({currentNumber}/{total})" : "Đang tải lên … ({số lượng hiện tại}/{tổng số})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} trong tổng số {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "‎Tải lên mục ‎‎đó không‎‎ được hỗ trợ‎",
    "Target folder does not exist any more" : "‎Thư  mục đích‎‎ không còn tồn tại nữa‎",
    "Operation is blocked by access control" : "‎Thao tác bị chặn bởi kiểm ‎‎soát truy cập‎",
    "Error when assembling chunks, status code {status}" : "‎Lỗi‎‎ khi lắp ráp khối, mã trạng thái {status}‎",
    "Actions" : "Actions",
    "Rename" : "Đổi tên",
    "Move" : "Dịch chuyển",
    "Copy" : "Sao chép",
    "Choose target folder" : "‎Chọn thư‎‎ ‎‎mục đích‎",
    "Set reminder" : "Thiết lập nhắc nhở",
    "Edit locally" : "Chỉnh sửa cục bộ/ngoại tuyến",
    "Open" : "Mở",
    "Delete file" : "Xóa tệp",
    "Delete folder" : "Xóa thư mục",
    "Disconnect storage" : "Bộ lưu trữ đã ngắt kết nối",
    "Leave this share" : "Rời khỏi mục chia sẻ này‎",
    "Could not load info for file \"{file}\"" : "Không thể tải thông tin cho tệp \"{file}\"",
    "Files" : "Tệp tin",
    "Details" : "Chi tiết",
    "Please select tag(s) to add to the selection" : "Vui lòng chọn (các) thẻ để thêm vào lựa chọn",
    "Apply tag(s) to selection" : "Áp dụng (các) thẻ cho lựa chọn",
    "Select directory \"{dirName}\"" : "Chọn thư mục \"{dirName}\"",
    "Select file \"{fileName}\"" : "Chọn tệp tin \"{fileName}\"",
    "Pending" : "Đang chờ",
    "Unable to determine date" : "Không thể xác định ngày",
    "This operation is forbidden" : "Thao tác bị cấm",
    "This directory is unavailable, please check the logs or contact the administrator" : "Thư mục này không sẵn có, hãy kiểm tra log hoặc liên hệ người quản lý",
    "Storage is temporarily not available" : "Kho lưu trữ tạm thời không khả dụng",
    "Could not move \"{file}\", target exists" : "Không thể di chuyển \"{file}\", trùng đích đến",
    "Could not move \"{file}\"" : "Không thể di chuyển \"{file}\"",
    "copy" : "sao chép",
    "Could not copy \"{file}\", target exists" : "Không thể sao chép \"{file}\",  tệp tin đích đã tồn tại",
    "Could not copy \"{file}\"" : "Không thể sao chép tệp tin \"{file}\"",
    "Copied {origin} inside {destination}" : "Được sao chép {origin} vào trong {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Đã sao chép {origin} và {nbfiles} các file vào trong {destination}",
    "Failed to redirect to client" : "Không thể chuyển hướng đến ứng dụng khách",
    "{newName} already exists" : "{newName} đã có",
    "Could not rename \"{fileName}\", it does not exist any more" : "Không thể đổi tên \"{fileName}\", tập tin không tồn tại",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Tên \"{targetName}\" đã được dùng trong thư mục \"{dir}\". Hãy thử tên khác",
    "Could not rename \"{fileName}\"" : "Không thể đổi tên \"{fileName}\"",
    "Could not create file \"{file}\"" : "Không thể tạo tập tin \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Không thể tạo tập tin \"{file}\" vì đã có ",
    "Could not create folder \"{dir}\" because it already exists" : "Không thể tạo thư mục “{dir}” vì đã có",
    "Could not fetch file details \"{file}\"" : "‎Không thể lấy chi tiết tệp \"{file}\"‎",
    "Error deleting file \"{fileName}\"." : "Lỗi khi xóa tập tin \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Không có kết quả tìm kiếm trong các thư mục khác cho {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "‎Nhập nhiều hơn hai ký tự để tìm kiếm trong các thư mục khác‎",
    "Name" : "Tên",
    "Size" : "Kích cỡ",
    "Modified" : "Thay đổi",
    "_%n folder_::_%n folders_" : ["%n thư mục"],
    "_%n file_::_%n files_" : ["%n tập tin"],
    "{dirs} and {files}" : "{dirs} và {files}",
    "_including %n hidden_::_including %n hidden_" : ["Bao gồm %n ẩn"],
    "You do not have permission to upload or create files here" : "Bạn không đủ quyền để Tải lên hoặc Tạo tập tin ở đây",
    "_Uploading %n file_::_Uploading %n files_" : ["Đang tải lên %n tập tin"],
    "New" : "Tạo mới",
    "New file/folder menu" : "Menu tập tin/thư mục mới",
    "Select file range" : "‎Chọn phạm vi tệp‎",
    "{used}%" : "{Đã sử dụng}%",
    "{used} of {quota} used" : "‎{used} trong { quota } ‎‎được‎‎ sử dụng‎",
    "{used} used" : "{used} được sử dụng‎",
    "\"{name}\" is an invalid file name." : "\"{name}\" không được chấp nhận",
    "File name cannot be empty." : "Tên file không được rỗng",
    "\"/\" is not allowed inside a file name." : "\"/\" ‎không được phép có trong tên tệp.‎",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" không phải là loại tập tin được cho phép",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Bộ nhớ của {owner} đã đầy, không thể cập nhật hoặc đồng bộ hóa tệp được nữa!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Thư mục nhóm \"{mountPoint}\" đã đầy, không thể cập nhật hoặc đồng bộ hóa tệp được nữa!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Bộ nhớ ngoài \"{mountPoint}\" đã đầy, không thể cập nhật hoặc đồng bộ hóa tệp được nữa!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Bộ nhớ của bạn đã đầy, không thể cập nhật hoặc đồng bộ hóa tệp được nữa!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "‎Dung lượng lưu trữ {owner} gần đầy ({usedSpacePercent}%).‎",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "‎Thư mục nhóm \"{mountPoint}\" gần đầy ({usedSpacePercent}%).‎",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "‎Bộ nhớ ngoài \"{mountPoint}\" gần đầy ({usedSpacePercent}%).‎",
    "Your storage is almost full ({usedSpacePercent}%)." : "‎Dung lượng lưu trữ của bạn gần đầy rồi ({usedSpacePercent}%).‎",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["khớp với \"{filter}\""],
    "View in folder" : "Xem trong thư mục",
    "Direct link was copied (only works for users who have access to this file/folder)" : "Đã sao chép đường dẫn trực tiếp(Chỉ áp dụng đối với người dùng có quyền truy cập vào thư mục/tệp tin)",
    "Path" : "Đường dẫn",
    "_%n byte_::_%n bytes_" : ["%n bytes"],
    "Favorited" : "Được ưa thích",
    "Favorite" : "Ưa thích",
    "Copy direct link (only works for users who have access to this file/folder)" : "Sao chép liên kết trực tiếp (chỉ hoạt động đối với những người dùng có quyền truy cập vào tệp / thư mục này)",
    "New folder" : "Tạo thư mục",
    "Create new folder" : "Tạo thư mục mới",
    "Upload file" : "Tải lên tập tin",
    "Recent" : "Gần đây",
    "Not favorited" : "‎Không được yêu thích‎",
    "Remove from favorites" : "Xóa khỏi ưa thích",
    "Add to favorites" : "Thêm vào ưa thích",
    "An error occurred while trying to update the tags" : "Đã xảy ra lỗi khi cố gắng cập nhật tags",
    "Added to favorites" : "Đã thêm vào mục yêu thích",
    "Removed from favorites" : "Đã xóa khỏi mục ưa thích",
    "You added {file} to your favorites" : "Bạn đã thêm {file} vào mục ưa thích của bạn",
    "You removed {file} from your favorites" : "Bạn đã xóa {file} khỏi mục ưa thích của mình",
    "Favorites" : "Ưa thích",
    "File changes" : "Tệp thay đổi",
    "Created by {user}" : "Được tạo bởi {user}",
    "Changed by {user}" : "Thay đổi bởi {user}",
    "Deleted by {user}" : "Đã xóa bởi {user}",
    "Restored by {user}" : "Được khôi phục bởi {user}",
    "Renamed by {user}" : "Đã đổi tên bởi {user}",
    "Moved by {user}" : "Đã di chuyển bởi {user}",
    "\"remote user\"" : "\"người dùng từ xa\"",
    "You created {file}" : "Bạn đã tạo {file}",
    "You created an encrypted file in {file}" : "‎Bạn đã tạo một tệp được mã hóa trong {file}‎",
    "{user} created {file}" : "{user} đã tạo {file}",
    "{user} created an encrypted file in {file}" : "‎{user} đã tạo một tệp được mã hóa trong {file}‎",
    "{file} was created in a public folder" : "{file} đã được tạo trong một thư mục công khai",
    "You changed {file}" : "Bạn đã thay đổi {file}",
    "You changed an encrypted file in {file}" : "‎Bạn đã thay đổi tệp được mã hóa trong {file}‎",
    "{user} changed {file}" : "{user} đã thay đổi {file}",
    "{user} changed an encrypted file in {file}" : "‎{user} đã thay đổi tệp được mã hóa trong {file}‎",
    "You deleted {file}" : "Bạn đã xóa {file}",
    "You deleted an encrypted file in {file}" : "‎Bạn đã xóa một tệp được mã hóa trong {file}‎",
    "{user} deleted {file}" : "{user} đã xóa {file}",
    "{user} deleted an encrypted file in {file}" : "‎{user} đã xóa một tệp được mã hóa trong {file}‎",
    "You restored {file}" : "Bạn đã khôi phục {file}",
    "{user} restored {file}" : "{user} đã khôi phục {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "‎Bạn đã đổi tên {oldfile} (ẩn) thành {newfile} (ẩn)‎",
    "You renamed {oldfile} (hidden) to {newfile}" : "‎Bạn đã đổi tên {oldfile} (ẩn) thành {newfile}‎",
    "You renamed {oldfile} to {newfile} (hidden)" : "‎Bạn đã đổi tên {oldfile} thành {newfile} (ẩn)‎",
    "You renamed {oldfile} to {newfile}" : "Bạn đã đổi tên {oldfile} thành {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "‎{user} được đổi tên thành {oldfile} (ẩn) thành {newfile} (ẩn)‎",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "‎{user} được đổi tên thành {oldfile} (ẩn) thành {newfile}‎",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "‎{user} được đổi tên thành {oldfile} thành {newfile} (ẩn)‎",
    "{user} renamed {oldfile} to {newfile}" : "{user} đổi tên thành {oldfile} thành {newfile}",
    "You moved {oldfile} to {newfile}" : "Bạn đã chuyển {oldfile} tới {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} đã chuyển {oldfile} tới {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Một tệp đã được thêm hoặc bị xóa khỏi <strong>mục yêu thích của bạn</strong>",
    "A file or folder has been <strong>changed</strong>" : "Tệp hoặc thư mục đã được <strong>thay đổi</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "‎Tệp hoặc thư mục yêu thích đã được ‎<strong>‎thay đổi‎</strong>",
    "Upload (max. %s)" : "Tải lên (tối đa. %s)",
    "Accept" : "Đồng ý",
    "Reject" : "‎Từ chối‎",
    "Incoming ownership transfer from {user}" : "‎Chuyển quyền sở hữu đến từ {user}‎",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "‎Bạn có muốn chấp nhận {path}? ‎\n\n‎Lưu ý: Quá trình chuyển quyền sau khi chấp nhận có thể mất tới 1 ‎‎giờ.‎",
    "Ownership transfer failed" : "‎Chuyển quyền sở hữu không thành công‎",
    "Your ownership transfer of {path} to {user} failed." : "‎Việc chuyển quyền sở hữu {path} sang {user} của bạn đã thất bại.‎",
    "The ownership transfer of {path} from {user} failed." : "‎Việc chuyển quyền sở hữu {path} từ {user} không thành công.‎",
    "Ownership transfer done" : "‎Chuyển quyền sở hữu được thực hiện‎",
    "Your ownership transfer of {path} to {user} has completed." : "‎Việc chuyển quyền sở hữu {path} sang {user} của bạn đã hoàn tất.‎",
    "The ownership transfer of {path} from {user} has completed." : "‎Việc chuyển quyền sở hữu {path} từ {user} đã hoàn tất.‎",
    "in %s" : "trong %s",
    "File Management" : "‎Quản lý tệp‎ tin",
    "Reload current directory" : "Tải lại thư mục hiện tại",
    "Go to the \"{dir}\" directory" : "Đi đến thư mục \"{dir}\"",
    "Drag and drop files here to upload" : "Kéo thả file vào đây để tải lên",
    "Upload successful" : "Tải lên thành công",
    "\"{displayName}\" action executed successfully" : "Hành động \"{displayName}\" đã thực thi thành công",
    "\"{displayName}\" action failed" : "Hành động \"{displayName}\" thất bại",
    "Select the row for {displayName}" : "Chọn hàng cho {displayName}",
    "Rename file" : "Đổi tên tệp tin",
    "File name" : "Tên tệp tin",
    "Folder name" : "Tên thư mục",
    "This node is unavailable" : "Nút này không có sẵn",
    "Download file {name}" : "Tải xuống tệp tin {name}",
    "\"{name}\" is not an allowed filetype." : "\"{name}\" không phải là định dạng được cho phép",
    "{newName} already exists." : "{newName} đã tồn tại.",
    "\"{char}\" is not allowed inside a file name." : "\"{char}\" không được phép bên trong tên tệp.",
    "Name cannot be empty" : "Tên không thể trống",
    "Another entry with the same name already exists" : "Đã tồn tại mục cùng tên",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Đã đổi tên \"{oldName}\" thành \"{newName}\"",
    "Could not rename \"{oldName}\", it does not exist any more" : "Không thể đổi tên \"{oldName}\", tệp tin không còn tồn tại",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Tên \"{newName}\" đã được sử dụng trong thư mục \"{dir}\". Vui lòng chọn một tên khác.",
    "Could not rename \"{oldName}\"" : "Could not rename \"{oldName}\"",
    "A long time ago" : "Một khoảng thời gian trước",
    "Could not copy {file}. {message}" : "Không thể sao chép {tệp}. {tin nhắn}",
    "Could not move {file}. {message}" : "Không thể di chuyển {tệp}. {tin nhắn}",
    "Total rows summary" : "Tóm tắt tổng số hàng",
    "Select all" : "Chọn tất cả",
    "Unselect all" : "Bỏ chọn tất cả",
    "\"{displayName}\" failed on some elements " : "\"{displayName}\" không thành công trên một số thành phần",
    "\"{displayName}\" batch action executed successfully" : "Hành động hàng loạt \"{displayName}\" được thực hiện thành công",
    "Sort list by {column}" : "Sắp xếp danh sách theo {cột}",
    "List of files and folders." : "Danh sách các tập tin và thư mục.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Danh sách này không được hiển thị đầy đủ vì lý do hiệu suất. Các tập tin sẽ được hiển thị khi bạn điều hướng qua danh sách.",
    "{summaryFile} and {summaryFolder}" : "{summaryFile} và {summaryFolder}",
    "File not found" : "Không tìm thấy tập tin",
    "_{count} file_::_{count} files_" : ["{đếm} tệp"],
    "_{count} folder_::_{count} folders_" : ["{đếm} thư mục"],
    "Storage informations" : "Thông tin lưu trữ",
    "{usedQuotaByte} used" : "{usedQuotaByte} đã được sử dụng",
    "{relative}% used" : "{tương đối}% đã sử dụng",
    "Could not refresh storage stats" : "Không thể làm mới số liệu thống kê bộ nhớ",
    "Transfer ownership of a file or folder" : "‎Chuyển quyền sở hữu tệp hoặc thư mục‎",
    "Choose file or folder to transfer" : "‎Chọn tệp hoặc cặp để chuyển‎",
    "Change" : "Chỉnh sửa",
    "New owner" : "‎Chủ sở hữu mới‎",
    "Choose a file or folder to transfer" : "‎Chọn tệp hoặc thư mục cần chuyển‎",
    "Transfer" : "‎Chuyển‎",
    "Transfer {path} to {userid}" : "‎Chuyển {path} sang {userid}‎",
    "Invalid path selected" : "‎Đường dẫn không hợp lệ được chọn‎",
    "Unknown error" : "Lỗi chưa biết",
    "Ownership transfer request sent" : "‎Yêu cầu chuyển quyền sở hữu đã được gửi‎",
    "Cannot transfer ownership of a file or folder you do not own" : "Không thể chuyển quyền sở hữu tệp hoặc thư mục mà bạn không sở hữu",
    "Select file or folder to link to" : "Chọn tập tin hoặc thư mục để liên kết đến",
    "Loading current folder" : "Đang tải thư mục hiện tại",
    "No files in here" : "Không có tệp nào",
    "Upload some content or sync with your devices!" : "Tải lên một số nội dung hoặc đồng bộ với thiết bị của bạn!",
    "Go to the previous folder" : "Chuyển đến thư mục trước đó",
    "Go back" : "Quay lại",
    "Share" : "Chia sẽ",
    "Shared by link" : "Được chia sẻ bởi liên kết",
    "Shared" : "Chia sẻ",
    "Switch to list view" : "Chuyển sang chế độ xem danh sách",
    "Switch to grid view" : "Chuyển sang chế độ xem dạng lưới",
    "Open the files app settings" : "Mở cài đặt ứng dụng tệp",
    "Files settings" : "Cài đặt tệp tin",
    "File cannot be accessed" : "Không thể truy cập tập tin",
    "You might not have have permissions to view it, ask the sender to share it" : "Bạn có thể không có quyền xem nó, hãy yêu cầu người gửi chia sẻ nó",
    "Sort favorites first" : "Sắp xếp mục yêu thích trước",
    "Show hidden files" : "Hiển thị các file ẩn",
    "Crop image previews" : "‎Xén ảnh ‎bản xem trước",
    "Enable the grid view" : "Bật chế độ xem lưới",
    "Additional settings" : "Cài đặt bổ sung",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "Sao chép vào clipboard",
    "Use this address to access your Files via WebDAV" : "Sử dụng địa chỉ này để truy cập Tệp của bạn qua WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Nếu bạn đã bật 2FA, bạn phải tạo và sử dụng mật khẩu ứng dụng mới bằng cách nhấp vào đây.",
    "Clipboard is not available" : "Bảng nhớ tạm không có sẵn",
    "WebDAV URL copied to clipboard" : "Đã sao chép URL WebDAV vào bảng nhớ tạm",
    "Unable to change the favourite state of the file" : "‎Không thể thay đổi trạng thái yêu thích của tệp‎",
    "Error while loading the file data" : "‎Lỗi xảy ra trong khi tải dữ liệu tệp‎",
    "Pick a template for {name}" : "‎Chọn một mẫu cho {name}‎",
    "Create" : "‎Tạo‎",
    "Create a new file with the selected template" : "‎Tạo tệp mới với mẫu đã chọn‎",
    "Creating file" : "‎Tạo tệp‎",
    "Blank" : "‎Trống‎",
    "Unable to create new file from template" : "‎Không thể tạo tệp mới từ mẫu‎",
    "Delete permanently" : "Xoá vĩnh viễn",
    "Destination is not a folder" : "Đích đến không phải là một thư mục",
    "This file/folder is already in that directory" : "Tệp/thư mục này đã có trong thư mục đó",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Bạn không thể di chuyển một tập tin/thư mục vào chính nó hoặc vào một thư mục con của chính nó",
    "A file or folder with that name already exists in this folder" : "Tệp hoặc thư mục có tên đó đã tồn tại trong thư mục này",
    "The files is locked" : "Các tập tin bị khóa",
    "The file does not exist anymore" : "Tập tin không tồn tại nữa",
    "Chose destination" : "Chọn điểm đến",
    "Copy to {target}" : "Copy to {mục tiêu}",
    "Move to {target}" : "Di chuyển đến {mục tiêu}",
    "Cancelled move or copy operation" : "Đã hủy thao tác di chuyển hoặc sao chép",
    "Open folder {displayName}" : "Mở thư mục {displayName}",
    "Open in Files" : "Mở trong Tệp",
    "Open details" : "Mở chi tiết",
    "Create new templates folder" : "Tạo thư mục mẫu mới",
    "Templates" : "‎Mẫu‎",
    "Unable to initialize the templates directory" : "‎Không thể khởi tạo thư mục mẫu‎",
    "Created new folder \"{name}\"" : "Đã tạo thư mục mới \"{name}\"",
    "_{folderCount} folder_::_{folderCount} folders_" : ["thư mục {folderCount}"],
    "_{fileCount} file_::_{fileCount} files_" : ["tệp {fileCount}"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 tệp và thư mục {folderCount}"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["tệp {fileCount} và 1 thư mục"],
    "{fileCount} files and {folderCount} folders" : "Tệp {fileCount} và thư mục {folderCount}",
    "List of favorites files and folders." : "Danh sách các tập tin và thư mục yêu thích.",
    "No favorites yet" : "‎Chưa có yêu thích nào‎",
    "Files and folders you mark as favorite will show up here" : "Các tệp và thư mục mà bạn đánh dấu là yêu thích sẽ hiển thị ở đây",
    "All files" : "Tất cả tệp tin",
    "List of your files and folders." : "Danh sách các tập tin và thư mục của bạn.",
    "List of recently modified files and folders." : "Danh sách các tập tin và thư mục được sửa đổi gần đây.",
    "No recently modified files" : "Không có tập tin được sửa đổi gần đây",
    "Files and folders you recently modified will show up here." : "Các tập tin và thư mục bạn sửa đổi gần đây sẽ hiển thị ở đây.",
    "Toggle %1$s sublist" : "Chuyển đổi danh sách phụ %1$s",
    "No entries found in this folder" : "Chưa có mục nào trong thư mục",
    "Upload too large" : "Tập tin tải lên quá lớn",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Các tập tin bạn đang tải lên vượt quá kích thước tối đa cho phép trên máy chủ .",
    "Text file" : "Tập tin văn bản",
    "New text file.txt" : "‎Tệp văn bản mới.txt‎",
    "Storage invalid" : "Lưu trữ không hợp lệ",
    "You can only favorite a single file or folder at a time" : "‎Bạn chỉ có thể chọn yêu thích một tệp hoặc thư mục duy nhất tại một thời điểm‎",
    "Unlimited" : "Không giới hạn",
    "Search users" : "‎Tìm kiếm người dùng‎",
    "Cancel" : "‎Hủy bỏ‎",
    "Set up templates folder" : "‎Thiết lập thư mục mẫu‎",
    "%s used" : "%s ‎đã sử dụng‎",
    "%s%%" : "%s%%",
    "%1$s of %2$s used" : "%1$s trên %2$s đã sử dụng",
    "Toggle grid view" : "‎Chuyển đổi dạng xem lưới‎",
    "Deleted files" : "Thùng rác",
    "Shares" : "Chia sẻ",
    "Shared with others" : "Chia sẻ với người khác",
    "Shared with you" : "Đã chia sẻ với bạn",
    "Deleted shares" : "‎Chia sẻ đã xóa‎",
    "Pending shares" : "Chia sẻ đang chờ xử lý‎",
    "This file has the tag {tag}" : "Tập tin này có nhãn {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Tệp tin này có nhãn {firstTags} và {lastTag}",
    "Open folder {name}" : "Mở thư mục {name}",
    "ascending" : "tăng dần",
    "descending" : "giảm dần",
    "Sort list by {column} ({direction})" : "Sắp xếp danh sách theo {column} ({direction})",
    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "anh sách này không được hiển thị đầy đủ vì lý do hiệu suất. Các tập tin sẽ được hiển thị khi bạn điều hướng qua danh sách.",
    "Search for an account" : "Tìm kiếm tài khoản",
    "Choose" : "Chọn",
    "No files or folders have been deleted yet" : "Chưa có tập tin hoặc thư mục nào bị xóa"
},
"nplurals=1; plural=0;");
