#personal-show + label {
	left: 230px !important;
	margin-top: 8px !important;
	box-sizing: border-box;
}

#renewpassword .strengthify-wrapper {
	left: 10px;
	margin-top: 65px;
	position: absolute;
	width: 219px;
}

#cancel-container p.info {
	margin-top: 10px;
	text-align: center;
}

#renewpassword .title {
	background-color: transparent;
}

.tooltip {
	position:absolute;
	display:block;
	font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen-Sans, Ubuntu, Cantarell, 'Helvetica Neue', Arial, sans-serif, 'Apple Color Emoji', 'Segoe UI Emoji', 'Segoe UI Symbol';
	font-style:normal;
	font-weight:400;
	letter-spacing:normal;
	line-break:auto;
	line-height:1.6;
	text-align:left;
	text-align:start;
	text-decoration:none;
	text-shadow:none;
	text-transform:none;
	white-space:normal;
	word-break:normal;
	word-spacing:normal;
	word-wrap:normal;
	font-size:12px;
	opacity:0;
	z-index:100000;
	filter:drop-shadow(0 1px 10px rgba(77, 77, 77, 0.75));
}

.tooltip.in {
	opacity:1
}

.tooltip.top {
	margin-top:-3px;
	padding:10px 0
}

.tooltip.bottom {
	margin-top:3px;
	padding:10px 0
}

.tooltip.right {
	margin-left:3px;
	padding:0 10px
}

.tooltip.right .tooltip-arrow {
	top:50%;
	left:0;
	margin-top:-10px;
	border-width:10px 10px 10px 0;
	border-right-color:#fff
}

.tooltip.left {
	margin-left:-3px;
	padding:0 5px
}

.tooltip.left .tooltip-arrow {
	top:50%;
	right:0;
	margin-top:-10px;
	border-width:10px 0 10px 10px;
	border-left-color:#fff
}

.tooltip.top .tooltip-arrow,.tooltip.top-left .tooltip-arrow,.tooltip.top-right .tooltip-arrow {
	bottom:0;
	border-width:10px 10px 0;
	border-top-color:#fff
}

.tooltip.top .tooltip-arrow {
	left:50%;
	margin-left:-10px
}

.tooltip.top-left .tooltip-arrow {
	right:10px;
	margin-bottom:-10px
}

.tooltip.top-right .tooltip-arrow {
	left:10px;
	margin-bottom:-10px
}

.tooltip.bottom .tooltip-arrow,.tooltip.bottom-left .tooltip-arrow,.tooltip.bottom-right .tooltip-arrow {
	top:0;
	border-width:0 10px 10px;
	border-bottom-color:#fff
}

.tooltip.bottom .tooltip-arrow {
	left:50%;
	margin-left:-10px
}

.tooltip.bottom-left .tooltip-arrow {
	right:10px;
	margin-top:-10px
}

.tooltip.bottom-right .tooltip-arrow {
	left:10px;
	margin-top:-10px
}

.tooltip-inner {
	max-width:350px;
	padding:5px 8px !important;
	background-color:#fff;
	color:#000 !important;
	text-align:center !important;
	font-weight:normal !important;
	border-radius:3px
}

.tooltip-arrow {
	position:absolute;
	width:0;
	height:0;
	border-color:transparent;
	border-style:solid
}
