OC.L10N.register(
    "twofactor_totp",
    {
    "Authenticate with a TOTP app" : "ตรวจสอบสิทธิ์ด้วยแอป TOTP",
    "Enable TOTP" : "เปิดใช้งาน TOTP",
    "Verify" : "ยืนยัน",
    "Submit" : "ส่ง"
},
"nplurals=1; plural=0;");
