OC.L10N.register(
    "password_policy",
    {
    "Unknown error" : "Bəlli olmayan səhv baş verdi",
    "Settings saved" : "Parametrlər yaddaşa verildi",
    "Saved" : "Saxlanıldı"
},
"nplurals=2; plural=(n != 1);");
