<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  88232 => 'Maritime Communications Partner (MCP)',
  88233 => 'Oration Technologies',
  882342 => 'BebbiCell AG',
  882347 => 'BebbiCell AG',
  88237 => 'AT&T Cingular Wireless Network',
  88249 => 'Monaco Telecom',
  88250 => 'Phonegroup',
);
