OC.L10N.register(
    "activity",
    {
    "Copied!" : "Копирано!",
    "Not supported!" : "Није подржано!",
    "Press ⌘-C to copy." : "Притисни ⌘-C за копирање.",
    "Press Ctrl-C to copy." : "Притисни Ctrl-C за копирање.",
    "{name} (invisible)" : "{name} (невидљиво) ",
    "{name} (restricted)" : "{name} (ограничено)",
    "Home" : "Почетна",
    "in {path}" : "у {path}",
    "This stream will show events like additions, changes & shares" : "Овде ће се приказати догађаји попут додавања, измена или дељења",
    "There are no events for this filter" : "Нема догађаја за овај филтер",
    "Today" : "данас",
    "Yesterday" : "јуче",
    "Open {filename}" : "Отвори `{filename}",
    "Activity" : "Активност",
    "Personal activity feed for %s" : "Довод личних активности корисника %s",
    "Your feed URL is invalid" : "УРЛ вашег довода није исправан",
    "Your settings have been updated." : "Ваше поставке су ажуриране.",
    "Settings have been updated." : "Поставке су ажуриране.",
    "Recent activity" : "Скорашње активности",
    "No activities" : "Нема активности",
    "More activities" : "Још активности",
    "Daily activity summary for %s" : "Извештај дневних активности за %s",
    "_and %n more _::_and %n more _" : ["и још %n","и још %n","и још %n"],
    "All activities" : "Све активности",
    "By others" : "туђе",
    "By you" : "ваше",
    "Activity at %s" : "Активност у %s",
    "Hello %s" : "Здраво %s",
    "Hello %s," : "Здраво %s,",
    "There was some activity at %s" : "Било је активности у %s ",
    "Mail" : "поштом",
    "Push" : "Гурај",
    "Notifications" : "Обавештења",
    "This application enables people to view a log of activities about them, their files or other data." : "Ова апликација омогућава људима да погледају дневник активности у вези са њима, своје фајлове, или остале податке.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Ова апликација омогућава људима да погледају акције у вези са њиховим фајловима и подацима у Nextcloud.\n\t\tСвака особа може да конфигурише подешавања за индивидуалне активности у личним подешавањима,\n\t\tзда изабере које активности би требало да се проследе на мобилне телефоне, пошаљу е-поштом\n\t\tили да ли се дневни извештај шаље свако јутро.\n\t\tВише информација се налази у документацији апликације Activity.",
    "Activity notification configuration" : "Подешавање обавештења о активностима",
    "Send email" : "Пошаљи е-пошту",
    "Send push notification" : "Слање брзих обавештења",
    "You need to set up your email address before you can receive notification emails." : "Морате поставити адресу е-поште пре почетка пријема обавештења.",
    "Send activity emails" : "Шаљи е-пошту са активностима",
    "As soon as possible" : "Што је пре могуће",
    "Hourly" : "сваки сат",
    "Daily" : "дневно",
    "Weekly" : "недељно",
    "No activity yet" : "Још нема активности",
    "Unable to load the activity list" : "Учитавање листе активности није било успешно",
    "Notification" : "Обавештење",
    "Enable notification emails" : "Укључи обавештења е-поштом",
    "Choose for which activities you want to get an email or push notification." : "Одаберите за које активности желите да добијате е-пошту или брза обавештења.",
    "Choose for which activities you want to get a push notification." : "Одаберите за које активности желите да добијате брза обавештења.",
    "Daily activity summary" : "Извештај дневних активности",
    "Send daily activity summary in the morning" : "Шаљи сумарни извештај дневних активности изјутра",
    "Default settings" : "Подразумеване поставке",
    "Configure the default notification settings for new accounts." : "Подешавање подразумеваних поставки обавештења за нове налоге.",
    "Unable to save the settings" : "Чување поставки није успело.",
    "Activity feed" : "Довод активности",
    "Activity settings" : "Подешавања активности",
    "Enable RSS feed" : "Укључи РСС довод",
    "RSS feed" : "РСС довод",
    "Copy RSS feed link" : "Копирај линк RSS вести",
    "Personal notification settings" : "Подешавања личних обавештења",
    "No more events to load" : "Нема више догађаја за приказ",
    "This application enables users to view a log of activities about them or about files." : "Ова апликација омогућава корисницима да погледају дневник активности у вези са њима и фајловима.",
    "This application enables users to view actions related to their files in Nextcloud.\n\t\tOnce enabled, users will see a new icon “Activity” in their apps menu.\n\t\tWhen clicked, a new page appears for users to track the activity related to files – from new files, to deleted files, move, rename, updates and shared activity.\n\t\tThe user can configure their individual activity settings in their personal menu.\n\t\tThis sets the type of activity to record, as well as whether to the user sees their own activities,\n\t\twhether these are only available online, and whether they get an email digest on a regular basis.\n\t\tMore information is available in the Activity documentation." : "Ова апликација омогућава корисницима да виде радње везане за њихове Некстклауд фајлове.\n\t\tКада се укључи, корисници ће видети нову иконицу \"Активности\" у главном менију.\n\t\tКада се она кликне, појављује се нова страна где корисник прати активности везане за фајлове – од нових фајлова, до брисања фајлова, премештања, преименовања, ажурирања и радњи дељења.\n\t\tКорисник може подесити појединачне поставке активности у личном менију.\n\t\tОвим се подешава које се активности бележе и да ли корисник види сопствене активности,\n\t\tда ли су активности доступне само на интернету и да ли се редовно добија е-пошта са сажетком.\n\t\tВише информација је доступно у документацији за Активности.",
    "Activities" : "Активности",
    "Configure the default notification settings for new users." : "Подеси подразумеване поставке обавештавања за нове кориснике."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
