OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Xubióse'l ficheru",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El ficheru xubíu supera la direutiva «upload_max_filesize» del ficheru php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El ficheru xubíu supera la direutiva «MAX_FILE_SIZE» que s'especificó nel formulariu HTML",
    "The file was only partially uploaded" : "El ficheru xubióse parcialmente",
    "No file was uploaded" : "Nun se xubió nengún ficheru",
    "Saving …" : "Guardando…",
    "Keyboard shortcuts" : "Atayos del tecláu",
    "Info" : "Información",
    "Show rich workspaces" : "Amosar espacios de trabayu arriquecíos",
    "Source language" : "Llingua d'orixe",
    "Target language" : "Llingua de destín"
},
"nplurals=2; plural=(n != 1);");
