OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Dashboard",
    "Dashboard app" : "App Dashboard",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an overview of your upcoming appointments, urgent emails, chat messages, incoming tickets, latest tweets and much more! Users can add the widgets they like and change the background to their liking." : "Inicie su día informado\n\nEl tablero de Nextcloud es el punto de partida de su día, ¡dándole una vista general de sus citas cercanas, correos electrónicos urgentes, mensajes de chat, próximos tickets, últimos tweets y mucho más!. Los usuarios podrán agregar los widgets que deseen y cambiar el fondo a gusto.",
    "\"{title} icon\"" : "\"icono {title}\"",
    "Customize" : "Personalizar",
    "Edit widgets" : "Editar widgets",
    "Get more widgets from the App Store" : "Conseguir más widgets desde la tienda de Apps",
    "Weather service" : "Servicio metereológico",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Por privacidad, los datos meteorológicos son solicitados por tu servidor Nextcloud en tu nombre de tal forma que el servicio no recibe información personal.",
    "Weather data from Met.no" : "Datos meteorológicos de Met.no",
    "geocoding with Nominatim" : "geocoding con Nominatim",
    "elevation data from OpenTopoData" : "datos de elevación de OpenTopoData",
    "Weather" : "El tiempo",
    "Status" : "Estado",
    "Good morning" : "Buenos días",
    "Good morning, {name}" : "Buenos días, {name}",
    "Good afternoon" : "Buenas tardes",
    "Good afternoon, {name}" : "Buenas tardes, {name}",
    "Good evening" : "Buenas tardes",
    "Good evening, {name}" : "Buenas tardes, {name}",
    "Hello" : "Hola",
    "Hello, {name}" : "Hola, {name}",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Comienza tu día informado\n\nEl Dashboard de Nextcloud es tu punto de partida del día, dándote un\nresumen de tus próximas citas, emails urgentes, mensajes de chat,\npróximos tickets, últimos tweets y mucho más! Los usuarios pueden agregr widgets\nque le gusten y cambiar el fondo a su gusto."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
