<?php
namespace Aws\Inspector2\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Inspector2** service.
 */
class Inspector2Exception extends AwsException {}
