<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  2431 => 'Kinshasa',
  2432 => 'Katanga',
  2433 => 'Bas-Congo/Bandundu',
  2434 => 'Kasai-Oriental/Kasai-Occidental',
  2435 => 'Province Orientale (Kisanga/Mbandaka)',
  2436 => 'Nord-Kivu/Sud-Kivu/Maniema',
);
