OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "No es pot escriure en la carpeta «config»!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Això normalment es pot solucionar donant al servidor web accés d'escriptura a la carpeta de configuració.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "O bé, si preferiu mantenir el fitxer config.php només de lectura, establir l'opció «config_is_read_only» com a «true».",
    "See %s" : "Consulteu %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Falta l'aplicació %1$s o té una versió no compatible amb aquest servidor. Comproveu la carpeta d'aplicacions.",
    "Sample configuration detected" : "S'ha detectat una configuració d'exemple",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "S'ha detectat que s'ha copiat la configuració d'exemple. Això no s'admet i pot malmetre la instal·lació. Llegiu la documentació abans d'aplicar cap canvi al fitxer config.php",
    "The page could not be found on the server." : "No s'ha pogut trobar la pàgina en el servidor.",
    "%s email verification" : "Verificació de l'adreça electrònica del %s",
    "Email verification" : "Verificació de l'adreça electrònica",
    "Click the following button to confirm your email." : "Feu clic en el botó següent per a confirmar la vostra adreça electrònica.",
    "Click the following link to confirm your email." : "Feu clic en l'enllaç següent per a confirmar la vostra adreça electrònica.",
    "Confirm your email" : "Confirma l'adreça electrònica",
    "Other activities" : "Altres activitats",
    "%1$s and %2$s" : "%1$s i %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s i %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s i %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s i %5$s",
    "Education Edition" : "Edició educativa",
    "Enterprise bundle" : "Paquet empresarial",
    "Groupware bundle" : "Paquet de treball en grup",
    "Hub bundle" : "Paquet Hub",
    "Social sharing bundle" : "Paquet social",
    "PHP %s or higher is required." : "Cal el PHP %s o superior.",
    "PHP with a version lower than %s is required." : "Cal el PHP amb una versió inferior a la %s.",
    "%sbit or higher PHP required." : "Cal el PHP de %s bits o superior.",
    "The following architectures are supported: %s" : "S'admeten les arquitectures següents: %s",
    "The following databases are supported: %s" : "S'admeten les bases de dades següents: %s",
    "The command line tool %s could not be found" : "No s'ha trobat l'eina de línia d'ordres %s",
    "The library %s is not available." : "La biblioteca %s no està disponible.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Cal la biblioteca %1$s amb una versió superior a la %2$s; la versió disponible és la %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Cal la biblioteca %1$s amb una versió inferior a la %2$s; la versió disponible és la %3$s.",
    "The following platforms are supported: %s" : "S'admeten les plataformes següents: %s",
    "Server version %s or higher is required." : "Cal la versió del servidor %s o superior.",
    "Server version %s or lower is required." : "Cal una versió del servidor %s o inferior.",
    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "L'usuari que ha iniciat la sessió ha de ser administrador, subadministrador o tenir un dret especial per a accedir a aquest paràmetre",
    "Logged in user must be an admin or sub admin" : "L'usuari que ha iniciat la sessió ha de ser administrador o subadministrador",
    "Logged in user must be an admin" : "L'usuari que ha iniciat la sessió ha de ser administrador",
    "Wiping of device %s has started" : "S'ha començat a esborrar el dispositiu %s",
    "Wiping of device »%s« has started" : "S'ha començat a esborrar el dispositiu «%s»",
    "»%s« started remote wipe" : "«%s» ha començat a esborrar dades en remot",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "El dispositiu o aplicació «%s» ha començat a esborrar les dades en remot. Rebreu un altre correu quan s'enllesteixi el procés.",
    "Wiping of device %s has finished" : "S'ha acabat d'esborrar el dispositiu %s",
    "Wiping of device »%s« has finished" : "S'ha acabat d'esborrar el dispositiu «%s»",
    "»%s« finished remote wipe" : "«%s» ha acabat d'esborrar dades en remot",
    "Device or application »%s« has finished the remote wipe process." : "El dispositiu o aplicació «%s» ha acabat d'esborrar les dades en remot.",
    "Remote wipe started" : "S'ha començat a esborrar en remot",
    "A remote wipe was started on device %s" : "S'han començat a esborrar les dades del dispositiu %s en remot",
    "Remote wipe finished" : "S'han acabat d'esborrar les dades en remot",
    "The remote wipe on %s has finished" : "S'han acabat d'esborrar les dades del dispositiu %s en remot",
    "Authentication" : "Autenticació",
    "Unknown filetype" : "Tipus de fitxer desconegut",
    "Invalid image" : "Imatge no vàlida",
    "Avatar image is not square" : "La imatge de l'avatar no és quadrada",
    "Files" : "Fitxers",
    "View profile" : "Visualitza el perfil",
    "Local time: %s" : "Hora local: %s",
    "today" : "avui",
    "tomorrow" : "demà",
    "yesterday" : "ahir",
    "_in %n day_::_in %n days_" : ["d'aquí a %n dia","d'aquí a %n dies"],
    "_%n day ago_::_%n days ago_" : ["fa %n dia","fa %n dies"],
    "next month" : "el mes vinent",
    "last month" : "el mes passat",
    "_in %n month_::_in %n months_" : ["d'aquí a %n mes","d'aquí a %n mesos"],
    "_%n month ago_::_%n months ago_" : ["fa %n mes","fa %n mesos"],
    "next year" : "l'any vinent",
    "last year" : "l'any passat",
    "_in %n year_::_in %n years_" : ["d'aquí a %n any","d'aquí a %n anys"],
    "_%n year ago_::_%n years ago_" : ["fa %n any","fa %n anys"],
    "_in %n hour_::_in %n hours_" : ["d'aquí a %n hora","d'aquí a %n hores"],
    "_%n hour ago_::_%n hours ago_" : ["fa %n hora","fa %n hores"],
    "_in %n minute_::_in %n minutes_" : ["d'aquí a %n minut","d'aquí a %n minuts"],
    "_%n minute ago_::_%n minutes ago_" : ["fa %n minut","fa %n minuts"],
    "in a few seconds" : "d'aquí a uns segons",
    "seconds ago" : "fa uns segons",
    "Empty file" : "Fitxer buit",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "El mòdul amb l'ID %s no existeix. Habiliteu-lo els paràmetres de les aplicacions o contacteu amb l'administrador.",
    "File already exists" : "El fitxer ja existeix",
    "Invalid path" : "El camí no és vàlid",
    "Failed to create file from template" : "No s'ha pogut crear el fitxer a partir de la plantilla",
    "Templates" : "Plantilles",
    "File name is a reserved word" : "El nom del fitxer és una paraula reservada",
    "File name contains at least one invalid character" : "El nom del fitxer conté almenys un caràcter no vàlid",
    "File name is too long" : "El nom del fitxer és massa llarg",
    "Dot files are not allowed" : "No es permeten els fitxers que comencen per un punt",
    "Empty filename is not allowed" : "No es permeten els noms de fitxers buits",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "L'aplicació «%s» no es pot instal·lar perquè no es pot llegir el fitxer appinfo.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "L'aplicació «%s» no es pot instal·lar perquè no és compatible amb aquesta versió del servidor.",
    "__language_name__" : "Català",
    "This is an automatically sent email, please do not reply." : "Això és un correu electrònic enviat automàticament, no el respongueu.",
    "Help" : "Ajuda",
    "Appearance and accessibility" : "Aspecte i accessibilitat",
    "Apps" : "Aplicacions",
    "Personal settings" : "Paràmetres personals",
    "Administration settings" : "Paràmetres d'administració",
    "Settings" : "Paràmetres",
    "Log out" : "Tanca la sessió",
    "Users" : "Usuaris",
    "Email" : "Adreça electrònica",
    "Mail %s" : "Envia un correu a %s",
    "Fediverse" : "Fedivers",
    "View %s on the fediverse" : "Visualitza %s en el fedivers",
    "Phone" : "Telèfon",
    "Call %s" : "Truca a %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Visualitza %s a Twitter",
    "Website" : "Lloc web",
    "Visit %s" : "Visita %s",
    "Address" : "Adreça",
    "Profile picture" : "Foto de perfil",
    "About" : "Quant a",
    "Display name" : "Nom de visualització",
    "Headline" : "Capçalera",
    "Organisation" : "Organització",
    "Role" : "Càrrec",
    "Unknown user" : "Usuari desconegut",
    "Additional settings" : "Paràmetres addicionals",
    "Enter the database username and name for %s" : "Introduïu el nom d'usuari i el nom de la base de dades per a %s",
    "Enter the database username for %s" : "Introduïu el nom d'usuari de la base de dades per a %s",
    "Enter the database name for %s" : "Introduïu el nom de la base de dades per a %s",
    "You cannot use dots in the database name %s" : "No podeu utilitzar punts en el nom de la base de dades %s",
    "MySQL username and/or password not valid" : "El nom d'usuari o la contrasenya del MySQL no són vàlids",
    "You need to enter details of an existing account." : "Heu d'introduir els detalls d'un compte existent.",
    "Oracle connection could not be established" : "No s'ha pogut establir la connexió amb Oracle",
    "Oracle username and/or password not valid" : "El nom d'usuari o la contrasenya d'Oracle no són vàlids",
    "PostgreSQL username and/or password not valid" : "El nom d'usuari o la contrasenya del PostgreSQL no són vàlids",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "El Mac OS X no s'admet i el %s no funcionarà correctament en aquesta plataforma. Utilitzeu-lo sota el vostre propi risc! ",
    "For the best results, please consider using a GNU/Linux server instead." : "Per a obtenir els millors resultats, considereu la possibilitat d'utilitzar un servidor amb GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Sembla que aquesta instància del %s s'està executant en un entorn del PHP de 32 bits i que s'ha configurat open_basedir en el fitxer php.ini. Això comportarà problemes amb els fitxers de més de 4 GB i és molt poc recomanable.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Suprimiu el paràmetre open_basedir del fitxer php.ini o canvieu al PHP de 64 bits.",
    "Set an admin username." : "Definiu un nom d'usuari per a l'administrador.",
    "Set an admin password." : "Definiu una contrasenya per a l'administrador.",
    "Cannot create or write into the data directory %s" : "No es pot crear la carpeta de dades %s ni escriure-hi",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El rerefons d'ús compartit %s ha d'implementar la interfície OCP\\Share_Backend",
    "Sharing backend %s not found" : "No s'ha trobat el rerefons d'ús compartit %s",
    "Sharing backend for %s not found" : "No s'ha trobat el rerefons d'ús compartit per a %s",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s ha compartit «%2$s» amb vós i vol afegir:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s ha compartit «%2$s» amb vós i vol afegir",
    "»%s« added a note to a file shared with you" : "%s ha afegit una nota a un fitxer compartit amb vós",
    "Open »%s«" : "Obre «%s»",
    "%1$s via %2$s" : "%1$s mitjançant %2$s",
    "You are not allowed to share %s" : "No podeu compartir %s",
    "Cannot increase permissions of %s" : "No es poden augmentar els permisos de %s",
    "Files cannot be shared with delete permissions" : "No es poden compartir fitxers amb permisos de supressió",
    "Files cannot be shared with create permissions" : "No es poden compartir fitxers amb permisos de creació",
    "Expiration date is in the past" : "La data de caducitat ja ha passat",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["No es pot establir la data de caducitat més d'%n dia en el futur","No es pot establir la data de caducitat més de %n dies en el futur"],
    "Sharing is only allowed with group members" : "Només es permet l'ús compartit amb membres del grup",
    "Sharing %s failed, because this item is already shared with user %s" : "No s'ha pogut compartir %s perquè l'element ja està compartit amb l'usuari %s",
    "%1$s shared »%2$s« with you" : "%1$s ha compartit «%2$s» amb vós",
    "%1$s shared »%2$s« with you." : "%1$s ha compartit «%2$s» amb vós.",
    "Click the button below to open it." : "Feu clic en el botó següent per a obrir-ho.",
    "The requested share does not exist anymore" : "L'element compartit sol·licitat ja no existeix",
    "The requested share comes from a disabled user" : "L'element compartit sol·licitat prové d'un usuari inhabilitat",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "No s'ha creat l'usuari perquè s'ha assolit el límit d'usuaris. Consulteu les notificacions per a obtenir més informació.",
    "Could not find category \"%s\"" : "No s'ha trobat la categoria «%s»",
    "Sunday" : "Diumenge",
    "Monday" : "Dilluns",
    "Tuesday" : "Dimarts",
    "Wednesday" : "Dimecres",
    "Thursday" : "Dijous",
    "Friday" : "Divendres",
    "Saturday" : "Dissabte",
    "Sun." : "Dg.",
    "Mon." : "Dl.",
    "Tue." : "Dt.",
    "Wed." : "Dc.",
    "Thu." : "Dj.",
    "Fri." : "Dv.",
    "Sat." : "Ds.",
    "Su" : "Dg",
    "Mo" : "Dl",
    "Tu" : "Dt",
    "We" : "Dc",
    "Th" : "Dj",
    "Fr" : "Dv",
    "Sa" : "Ds",
    "January" : "Gener",
    "February" : "Febrer",
    "March" : "Març",
    "April" : "Abril",
    "May" : "Maig",
    "June" : "Juny",
    "July" : "Juliol",
    "August" : "Agost",
    "September" : "Setembre",
    "October" : "Octubre",
    "November" : "Novembre",
    "December" : "Desembre",
    "Jan." : "Gen.",
    "Feb." : "Febr.",
    "Mar." : "Mar.",
    "Apr." : "Abr.",
    "May." : "Mai.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Ag.",
    "Sep." : "Set.",
    "Oct." : "Oct.",
    "Nov." : "Nov.",
    "Dec." : "Des.",
    "A valid password must be provided" : "Heu de proporcionar una contrasenya vàlida",
    "The username is already being used" : "El nom d'usuari ja està en ús",
    "Could not create user" : "No s'ha pogut crear l'usuari",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Només es permeten els caràcters següents en un nom d'usuari: «a-z», «A-Z», «0-9», espais i «_.@-'»",
    "A valid username must be provided" : "Heu de proporcionar un nom d'usuari vàlid",
    "Username contains whitespace at the beginning or at the end" : "El nom d'usuari conté espais en blanc al principi o al final",
    "Username must not consist of dots only" : "El nom d'usuari no pot estar format només per punts",
    "Username is invalid because files already exist for this user" : "El nom d'usuari no és vàlid perquè ja existeixen fitxers per a aquest usuari",
    "User disabled" : "Usuari inhabilitat",
    "Login canceled by app" : "L'aplicació ha cancel·lat l'inici de sessió",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "L'aplicació «%1$s» no es pot instal·lar perquè no es compleixen les dependències següents: %2$s",
    "a safe home for all your data" : "Un lloc segur per a totes les vostres dades",
    "File is currently busy, please try again later" : "El fitxer està ocupat actualment; torneu-ho a provar més tard",
    "Cannot download file" : "No es pot baixar el fitxer",
    "Application is not enabled" : "L'aplicació no està habilitada",
    "Authentication error" : "Error d'autenticació",
    "Token expired. Please reload page." : "El testimoni ha caducat. Torneu a carregar la pàgina.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "No s'ha instal·lat cap controlador de bases de dades (sqlite, mysql o postgresql).",
    "Cannot write into \"config\" directory." : "No es pot escriure en la carpeta «config».",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Això normalment es pot solucionar donant al servidor web accés d'escriptura a la carpeta de configuració. Consulteu %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "O bé, si preferiu mantenir el fitxer config.php només de lectura, establir l'opció «config_is_read_only» com a «true». Consulteu %s",
    "Cannot write into \"apps\" directory." : "No es pot escriure en la carpeta «apps».",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Això normalment pot solucionar donant al servidor web accés d'escriptura a la carpeta d'aplicacions o inhabilitant la botiga d'aplicacions en el fitxer de configuració.",
    "Cannot create \"data\" directory." : "No es pot crear la carpeta «data».",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Això normalment es pot solucionar donant accés d'escriptura al servidor web a la carpeta arrel. Consulteu %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Els permisos normalment es poden corregir donant accés d'escriptura al servidor web a la carpeta arrel. Consulteu %s.",
    "Your data directory is not writable." : "No es pot escriure en la carpeta de dades.",
    "Setting locale to %s failed." : "No s'ha pogut establir la configuració regional %s.",
    "Please install one of these locales on your system and restart your web server." : "Instal·leu una d'aquestes configuracions regionals en el sistema i reinicieu el servidor web.",
    "PHP module %s not installed." : "El mòdul del PHP %s no està instal·lat.",
    "Please ask your server administrator to install the module." : "Demaneu a l'administrador del sistema que instal·li el mòdul.",
    "PHP setting \"%s\" is not set to \"%s\"." : "El paràmetre del PHP «%s» no està establert en «%s».",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Si ajusteu aquest paràmetre en el fitxer php.ini, el Nextcloud tornarà a funcionar",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> té el valor <code>%s</code> en comptes del valor esperat <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Per a resoldre aquest problema, establiu <code>mbstring.func_overload</code> en <code>0</code> en el fitxer php.ini.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Sembla que el PHP està configurat per a suprimir els blocs de documentació entre línies. Això farà que diverses aplicacions principals no siguin accessibles.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Això probablement és provocat per un mecanisme de memòria cau o accelerador com Zend OPcache o eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "S'han instal·lat mòduls del PHP, però encara apareixen com si no hi fossin?",
    "Please ask your server administrator to restart the web server." : "Demaneu a l'administrador que reiniciï el servidor web.",
    "The required %s config variable is not configured in the config.php file." : "No s'ha configurat la variable obligatòria %s en el fitxer config.php.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Demaneu a l'administrador del servidor que comprovi la configuració del Nextcloud.",
    "Your data directory is readable by other users." : "Els altres usuaris poden llegir la carpeta de dades.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Canvieu els permisos a 0770 perquè els altres usuaris no puguin veure el contingut de la carpeta.",
    "Your data directory must be an absolute path." : "La carpeta de dades ha de ser un camí absolut.",
    "Check the value of \"datadirectory\" in your configuration." : "Comproveu el valor de «datadirectory» en la configuració.",
    "Your data directory is invalid." : "La carpeta de dades no és vàlida.",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Assegureu-vos que hi hagi un fitxer anomenat «.ocdata» en l'arrel de la carpeta de dades.",
    "Action \"%s\" not supported or implemented." : "L'acció «%s» no està admesa o implementada.",
    "Authentication failed, wrong token or provider ID given" : "No s'ha pogut autenticar; s'ha proporcionat un testimoni o un ID de proveïdor incorrecte",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Falten paràmetres per a completar la sol·licitud. Els paràmetres que falten són: «%s»",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "L'ID «%1$s» ja l'utilitza el proveïdor de federació del núvol «%2$s»",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "El proveïdor de federació del núvol amb l'ID «%s» no existeix.",
    "Could not obtain lock type %d on \"%s\"." : "No s'ha pogut obtenir el tipus de blocatge %d a «%s».",
    "Storage unauthorized. %s" : "L'emmagatzematge no està autoritzat. %s",
    "Storage incomplete configuration. %s" : "La configuració de l'emmagatzematge està incompleta. %s",
    "Storage connection error. %s" : "S'ha produït un error de connexió amb l'emmagatzematge. %s",
    "Storage is temporarily not available" : "L'emmagatzematge no està disponible temporalment",
    "Storage connection timeout. %s" : "S'ha superat el temps d'espera de la connexió d'emmagatzematge. %s",
    "Free prompt" : "Sol·licitud lliure",
    "Runs an arbitrary prompt through the language model." : "Executa una sol·licitud arbitrària mitjançant el model de llengua.",
    "Generate headline" : "Genera un titular",
    "Generates a possible headline for a text." : "Genera un titular possible per a un text.",
    "Summarize" : "Resumeix",
    "Summarizes text by reducing its length without losing key information." : "Resumeix el text reduint-ne la longitud sense perdre la informació clau.",
    "Extract topics" : "Extreu els temes",
    "Extracts topics from a text and outputs them separated by commas." : "Extreu els temes d'un text i els retorna separats per comes.",
    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Els fitxers de l'aplicació %1$s no s'han substituït correctament. Assegureu-vos que sigui una versió compatible amb el servidor.",
    "Full name" : "Nom complet",
    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "S'ha assolit el límit d'usuaris i no s'ha creat l'usuari. Consulteu les notificacions per a obtenir més informació.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Només es permeten els caràcters següents en un nom d'usuari: «a-z», «A-Z», «0-9» i «_.@-'»",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Cal almenys libxml2 2.7.0. Actualment s'ha instal·lat %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "Per a resoldre aquest problema, actualitzeu la versió de libxml2 i reinicieu el servidor web.",
    "PostgreSQL >= 9 required." : "Cal el PostgreSQL >= 9.",
    "Please upgrade your database version." : "Actualitzeu la versió de la base de dades.",
    "404" : "404"
},
"nplurals=2; plural=(n != 1);");
