OC.L10N.register(
    "related_resources",
    {
    "Calendar" : "Kalenteri",
    "Calendar \"%s\"" : "Kalenteri \"%s\"",
    "Deck" : "Pakka",
    "Deck board \"%s\"" : "Deck-taulu \"%s\"",
    "Files" : "Tiedostot",
    "File \"%s\"" : "Tiedosto \"%s\"",
    "Group Folder" : "Ryhmäkansio",
    "Group Folder \"%s\"" : "Ryhmäkansio \"%s\"",
    "Talk conversation" : "Talk-keskustelu",
    "Conversation with %s" : "Keskustelu käyttäjän %s kanssa",
    "Talk" : "Talk",
    "Talk conversation \"%s\"" : "Keskustelu \"%s\"",
    "Related Resources" : "Liittyvät resurssit",
    "Displays resources related to current item in right panel" : "Näyttää nykyiseen kohteeseen liittyvät resurssit oikealla paneelissa",
    "Displays resources related to current item in right panel." : "Näyttää nykyiseen kohteeseen liittyvät resurssit oikealla paneelissa."
},
"nplurals=2; plural=(n != 1);");
