OC.L10N.register(
    "core",
    {
    "Please select a file." : "Veldu skrá.",
    "File is too big" : "Skrá er of stór",
    "The selected file is not an image." : "Valda skráin er ekki mynd.",
    "The selected file cannot be read." : "Ekki hægt að lesa völdu skrána.",
    "The file was uploaded" : "Skráin var send inn",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Innsend skrá er stærri en upload_max stillingin í php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Innsenda skráin er stærri en MAX_FILE_SIZE sem skilgreint er í HTML sniðinu.",
    "The file was only partially uploaded" : "Einungis hluti af innsendri skrá skilaði sér",
    "No file was uploaded" : "Engin skrá skilaði sér",
    "Missing a temporary folder" : "Vantar bráðabirgðamöppu",
    "Could not write file to disk" : "Tókst ekki að skrifa skrá á disk.",
    "A PHP extension stopped the file upload" : "PHP-viðbót stöðvaði innsendingu skráar",
    "Invalid file provided" : "Ógild skrá gefin",
    "No image or file provided" : "Engin mynd eða skrá gefin",
    "Unknown filetype" : "Óþekkt skráartegund",
    "An error occurred. Please contact your admin." : "Villa kom upp. Hafðu samband við kerfisstjóra.",
    "Invalid image" : "Ógild mynd",
    "No temporary profile picture available, try again" : "Engin bráðabirgða-auðkennismynd er tiltæk, reyndu aftur",
    "No crop data provided" : "Enginn gögn um utanskurð gefin",
    "No valid crop data provided" : "Enginn gild gögn um utanskurð gefin",
    "Crop is not square" : "Utanskurður er ekki ferningslaga",
    "State token does not match" : "Stöðuteikn samsvarar ekki",
    "Invalid app password" : "Ógilt lykilorð forrits",
    "Could not complete login" : "Gat ekki lokið innskráningu",
    "Your login token is invalid or has expired" : "Innskráningartákn er ógilt eða útrunnið",
    "Login" : "Innskráning",
    "Password reset is disabled" : "Endurstilling lykilorðs er óvirk",
    "Could not reset password because the token is expired" : "Gat ekki endurstillt lykilorðið vegna þess að teiknið er útrunnið",
    "Could not reset password because the token is invalid" : "Gat ekki endurstillt lykilorðið vegna þess að teiknið er ógilt",
    "%s password reset" : "%s lykilorð endurstillt",
    "Password reset" : "Endurstilling lykilorðs",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Smelltu á eftirfarandi hnapp til að endurstilla lykilorðið þitt. Ef þú hefur ekki beðið um endurstillingu lykilorðs, skaltu hunsa þennan tölvupóst.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Smelltu á eftirfarandi tengil til að endurstilla lykilorðið þitt. Ef þú hefur ekki beðið um endurstillingu lykilorðs, skaltu hunsa þennan tölvupóst.",
    "Reset your password" : "Endurstilltu lykilorðið þitt",
    "Internal error" : "Innri villa",
    "Nextcloud Server" : "Nextcloud þjónn",
    "Some of your link shares have been removed" : "Sumir tenglar þínir á sameignir hafa verið fjarlægðir",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Vegna öryggisgalla hafa sumir tenglar þínir á sameignir hafa verið fjarlægðir. Skoðaðu tengilinn til að sjá frekari upplýsingar.",
    "The user limit of this instance is reached." : "Hámarksfjölda notenda á þessu tilviki er náð.",
    "Learn more ↗" : "Kanna nánar ↗",
    "Preparing update" : "Undirbý uppfærslu",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Þrep viðgerðar:",
    "Repair info:" : "Viðgerðarupplýsingar:",
    "Repair warning:" : "Viðvörun vegna viðgerðar:",
    "Repair error:" : "Villa í viðgerð:",
    "Turned on maintenance mode" : "Kveikt á viðhaldsham",
    "Turned off maintenance mode" : "Slökkt á viðhaldsham",
    "Maintenance mode is kept active" : "Viðhaldsham er haldið virkum",
    "Updating database schema" : "Uppfæri gagnagrunnsskema",
    "Updated database" : "Uppfærði gagnagrunn",
    "Update app \"%s\" from App Store" : "Uppfæra forritið \"%s\" úr App Store hugbúnaðarsafni",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Athuga hvort hægt sé að uppfæra gagnagrunnsskema fyrir %s (þetta getur tekið langan tíma ef gagnagrunnurinn er mjög stór)",
    "Updated \"%1$s\" to %2$s" : "Uppfærði \"%1$s\" í %2$s",
    "Set log level to debug" : "Setja annálsstig á aflúsun",
    "Reset log level" : "Frumstilla annálsstig",
    "Starting code integrity check" : "Ræsi athugun á áreiðanleika kóða",
    "Finished code integrity check" : "Lauk athugun á áreiðanleika kóða",
    "%s (incompatible)" : "%s (ósamhæft)",
    "The following apps have been disabled: %s" : "Eftirfarandi forrit hafa verið gerð óvirk: %s",
    "Already up to date" : "Allt uppfært nú þegar",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Vefþjónninn er ekki enn sett upp á réttan hátt til að leyfa skráasamstillingu því WebDAV viðmótið virðist vera skemmt.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Vefþjónninn þinn er ekki uppsettur þannig að hann geti leyst \"{url}\". Frekari upplýsingar er að finna í {linkstart}hjálparskjölum ↗{linkend} okkar.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Það lítur út eins og að PHP sé ekki rétt sett upp varðandi fyrirspurnir um umhverfisbreytur. Prófun með getenv(\"PATH\") skilar auðu svari.",
    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Endilega skoðaðu {linkstart}hjálparskjöl uppsetningarinnar ↗{linkend} varðandi athugasemdir vegna uppsetningar PHP og sjálfa uppsetningu PHP-þjónsins, sérstaklega ef þú notar php-fpm.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Skrifvarða stillingaskráin hefur verið virkjuð. Þetta kemur í veg fyrir að hægt sé að sýsla með sumar stillingar í gegnum vefviðmótið. Að auki þarf þessi skrá að vera skrifanleg við hverja uppfærslu.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Gagnagrunnurinn keyrir ekki með \"READ COMMITTED\" færsluaðgreiningarstiginu. Þetta getur valdið vandamálum þegar margar aðgerðir eru keyrðar í einu.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "PHP-eininguna \"fileinfo\" vantar. Við mælum eindregið með notkun þessarar einingar til að fá bestu útkomu við greiningu á MIME-skráagerðum.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "Færslulæsing skráa (transactional file locking) er óvirk, þetta gæti leitt til vandamála út frá forgangsskilyrðum (race conditions). Virkjaðu 'filelocking.enabled' í config.php til að forðast slík vandamál. Skoðaðu {linkstart}hjálparskjölin ↗{linkend} til að sjá nánari upplýsingar.",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Ekki var hægt að keyra cron-verkið á skipanalínu. Eftirfarandi tæknilegar villur komu upp:",
    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "Síðasta keyrsla bakgrunnsverks var keyrt {relativeTime}. Eitthvað er ekki eins og það á að sér að vera. {linkstart}Athugaðu stillingar fyrir bakgrunnsvinnslu ↗{linkend}.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Ekkert skyndiminni (cache) hefur verið stillt. Til að auka afköst ættirðu að setja upp skyndiminni (með memcache) ef það er tiltækt. Hægt er að finna nánari upplýsingar um þetta í {linkstart}hjálparskjölum ↗{linkend} okkar.",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Enginn hentugur gagnagjafi fyrir handahófsreikning fannst fyrir PHP, sem er mjög óráðlegt af öryggisástæðum. Hægt er að finna nánari upplýsingar um þetta í {linkstart}hjálparskjölum ↗{linkend} okkar.",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Uppsetning gagnstæðs milliþjónshauss (reverse proxy header) er röng, eða að þú ert að tengjast Nextcloud frá treystum milliþjóni. Ef þú ert ekki að tengjast Nextcloud frá treystum milliþjóni, þá er þetta er öryggisvandamál og getur leyft árásaraðilum að dulbúa IP-vistfang þeirra sem sýnilegt í Nextcloud. Nánari upplýsingar má finna í {linkstart}hjálparskjölum ↗{linkend} okkar.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached er sett upp sem dreift skyndiminni, en hinsvegar er ranga PHP-einingin \"memcache\" uppsett. \\OC\\Memcache\\Memcached styður einungis \"memcached\" en ekki \"memcache\". Skoðaðu {linkstart}memcached wiki-síðurnar um báðar einingarnar ↗{linkend}.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Sumar skrár hafa ekki staðist áreiðanleikaprófun Hægt er að finna nánari upplýsingar um þetta í {linkstart1}hjálparskjölum ↗{linkend} okkar. ({linkstart2}Listi yfir ógildar skrár…{linkend} / {linkstart3}Endurskanna…{linkend})",
    "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "PHP OPcache einingin er ekki rétt uppsett. Frekari upplýsingar má sjá í {linkstart}hjálparskjölunum ↗{linkend}.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP-fallið \"set_time_limit\" er ekki tiltækt. Þetta gæti valdið því að skriftur stöðvist í miðri keyrslu og skemmi uppsetninguna þína. Við mælumst til þess að þetta fall sé gert virkt.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "PHP-uppsetningin er ekki með stuðning við Free Type. Þetta mun valda því að notendamyndir og stillingaviðmót virki ekki.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Vantar vísinn \"{indexName}\" í töflunni \"{tableName}\".",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Gagnagrunninn vantar nokkra atriðavísa (indexes). Vegna þess að það að bæta atriðavísum við stórar töflur getur tekið töluverðan tíma, þá var þeim ekki bætt við sjálfvirkt. Með því að keyra \"occ db:add-missing-indices\" væri hægt að bæta inn þessum atriðavísum sem vantar, á meðan kerfið er í gangi. Um leið og búið er að bæta inn þessum atriðavísum, munu fyrirspurnir í þessar töflur verða miklu hraðvirkari.",
    "Missing primary key on table \"{tableName}\"." : "Vantar aðalvísinn í töflunni \"{tableName}\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Gagnagrunninn vantar nokkra aðallykla (primary keys). Vegna þess að það að bæta aðallyklum við stórar töflur getur tekið töluverðan tíma, þá var þeim ekki bætt við sjálfvirkt. Með því að keyra \"occ db:add-missing-primary-keys\" væri hægt að bæta inn þessum aðallyklum sem vantar, á meðan kerfið er í gangi. Um leið og búið er að bæta inn þessum aðallyklum, munu fyrirspurnir í þessar töflur verða miklu hraðvirkari.",
    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Vantar valkvæða dálkinn \"{columnName}\" í töflunni \"{tableName}\".",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Í þetta kerfistilvik vantar ýmsar PHP-einingar sem mælt er með. Til að bæta afköst og betri samhæfni er mælt eindregið með að setja þær upp.",
    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Í kerfiseininguna php-imagick vantar stuðning við SVG. Til að bæta afköst og betri samhæfni er mælt eindregið með að setja hana upp.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Núna er stuðst við SQLite sem bakenda fyrir gagnagrunn. Fyrir stærri uppsetningar mælum við með að skipta yfir í annan gagnagrunnsbakenda.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Mælt er sérstaklega með þessu þegar skjáborðsforritið er notað til að samstilla skrár.",
    "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "Til að yfirfæra í annan gagnagrunn skaltu nota skipanalínutólið: \"occ db:convert-type\", eða lesa {linkstart}hjálparskjölin ↗ {linkend}.",
    "The PHP memory limit is below the recommended value of 512MB." : "Minnismörk PHP eru lægri en gildið sem mælt er með; 512MB.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Sumar forritamöppur eru í eigu annarra notenda en möppurnar á vefþjóninum. Þetta getur komið upp ef forritin hafa verið sett upp handvirkt. Athugaðu með heimildir á eftirfarandi forritamöppum:",
    "Error occurred while checking server setup" : "Villa kom upp við athugun á uppsetningu þjóns",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Frekari upplýsingar má sjá í {linkstart}hjálparskjölunum ↗{linkend}.",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Gagnamappan og skrárnar þínar eru líklega aðgengilegar öllum af internetinu vegna þess að .htaccess skrá er ekki virk. Við mælum eindregið með að þú stillir vefþjóninn þinn á þann hátt að gagnamappa er ekki lengur aðgengileg eða þú færir gagnamöppu út fyrir skjalarót vefþjóns.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTP-hausinn er ekki stilltur á \"{expected}\". Þetta er möguleg áhætta varðandi  öryggi og gagnaleynd, við mælum með því að laga þessa stillingu.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTP-hausinn er ekki stilltur á \"{expected}\". Einhverjir eiginleikar gætu virkað ekki rétt, við mælum með því að laga þessa stillingu.",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "HTTP-hausinn \"{header}\" er ekki stilltur á \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" eða \"{val5}\" Þetta getur lekið upplýsingum um kerfið. Skoðaðu hvað {linkstart}W3C mælir með ↗{linkend}.",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "\"Strict-Transport-Security\" HTTP-hausinn er ekki stilltur á að minnsta kosti \"{seconds}\" sekúndur. Fyrir aukið öryggi mælum við með því að virkja HSTS eins og lýst er í {linkstart}öryggisleiðbeiningunum ↗ {linkend}.",
    "unknown text" : "óþekktur texti",
    "Hello world!" : "Halló heimur!",
    "sunny" : "sólríkt",
    "Hello {name}, the weather is {weather}" : "Halló {name},veðrið er {weather}",
    "Hello {name}" : "Halló {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Hér eru leitarniðurstöðurnar þínar<script>alert(1)</script></strong>",
    "new" : "nýtt",
    "_download %n file_::_download %n files_" : ["sækja %n skrá","sækja %n skrár"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Uppfærslan er í gangi, ef farið er af þessari síðu gæti það truflað ferlið á sumum kerfum.",
    "Update to {version}" : "Uppfæra í {version}",
    "An error occurred." : "Villa átti sér stað.",
    "Please reload the page." : "Þú ættir að hlaða síðunni aftur inn.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Uppfærslan tókst ekki. Til að fá frekari upplýsingar <a href=\"{url}\">skoðaðu færslu á spjallsvæðinu okkar</a> sem fjallar um þetta mál.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Uppfærslan tókst ekki. Skoðaðu annálana á kerfisstjórnunarsíðunni og sendu inn tilkynningu um vandamálið til <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud samfélagsins</a>.",
    "Continue to {productName}" : "Halda áfram í {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Uppfærslan heppnaðist. Beini þér til {productName} eftir %n sekúndu.","Uppfærslan heppnaðist. Beini þér til {productName} eftir %n sekúndur."],
    "More apps" : "Fleiri forrit",
    "Log in" : "Skrá inn",
    "Logging in …" : "Skrái inn …",
    "Server side authentication failed!" : "Auðkenning af hálfu þjóns tókst ekki!",
    "Please contact your administrator." : "Hafðu samband við kerfisstjóra.",
    "An internal error occurred." : "Innri villa kom upp.",
    "Please try again or contact your administrator." : "Reyndu aftur eða hafðu samband við kerfisstjóra.",
    "Password" : "Lykilorð",
    "Wrong username or password." : "Rangt notandanafn eða lykilorð.",
    "User disabled" : "Notandi óvirkur",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Við urðum vör við margar misheppnaðar innskráningar í röð frá IP-vistfanginu þínu. Þar með verður næsta innskráning tafin (throttled) um 30 sekúndur.",
    "Log in with a device" : "Skrá inn með tæki",
    "Username or email" : "Notandanafn eða tölvupóstur",
    "Your account is not setup for passwordless login." : "Aðgangur þinn er ekki uppsettur með lykilorðalausri innskráningu.",
    "Browser not supported" : "Það er ekki stuðningur við vafrann",
    "Passwordless authentication is not supported in your browser." : "Lykilorðalaus auðkenning er ekki studd í vafranum þínum.",
    "Your connection is not secure" : "Tengingin þín er ekki örugg",
    "Passwordless authentication is only available over a secure connection." : "Lykilorðalaus auðkenning er aðeins tiltæk í gegnum örugga tengingu.",
    "Reset password" : "Endursetja lykilorð",
    "Couldn't send reset email. Please contact your administrator." : "Gat ekki sent endurstillingu í tölvupósti. Hafðu samband við kerfisstjóra.",
    "Password cannot be changed. Please contact your administrator." : "Ekki er hægt að breyta lykilorði. Hafðu samband við kerfisstjóra.",
    "Back to login" : "Til baka í innskráningu",
    "New password" : "Nýtt lykilorð",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Skrárnar þínar eru dulritaðar. Það er engin leið til að fá gögnin þín til baka eftir lykilorðið þitt er endurstillt. Ef þú ert ekki viss hvað eigi að gera, skaltu hafa samband við kerfisstjórann áður en þú heldur áfram. Viltu halda áfram?",
    "I know what I'm doing" : "Ég veit hvað ég er að gera",
    "Resetting password" : "Endurstilli lykilorð",
    "Recommended apps" : "Ráðlögð forrit",
    "Loading apps …" : "Hleð inn forritum …",
    "Could not fetch list of apps from the App Store." : "Gat ekki sótt lista yfir forrit úr App Store.",
    "Installing apps …" : "Set upp forrit …",
    "App download or installation failed" : "Niðurhal eða uppsetning forrits mistókst",
    "Cannot install this app because it is not compatible" : "Ekki er hægt að setja upp forritið því það er ekki samhæft",
    "Cannot install this app" : "Get ekki sett upp þetta forrit",
    "Skip" : "Sleppa",
    "Install recommended apps" : "Setja upp ráðlögð forrit",
    "Schedule work & meetings, synced with all your devices." : "Áætlun vinnu og stefnumóta, samstillt við öll tækin þín.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Hafðu samstarfsfólk og vini á einum stað án þess að leka einkaupplýsingum þeirra.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Einfalt og stílhreint tölvupóstforrit sem virkar með skráaforritinu, tengiliðum og dagatalinu.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Spjall, myndfundir, skjádeiling, netfundir og vefráðstefnur – í vafranum þínum og með farsímaforritum.",
    "Search contacts …" : "Leita í tengiliðum ",
    "Could not load your contacts" : "Gat ekki hlaðið inn tengiliðalistanum þínum",
    "No contacts found" : "Engir tengiliðir fundust",
    "Show all contacts …" : "Birta alla tengiliði ...",
    "Install the Contacts app" : "Setja upp tengiliðaforritið",
    "Loading your contacts …" : "Hleð inn tengiliðalistum ...",
    "Looking for {term} …" : "Leita að {term} …",
    "Forgot password?" : "Gleymdirðu lykilorði?",
    "Back" : "Til baka",
    "Login form is disabled." : "Innskráningarform er óvirkt.",
    "Edit Profile" : "Breyta sniði",
    "You have not added any info yet" : "Þú hefur ekki bætt við neinum upplýsingum ennþá",
    "{user} has not added any info yet" : "{user} hefur ekki bætt við neinum upplýsingum ennþá",
    "Reset search" : "Núllstilla leit",
    "Start search" : "Byrja að leita",
    "Search for {name} only" : "Leita einungis að {name}",
    "Start typing to search" : "Skrifaðu hér til að leita",
    "Loading more results …" : "Hleð inn fleiri niðurstöðum …",
    "Load more results" : "Hlaða inn fleiri niðurstöðum",
    "Search" : "Leita",
    "No results for {query}" : "Engar niðurstöður fyrir {query}",
    "An error occurred while searching for {type}" : "Villa kom upp við leit að {type}",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Settu inn {minSearchLength} staf eða fleiri til að leita","Settu inn {minSearchLength} stafi eða fleiri til að leita"],
    "Settings menu" : "Stillingavalmynd",
    "Search {types} …" : "Leita að {types} …",
    "No" : "Nei",
    "Yes" : "Já",
    "Choose" : "Veldu",
    "Copy" : "Afrita",
    "Move" : "Færa",
    "OK" : "Í lagi",
    "Error loading message template: {error}" : "Villa við að hlaða inn sniðmáti fyrir skilaboð: {error}",
    "read-only" : "skrifvarið",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} árekstur skráa","{count} árekstrar skráa"],
    "One file conflict" : "Einn árekstur skráa",
    "New Files" : "Nýjar skrár",
    "Already existing files" : "Skrá er nú þegar til",
    "Which files do you want to keep?" : "Hvaða skrám vilt þú vilt halda eftir?",
    "If you select both versions, the copied file will have a number added to its name." : "Ef þú velur báðar útgáfur, þá mun verða bætt tölustaf aftan við heiti afrituðu skrárinnar.",
    "Cancel" : "Hætta við",
    "Continue" : "Halda áfram",
    "(all selected)" : "(allt valið)",
    "({count} selected)" : "({count} valið)",
    "Error loading file exists template" : "Villa við að hlaða inn sniðmáti fyrir skrá-er-til",
    "Saving …" : "Vista …",
    "seconds ago" : "sekúndum síðan",
    "Connection to server lost" : "Tenging við miðlara rofnaði",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Vandamál við að hlaða inn síðu, endurhleð eftir %n sekúndu","Vandamál við að hlaða inn síðu, endurhleð eftir %n sekúndur"],
    "Add to a project" : "Bæta við verkefni",
    "Show details" : "Birta nánari upplýsingar",
    "Hide details" : "Fela nánari upplýsingar",
    "Rename project" : "Endurnefna verkefni",
    "Failed to rename the project" : "Mistókst að endurnefna verkefnið",
    "Failed to create a project" : "Mistókst að útbúa verkefni",
    "Failed to add the item to the project" : "Mistókst að bæta atriðinu í verkefnið",
    "Connect items to a project to make them easier to find" : "Að tengja atriði við verkefni gerir auðveldara að finna þau",
    "Type to search for existing projects" : "Skrifaðu hér til að leita að fyrirliggjandi verkefnum",
    "New in" : "Nýtt í",
    "View changelog" : "Skoða breytingaannál",
    "Very weak password" : "Mjög veikt lykilorð",
    "Weak password" : "Veikt lykilorð",
    "So-so password" : "Miðlungs lykilorð",
    "Good password" : "Gott lykilorð",
    "Strong password" : "Sterkt lykilorð",
    "No action available" : "Engin aðgerð tiltæk",
    "Error fetching contact actions" : "Villa við að sækja aðgerðir tengiliða",
    "Non-existing tag #{tag}" : "Merki sem er ekki til #{tag}",
    "Restricted" : "Takmarkað",
    "Invisible" : "Ósýnilegt",
    "Delete" : "Eyða",
    "Rename" : "Endurnefna",
    "Collaborative tags" : "Samstarfsmerkingar",
    "No tags found" : "Engin merki fundust",
    "Personal" : "Einka",
    "Users" : "Notendur",
    "Apps" : "Forrit",
    "Admin" : "Stjórnun",
    "Help" : "Hjálp",
    "Access forbidden" : "Aðgangur bannaður",
    "Profile not found" : "Sniðið finnst ekki",
    "The profile does not exist." : "Sniðið er ekki til.",
    "Back to %s" : "Til baka í %s",
    "Page not found" : "Síða fannst ekki",
    "Too many requests" : "Of margar beiðnir",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Það komu of margar beiðnir frá netkerfinu þínu. Reyndu aftur eða hafðu samband við kerfisstjóra ef þetta er ekki rétt.",
    "Error" : "Villa",
    "Previous" : "Fyrra",
    "Internal Server Error" : "Innri villa",
    "The server was unable to complete your request." : "Þjóninum tókst ekki að afgreiða beiðnina þína.",
    "If this happens again, please send the technical details below to the server administrator." : "Ef þetta gerist aftur, sendu tæknilegu lýsinguna hér fyrir neðan til kerfisstjóra þjónsins.",
    "More details can be found in the server log." : "Nánari upplýsingar er að finna í atburðaskrá (annál) þjónsins.",
    "Technical details" : "Tæknilegar upplýsingar",
    "Remote Address: %s" : "fjartengt vistfang: %s",
    "Request ID: %s" : "Beiðni um auðkenni: %s",
    "Type: %s" : "Tegund: %s",
    "Code: %s" : "Kóði: %s",
    "Message: %s" : "Skilaboð: %s",
    "File: %s" : "Skrá: %s",
    "Line: %s" : "Lína: %s",
    "Trace" : "Rekja",
    "Security warning" : "Öryggisviðvörun",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Gagnamappan og skrárnar eru líklega aðgengilegar af internetinu vegna þess að .htaccess skrá er ekki virk.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Til að fá upplýsingar hvernig á að stilla miðlarann almennilega, skaltu skoða <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">hjálparskjölin</a>.",
    "Create an <strong>admin account</strong>" : "Útbúa <strong>kerfisstjóraaðgang</strong>",
    "Username" : "Notandanafn",
    "Show password" : "Sýna lykilorð",
    "Toggle password visibility" : "Breyta sýnileika lykilorðs",
    "Storage & database" : "Geymsla & gagnagrunnur",
    "Data folder" : "Gagnamappa",
    "Configure the database" : "Stilla gagnagrunninn",
    "Only %s is available." : "Aðeins %s eru laus.",
    "Install and activate additional PHP modules to choose other database types." : "Setja upp og virkja viðbótar PHP-einingar til að geta valið aðrar tegundir gagnagrunna.",
    "For more details check out the documentation." : "Frekari upplýsingar eru í hjálparskjölum.",
    "Database user" : "Notandi gagnagrunns",
    "Database password" : "Lykilorð gagnagrunns",
    "Database name" : "Heiti gagnagrunns",
    "Database tablespace" : "Töflusvæði gagnagrunns",
    "Database host" : "Netþjónn gagnagrunns",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Taktu fram númer gáttar ásamt nafni hýsilvélar (t.d., localhost:5432).",
    "Performance warning" : "Afkastaviðvörun",
    "You chose SQLite as database." : "Þú valdir SQLite sem gagnagrunn.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite ætti aðeins að nota fyrir lágmarksuppsetningar og til prófana. Fyrir stærri uppsetningar mælum við með að velja annan gagnagrunnsbakenda.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ef verið er að nota biðlaraforrit til að samstilla skrár, þá er ekki mælt með notkun SQLite.",
    "Install" : "Setja upp",
    "Installing …" : "Set upp…",
    "Need help?" : "Þarftu hjálp?",
    "See the documentation" : "Sjá hjálparskjölin",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Þetta forrit krefst JavaScript fyrir rétta virkni. {linkstart} virkjaðu JavaScript {linkend} og endurlestu síðan síðuna.",
    "Skip to main content" : "Sleppa og fara í meginefni",
    "Skip to navigation of app" : "Hlaupa yfir í flakk innan forrits",
    "Go to %s" : "Farðu í %s",
    "Get your own free account" : "Fáðu þér eigin ókeypis aðgang",
    "This action requires you to confirm your password" : "Þessi aðgerð krefst þess að þú staðfestir lykilorðið þitt",
    "Confirm your password" : "Staðfestu lykilorðið þitt",
    "Confirm" : "Staðfesta",
    "Connect to your account" : "Tengdu við notandaaðganginn þinn",
    "Please log in before granting %1$s access to your %2$s account." : "Skráðu þig inn áður en þú leyfir %1$s aðgang að %2$s notandaaðgangnum þínum.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ef þú ert ekki að reyna að setja upp nýtt tæki eða forrit, þá er einhver annar að reyna að gabba þig til að gefa þeim aðgang að gögnunum þínum. Ef svo er, skaltu ekki halda áfram í þessu ferli og hafa strax samband við kerfisstjórann þinn.",
    "App token" : "Teikn forrits",
    "Grant access" : "Veita aðgengi",
    "Alternative log in using app token" : "Önnur innskráning með forritsteikni",
    "Account access" : "Aðgangur að notandaaðgangi",
    "Currently logged in as %1$s (%2$s)." : "Í augnablikinu er skráð inn sem %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Þú ert að fara að leyfa \"%1$s\" aðgang að %2$s notandaaðgangnum þínum.",
    "Account connected" : "Aðgangur er tengdur",
    "Your client should now be connected!" : "Biðlaraforritið þitt ætti núna að vera tengt!",
    "You can close this window." : "Þú mátt loka þessum glugga.",
    "This share is password-protected" : "Þessi sameign er varin með lykilorði",
    "The password is wrong or expired. Please try again or request a new one." : "Lykilorðið er rangt eða útrunnið. Prófaðu aftur eða biddu um nýtt lykilorð.",
    "Please type in your email address to request a temporary password" : "Settu inn tölvupóstfangið þitt til að biðja um bráðabirgðalykilorð",
    "Email address" : "Tölvupóstfang",
    "Password sent!" : "Lykilorð sent!",
    "You are not authorized to request a password for this share" : "Þú hefur ekki heimild til að biðja um lykilorð fyrir þessa sameign",
    "Two-factor authentication" : "Tveggja-þrepa auðkenning",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Aukið öryggi var virkjað fyrir aðganginn þinn. Veldu aukaþrep til auðkenningar:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Gat ekki hlaðið inn a.m.k. einni af virkum tveggja-þrepa auðkenningaraðferðunum þínum. Hafðu samband við kerfisstjóra.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Tveggja-þátta auðkenningar er krafist, en er ekki búið að setja upp á aðgangnu þínum. Hafðu samband við kerfisstjóra til að fá aðstoð varðandi þetta.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Tveggja-þátta auðkenningar er krafist, en er ekki búið að setja upp á aðgangnum þínum. Hafðu samband við kerfisstjóra til að fá aðstoð varðandi þetta.",
    "Set up two-factor authentication" : "Setja upp tveggja-þátta auðkenningu",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Tveggja-þátta auðkenningar er krafist, en er ekki búið að setja upp á aðgangnu þínum. Notaðu einn af öryggisafritunarkóðunum þínum til að skrá þig inn, eða hafðu samband við kerfisstjóra til að fá aðstoð varðandi þetta.",
    "Use backup code" : "Nota öryggisafritskóða",
    "Cancel login" : "Hætta við innskráningu",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Aukið öryggi var virkjað fyrir aðganginn þinn. Veldu hvaða auðkenningarveitu eigi að nota til auðkenningar:",
    "Error while validating your second factor" : "Villa við að sannreyna seinna þrepið",
    "Access through untrusted domain" : "Tenging frá ótreystu léni",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Hafðu samband við kerfisstjóra. Ef þú ert stjórnandi, stilltu \"trusted_domains\" setninguna í config/config.php. Dæmi um stillingar má sjá í config/config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Frekari upplýsingar um hvernig hægt er að stilla þetta má finna í %1$shjálparskjölunum%2$s.",
    "App update required" : "App þarfnast uppfærslu ",
    "%1$s will be updated to version %2$s" : "%1$s verður uppfært í útgáfu %2$s.",
    "The following apps will be updated:" : "Eftirfarandi forrit verða uppfærð:",
    "These incompatible apps will be disabled:" : "Eftirfarandi forrit eru ósamhæfð og verið gerð óvirk: %s",
    "The theme %s has been disabled." : "Þema %s hefur verið gert óvirkt.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Gakktu úr skugga um að gagnagrunnurinn, config mappan og gagnamappan hafi verið öryggisafritaðar áður en lengra er haldið.",
    "Start update" : "Hefja uppfærslu",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Til að forðast að falla á tímamörkum með stærri uppsetningar, getur þú í staðinn keyrt eftirfarandi skipun úr uppsetningarmöppunni:",
    "Detailed logs" : "Ítarlegar atvikaskrár",
    "Update needed" : "Þarfnast uppfærslu",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Endilega notaðu uppfærslutólið af skipanalínu, því þú ert með mjög stóra uppsetningu með fleiri en 50 notendum.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Til að fá hjálp er best að skoða fyrst  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">hjálparskjölin</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Ég veit að ef ég held uppfærslunni áfram í gegnum vefviðmótið, þá er sú áhætta fyrir hendi að beiðnin falli á tímamörkum, sem aftur gæti valdið gagnatapi - en ég á öryggisafrit og veit hvernig ég get endurheimt uppsetninguna mína ef aðgerðin misferst.",
    "Upgrade via web on my own risk" : "Uppfæra með vefviðmóti á mína eigin ábyrgð",
    "Maintenance mode" : "Viðhaldshamur",
    "This %s instance is currently in maintenance mode, which may take a while." : "Þessi %s er nú í viðhaldsham, sem getur tekið smá stund.",
    "This page will refresh itself when the instance is available again." : "Þessi síða mun uppfæra sig þegar tilvikið er í boði á ný.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Hafðu samband við kerfisstjóra ef þessi skilaboð eru viðvarandi eða birtust óvænt.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Þessi þjónn er ekki með virka internettengingu: ekki náðis tenging við fjölmarga endapunkta. Þetta þýðir að sumir eiginleikar eins og að virkja ytri gagnageymslu, tilkynningar um uppfærslur eða uppsetningu á forritum þriðja aðila, mun ekki virka. Fjartengdur aðgangur að skrám og sending tilkynninga í tölvupósti virka líklega ekki heldur. Við leggjum til að internettenging sé virkjuð fyrir þennan vefþjón ef þú vilt hafa alla eiginleika tiltæka.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Þú ert að keyra PHP {version}. Við hvetjum þig til að uppfæra PHP útgáfuna til að njóta {linkstart}afkastaaukningar og öryggisuppfærslna frá PHP Group ↗{linkend} um leið og dreifingin þín styður það.",
    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Tengill til að endurstilla lykilorðið þitt hefur verið sendur á tölvupósfang þessa notandaaðgangs. Ef þú færð ekki póstinn, athugaðu þá ruslpóstmöppurnar þínar eða spurðu kerfisstjórann þinn um mögulegar ástæður þess.",
    "If it is not there ask your local administrator." : "Ef hann er ekki þar, spurðu þá kerfisstjórann þinn. ",
    "Press enter to start searching" : "Ýttu á Enter til að hefja leit",
    "Open settings menu" : "Opna stillingavalmynd",
    "Settings" : "Stillingar",
    "No files in here" : "Engar skrár hér",
    "New folder" : "Ný mappa",
    "No more subfolders in here" : "Engar fleiri undirmöppur hér",
    "Name" : "Nafn",
    "Size" : "Stærð",
    "Modified" : "Breytt",
    "\"{name}\" is an invalid file name." : "\"{name}\" er ógilt skráarheiti.",
    "File name cannot be empty." : "Heiti skráar má ekki vera tómt",
    "\"/\" is not allowed inside a file name." : "\"/\" er er ekki leyfilegt innan í skráarheiti.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" er ógild skráartegund",
    "{newName} already exists" : "{newName} er þegar til",
    "Error loading file picker template: {error}" : "Villa við að hlaða inn sniðmáti fyrir skráaveljara: {error}",
    "Show list view" : "Birta listasýn",
    "Show grid view" : "Birta reitasýn",
    "Pending" : "Í bið",
    "Home" : "Heima",
    "Copy to {folder}" : "Afrita í {folder}",
    "Move to {folder}" : "Færa í {folder}",
    "Authentication required" : "Auðkenningar krafist",
    "Failed to authenticate, try again" : "Tókst ekki að auðkenna, prófaðu aftur",
    "File not found" : "Skrá finnst ekki",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Skjalið fannst ekki á þjóninum. Hugsanlega hefur sameigninni verið eytt eða sé útrunnin?",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Endilega notaðu uppfærslutólið af skipanalínu, því sjálfvirkar uppfærslur eru gerðar óvirkar í config.php."
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
