<?php
namespace Aws\ACMPCA\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Certificate Manager Private Certificate Authority** service.
 */
class ACMPCAException extends AwsException {}
