OC.L10N.register(
    "photos",
    {
    "Public link" : "Liga pública",
    "Photos" : "Fotos",
    "Your memories under your control" : "Tus recuerdos bajo tu control",
    "All media" : "Todos los medios",
    "Videos" : "Videos",
    "Albums" : "Álbumes",
    "Collaborative albums" : "Álbumes colaborativos",
    "People" : "Personas",
    "Folders" : "Carpetas",
    "Favorites" : "Favoritos",
    "On this day" : "En este día",
    "Shared with you" : "Compartido con usted",
    "Tags" : "Etiquetas",
    "Places" : "Lugares",
    "Map" : "Mapa",
    "Photos settings" : "Configuración de Fotos",
    "Mark selection as favorite" : "Marcar selección como favorita",
    "Add selection to favorites" : "Agregar selección a favoritos",
    "Remove selection from favorites" : "Eliminar selección de favoritos",
    "Name of the album" : "Nombre del álbum",
    "Location of the album" : "Ubicación del álbum",
    "Back" : "Atrás",
    "Add collaborators" : "Agregar colaboradores",
    "Save" : "Guardar",
    "Create album" : "Crear álbum",
    "Add to Album" : "Agregar a álbum",
    "Add selection to album {albumName}" : "Agregar selección a álbum {nombreÁlbum}",
    "Shared by" : "Compartido por",
    "Create a new album." : "Crear un nuevo álbum.",
    "Create new album" : "Crear nuevo álbum",
    "New album" : "Nuevo álbum",
    "_%n item_::_%n photos and videos_" : ["%n elemento","%n fotos y videos","%n fotos y videos"],
    "Add people or groups who can edit your album" : "Agregar personas o grupos que puedan editar tu álbum",
    "Search people or groups" : "Buscar personas o grupos",
    "No recommendations. Start typing." : "No hay recomendaciones. Comienza a escribir.",
    "Group" : "Grupo",
    "Remove {collaboratorLabel} from the collaborators list" : "Eliminar {etiquetaColaborador} de la lista de colaboradores",
    "Copy the public link" : "Copiar el enlace público",
    "Public link copied!" : "¡Enlace público copiado!",
    "Copy public link" : "Copiar enlace público",
    "Delete the public link" : "Eliminar el enlace público",
    "Create public link share" : "Crear enlace público para compartir",
    "Share via public link" : "Compartir mediante enlace público",
    "Failed to fetch collaborators list." : "Error al obtener la lista de colaboradores.",
    "Failed to update album." : "Error al actualizar el álbum.",
    "This collection does not exist" : "Esta colección no existe",
    "An error occurred" : "Se produjo un error",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n foto sin asignar","%n fotos sin asignar","%n fotos sin asignar"],
    "Select image {imageName}" : "Seleccionar imagen {nombreImagen}",
    "The file is in the favorites" : "El archivo está en los favoritos",
    "Open the full size \"{name}\" image" : "Abrir la imagen \"{nombre}\" en tamaño completo",
    "There are no photos or videos yet!" : "¡Aún no hay fotos o videos!",
    "Add to {destination}" : "Agregar a {destino}",
    "Open the \"{name}\" sub-directory" : "Abrir el subdirectorio \"{nombre}\"",
    "Back to {folder}" : "Volver a {carpeta}",
    "Share this folder" : "Compartir esta carpeta",
    "_{years} year ago_::_{years} years ago_" : ["{years} año atrás","{years} años atrás","{years} años atrás"],
    "Enable squared photos view" : "Habilitar vista de fotos cuadradas",
    "Default Photos upload and Albums location" : "Ubicación predeterminada de carga de fotos y álbumes",
    "Choose default Photos upload and Albums location" : "Seleccionar ubicación predeterminada de carga de fotos y álbumes",
    "Select the default location for your media" : "Seleccionar la ubicación predeterminada para tus medios",
    "Invalid location selected" : "Ubicación seleccionada no válida",
    "View" : "Ver",
    "Photos directory" : "Directorio de fotos",
    "_%n photo_::_%n photos_" : ["%n foto","%n fotos","%n fotos"],
    "Unselect all" : "Desmarcar todo.",
    "Manage collaborators for this album" : "Administrar colaboradores para este álbum",
    "Open actions menu" : "Abrir menú de acciones",
    "Edit album details" : "Editar detalles del álbum",
    "Download all files in album" : "Descargar todos los archivos del álbum",
    "Delete album" : "Eliminar álbum",
    "Download selected files" : "Descargar archivos seleccionados",
    "Remove selection from album" : "Eliminar selección del álbum",
    "This album does not have any photos or videos yet!" : "¡Este álbum aún no tiene fotos o videos!",
    "Add photos to this album" : "Agregar fotos a este álbum",
    "Add photos to {albumName}" : "Agregar fotos a {nombreÁlbum}",
    "Manage collaborators" : "Administrar colaboradores",
    "Save collaborators for this album." : "Guardar colaboradores para este álbum.",
    "Cover photo for album {albumName}" : "Foto de portada para el álbum {nombreÁlbum}",
    "There is no album yet!" : "¡Aún no hay álbumes!",
    "This person could not be found" : "No se pudo encontrar a esta persona",
    "Rename person" : "Renombrar persona",
    "Merge with different person" : "Fusionar con otra persona",
    "Download selected photos" : "Descargar fotos seleccionadas",
    "Favorite" : "Hacer favorito",
    "Remove from favorites" : "Eliminar de favoritos",
    "Remove person" : "Eliminar persona",
    "Name of this person" : "Nombre de esta persona",
    "Save." : "Guardar.",
    "Merge person" : "Fusionar persona",
    "Move to different person" : "Mover a otra persona",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Mover foto a otra persona","Mover fotos a otra persona","Mover fotos a otra persona"],
    "_Remove photo from person_::_Remove photos from person_" : ["Eliminar foto de la persona","Eliminar fotos de la persona","Eliminar fotos de la persona"],
    "This might take some time depending on the size of your photo library." : "Esto podría llevar algún tiempo dependiendo del tamaño de tu biblioteca de fotos.",
    "Recognized people will show up here" : "Aquí aparecerán las personas reconocidas",
    "This folder does not exist" : "Esta carpeta no existe",
    "Loading folders …" : "Cargando carpetas...",
    "No photos in here" : "No hay fotos aquí",
    "This place does not have any photos or videos yet!" : "¡Este lugar aún no tiene fotos o videos!",
    "Add photos to this place" : "Agregar fotos a este lugar",
    "Cover photo for place {placeName}" : "Foto de portada para el lugar {nombreLugar}",
    "There is no place yet!" : "¡Aún no hay ningún lugar!",
    "Cover photo for shared album {albumName}." : "Foto de portada para el álbum compartido {nombreÁlbum}.",
    "Back to tags overview" : "Volver a la vista general de etiquetas",
    "No photos with this tag yet" : "Aún no hay fotos con esta etiqueta",
    "No tags yet" : "Aún no hay etiquetas",
    "Photos with tags will show up here" : "Aquí aparecerán las fotos con etiquetas",
    "Popular tags" : "Etiquetas populares",
    "Add" : "Agregar",
    "Add to album" : "Agregar al álbum",
    "Delete selection" : "Eliminar selección",
    "No photos or videos in here" : "No hay fotos o videos aquí",
    "Unassigned faces" : "Rostros sin asignar",
    "_%n photos_::_%n photos_" : ["%n fotos","%n fotos","%n fotos"],
    "Failed to fetch collection." : "Error al obtener la colección.",
    "Failed to fetch collections list." : "Error al obtener la lista de colecciones.",
    "Failed to fetch faces list." : "Error al obtener la lista de rostros.",
    "All your media" : "Todos tus medios",
    "Album {title}" : "Álbum {título}",
    "Shared Albums" : "Álbumes compartidos",
    "Shared album {title}" : "Álbum compartido {título}",
    "Public album {title}" : "Álbum público {título}",
    "Tagged photos" : "Fotos etiquetadas",
    "Tagged photo {title}" : "Foto etiquetada {título}",
    "{title}'s face" : "Rostro de {título}",
    "Failed to rename {oldName} to {faceName}." : "Error al cambiar el nombre de {antiguoNombre} a {nuevoNombre}.",
    "Failed to delete {faceName}." : "Error al eliminar {nombreRostro}.",
    "Failed to delete {fileId}." : "Error al eliminar {idArchivo}.",
    "Failed to delete {fileName}." : "Error al eliminar {nombreArchivo}.",
    "Failed to set favorite state for {fileId}." : "Error al establecer el estado de favorito para {idArchivo}.",
    "Failed to set favorite state for {fileName}." : "Error al establecer el estado de favorito para {nombreArchivo}.",
    "Locations" : "Ubicaciones",
    "Go back to the previous view." : "Volver a la vista anterior.",
    "Go to the add collaborators view." : "Ir a la vista de agregar colaboradores.",
    "Create the album." : "Crear el álbum.",
    "Back to the new album form." : "Volver al formulario de nuevo álbum.",
    "_Share with %n user_::_Share with %n users_" : ["Compartir con %n usuario","Compartir con %n usuarios","Compartir con %n usuarios"],
    "Search for collaborators" : "Buscar colaboradores",
    "Add {collaboratorLabel} to the collaborators list" : "Agregar {etiquetaColaborador} a la lista de colaboradores",
    "No collaborators available" : "No hay colaboradores disponibles",
    "Failed to fetch album." : "Error al obtener el álbum.",
    "Add photos to the album" : "Agregar fotos al álbum",
    "Failed to fetch albums list." : "Error al obtener la lista de álbumes.",
    "Shared albums" : "Álbumes compartidos",
    "Create a new album" : "Crear un nuevo álbum",
    "Add selection to an album" : "Agregar selección a un álbum",
    "Failed to create {albumName}." : "Error al crear {nombreÁlbum}.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Error al cambiar el nombre de {nombreÁlbumActual} a {nombreÁlbumNuevo}."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
