OC.L10N.register(
    "photos",
    {
    "Public link" : "קישור ציבורי",
    "Photos" : "תמונות",
    "Your memories under your control" : "הזכרונות שלך בשליטתך",
    "All media" : "כל המדיה",
    "Videos" : "סרטונים",
    "Albums" : "אלבומים",
    "Folders" : "תיקייה",
    "Favorites" : "מועדפים",
    "On this day" : "בתאריך זה",
    "Shared with you" : "משותף אתך",
    "Tags" : "תגיות",
    "Name of the album" : "שם האלבום",
    "Location of the album" : "מיקום גיאוגראפי של האלבום",
    "Back" : "חזרה",
    "Add collaborators" : "הוספת שותפים",
    "Save" : "שמירה",
    "Create album" : "יצירת אלבום",
    "Shared by" : "שותף על ידי",
    "No recommendations. Start typing." : "אין המלצות. נא להתחיל להקליד.",
    "Group" : "קבוצה",
    "Copy public link" : "העתקת הקישור הציבורי",
    "An error occurred" : "אירעה שגיאה",
    "Open the full size \"{name}\" image" : "לפתוח את התמונה „{name}” בגודל מלא",
    "Open the \"{name}\" sub-directory" : "לפתוח את תת־התיקייה „{name}”",
    "Back to {folder}" : "חזרה אל {folder}",
    "Share this folder" : "שיתוף התיקייה הזו",
    "Enable squared photos view" : "הפעלת תצוגת תמונות מרובעות",
    "View" : "צפייה",
    "Favorite" : "סימון כמועדף",
    "Remove from favorites" : "הסרה מהמועדפים",
    "No photos in here" : "אין כאן תמונות",
    "No tags yet" : "אין תגיות עדיין",
    "Photos with tags will show up here" : "תמונות עם תגיות תמיד תופענה כאן",
    "Add" : "הוספה",
    "Delete selection" : "מחיקת בחירה",
    "All your media" : "כל המדיה שלך",
    "Shared Albums" : "אלבומים משותפים",
    "Tagged photos" : "תמונות מתויגות",
    "Locations" : "מיקומים",
    "Go to the add collaborators view." : "מעבר לתצוגה של הוספת שותפים",
    "Add {collaboratorLabel} to the collaborators list" : "הוסף {collaboratorLabel} לרשימת השותפים",
    "Shared albums" : "אלבומים משותפים"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
