OC.L10N.register(
    "twofactor_totp",
    {
    "TOTP (Authenticator app)" : "TOTP (Tapatybės nustatymo programėlė)",
    "Enable TOTP" : "Įjungti TOTP",
    "Could not enable TOTP" : "Nepavyko įjungti TOTP",
    "Your new TOTP secret is:" : "Jūsų nauja TOTP paslaptis yra:",
    "For quick setup, scan this QR code with your TOTP app:" : "Greitai sąrankai, nuskenuokite šį QR kodą naudodami savo TOTP programėlę:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Sukonfigūravę savo programėlę, žemiau įveskite bandomąjį kodą, kad būtų užtikrinta, jog viskas veikia tinkamai:",
    "Authentication code" : "Tapatybės nustatymo kodas",
    "Verify" : "Patikrinti",
    "Get the authentication code from the two-factor authentication app on your device." : "Gaukite tapatybės nustatymo kodą iš dviejų faktorių tapatybės nustatymo programėlės savo įrenginyje.",
    "Submit" : "Pateikti"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
