OC.L10N.register(
    "support",
    {
    "Link:" : "Enlace:",
    "Password:" : "Contraseña:",
    "Generating system report failed." : "Error al generar el informe del sistema.",
    "Could not create folder \"System information\" to store generated report." : "No se pudo crear la carpeta \"System information\" para almacenar el informe generado.",
    "Could not create file \"%s\" to store generated report." : "No se pudo crear el archivo \"%s\" para guardar el informe generado.",
    "Could not share file \"%s\". Nevertheless, you can find it in the folder \"System information\"." : "No se ha podido compartir el archivo «%s». De todas formas, se puede encontrar en la carpeta «Información del sistema».",
    "Subscription notifications" : "Notificaciones de suscripciones",
    "Nextcloud Subscription" : "Suscripción a Nextcloud",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Tu servidor no dispone de una Suscripción a Nextcloud o tu Suscripción ha caducado.",
    "Your Nextcloud server subscription does not cover your number of users." : "Su suscripción al servidor Nextcloud no cubre su número de usuarios.",
    "Your Nextcloud Subscription has expired!" : "¡Su suscripción a Nextcloud ha caducado!",
    "Your server has no Nextcloud Subscription" : "Tu servidor no tiene suscripción a Nextcloud",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Su servidor Nextcloud no está respaldado por una suscripción a Nextcloud Enterprise.",
    "If your server setup breaks and employees can't work anymore, you don't have to rely on searching online forums for a solution. You have direct access to our experienced engineers!" : "Si la configuración de su servidor falla y los empleados dejan de poder trabajar, no tienes que depender de búsquedas en foros para encontrar la solución. Tienes acceso directo a nuestros experimentados ingenieros.",
    "You have a contract with the vendor providing early security information, mitigations, patches and updates." : "Tienes un contrato con el proveedor que proporciona información de seguridad temprana, mitigaciones, parches y actualizaciones.",
    "If you need to stay longer on your current version without disruptions, you don't have to run software without security updates." : "Si necesitas permanecer más tiempo en la versión actual sin disrupciones, no tienes que ejecutar software sin actualizaciones de seguridad.",
    "You have the best expertise at hand to deal with performance and scalability issues." : "Tienes a mano a los mejores expertos para tratar con problemas de rendimiento y escalabilidad.",
    "You have access to the right documentation and expertise to quickly answer compliance questions or deliver on GDPR, HIPAA and other regulation requirements." : "Tienes acceso a documentación y expertos que pueden resolver preguntas de cumplimiento y entrega sobre la GDPR, HIPAA y otros requerimientos regulatorios.",
    "We can also provide Outlook integration, Online Office, scalable integrated audio-video and chat communication and other features only available in a limited form for free or develop further integrations and capabilities to your needs." : "También podemos proporcionarle la integración de Outlook, Online Office, una comunicación escalable e integrada de audio-vídeo y chat y otras características sólo disponibles de forma limitada de forma gratuita o desarrollar más integraciones y capacidades a sus necesidades.",
    "A subscription helps you get the most out of Nextcloud!" : "La suscripción te ayuda a conseguir lo mejor de Nextcloud.",
    "Learn more now" : "Aprende más ahora",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %1$s because you have over %2$s registered users." : "Este correo ha sido enviado a todos los administradores por la app de Soporte en tu instancia de Nextcloud en %1$s porque tienes más de %2$s usuarios registrados.",
    "Your Nextcloud server Subscription is over limit" : "Su suscripción al servidor de Nextcloud está por encima del límite",
    "Dear admin," : "Estimado administrador,",
    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact your Nextcloud account manager to get your subscription updated!" : "Tu suscripción a Nextcloud no cubre el número de usuarios que están activos actualmente en este servidor. Por favor, contacta con tu gestor de cuenta de Nextcloud para actualizar tu suscripción.",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "%1$s es tu gestor de cuenta y se le puede contactar por correo vía %2$s o por teléfono vía %3$s.",
    "Thank you," : "Gracias,",
    "Your Nextcloud team" : "Su equipo de Nextcloud",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because you have more users than your subscription covers." : "Este correo se ha mandado a todos los administradores por la app de Soporte en tu instancia de Nexstcloud en %s porque tienes más usuarios que los que cubre tu suscripción.",
    "Your Nextcloud server Subscription is expired" : "Su suscripción de Nextcloud ha terminado",
    "Your Nextcloud server Subscription is expired!" : "¡Su suscripción de Nextcloud ha caducado!",
    "Your Nextcloud Subscription has expired! Please contact your Nextcloud account manager to get your subscription updated!" : "¡Tu suscripción a Nextcloud ha caducado! Por favor, ponte en contacto con tu gestor de cuentas de Nextcloud para actualizar tu suscripción.",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because your subscription expired." : "Este correo ha sido enviado a todos los administradores por la app de soporte en tu instancia de Nextcloud en %s porque tu suscripción ha caducado.",
    "Support" : "Soporte",
    "Getting support and help for your Nextcloud" : "Obtener soporte y ayuda para su Nextcloud",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "La app de soporte te cubre con acceso directo a la ayuda y los recursos del consulta, opciones dedicadas de contacto con tu gestor de cuenta y una vista general de tu suscripción empresarial.",
    "Basic subscription" : "Suscripción Básica",
    "Standard subscription" : "Suscripción Standard",
    "Premium subscription" : "Suscripción Premium",
    "Géant subscription" : "Suscripción Gigante",
    "Silver partner subscription" : "Suscripción de socio Plata",
    "Gold partner subscription" : "Suscripción de socio Oro",
    "Subscription" : "Suscripción",
    "Over subscription limit" : "Sobre el límite de la suscripción",
    "Valid subscription" : "Suscripción válida",
    "Expired subscription" : "Suscripción caducada",
    "Subscription key:" : "Clave de suscripción:",
    "Expires in: " : "Caduca en: ",
    "_%n year_::_%n years_" : ["%n año","%n años","%n años"],
    "_%n month_::_%n months_" : ["%n mes","%n meses","%n meses"],
    "_%n week_::_%n weeks_" : ["%n semana","%n semanas","%n semanas"],
    "_%n day_::_%n days_" : ["%n día","%n días","%n días"],
    "For an unlimited amount of users" : "Para una cantidad ilimitada de usuarios",
    "_For %n active users_::_For %n active users_" : ["Para %n usuario activo","Para %n usuarios activos","Para %n usuarios activos"],
    "_For %n users_::_For %n users_" : ["Para %n usuarios","Para %n usuarios","Para %n usuarios"],
    "_currently at %n user_::_currently at %n users_" : ["actualmente en %n usuario","actualmente en %n usuarios","actualmente en %n usuarios"],
    "Includes support for %s" : "Incluye soporte para %s",
    "Includes support for %1$s & %2$s" : "Incluye soporte para %1$s y %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Incluye soporte para %1$s, %2$s y %3$s",
    "Extended maintenance life cycle" : "Ciclo de vida de mantenimiento extendido",
    "Update subscription key" : "Actualizar clave de suscripción",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s es tu gestor de cuenta. No dudes en contactar con nosotros si tienes preguntas acerca de tu suscripción.",
    "You can find answers to common question in our portal and also file support requests there." : "Puedes encontrar respuesta a preguntas comunes en nuestro portal y también archivar allí las peticiones de soporte.",
    "Access Nextcloud portal" : "Acceso al portal Nextcloud",
    "System information" : "Información del sistema",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Recogida de información del sistema para casos de soporte. El botón a continuación genera un archivo de texto en la carpeta \"System information\" —Información del sistema— y la comparte como un enlace público protegido con contraseña. El enlace es válido durante 2 semanas.",
    "Generate system report" : "Generar un informe del sistema",
    "Enterprise subscription recommended" : "Suscripción empresarial recomendada",
    "No active enterprise subscription" : "Sin suscripción Enterprise activa",
    "Unsupported" : "No soportado",
    "This Nextcloud server has no Enterprise Subscription." : "Este servidor de Nextcloud no dispone de una suscripción Enterprise",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "Una Suscripción Empresarial de Nextcloud te ayuda a conseguir el máximo de tu Nextcloud, mantiene tus datos seguros y tu servidor funcionando fiablemente en todo momento.",
    "Advantages" : "Ventajas",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "Acceso a la experiencia técnica de los desarrolladores de Nextcloud a través de documentación y soporte",
    "Access to additional capabilities like Outlook integration, online office and more" : "Acceso a capacidades adicionales como integración con Outlook, ofimática online y más",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "Acceso a experiencia en escalabilidad y capacidades de escalabilidad para Archivos y Talk",
    "Optional branding, consulting, architecture advice" : "Consejos sobre branding, consultoría y arquitectura opcionales",
    "Confidential security notification service, mitigations, patches and advice" : "Servicio de notificaciones confidenciales de seguridad, mitigaciones, parches y consejos ",
    "Compliance certification, advice and documentation" : "Certificación de cumplimiento, consejos y documentación",
    "Get a quote" : "Consigue una ofertra",
    "More information" : "Más información",
    "Subscription benefits" : "Beneficios de la suscripción",
    "Pricing" : "Precios",
    "Community support" : "Soporte comunitario",
    "Forum" : "Foro",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud es software libre soportado por una comunidad muy activa. Por favor, regístrate en el foro para hacer preguntas y conversar con otros",
    "Nextcloud forum" : "Foro de Nextcloud",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud usa GitHub como plataforma para trabajar colaborativamente. Puedes rellenar informes de error directamente allí.",
    "Nextcloud at GitHub" : "Nextcloud en GitHub",
    "Subscription key" : "Clave de suscripción",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Si tienes una suscripción activa a Nextcloud, introduce aquí tu clave de suscripción, por favor.",
    "Learn more about an enterprise subscription." : "Aprende más sobre la suscripción empresarial.",
    "Set subscription key" : "Establecer clave de suscripción",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "La información de suscripción no se ha podido recuperar correctamente. Se ha programado un reintento. Por favor, compruébalo de nuevo más tarde.",
    "The subscription key was invalid." : "La clave de suscripción no era válida.",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "La clave de suscripción no se ha podido verificar porque este servidor no tiene conexión a internet. Por favor, ponte en contacto con el equipo de soporte para solucionar esto",
    "The subscription key had an invalid format." : "La clave de suscripción no tiene un formato válido.",
    "While fetching the subscription information an error happened." : "Ha ocurrido un error mientras se recuperaba la información de suscripción.",
    "The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "El siguiente botón genera un archivo de texto en la carpeta \"Información del sistema\" y lo comparte como un enlace público protegido por contraseña. El enlace es válido por 2 semanas.",
    "News" : "Noticias",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "Para conseguir información actualizada de qué está pasando en Nextcloud, apúntate al boletión y sigue nuestras cuentas de medios sociales.",
    "Like our Facebook page" : "Me gusta en nuestra página de Facebook",
    "Follow us on Twitter" : "Síguenos en Twitter",
    "Check out our blog" : "Mira nuestro blog",
    "Subscribe to our newsletter" : "Suscríbete a nuestro boletín"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
