OC.L10N.register(
    "files_external",
    {
    "(Group)" : "(그룹)",
    "Compatibility with Mac NFD encoding (slow)" : "Mac NFD 인코딩 호환성 사용(느림)",
    "Enable encryption" : "암호화 사용",
    "Enable previews" : "미리 보기 사용",
    "Enable sharing" : "공유 사용",
    "Check for changes" : "변경 사항 감시",
    "Never" : "하지 않음",
    "Once every direct access" : "한 번 직접 접근할 때마다",
    "Read only" : "읽기 전용",
    "Disconnect" : "연결 해제",
    "Admin defined" : "관리자 지정",
    "Delete storage?" : "저장소를 삭제하시겠습니까?",
    "Saved" : "저장됨",
    "Saving …" : "저장 중 …",
    "Save" : "저장",
    "Storage with ID \"%d\" not found" : "ID \"%d\"인 공유를 찾을 수 없음",
    "Invalid backend or authentication mechanism class" : "백엔드나 인증 방식 클래스가 잘못됨",
    "Invalid mount point" : "잘못된 마운트 지점",
    "Objectstore forbidden" : "Objectstore에 접근 금지됨",
    "Invalid storage backend \"%s\"" : "잘못된 저장소 백엔드 \"%s\"",
    "Not permitted to use backend \"%s\"" : "백엔드 \"%s\" 사용이 허가되지 않았음",
    "Not permitted to use authentication mechanism \"%s\"" : "인증 방식 \"%s\" 사용이 허가되지 않았음",
    "Unsatisfied backend parameters" : "백엔드 인자가 부족함",
    "Unsatisfied authentication mechanism parameters" : "인증 방식 인자가 부족함",
    "Insufficient data: %s" : "충분하지 않은 데이터: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "저장소 ID \"%d\"을(를) 사용자가 편집할 수 없음",
    "Access key" : "접근 키",
    "Secret key" : "비밀 키",
    "Builtin" : "내장",
    "None" : "없음",
    "OAuth1" : "OAuth1",
    "App key" : "앱 키",
    "App secret" : "앱 비밀 값",
    "OAuth2" : "OAuth2",
    "Client ID" : "클라이언트 ID",
    "Client secret" : "클라이언트 비밀 값",
    "OpenStack v2" : "OpenStack v2",
    "Username" : "사용자 이름",
    "Password" : "암호",
    "Tenant name" : "테넌트 이름",
    "Identity endpoint URL" : "아이덴티티 끝점(Endpoint) URL",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "도메인",
    "Rackspace" : "Rackspace",
    "API key" : "API 키",
    "Global credentials" : "글로벌 인증",
    "Log-in credentials, save in database" : "데이터베이스에 저장된 로그인 인증 정보",
    "Username and password" : "사용자 이름과 암호",
    "Log-in credentials, save in session" : "로그인 인증 정보, 세션에 저장됨",
    "User entered, store in database" : "사용자 데이터베이스에 저장",
    "RSA public key" : "RSA 공개 키",
    "Public key" : "공개 키",
    "RSA private key" : "RSA 비밀 키",
    "Private key" : "비밀 키",
    "Kerberos ticket" : "Kerberos 티켓",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "버킷",
    "Hostname" : "호스트 이름",
    "Port" : "포트",
    "Region" : "지역",
    "Enable SSL" : "SSL 사용",
    "Enable Path Style" : "경로 스타일 사용",
    "Legacy (v2) authentication" : "레거시(v2) 인증",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "원격 하위 폴더",
    "Secure https://" : "보안 https://",
    "FTP" : "FTP",
    "Host" : "호스트",
    "Secure ftps://" : "보안 ftps://",
    "Local" : "로컬",
    "Location" : "위치",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "루트",
    "SFTP with secret key login" : "비밀 키 로그인을 사용하는 SFTP",
    "Share" : "공유",
    "Show hidden files" : "숨김 파일 표시",
    "Timeout" : "시간 초과",
    "Username as share" : "사용자 이름으로 공유",
    "OpenStack Object Storage" : "OpenStack 객체 저장소",
    "Service name" : "서비스 이름",
    "Request timeout (seconds)" : "요청 시간 제한(초)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "PHP의 cURL 지원이 비활성화되어 있거나 설치되어 있지 않습니다. %s을(를) 마운트할 수 없습니다. 시스템 관리자에게 설치를 요청하십시오.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "PHP의 FTP 지원이 비활성화되어 있거나 설치되어 있지 않습니다. %s을(를) 마운트할 수 없습니다. 시스템 관리자에게 설치를 요청하십시오.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\"이(가) 설치되어 있지 않습니다. \"%2$s\"을(를) 탑재할 수 없습니다. 시스템 관리자에게 설치를 요청하십시오.",
    "External storage" : "외부 저장소",
    "External storage support" : "외부 저장소 지원",
    "Adds basic external storage support" : "기본적인 외부 저장소 지원 추가",
    "This application enables administrators to configure connections to external storage providers, such as FTP servers, S3 or SWIFT object stores, other Nextcloud servers, WebDAV servers, and more. Administrators can choose which types of storage to enable and can mount these storage locations for a user, a group, or the entire system. Users will see a new folder appear in their root Nextcloud directory, which they can access and use like any other Nextcloud folder. External storage also allows users to share files stored in these external locations. In these cases, the credentials for the owner of the file are used when the recipient requests the file from external storage, thereby ensuring that the recipient can access the shared file.\n\nExternal storage can be configured using the GUI or at the command line. This second option provides the advanced user with more flexibility for configuring bulk external storage mounts and setting mount priorities. More information is available in the external storage GUI documentation and the external storage Configuration File documentation." : "이 앱을 사용하면 관리자가 FTP 서버, S3 또는 SWIFT 객체 저장소, 다른 Nextcloud 서버, WebDAV 서버 등 외부 저장소 공급자에 연결할 수 있습니다. 관리자는 활성화할 저장소 종류와 저장소 마운트 위치를 사용자, 그룹, 전체 시스템 단위로 설정할 수 있습니다. 사용자의 개별 Nextcloud 루트 디렉터리에 새 폴더가 나타나며, 다른 Nextcloud 폴더처럼 사용할 수 있습니다. 외부 저장소 앱을 사용하여 해당 외부 저장소에 저장된 파일에 접근할 수 있습니다. 이 때 받는 사람이 외부 저장소의 파일을 요청하면 파일 소유자의 인증 정보를 사용하여 해당 파일에 접근할 수 있도록 합니다.\n\n외부 저장소는 GUI나 명령행으로 설정할 수 있습니다. 명령행 옵션을 사용하면 고급 사용자가 대량으로 외부 저장소를 마운트하거나 마운트 우선 순위를 설정하는 등 전문가 설정을 변경할 수 있습니다. 더 많은 정보를 보려면 외부 저장소 GUI 문서와 외부 저장소 설정 파일 문서를 참조하십시오.",
    "External mount error" : "외부 마운트 오류",
    "Storage type" : "저장소 종류",
    "Unknown" : "알 수 없음",
    "Scope" : "범위",
    "Personal" : "개인",
    "System" : "시스템",
    "No external storage configured or you don't have the permission to configure them" : "외부 저장소가 구성되지 않았거나 외부 저장소를 구성할 권한이 없습니다.",
    "Open documentation" : "문서 열기",
    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices. You may also allow users to mount their own external storage services." : "외부 저장소를 사용하여 외부 저장소 서비스나 장치를 Nextcloud 이차 저장 장치로 마운트할 수 있습니다. 사용자가 개별 외부 저장소 서비스를 마운트할 수 있도록 허용할 수도 있습니다.",
    "Folder name" : "폴더 이름",
    "Authentication" : "인증",
    "Configuration" : "설정",
    "Available for" : "다음으로 사용 가능",
    "Click to recheck the configuration" : "설정을 다시 확인하려면 클릭",
    "Add storage" : "저장소 추가",
    "Advanced settings" : "고급 설정",
    "Allow users to mount external storage" : "사용자가 외부 저장소를 마운트하도록 허용",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "전역 인증 정보를 사용하여 같은 인증 정보를 사용하는 여러 외부 저장소에 인증할 수 있습니다.",
    "Grant access" : "접근 권한 부여",
    "Error configuring OAuth1" : "OAuth1 설정 오류",
    "Please provide a valid app key and secret." : "올바른 앱 키와 비밀 값을 입력하십시오.",
    "Error configuring OAuth2" : "OAuth2 설정 오류",
    "Generate keys" : "키 생성",
    "Error generating key pair" : "키 쌍을 생성하는 중 오류 발생",
    "Empty response from the server" : "서버에서 빈 응답이 돌아옴",
    "Couldn't access. Please log out and in again to activate this mount point" : "접속할 수 없습니다. 이 마운트 지점을 활성화하기 위해 로그아웃 후 다시 로그인 해 주세요",
    "Couldn't get the information from the remote server: {code} {type}" : "원격 서버에서 정보를 가져올 수 없음: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "외부 마운트 지점 목록을 가져올 수 없음: {type}",
    "There was an error with message: " : "오류 메시지: ",
    "external-storage" : "external-storage",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Windows 네트워크 드라이브 마운트 지점 목록을 가져올 수 없음: 서버에서 빈 응답이 돌아옴",
    "Please enter the credentials for the {mount} mount" : "{mount} 마운트 인증 정보를 입력하십시오",
    "Credentials saved" : "인증 정보 저장됨",
    "Credentials saving failed" : "인증 정보를 저장할 수 없음",
    "Credentials required" : "인증 정보 필요함",
    "Name" : "이름"
},
"nplurals=1; plural=0;");
