OC.L10N.register(
    "core",
    {
    "Please select a file." : "Seletziona un'archìviu.",
    "File is too big" : "S'archìviu est tropu mannu",
    "The selected file is not an image." : "S'archìviu seletzionadu no est un'imàgine.",
    "The selected file cannot be read." : "S'archìviu seletzionadu non si podet lèghere.",
    "The file was uploaded" : "S'archìviu est istadu carrigadu",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "S'archìviu carrigadu superat sa diretiva upload_max_filesize in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "S'archìviu carrigadu superat sa diretiva MAX_FILE_SIZE ispetzificada in su mòdulu HTML",
    "The file was only partially uploaded" : "Isceti una parte de s'archìviu est carrigada",
    "No file was uploaded" : "Perunu archìviu carrigadu",
    "Missing a temporary folder" : "Mancat una cartella temporànea",
    "Could not write file to disk" : "No at fatu a iscrìere s'archìviu in su discu",
    "A PHP extension stopped the file upload" : "Un'estensione PHP at firmadu su carrigamentu de s'archìviu",
    "Invalid file provided" : "S'archìviu frunidu no est vàlidu",
    "No image or file provided" : "Peruna immàgine o archìviu",
    "Unknown filetype" : "Genia de archìviu disconnota",
    "An error occurred. Please contact your admin." : "B'at àpidu un'errore. Cuntata s'amministratzione tua.",
    "Invalid image" : "Imàgine non bàlida",
    "No temporary profile picture available, try again" : "Peruna foto de profilu temporànea a disponimentu, torra a proare",
    "No crop data provided" : "Perunu datu frunidu",
    "No valid crop data provided" : "Perunu datu vàlidu frunidu",
    "Crop is not square" : "Su retàlliu no est a iscuadra",
    "State token does not match" : "S'istadu de s'autenticadore non currispondet",
    "Invalid app password" : "Crae de aplicatzione non vàlida",
    "Could not complete login" : "Non s'est pòdida cumpletare s'intrada",
    "Your login token is invalid or has expired" : "S'atzessu cun autenticadore no est vàlidu o est iscadidu",
    "Login" : "Atzessu",
    "Password reset is disabled" : "Su riprìstinu de sa crae est disativadu",
    "%s password reset" : "%s riprìstinu de sa crae",
    "Password reset" : "Riprìstinu de sa crae",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Incarca in su butone in fatu pro ripristinare sa crae. Si no as pedidu su riprìstinu de sa crae, non cunsìderes custu messàgiu.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Incarca in su ligòngiu in fatu pro ripristinare sa crae. Si no as pedidu su riprìstinu de sa crae, non cunsìderes custu messàgiu.",
    "Reset your password" : "Riprìstina sa crae",
    "Internal error" : "Errore internu",
    "Nextcloud Server" : "Serbidore de Nextcloud",
    "Some of your link shares have been removed" : "Carchi ligòngiu de cumpartzidura tuo nch'est istadu bogadu",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Pro un'errore de seguresa nch'amus dèpidu bogare carchi ligòngiu de cumpartzidura. Càstia su ligòngiu pro àteras informatziones.",
    "The user limit of this instance is reached." : "S'est lòmpidu su lìmite de utèntzia pro custa istàntzia.",
    "Learn more ↗" : "Àteras informatziones ↗",
    "Preparing update" : "Aprontende s'agiornamentu",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Passu de s'acontzu:",
    "Repair info:" : "Informatziones de s'acontzu:",
    "Repair warning:" : "Avisu de s'acontzu:",
    "Repair error:" : "Errore in s'acontzu:",
    "Turned on maintenance mode" : "Furriadu a modalidade de mantenidura",
    "Turned off maintenance mode" : "Modalidade de mantenidura disativada",
    "Maintenance mode is kept active" : "Sa modalidade de mantenidura abarrat ativa",
    "Updating database schema" : "Agiornende s'ischema de sa base de datos",
    "Updated database" : "Base de datos agionada",
    "Update app \"%s\" from App Store" : "Agiorna s'aplicatzione \"%s\" dae sa butega de is aplicatziones",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Averguende si s'ischema de sa base de datos de %s faghet a dd'agiornare (podet trigare segundu sa mannària de sa base de datos)",
    "Updated \"%1$s\" to %2$s" : "Agiornadu \"%1$s\" a %2$s",
    "Set log level to debug" : "Imposta livellu de registratzione de currègere",
    "Reset log level" : "Reseta livellu de registratzione",
    "Starting code integrity check" : "Cumintzende su controllu de integridade de còdighe",
    "Finished code integrity check" : "Controllu de integridade de còdighe agabbadu",
    "%s (incompatible)" : "%s (non cumpatìbile)",
    "The following apps have been disabled: %s" : "Is aplicatziones in fatu sunt istadas disativadas: %s",
    "Already up to date" : "Giai agiornadu",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Su serbidore tuo no est impostadu pro permìtere sa sincronizatzione de is archìvios, ca s'interfache WebDAV paret arrogada.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Si serbidore tuo no est impostadu pro risòlvere \"{url}\". Podes agatare àteras informatziones in sa {linkstart} documentatzione ↗{linkend}..",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Su serbidore internet tuo no est cunfiguradu comente si depet pro resòlvere \"{url}\". Est probàbile chi custu dipendat dae una cunfiguratzione de su serbidore no agiornada pro cunsignare deretu custa cartella. Cunfronta sa cunfiguratzione tua cun is règulas de re-iscritura imbiadas in \".htaccess\" pro Apache o cussa frunida in sa documentatzione pro Nginx in sa  {linkstart}pàgina de documentatzione ↗{linkend}. In Nginx giai semper sunt is lìneas chi incarrerant cun \"location ~\" chi tenent bisòngiu de un'agiornamentu.",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Su serbidore internet tuo no est cunfiguradu comente si depet pro produire archìvios .woff2. Custu est giai semper unu problema de sa cunfiguratzione Nginx. Pro Nextcloud 15 tocat de dd'adecuare pro produire puru archìvios .woff2. Cunfronta sa cunfiguratzione Nginx tua cun sa cunfiguratzione cussigiada in sa {linkstart}documentation ↗{linkend} nostra.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Paret chi PHP no est cunfigradu comente si depet pro rechèrrere variàbiles de ambiente de sistema. Sa proa cun getenv(\"PATH\") at torradu isceti una isceda bòida.",
    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Càstia sa {linkstart}documentatzione de installatzione ↗{linkend} pro is notas de cunfiguratzione de su PHP e sa cunfiguratzione de su serbidore tuo, prus che totu cando impreas php-fpm.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Sa cunfinguratzione de letura isceti est istètia ativada. Custu evitat de pònere cunfiguratziones cun sa interfache-web. In prus, s'archìviu depet èssere produidu pro èssere iscritu a manu a cada agiornamentu.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Sa base de datos tua non funtzionat cun su livellu de isulamentu de sa transatzione \"READ COMMITTED\". Custu podet causare problemas cando si faghent prus atziones in parallelu.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Mancat su mòdulu PHP \"fileinfo\". Est cussigiadu meda de ativare custu mòdulu pro otènnere is mègius resurtados in sa chirca de sa genia MIME.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "Su blocu de s'archìviu de transatzione est disativadu, e custu podet cumportare problemas cun is situatziones de carrera. Ativa \"filelocking.enabled\" in config.php pro evitare custos problemas. Càstia sa {linkstart}documentatzione ↗{linkend} pro àteras informatziones. ",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Impossìbile a esecutare s'utilidade cron cun CLI. Sunt aparessidos is errores tècnicos in fatu:",
    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "S'urtima atividade de background est partida {relativeTime}. Calicuna cosa paret isballiada. {linkstart}Càstia is impostatziones de s'atividade de background ↗{linkend}.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Peruna memòria de depòsitu cunfigurada. Pro megiorare s'esecutzione, cunfigura una memòria de depòsitu, si est disponìbile. Podes agatare àteras informatziones in sa {linkstart}documentatzione ↗{linkend}.",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "PHP no at agatadu pro casualidade peruna orìgine adata e si cussìgiat de no ddu impreare pro resones de seguresa. Podes agatare àteras informatziones in sa {linkstart}documentatzione ↗{linkend}.",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Sa cunfiguratzione de s'intestatzione de su serbidore intermèdiu cuntràriu est isballiada, o ses faghende s'atzessu in Nextcloud dae unu serbidore intermèdiu fidadu. Chi no est aici, ddoe est unu problema de seguresa chi podet permìtere a chie atachet de copiare su IP issoro comente si bidet in Nextcloud. Podes agatare àteras informatziones in sa {linkstart}documentatzione ↗{linkend}.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached est cunfiguradu comente su depòsitu distribuidu, ma est installadu su mòdulu PHP \"memcache\" isballiadu. \\OC\\Memcache\\Memcached suportat isceti \"memcached\" e no \"memcache\". Càstia sa {linkstart}memcached wiki subra de is duos mòdulos ↗{linkend}.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Calicunu archìviu no at passadu su controllu de integridade. Podes agatare prus informatziones subra comente resòlvere custu problema in sa {linkstart1}documentatzione ↗{linkend}. ({linkstart2}Elencu de is archìvios non vàlidos…{linkend} / {linkstart3}Torra a analizare…{linkend})",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "Sa funtzione PHP \"set_time_limit\" no est disponìbile. Custu podet essire in programmas firmados in cursu de esecutzione, trunchende s'installatzione. Est cussigiadu meda a ativare custa funtzione.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Su PHP tuo no tenet su suportu FreeType, e custu càusat dannos in is immàgines de profilu e in s'interfache de is impostatziones.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Mancat s'ìnditze \"{indexName}\" in sa tàula \"{tableName}\".",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "In sa base de datos mancat calicunu ìnditze. Agiùnghere is ìnditzes a tàulas mannas podet pigare unu pagu de tempus, tando no s'agiunghent de manera automàtica. Impreende  \"occ db:add-missing-indices\" si podent agiùnghere a manu is ìnditzes chi mancant in s'interis chi s'istàntzia est in funtzione. Cando is ìnditzes sunt agiuntos is rechestas a custas tàulas andant giai semper prus a lestru meda.",
    "Missing primary key on table \"{tableName}\"." : "Mancat sa crae primària in sa tàula \"{tableName}\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "In sa base de datos mancat calicuna crae primària. Agiùnghere is craes primàrias a tàulas mannas podet pigare unu pagu de tempus, tando no s'agiunghent de manera automàtica. Impreende \"occ db:add-missing-primary-keys\". Si podent agiùnghere a manu is craes primàrias chi mancant in s'interis chi s'istàntzia est in funtzione.",
    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Mancat sa colunna optzionale \"{columnName}\" in sa tàula \"{tableName}\".",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "In sa base de datos mancat calicuna colunna optzionale. Agiùnghere is colunnas optzionale a tàulas mannas podet pigare unu pagu de tempus, tando no s'agiunghent de manera automàtica. Impreende \"occ db:add-missing-columns\" si podent agiùnghere a manu is ìnditzes chi mancant in s'interis chi s'istàntzia est in funtzione. Cando is colunnas sunt agiuntas unas cantas funtzionalidades diant pòdere resurtare prus reativos o prus bellu a impreare. ",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "In custa istàntzia mancat unos cantos mòdulos PHP cussigiados. Pro megiorare s'esecutzione e sa compatibilidade est cussigiadu meda a ddus installare.",
    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Su mòdulu php-imagick in custa istàntzia no tenet suportu SVG. Pro megiorare sa compatibilidade est cussigiadu meda a ddu installare.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Ses impreende SQLite comente base de datos de palas. Pro installatziones prus mannas ti cussigiamos de cambiare a un'àtera base de datos de palas.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Est cussigiadu prus che totu cando impreas su cliente de s'iscrivania pro sa sincronizatzione de is archìvios.",
    "The PHP memory limit is below the recommended value of 512MB." : "Su lìmite de sa memòria PHP est suta de su balore cussigiadu de 512 MB.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Ddoe sunt cartella de aplicatzione de propiedade de utentes diversos dae su serbidore de internet. Podet èssere su casu de aplicatziones installadas a manu. Càstia is permissos relativos a is cartellas de aplicatziones in fatu:",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL est impreadu comente base de datos ma no suportat is caràteres in 4-byte. Pro pòdere manigiare is caràteres in 4-byte (comente emojis) chena problemas pro esèmpiu in nùmenedearchìviu o in commentos, est cussugiadu ativare su suportu pro 4-byte in MySQL. Pro àteros detàllios leghe {linkstart}sa pàgina de sa documentatzione subre de custu ↗{linkend}.",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Custa istàntzia impreat un'ogetu de base S3 comente memòria primària. Is archìvios carrigados sunt allogados in manera temporale in su serbidore, tando est cussigiadu tènnere 50 GB de logu disponìbile in sa cartella temp de PHP. Càstia is registros pro totu is detàllios subra de su caminu e su logu disponìbile. Pro ddu megiorare càmbia sa cartella temporale in php.ini o faghe prus logu in custu caminu.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Ses faghende s'atzessu a s'istàntzia dae una connessione segura, ma in cada manera s'istàntzia est generende URLs no seguros. Est meda probàbile chi siast a palas de unu serbidore intermèdiu e is variàbiles de sa cunfiguratzione de sa subra-iscritura no siant impostadas in sa manera curreta. Leghe {linkstart}sa pàgina de sa documentatzione subra de custu ↗{linkend}.",
    "Error occurred while checking server setup" : "Ddoe at àpidu un'errore in su controllu de sa cunfiguratzione de su serbidore",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Pro àteros detàllios controlla sa {linkstart}documentatzione ↗{linkend}.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "S'intestatzione HTTP \"{header}\" no est impostada in \"{expected}\". Custu est un'arriscu possìbile de seguresa o privadesa, tando est cussigiadu a arrangiare cust'impostatzione de cunsighèntzia.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "S'intestatzione HTTP \"{header}\" no est impostada in \"{expected}\". Calicunu elementu diat pòdere no funtzionare in sa manera curreta, tando est cussigiadu a arrangiare cust'impostatzione de cunsighèntzia.",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "S'intestatzione HTTP \"{header}\" no est impostada cun \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" o \"{val5}\". Custu podet fàghere essire informatziones de s'orìgine. Càstia sa {linkstart}W3C 1Racumandatzione ↗{linkend}.",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "S'intestatzione HTTP \"Seguresa-Strinta-deTràmuda\" no est impostada pro a su mancu \"{segundos}\" segundos. Pro megiorare sa seguresa, est cussigiadu a ativare HSST comente descritu in is {linkstart}impòsitos de seguresa ↗{linkend}.",
    "unknown text" : "testu disconnotu",
    "Hello world!" : "Salude mundu!",
    "sunny" : "solianu",
    "Hello {name}, the weather is {weather}" : "Salude {name}, su tempus est {weather}",
    "Hello {name}" : "Salude {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Custos sunt is resurtados de sa chirca <script>avisu(1)</script></strong>",
    "new" : "nou",
    "_download %n file_::_download %n files_" : ["iscàrriga %n documentu","iscàrriga %narchìvios"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "S'agiornamentu est in cursu, lassende sa pàgina su protzessu si diat pòdere  suspèndere.",
    "Update to {version}" : "Agiorna a {version}",
    "An error occurred." : "B'at àpidu un'errore.",
    "Please reload the page." : "Torra a carrigare sa pàgina.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "S'agiornamentu est andadu male. Pro àteras informatziones <a href=\"{url}\">controlla sa publicatzione subra de custu </a> in su forum.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "S'agiornamentu no est andadu bene. Sinnala custu problema a sa <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunidade de Nextcloud </a>.",
    "Continue to {productName}" : "Sighi a {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["S'agiornamentu est andadu bene. Indiritzende·ti a {productName} intre %n segundu.","S'agiornamentu est andadu bene. Indiritzende·ti a {productName} intre %n segundos."],
    "More apps" : "Àteras aplicatziones",
    "Log in" : "Intra",
    "Logging in …" : "Intrende ...",
    "Server side authentication failed!" : "Autenticatzione de s'ala de su serbidore faddida!",
    "Please contact your administrator." : "Cuntata s'amministratzione.",
    "An internal error occurred." : "B'at àpidu un'errore internu.",
    "Please try again or contact your administrator." : "Torra a proare o cuntata s'amministratzione.",
    "Password" : "Crae",
    "Wrong username or password." : "Nùmene utente o crae isballiada.",
    "User disabled" : "Utèntzia disativada",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Amus agatadu tentativos meda de atzessu dae s'IP tuo. Duncas s'atzessu tuo imbeniente dd'as a pòdere fàghere intre 30 segundos.",
    "Log in with a device" : "Autentica·ti cun unu dispositivu",
    "Username or email" : "Nùmene utente o indiritzu de posta",
    "Your account is not setup for passwordless login." : "Su contu tuo no est fatu pro autenticatziones chene crae.",
    "Browser not supported" : "Navigadore non suportadu",
    "Passwordless authentication is not supported in your browser." : "S'autenticatzione chene crae no est suportada in su navigadore tuo.",
    "Your connection is not secure" : "Sa connessione tua no est segura",
    "Passwordless authentication is only available over a secure connection." : "S'autenticatzione chene crae est a disponimentu isceti cun connessiones seguras.",
    "Reset password" : "Riprìstina sa crae",
    "Couldn't send reset email. Please contact your administrator." : "No at fatu a ripristinare sa posta eletrònica. Cuntata s'amministratzione.",
    "Password cannot be changed. Please contact your administrator." : "Sa crae non faghet a dda cambiare. Cuntata s'amministratzione.",
    "Back to login" : "Torra a s'autenticatzione",
    "New password" : "Crae noa",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Is archìvios sunt critografados. Non ddoe at a èssere manera pro tènnere is datos a pustis de su riprìstinu de sa crae. Si tenes dudas, cuntata s'amministratzione in antis. A beru boles sighire?",
    "I know what I'm doing" : "Giai dd'isco ite so faghinde",
    "Resetting password" : "Ripristinende sa crae",
    "Recommended apps" : "Aplicatziones racumandadas",
    "Loading apps …" : "Carrighende aplicatziones ...",
    "Could not fetch list of apps from the App Store." : "No at fatu a recuperare sa lista dae sa butega de is aplicatziones.",
    "Installing apps …" : "Installende aplicatziones ...",
    "App download or installation failed" : "Iscarrigamentu de s'aplicatzione o installatzione faddida",
    "Cannot install this app because it is not compatible" : "Non faghet a installare custa aplicatzione ca no est cumpatìbile",
    "Cannot install this app" : "Non faghet a installare custa aplicatzione",
    "Skip" : "Brinca",
    "Install recommended apps" : "Installa is aplicatziones racumandadas",
    "Schedule work & meetings, synced with all your devices." : "Programma atividades e addòbios, sincronizados cun is dispositivos tuos.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Mantene is collegas e is amistades tuas in unu logu chene mustrare is datos privados issoro.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplicatzione de posta eletrònica simpre e integrada bene cun Archìvios, Cuntatos e Calendàriu.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Tzarradas, video mutidas, cumpartzidura de s'ischermu, reuniones in lìnia e vìdeo-cunferèntzias – in su navigadore tuo e cun aplicatziones mòbiles.",
    "Search contacts …" : "Chirca cuntatos ...",
    "Could not load your contacts" : "No at fatu a carrigare is cuntatos",
    "No contacts found" : "Perunu cuntatu agatadu",
    "Show all contacts …" : "Mustra totu is cuntatos ...",
    "Install the Contacts app" : "Installa s'aplicatzione de is cuntatos",
    "Loading your contacts …" : "Carrighende is cuntatos...",
    "Looking for {term} …" : "Chirchende {term} …",
    "Forgot password?" : "Crae iscaressida?",
    "Back" : "A coa",
    "Login form is disabled." : "Su mòdulu de atzessu est disativadu.",
    "Reset search" : "Riprìstina chirca",
    "Search for {name} only" : "Chirca pro {name} ebbia",
    "Start typing to search" : "Cumintza a iscrìere pro chircare",
    "Loading more results …" : "Carrighende àteros resurtados ...",
    "Load more results" : "Càrriga àteros resurtados",
    "Search" : "Chirca",
    "No results for {query}" : "Perunu resurtadu pro {query}",
    "An error occurred while searching for {type}" : "B'at àpidu un'errore in sa chirca de {type}",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Inserta {longàriaMinChirca} o prus caràteres pro chircare","Inserta·nche {minSearchLength} o prus caràteres pro chircare"],
    "Settings menu" : "Menu de is impostatziones",
    "Search {types} …" : "Chirca {types} …",
    "No" : "No",
    "Yes" : "Eja",
    "Choose" : "Sèbera",
    "Copy" : "Còpia",
    "Move" : "Tràmuda",
    "OK" : "AB",
    "Error loading message template: {error}" : "Errore in su carrigamentu de su modellu de messàgiu: {error}",
    "read-only" : "letura sola",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} cunflitu de archìviu","{count} cunflitos de archìviu"],
    "One file conflict" : "Unu cunflitu de archìviu",
    "New Files" : "Archìvios noos",
    "Already existing files" : "Archìvios chi esistint giai",
    "Which files do you want to keep?" : "Cales archìvios boles mantènnere?",
    "If you select both versions, the copied file will have a number added to its name." : "Si seletzionas ambas is versiones, s'archìviu copiadu at a tènnere unu nùmeru in agiunta a su nùmene.",
    "Cancel" : "Annulla",
    "Continue" : "Sighi",
    "(all selected)" : "(totu seletzionadu)",
    "({count} selected)" : "({count} seletzionadu)",
    "Error loading file exists template" : "Errore in su carrigamentu de su modellu de archìviu",
    "Saving …" : "Sarvende …",
    "seconds ago" : "segundos a immoe",
    "Connection to server lost" : "Connessione a su serbidore pèrdida",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Si seletzionas ambas is versiones, su documentu copiadu at a tènnere unu nùmeru in agiunta a su nùmene.","Problema in su carrigamentu de sa pàgina, torrende a carrigare intre %n segundos"],
    "Add to a project" : "Agiunghe a unu progetu",
    "Show details" : "Mustra detàllios",
    "Hide details" : "Cua detàllios",
    "Rename project" : "Torra a numenare su progetu",
    "Failed to rename the project" : "Impossìbile a numenare su progetu",
    "Failed to create a project" : "Impossìbile a creare unu progetu",
    "Failed to add the item to the project" : "No at fatu a agiunghere s'elementu a su progetu",
    "Connect items to a project to make them easier to find" : "Connete elementos a unu progetu pro chi siat prus fàtzile a ddos agatare",
    "Type to search for existing projects" : "Iscrie pro chircare is progetos chi ddoe sunt giai",
    "New in" : "Prima borta in",
    "View changelog" : "Càstia su registru de is càmbios",
    "Very weak password" : "Crae dèbile meda",
    "Weak password" : "Crae dèbile",
    "So-so password" : "Crae aici aici",
    "Good password" : "Crae bona",
    "Strong password" : "Crae bona a beru",
    "No action available" : "Peruna atzione a disponimentu",
    "Error fetching contact actions" : "Errore in su recùperu de is atziones de cuntatu",
    "Non-existing tag #{tag}" : "S'eticheta no esistit #{tag}",
    "Restricted" : "Limitadu",
    "Invisible" : "Invisìbile",
    "Delete" : "Cantzella",
    "Rename" : "Torra a numenare",
    "Collaborative tags" : "Etichetas collaborativas",
    "No tags found" : "Peruna eticheta agatada",
    "Personal" : "Personale",
    "Users" : "Utentes",
    "Apps" : "Aplicatziones",
    "Admin" : "Amministratzione",
    "Help" : "Agiudu",
    "Access forbidden" : "Atzessu proibidu",
    "Back to %s" : "A coa a %s",
    "Page not found" : "Pàgina no agatada",
    "Too many requests" : "Tropu dimandas",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Tropu rechestas sunt arribadas dae sa rete tua. Torra a proare prus a tardu o cuntata s'amministradore tuo chi ddoe at un'errore.",
    "Error" : "Errore",
    "Previous" : "Pretzedente",
    "Internal Server Error" : "Errore serbidore internu",
    "The server was unable to complete your request." : "Su serbidore no at pòdidu cumpletare sa rechesta tua.",
    "If this happens again, please send the technical details below to the server administrator." : "Si torrat a capitare, imbia is detàllios tècnicos in bàsciu a s'amministratzione de su serbidore.",
    "More details can be found in the server log." : "S'ant a agatare àteros detàllios in su registru de su serbidore.",
    "Technical details" : "Detàllios tècnicos",
    "Remote Address: %s" : "Indiritzu remotu: %s",
    "Request ID: %s" : "Rechesta ID: %s",
    "Type: %s" : "Genia: %s",
    "Code: %s" : "Còdighe: %s",
    "Message: %s" : "Messàgiu: %s",
    "File: %s" : "Archìviu: %s",
    "Line: %s" : "Lìnia: %s",
    "Trace" : "Arrasta",
    "Security warning" : "Avisu de seguresa",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Is cartellas de datos e is archìvios tuos fortzis sunt atzessìbiles dae s'internet ca s'archìviu .htaccess no est funtzionende.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pro informatziones subra de comente cunfigurare su serbidore tuo, càstia in sa <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentatzione</a>.",
    "Create an <strong>admin account</strong>" : "Crea unu <strong>contu de amministratzione</strong>",
    "Username" : "Nùmene utente",
    "Show password" : "Mustra crae",
    "Toggle password visibility" : "Càmbia sa visibilidade de sa crae",
    "Storage & database" : "Depòsitu e base de datos",
    "Data folder" : "Cartella de datos",
    "Configure the database" : "Cunfigura sa base de datos",
    "Only %s is available." : "%s isceti est a disponimentu.",
    "Install and activate additional PHP modules to choose other database types." : "Installa e ativa àteros mòdulos PHP pro seberare àteras genias de base de datos.",
    "For more details check out the documentation." : "Pro àteros detàllios controlla sa documentatzione.",
    "Database user" : "Utente base de datos",
    "Database password" : "Crae base de datos",
    "Database name" : "Nùmene base de datos",
    "Database tablespace" : "Logu de sa tauledda de sa base de datos",
    "Database host" : "Retzidore de sa base de datos",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Ispetzìfica su nùmeru de sa gianna aintru de su nùmene de su retzidore (p.e., retzidorelocale:5432).",
    "Performance warning" : "Avisu de atuatzione",
    "You chose SQLite as database." : "As seberadu SQLite comente base de datos.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite diat èssere impreadu isceti pro istàntzias mìnimas e de isvilupu. Pro sa produtzione cussigiamus un'àtera base de datos de palas.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Chi impreas clientes pro sa sincronizatzione de is archìvios, SQLite no est cussigiadu pro nudda.",
    "Install" : "Installa",
    "Need help?" : "Boles agiudu?",
    "See the documentation" : "Càstia sa documentatzione",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Paret chi ses chirchende de torrare a installare Nextcloud. In cada manera, mancat s'archìviu CAN_INSTALL in sa cartella de cunfiguratzione. Crea s'archìviu CAN_INSTALL in sa cartella de cunfiguratzione pro sighire.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "No at fatu a nche bogare CAN_INSTALL dae sa cartella de cunfiguratzione. Boga custu archìviu a manu.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Custa aplicatzione rechedet JavaScript pro un'operatzione curreta. {linkstart} Ativa JavaScript{linkend} e torra a carrigare sa pàgina.",
    "Skip to main content" : "Brinca a su cuntenutu printzipale",
    "Skip to navigation of app" : "Brinca a sa navigatzione de s'aplicatzione",
    "Go to %s" : "Bae a %s",
    "Get your own free account" : "Otene su contu tuo a gratis",
    "This action requires you to confirm your password" : "Pro custa atzione ti tocat de cunfirmare sa crae",
    "Confirm your password" : "Cunfirma sa crae",
    "Confirm" : "Cunfirma",
    "Connect to your account" : "Connete·ti a su contu tuo",
    "Please log in before granting %1$s access to your %2$s account." : "Faghe s'atzessu prima de permìtere a %1$s de intrare a su %2$s contu tuo.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Chi non ses chirchende de impostare unu dispositivu o un'aplicatzione noa, calecunu est proende a si fàghere dare atzessu a is datos tuos. In custu casu, no sigast e cuntata s'amministradore de sistema tuo.",
    "App token" : "Autenticadore de s'aplicatzione",
    "Grant access" : "Dona atzessu",
    "Alternative log in using app token" : "Atzessu alternativu cun s'autenticadore de s'aplicatzione",
    "Account access" : "Atzessu a su contu",
    "You are about to grant %1$s access to your %2$s account." : "Ses acanta de donare %1$s atzessu a su contu %2$s tuo.",
    "Account connected" : "Contu collegadu",
    "Your client should now be connected!" : "Su cliente tuo immoe diat dèpere èssere collegadu!",
    "You can close this window." : "Podes serrare custa ventana",
    "This share is password-protected" : "Custa cumpartzidura est amparada dae una crae",
    "Email address" : "Indiritzu de posta eletrònica",
    "Two-factor authentication" : "Autenticatzione a duos fatores",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Su megioru de seguresa est ativadu in su contu tuo. Sèbera unu segundu fatore pro s'autenticatzione:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "No at fatu a carriggare a su mancu unu de is mètodos de autenticatzione a duos fatores ativados. Cuntata s'amministratzione.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "S'est imposta s'autenticatzione a duos fatores ma non s'est cunfigurada in su contu tuo. Cuntata s'amministratzione si boles agiudu.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "S'est imposta s'autenticatzione a duos fatores ma non s'est cunfigurada in su contu tuo. Sighi pro impostare s'autenticatzione a duos fatores.",
    "Set up two-factor authentication" : "Cunfigura s'autenticatzione a duos fatores",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "S'est imposta s'autenticatzione a duos fatores ma non s'est cunfigurada in su contu tuo. Pro intrare imprea unu de is còdighes pro sa còpia de seguresa o cuntata s'amministratzione.",
    "Use backup code" : "Imprea su còdighe de sa còpia de seguresa",
    "Cancel login" : "Annulla atzessu",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "S'est impostu unu megioru de seguresa in su contu tuo. Sèbera su frunidore chi boles impostare:",
    "Error while validating your second factor" : "Errore in sa validatzione de su seguntu fatore tuo",
    "Access through untrusted domain" : "Atzessu cun domìniu non seguru",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Àteras informatziones pro sa cunfiguratzione ddas podes agatare in sa %1$sdocumentatzione%2$s.",
    "App update required" : "Agiornamentu de aplicatzione rechertu",
    "%1$s will be updated to version %2$s" : "%1$s at a èssere agiornada a sa versione %2$s",
    "The following apps will be updated:" : "Is aplicatziones in fatu ant a èssere agiornadas:",
    "These incompatible apps will be disabled:" : "Custas aplicatziones non cumpatìbiles ant a èssere disativadas:",
    "The theme %s has been disabled." : "Su tema %s est istadu disativadu.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Prima de sighire, assegura·ti ca sa base de datos, sa cartella de cunfiguratzione e cussa de is datos tenent una còpia de seguresa.",
    "Start update" : "Cumintza agiornamentu",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Pro evitare pasadas cun installatziones mannas, podes dare su cumandu in fatu dae sa cartella de installatzione:",
    "Detailed logs" : "Registros detalliados",
    "Update needed" : "Tocat de agiornare",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Imprea s'atualizadore a lìnia de cummandu ca tenes un'istàntzia manna cun prus de 50 utentes.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Pro agiudos, càstia sa  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentatzione</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Giai dd'isco ca chi sigu cun s'agiornamentu via internet UI ddoe at s'arriscu chi sa rechesta arribet a una pasada e podet causare sa pèrdida de is datos, ma tèngio una còpia de seguresa e isco comente recuperare s'istàntzia in casu de errore.",
    "Upgrade via web on my own risk" : "Agiorna via web suta responsabilidade mia",
    "Maintenance mode" : "Modalidade de mantenidura",
    "This %s instance is currently in maintenance mode, which may take a while." : "Immoe custa %s istàntzia est in modalidade de mantenidura, e podet trigare unu pagu.",
    "This page will refresh itself when the instance is available again." : "Custa pàgina s'at a atualizare cando s'istàntzia at a èssere torra a disponimentu.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Cuntata s'amministratzione de sistema si custu messàgiu abarrat o torrat a cumpàrrere",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "S'installatzione no tenet cunfigurada una regione pro su telèfonu predefinida. Custu serbit pro balidare is nùmeros de telèfonu in is impostatziones de profilu chene su còdighe de Istadu. Pro pòdere impreare nùmeros chene su còdighe de Istadu, agiunghe \"default_phone_region\" cun su relativu {linkstart}ISO 3166-1 code ↗{linkend} de sa regione pro cunfigurare s'archìviu tuo. ",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Immoe ses impreende PHP {versione}. Agiorna sa versione tua de PHP pro isfrutare {linkstart}is novidades de esecutzione e seguresa frunidas dae su PHP Group ↗{linkend} cando sa distributzione tua ddas at a suportare.",
    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Est istadu imbiadu unu messàgiu pro su risprìstinu de sa crae a s'indiritzu de posta eletrònica de custu contu. Si non ddu retzis, controlla in is cartellas de s'àliga o pide agiudu a s'amministratzione.",
    "If it is not there ask your local administrator." : "Si no est in cue, dimanda a s'amministratzione locale tua.",
    "Settings" : "Cunfiguratziones",
    "No files in here" : "Perunu archìviu",
    "New folder" : "Cartella noa",
    "No more subfolders in here" : "Non ddoe at àteras suta-cartellas",
    "Name" : "Nùmene",
    "Size" : "Mannària",
    "Modified" : "Modificadu",
    "\"{name}\" is an invalid file name." : "\"{name}\" est unu nùmene de archìviu non vàlidu.",
    "File name cannot be empty." : "Su nùmene de s'archìviu non podet èssere bòidu.",
    "\"/\" is not allowed inside a file name." : "\"/\" no est permìtidu in unu nùmene de archìviu.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" no est una genia de archìviu permìtida",
    "{newName} already exists" : "{newName} esistit giai",
    "Error loading file picker template: {error}" : "Errore in su carrigamentu de su modellu de regorta de archìvios: {error}",
    "Pending" : "In suspesu",
    "Home" : "Pàgina printzipale",
    "Copy to {folder}" : "Còpia in {folder}",
    "Move to {folder}" : "Tràmuda a {folder}",
    "Authentication required" : "Autenticatzione recherta",
    "Failed to authenticate, try again" : "Impossìbile a s'autenticare, torra a proare",
    "File not found" : "Archìviu no agatadu",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Su documentu non s'est agatadu in su serbidore. Mancari sa cumpartzidura nch'est istada cantzellada o est iscadida?",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Imprea s'atualizadore a lìnia de cummandu ca s'agiornamentu automàticu est disativadu in sa config.php."
},
"nplurals=2; plural=(n != 1);");
