OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "Adieu %s",
    "Hello %s," : "Adieu %s,",
    "_New notification for %s_::_%n new notifications for %s_" : ["Notificacion novèla per %s","%n notificacions novèlas per %s"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["Avètz una notificacion novèla per %s","Avètz %n notificacions novèlas per %s"],
    "Admin notifications" : "Notificacions admin",
    "Notifications" : "Notificacions",
    "Dismiss" : "Ignorar",
    "seconds ago" : "fa qualques segondas",
    "in {path}" : "dins {path}",
    "Dismiss all notifications" : "Tancar totas las notificacions",
    "No notifications" : "Cap de notificacion",
    "Never" : "Jamai",
    "1 hour" : " 1 ora",
    "3 hours" : "3 oras",
    "1 day" : "1 jorn",
    "1 week" : "1 setmana",
    "Your settings have been updated." : "Paramètres actualizats.",
    "An error occurred while updating your settings." : "Una error s’es producha pendent l’actualizacion dels paramètres."
},
"nplurals=2; plural=(n > 1);");
