#preview{text-align:center}#preview .notCreatable{display:none}#noPreview{display:none;padding-top:80px}#imgframe{height:75%;padding-bottom:32px;padding-top:32px;width:80%;margin:0 auto}#imgframe #viewer{height:100%;width:100%}#imgframe img{max-height:calc(100vh - var(--header-height) - 65px - 200px - 16px) !important;max-width:100% !important;width:unset !important}#imgframe :not(#viewer) img{min-width:100px}#imgframe video{max-height:calc(100vh - var(--header-height) - 65px - 200px - 16px)}#imgframe .plyr:fullscreen video{max-height:unset}#imgframe audio{display:block;margin-left:auto;margin-right:auto}#imgframe #viewer[data-handler=audios]{margin-top:400px}#imgframe .plyr{top:0px !important}#imgframe .text-preview{display:inline-block;position:relative;text-align:left;white-space:pre-wrap;overflow-y:scroll;height:auto;min-height:200px;max-height:800px}#imgframe .ellipsis{font-size:1.2em}#imgframe .viewer__file{height:100%;width:100%}#imgframe .plyr{max-height:100%}.app-files_sharing #app-content footer{position:sticky !important}thead{left:0 !important}#data-upload-form{position:relative;right:0;height:32px;overflow:hidden;padding:0;float:right;display:inline;margin:0}.directDownload #downloadFile{white-space:nowrap;overflow:hidden;text-overflow:ellipsis;max-width:90%;display:inline-block;margin-left:auto;margin-right:auto;margin-top:16px}.download-size{opacity:.5}#details{display:inline-flex}#details button,#details input,#details .button{margin:0 5px;line-height:normal}#details button:hover,#details input:hover,#details .button:hover{border-color:rgba(0,0,0,.3) !important}#public-upload .avatardiv{margin:0 auto}.emptycontent.has-note{margin-top:5vh}#public-upload .emptycontent h2{margin:10px 0 5px 0}#public-upload .emptycontent h2+p{margin-bottom:30px}#public-upload .emptycontent .icon-folder{height:16px;width:16px;background-size:16px;display:inline-block;vertical-align:text-top;margin-bottom:0;margin-right:5px;opacity:1}#public-upload .emptycontent #displayavatar .icon-folder{height:48px;width:48px;background-size:48px}#public-upload .emptycontent .button{display:inline-block;height:auto;width:auto;background-size:16px;background-position:16px;opacity:.7;font-size:20px;line-height:initial;margin:20px;padding:10px 20px;padding-left:42px}#public-upload .emptycontent ul{width:230px;margin:5px auto 5vh;text-align:left}#public-upload .emptycontent li{overflow:hidden;text-overflow:ellipsis;white-space:nowrap;padding:7px 0}#public-upload .emptycontent li img{margin-right:5px;position:relative;top:2px}#drop-upload-progress-indicator span.icon-loading-small{padding-left:18px;margin-right:7px}#drop-uploaded-files li #drop-upload-name{float:left;max-width:180px;text-overflow:ellipsis;white-space:nowrap;overflow:hidden}#drop-uploaded-files li #drop-upload-status{float:right}.disclaimer,.note{margin:0 auto 30px;max-width:400px;text-align:left}#note-content{padding:5px;display:inline-block;width:350px}#note-content .content{overflow:auto;max-height:200px}#show-terms-dialog{cursor:pointer;font-weight:bold}@media only screen and (min-width: 1025px){#body-public .header-right #header-actions-menu>ul>li#download{display:none}}@media only screen and (max-width: 1024px){#body-public .header-right #header-primary-action{display:none}}@media only screen and (max-width: 1024px){#header.share-file{position:absolute !important}table th.column-size,table td.filesize,table th.column-mtime,table td.date{display:none}table td.filename .nametext{max-width:75% !important}#imgframe{width:100%;padding:0}#imgframe .publicpreview{margin-top:32px}.files-fileList a.action img{padding:0 6px 0 12px}.files-fileList a.action:not(.menuitem) span{display:none}.nametext{width:60%;white-space:nowrap;overflow:hidden;text-overflow:ellipsis}#header .menutoggle{padding-right:14px;background-position:center}.note{padding:0 20px}.emptycontent{margin-top:10vh}}/*# sourceMappingURL=publicView.css.map */
