OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Omogućili ste TOTP dvofaktorsku autentifikaciju za svoj račun",
    "You disabled TOTP two-factor authentication for your account" : "Onemogućili ste TOTP dvofaktorsku autentifikaciju za svoj račun",
    "TOTP two-factor authentication disabled by an admin" : "Administrator je onemogućio TOTP dvofaktorsku autentifikaciju",
    "TOTP (Authenticator app)" : "TOTP (aplikacija za autentifikaciju)",
    "Authenticate with a TOTP app" : "Izvršite autentifikaciju putem aplikacije TOTP",
    "Two-Factor TOTP Provider" : "Davatelj usluge dvofaktorskog TOTP-a",
    "TOTP two-factor provider" : "Davatelj usluge dvofaktorskog TOTP-a",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "Davatelj usluge dvofaktorske autentifikacije za TOTP (RFC 6238)",
    "Enable TOTP" : "Omogući TOTP",
    "Could not enable TOTP" : "Nije moguće omogućiti TOTP",
    "Could not verify your key. Please try again" : "Vaš ključ nije moguće potvrditi. Pokušajte ponovno",
    "Your new TOTP secret is:" : "Vaš novi tajni ključ za TOTP je:",
    "For quick setup, scan this QR code with your TOTP app:" : "Za brzo postavljanje, skenirajte ovaj QR kôd sa svojom aplikacijom TOTP:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Nakon što konfigurirate aplikaciju, unesite testnu šifru navedenu u nastavku kako biste bili sigurni da sve ispravno radi:",
    "Authentication code" : "Šifra za autentifikaciju",
    "Verify" : "Provjeri",
    "Get the authentication code from the two-factor authentication app on your device." : "Nabavite šifru za autentifikaciju iz aplikacije za dvofaktorsku autentifikaciju na uređaju.",
    "Submit" : "Šalji"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
