OC.L10N.register(
    "related_resources",
    {
    "Calendar" : "Calendario",
    "Calendar \"%s\"" : "Calendario \"%s\"",
    "Deck" : "Deck",
    "Deck board \"%s\"" : "Tablero de Deck \"%s\"",
    "Files" : "Archivos",
    "File \"%s\"" : "Archivo \"%s\"",
    "Group Folder" : "Carpeta de Grupo",
    "Group Folder \"%s\"" : "Carpeta de Grupo \"%s\"",
    "Talk conversation" : "Conversación de Talk",
    "Conversation with %s" : "Conversación con %s",
    "Talk" : "Hablar",
    "Talk conversation \"%s\"" : "Conversación de Talk \"%s\"",
    "Related Resources" : "Recursos relacionados",
    "Displays resources related to current item in right panel" : "Muestra los recursos relacionados con el elemento actual en el panel derecho",
    "Displays resources related to current item in right panel." : "Muestra los recursos relacionados con el elemento actual en el panel derecho."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
