<?php

namespace Doctrine\DBAL\Platforms\Keywords;

/**
 * Microsoft SQL Server 2012 reserved keyword dictionary.
 *
 * @deprecated Use {@see SQLServerKeywords} instead.
 */
class SQLServer2012Keywords extends SQLServerKeywords
{
}
