OC.L10N.register(
    "text",
    {
    "New text file" : "Nuevo archivo de texto",
    "The file was uploaded" : "El archivo fue cargado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo cargado excede el valor establecido en la directiva upload_max_filesize en el archivo php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo cargado excede el valor especificado de la directiva MAX_FILE_SIZE en la forma de HTML",
    "The file was only partially uploaded" : "El archivo sólo fue cargado parcialmente",
    "No file was uploaded" : "No se cargó el archivo",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No fue posible escribir a disco",
    "A PHP extension stopped the file upload" : "Una extensión de PHP detuvo la carga del archivo",
    "Nextcloud Text" : "Texto de Nextcloud",
    "Readme" : "Leame",
    "Text" : "Texto",
    "📝 Collaborative document editing" : "📝 Edición colaborativa de documento ",
    "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "** 📝 ¡Edición Colaborativa de documento!**\n\n- **📝 Enfoque en escritura:** Sin distracciones, solo los formatos que necesitas.\n- **🙋 Trabajando juntos:** ¡Comparte y colabora con amigos y compañeros, sin importar si usan Nextcloud o no!\n- **💾 Formatos abiertos:** Los archivos son guardados como [Markdown](https://en.wikipedia.org/wiki/Markdown), asi puedes editarlos desde cualquier otra aplicación de texto.\n- **✊ Fundación sólida:** Usamos [🐈 tiptap](https://tiptap.scrumpy.io) el cual está basado en [🦉 ProseMirror](https://prosemirror.net) – ¡Muchas gracias a ellos!",
    "Translate" : "Traducir",
    "Use current version" : "Usar la versión actual",
    "Use the saved version" : "Usar la versión guardada",
    "The document has been changed outside of the editor. The changes cannot be applied." : "El documento ha sido cambiado fuera de el editor. Los cambios no pueden ser aplicados.",
    "Edit guest name" : "Editar nombre de invitado",
    "Guest" : "Invitado",
    "Save guest name" : "Guardar nombre de invitado",
    "guest" : "invitado",
    "Offline" : "Sin conexión",
    "Saved" : "Guardado",
    "Unsaved changes" : "Cambios no guardados",
    "Formatting help" : "Ayuda de formato",
    "Keyboard shortcuts" : "Atajos del teclado",
    "Bold" : "Negritas",
    "Italic" : "Cursiva",
    "Strikethrough" : "Tachada",
    "Heading 1" : "Título 1",
    "Heading 6" : "Título 6",
    "Unordered list" : "Lista desordenada",
    "Ordered list" : "Lista ordenada",
    "Blockquote" : "Cita",
    "Code block" : "Bloque de código",
    "Remove link" : "Eliminar enlace",
    "Select language" : "Selecciona el idioma",
    "to" : "para",
    "Replace" : "Reemplazar",
    "Source code" : "Código fuente",
    "Unsupported image type" : "Tipo de imagen no soportado",
    "Undo" : "Deshacer",
    "Redo" : "Rehacer",
    "Headings" : "Títulos",
    "Heading 2" : "Título 2",
    "Heading 3" : "Título 3",
    "Heading 4" : "Título 4",
    "Heading 5" : "Título 5",
    "Info" : "Info",
    "Success" : "Éxito",
    "Warning" : "Advertencia",
    "Add notes, lists or links …" : "Agregar notas, listas o ligas ...",
    "Edit" : "Editar"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
