OC.L10N.register(
    "recommendations",
    {
    "Recommended files" : "Ficheros recomendaos",
    "No recommendations yet" : "Nun hai nenguna recomendación",
    "Recommendations" : "Recomendaciones",
    "Shows recommended files" : "Amuesa ficheros recomendaos",
    "Shows recommended files for quick access of files and folders with recent activity" : "Amuesa ficheros recomendaos p'acceder aína a les carpetes y los ficheros con actividá recién"
},
"nplurals=2; plural=(n != 1);");
