OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "내 계정의 2단계 인증 백업 코드를 생성함",
    "Second-factor backup codes" : "2단계 인증 백업 코드",
    "Generate backup codes" : "백업 코드 생성",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "2단계 인증을 활성화했으나 아직 백업 코드를 생성하지 않았습니다. 백업코드는 2단계 인증을 잃어버려 계정을 복구할 때 필요합니다.",
    "Backup code" : "백업 코드",
    "Use backup code" : "백업 코드 사용",
    "Two factor backup codes" : "2단계 인증 백업 코드",
    "A two-factor auth backup codes provider" : "2단계 인증 백업 코드 공급자",
    "Backup codes have been generated. {used} of {total} codes have been used." : "백업 코드가 생성되었습니다. {total}개 중 {used}개의 코드가 사용되었습니다.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "다음은 백업 코드입니다. 이 코드는 나중에 다시 확인할 수 없으므로 저장하거나 인쇄하십시오.",
    "Save backup codes" : "백업 코드 저장",
    "Print backup codes" : "백업 코드 인쇄",
    "Regenerate backup codes" : "백업 코드 다시 생성",
    "If you regenerate backup codes, you automatically invalidate old codes." : "백업 코드를 다시 생성하면 이전 코드는 자동으로 무효화됩니다.",
    "An error occurred while generating your backup codes" : "백업 코드를 생성하는 중 오류가 발생했습니다.",
    "{name} backup codes" : "{name} 백업 코드",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "2단계 인증을 설정할 때 저장한 백업 코드를 사용하십시오.",
    "Submit" : "제출"
},
"nplurals=1; plural=0;");
