OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "شما احراز هویت دو مرحله ای TOTP را برای حساب خود فعال کرده اید",
    "You disabled TOTP two-factor authentication for your account" : "شما احراز هویت دو مرحله ای TOTP را برای حساب خود غیرفعال کردید",
    "TOTP two-factor authentication disabled by an admin" : "احراز هویت دو مرحله‌ای TOTP توسط یک مدیر غیرفعال شد",
    "TOTP (Authenticator app)" : "TOTP (برنامه Authenticator)",
    "Authenticate with a TOTP app" : "با یک برنامه TOTP احراز هویت",
    "Two-Factor TOTP Provider" : "ارائه دهنده TOTP دو عاملی",
    "TOTP two-factor provider" : "ارائه دهنده دو عامل TOTP",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "ارائه‌دهنده تأییدیه دو عاملی برای TOTP (RFC 6238)",
    "Enable TOTP" : "TOTP را فعال کنید",
    "Could not enable TOTP" : "TOTP فعال نشد",
    "Could not verify your key. Please try again" : "کلید شما تأیید نشد. لطفا دوباره تلاش کنید",
    "Your new TOTP secret is:" : "راز جدید TOTP شما این است:",
    "For quick setup, scan this QR code with your TOTP app:" : "برای راه اندازی سریع، این کد QR را با برنامه TOTP خود اسکن کنید:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "پس از پیکربندی برنامه خود، یک کد آزمایشی در زیر وارد کنید تا مطمئن شوید همه چیز به درستی کار می کند:",
    "Authentication code" : "کد هویت",
    "Verify" : "تأیید کنید",
    "Get the authentication code from the two-factor authentication app on your device." : "کد احراز هویت را از برنامه احراز هویت دو مرحله ای در دستگاه خود دریافت کنید.",
    "Submit" : "ارسال"
},
"nplurals=2; plural=(n > 1);");
