<?php
namespace Aws\SupportApp\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Support App** service.
 */
class SupportAppException extends AwsException {}
