OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Federated sharing",
    "Invalid Federated Cloud ID" : "ID Federated Cloud incorrècte",
    "Sharing %s failed, because this item is already shared with %s" : "Lo partiment de %s a fracassat perque aqueste objècte es ja partejat amb %s",
    "File is already shared with %s" : "Lo fichièr es ja partejat amb %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Lo partiment de %s a fracassat : impossible de trobar %s. Benlèu que lo servidor es momentanèament injonhable.",
    "Accept" : "Acceptar",
    "Decline" : "Refusar",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Partejatz amb ieu gràcias a mon identificant Federated Cloud #Nextcloud %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Partejatz amb ieu gràcias a mon identificant Federated Cloud #Nextcloud",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "Open documentation" : "Veire la documentacion",
    "Allow users on this server to send shares to other servers" : "Autorizar los utilizaires d'aqueste servidor a mandar de partiments cap a d'autres servidors",
    "Allow users on this server to receive shares from other servers" : "Autorizar los utilizaires d'aqueste servidor a recebre de partiments d'autres servidors",
    "Federated Cloud" : "Federated Cloud",
    "Your Federated Cloud ID:" : "Vòstre identificant Federated Cloud :",
    "Share it:" : "Partejar :",
    "Add to your website" : "Apondre a vòstre site web",
    "Share with me via Nextcloud" : "Partejatz amb ieu via Nextcloud",
    "HTML Code:" : "Còdi HTML :"
},
"nplurals=2; plural=(n > 1);");
