<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  6610 => 'กรุงเทพ/นนทบุรี/ปทุมธานี/สมุทรปราการ',
  6616 => 'กรุงเทพ/นนทบุรี/ปทุมธานี/สมุทรปราการ',
  6618 => 'กรุงเทพ/นนทบุรี/ปทุมธานี/สมุทรปราการ',
  6619 => 'กรุงเทพ/นนทบุรี/ปทุมธานี/สมุทรปราการ',
  662 => 'กรุงเทพ/นนทบุรี/ปทุมธานี/สมุทรปราการ',
  6632 => 'เพชรบุรี/ประจวบคีรีขันธ์/ราชบุรี',
  6633 => 'ฉะเชิงเทรา/ชลบุรี/ระยอง',
  6634 => 'กาญจนบุรี/นครปฐม/สมุทรสาคร/สมุทรสงคราม',
  6635 => 'อ่างทอง/พระนครศรีอยุธยา/สุพรรณบุรี',
  6636 => 'ลพบุรี/สระบุรี/สิงห์บุรี',
  6637 => 'นครนายก/ปราจีนบุรี/สระแก้ว',
  6638 => 'ฉะเชิงเทรา/ชลบุรี/ระยอง',
  6639 => 'จันทบุรี/ตราด',
  6642 => 'เลย/มุกดาหาร/นครพนม/หนองคาย/สกลนคร/อุดรธานี',
  6643 => 'กาฬสินธุ์/ขอนแก่น/มหาสารคาม/ร้อยเอ็ด',
  6644 => 'บุรีรัมย์/ชัยภูมิ/นครราชสีมา/สุรินทร์',
  6645 => 'อำนาจเจริญ/ศรีสะเกษ/อุบลราชธานี/ยโสธร',
  6652 => 'เชียงใหม่/เชียงราย/ลำพูน/แม่ฮ่องสอน',
  6653 => 'เชียงใหม่/เชียงราย/ลำพูน/แม่ฮ่องสอน',
  6654 => 'ลำปาง/น่าน/พะเยา/แพร่',
  6655 => 'กำแพงเพชร/พิษณุโลก/สุโขทัย/ตาก/อุตรดิตถ์',
  6656 => 'ชัยนาท/นครสวรรค์/เพชรบูรณ์/พิจิตร/อุทัยธานี',
  6673 => 'นราธิวาส/ปัตตานี/ยะลา',
  6674 => 'พัทลุง/สตูล/สงขลา',
  6675 => 'กระบี่/นครศรีธรรมราช/ตรัง',
  6676 => 'พังงา/ภูเก็ต',
  6677 => 'ชุมพร/ระนอง/สุราษฎร์ธานี',
);
