OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "檔案提醒",
    "Reminder for {name}" : "{name} 的提醒",
    "View file" : "檢視檔案",
    "View folder" : "檢視資料夾",
    "Set file reminders" : "設定檔案提醒",
    "**📣 File reminders**\n\nSet file reminders." : "**📣 檔案提醒**\n\n設定檔案提醒。",
    "Back" : "上星期",
    "Clear reminder" : "清除提醒",
    "Set custom reminder" : "設定自訂提醒",
    "Later today" : "今日稍後",
    "Set reminder for later today" : "設定今天稍後的提醒",
    "Tomorrow" : "明日",
    "Set reminder for tomorrow" : "設定明天的提醒",
    "This weekend" : "本週末",
    "Set reminder for this weekend" : "設定本週末的提醒",
    "Next week" : "下星期",
    "Set reminder for next week" : "設定下星期的提醒",
    "Set reminder at custom date & time" : "設定自訂日期與時間的提醒",
    "Reminder set for \"{fileName}\"" : "「{fileName}」的提醒設定",
    "Failed to set reminder" : "設定提醒失敗",
    "Please choose a valid date & time" : "請選擇有效的日期與時間",
    "Reminder cleared" : "提醒已清除",
    "Failed to clear reminder" : "清除提醒失敗",
    "Failed to load reminder" : "載入提醒失敗"
},
"nplurals=1; plural=0;");
