OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Указанное название слишком длинное",
    "The given web address is too long" : "Указанный веб-адрес слишком длинный",
    "The given web address is not a valid URL" : "Указанный веб-адрес не является действительным URL",
    "The given legal notice address is too long" : "Указанный адрес на официальное уведомление слишком длинный",
    "The given legal notice address is not a valid URL" : "Указанный адрес на официальное уведомление не является действительным URL",
    "The given privacy policy address is too long" : "Указанный адрес политики конфиденциальности слишком длинный",
    "The given privacy policy address is not a valid URL" : "Указанный адрес политики конфиденциальности не является действительным URL",
    "The given slogan is too long" : "Указанный слоган слишком длинный",
    "The given color is invalid" : "Задан неправильный цвет",
    "Disable-user-theming should be true or false" : "Disable-user-theming должен быть true или false",
    "Saved" : "Сохранено",
    "The file was uploaded" : "Файл был загружен",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Размер переданного файла превышает установленный предел upload_max_filesize в php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Размер переданного файла превышает установленный предел MAX_FILE_SIZE в HTML-форме",
    "The file was only partially uploaded" : "Файл был получен частично",
    "No file was uploaded" : "Не было отправлено ни одного файла",
    "Missing a temporary folder" : "Отсутствует временный каталог",
    "Could not write file to disk" : "Невозможно записать файл на диск",
    "A PHP extension stopped the file upload" : "Расширение PHP прервало загрузку файла",
    "No file uploaded" : "Нет загруженных файлов",
    "Failed to clean up the old administration theming images folder" : "Не удалось очистить старую папку с изображениями для администрирования тем",
    "Failed to clean up the old administration image folder" : "Не удалось очистить старую папку с изображением для администрирования",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Вы уже используете настраиваемое оформление, которое может быть перезаписано этим приложением.",
    "Theming" : "Внешний вид",
    "Appearance and accessibility" : "Внешний вид и доступность",
    "Dark theme with high contrast mode" : "Темная тема с режимом высокой контрастности",
    "Enable dark high contrast mode" : "Включить темную тему в режиме высокой контрастности",
    "Similar to the high contrast mode, but with dark colours." : "Аналогично режиму высокой контрастности, но с использованием темных цветов.",
    "Dark theme" : "Тёмное оформление",
    "Enable dark theme" : "Использовать тёмное оформление",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Темная тема для облегчения работы ваших глаз за счет уменьшения общей яркости.",
    "System default theme" : "Системная тема по умолчанию",
    "Enable the system default" : "Включить системную тему по умолчанию",
    "Using the default system appearance." : "Используется внешний вид системы по умолчанию.",
    "Dyslexia font" : "Шрифт Dyslexia",
    "Enable dyslexia font" : "Использовать шрифт Dyslexia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic — бесплатный шрифт, который смягчает некоторые распространённые ошибки чтения, вызываемые дислексией.",
    "High contrast mode" : "Режим высокой контрастности",
    "Enable high contrast mode" : "Включить режим высокой контрастности",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Этот режим делает ярлыки и кнопки меню более чёткими за счёт уменьшения качества.",
    "Light theme" : "Светлая тема",
    "Enable the default light theme" : "Включить светлую тему по умолчанию",
    "The default light appearance." : "Подсветка по умолчанию.",
    "Legal notice" : "Официальное уведомление",
    "Privacy policy" : "Политика конфиденциальности",
    "Adjust the Nextcloud theme" : "Скорректируйте тему Nextcloud'а",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Этот модуль позволяют настроить внешний вид сервера и поддерживаемых клиентов. Настройки, определённые в этом модуле, распространяются на всех пользователей.",
    "Advanced options" : "Дополнительные параметры",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Для автоматической генерации favicon на основе загруженного логотипа и цвета нужно установить PHP расширение ImageMagick  с поддержкой изображений SVG ",
    "Name" : "Название",
    "Web link" : "Ссылка",
    "a safe home for all your data" : "надёжный дом для всех ваших данных",
    "Slogan" : "Слоган",
    "Color" : "Цвет",
    "Logo" : "Логотип",
    "Upload new logo" : "Загрузить новый логотип",
    "Background and login image" : "Фоновое изображение и изображение входа в систему",
    "Upload new background and login image" : "Загрузите новое фоновое изображение и изображение для входа в систему",
    "Legal notice link" : "Ссылка на официальное уведомление",
    "Privacy policy link" : "Ссылка на политику конфиденциальности",
    "Header logo" : "Логотип заголовка",
    "Upload new header logo" : "Загрузить логотип заголовка",
    "Favicon" : "Favicon (значок сайта)",
    "Upload new favicon" : "Загрузить значок сайта",
    "User settings" : "Параметры пользователя",
    "Disable user theming" : "Отключить выбор темы для пользователей",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Хотя вы можете выбрать и настроить свой экземпляр, пользователи могут изменять свой фон и цвета. Если вы хотите принудительно применить свои настройки для всех, вы можете включить это.",
    "Background" : "Фон",
    "Customization has been disabled by your administrator" : "Настройка тем была отключена вашим администратором",
    "Set a custom background" : "Установить пользовательский фон",
    "Keyboard shortcuts" : "Сочетания клавиш",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "В некоторых случаях сочетания клавиш могут мешать работе инструментов специальных возможностей. Чтобы правильно сфокусироваться на вашем инструменте, вы можете отключить здесь все сочетания клавиш. Это также отключит все доступные ярлыки в приложениях.",
    "Disable all keyboard shortcuts" : "Отключить все сочетания клавиш",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Доступная среда очень важна для нас. При разработке мы следуем веб-стандартам, контролируя возможность пользования всем сервисом без помощи мыши и с использованием вспомогательных программ, например, выполняющих чтение с экрана. Мы стремимся к выполнению рекомендаций {guidelines}Руководства доступности Веб-Контента{linkend} 2.1 на уровне АА, а при использовании режима высокой контрастности  — даже на уровне ААА.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "При обнаружении ошибок, не стесняйтесь сообщать о них {issuetracker}на наш форум{linkend}. Если Вы заинтересованы в продвижении проекта присоединяйтесь к {designteam}нашей команде дизайнеров{linkend}!",
    "Move up" : "Переместить выше",
    "Move down" : "Переместить ниже",
    "Custom background" : "Пользовательский фон",
    "Default background" : "Фоновое изображение по умолчанию",
    "Change color" : "Изменить цвет",
    "No background" : "Без фона",
    "Select a background from your files" : "Выберите фон из ваших файлов",
    "Select background" : "Выбрать фоновое изображение",
    "No background has been selected" : "Фоновое изображение не было выбрано",
    "Theme selection is enforced" : "Выбор темы принудительно",
    "Select a custom color" : "Выберать собственный цвет",
    "Reset to default" : "Сбросить изменения",
    "Upload" : "Отправить",
    "Remove background image" : "Убрать фоновое изображение ",
    "Loading preview…" : "Загружается предпросмотр…",
    "Admin" : "Администратор",
    "Error uploading the file" : "Ошибка при загрузке файла",
    "Name cannot be empty" : "Имя не может быть пустым",
    "Migrate and clean up admin theming images" : "Перенос и очистка изображений темы администратора",
    "Failed to clean up the old admin theming images folder" : "Не удалось очистить старую папку с изображением для администрирования",
    "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "В некоторых случаях сочетания клавиш могут мешать работе инструментов специальных возможностей. Чтобы правильно сфокусироваться на вашем инструменте, вы можете отключить здесь все сочетания клавиш. Это также отключит все доступные ярлыки в приложениях.",
    "Pick from Files" : "Выбрать из файлов",
    "Default image" : "Изображение по умолчанию",
    "Custom color" : "Свой цвет",
    "Plain background" : "Обычный фон",
    "Insert from {productName}" : "Вставить из {productName}",
    "Open documentation" : "Открыть документацию",
    "https://…" : "https://",
    "Upload new login background" : "Загрузить новый фон для экрана входа в систему",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can check this box." : "Хотя вы можете выбрать и настроить свой экземпляр, пользователи могут изменять свой фон и цвета. Если вы хотите принудительно применить свою настройку для всех, вы можете включить это.",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Для автоматической генерации favicon на основе загруженного логотипа и цвета нужно установить PHP расширение Imagemagick  с поддержкой изображений SVG "
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
