OC.L10N.register(
    "photos",
    {
    "Public link" : "Verejný odkaz",
    "Photos" : "Fotografie",
    "Your memories under your control" : "Vaše spomienky pod vašou kontrolou",
    "All media" : "Všetky médiá",
    "Videos" : "Videá",
    "Albums" : "Albumy",
    "Collaborative albums" : "Kolaboratívne albumy",
    "People" : "Ľudia",
    "Folders" : "Priečinky",
    "Favorites" : "Obľúbené",
    "On this day" : "V tento deň",
    "Shared with you" : "Vám sprístupnené",
    "Tags" : "Štítky",
    "Places" : "Miesta",
    "Map" : "Mapa",
    "Photos settings" : "Nastavenia fotiek",
    "Mark selection as favorite" : "Označiť vybrané ako obľúbené",
    "Add selection to favorites" : "Pridať vybrané ako obľúbené",
    "Remove selection from favorites" : "Odstrániť vybrané z obľúbených",
    "Name of the album" : "Pomenovať album",
    "Location of the album" : "Umiestnenie albumu",
    "Back" : "Späť",
    "Add collaborators" : "Pridať spolupracujúcich",
    "Save" : "Uložiť",
    "Create album" : "Vytvoriť album",
    "Add to Album" : "Pridať do Albumu",
    "Add selection to album {albumName}" : "Pridať vybrané do albumu {ablumName}",
    "Shared by" : "Zdieľané od",
    "Create a new album." : "Vytvoriť nový album.",
    "Create new album" : "Vytvoriť nový album",
    "New album" : "Nový album",
    "_%n item_::_%n photos and videos_" : ["%n fotka alebo video","%n fotky a videá","%n fotiek a videí","%n fotiek a videí"],
    "Add people or groups who can edit your album" : "Pridať užívateľov alebo skupiny ktoré môžu upravovať váš album",
    "Search people or groups" : "Vyhľadať užívateľov alebo skupiny",
    "No recommendations. Start typing." : "Žiadne odporúčania. Môžete začať písať.",
    "Group" : "Skupina",
    "Remove {collaboratorLabel} from the collaborators list" : "Odobrať {collaboratorLabel} zo zoznamu spolupracovníkov",
    "Copy the public link" : "Kopírovať verejný odkaz",
    "Public link copied!" : "Verejný odkaz skopírovaný!",
    "Copy public link" : "Kopírovať verejný odkaz",
    "Delete the public link" : "Zmazať verejný odkaz",
    "Create public link share" : "Vytvoriť verejný odkaz so zdieľaním",
    "Share via public link" : "Zdieľať ako verejný odkaz",
    "Failed to fetch collaborators list." : "Nepodarilo sa získať zoznam spolupracovníkov.",
    "Failed to update album." : "Nepodarilo sa aktualizovať album.",
    "This collection does not exist" : "Kolekcia neexistuje",
    "An error occurred" : "Vyskytla sa chyba",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n nepriradená fotografia","%n nepriradené fotografie","%n nepriradených fotografií","%n nepriradených fotografií"],
    "Select image {imageName}" : "Vybrať obrázok {imageName}",
    "The file is in the favorites" : "Súbor je medzi obľúbenými",
    "Open the full size \"{name}\" image" : "Otvoriť fotografiu „{name}“ v pôvodnej veľkosti",
    "There are no photos or videos yet!" : "Zatiaľ tu nie sú žiadne fotky alebo videá!",
    "Add to {destination}" : "Pridať do {destination}",
    "Open the \"{name}\" sub-directory" : "Otvoriť podpriečinok „{name}“",
    "Back to {folder}" : "Späť do {folder}",
    "Share this folder" : "Sprístupniť tento priečinok",
    "_{years} year ago_::_{years} years ago_" : ["{years} rok spať","{years} roky späť","{years} rokov späť","{years} rokov späť"],
    "Enable squared photos view" : "Zapnúť štvorcové zobrazenie fotiek",
    "Default Photos upload and Albums location" : "Predvolené umiestnenie pre nahrávané Fotky a Albumy",
    "Choose default Photos upload and Albums location" : "Vyberte predvolené umiestnenie pre nahrávané Fotky a Albumy",
    "Select the default location for your media" : "Vyberte východzie umiestnenie pre vaše médiá",
    "Invalid location selected" : "Bolo vybrané neplatné umiestnenie",
    "View" : "Prezerať",
    "Photos directory" : "Priečinok pre fotky",
    "_%n photo_::_%n photos_" : ["%n fotka","%n fotky","%n fotiek","%n fotiek"],
    "Unselect all" : "Zrušiť výber",
    "Manage collaborators for this album" : "Spravovať spolupracovníkov pre tento album",
    "Open actions menu" : "Otvoriť ponuku akcií",
    "Edit album details" : "Upraviť podrobnosti o albume",
    "Download all files in album" : "Stiahnuť všetky súbory z albumu",
    "Delete album" : "Zmazať album",
    "Download selected files" : "Stiahnuť vybrané súbory",
    "Remove selection from album" : "Odstrániť vybrané z albumu",
    "This album does not have any photos or videos yet!" : "Tento album zatiaľ neobsahuje žiadne fotky alebo videá!",
    "Add photos to this album" : "Pridať fotky do tohto albumu",
    "Manage collaborators" : "Spravovať spolupracovníkov",
    "Save collaborators for this album." : "Uložiť spolupracovníkov pre tento album.",
    "Cover photo for album {albumName}" : "Fotka obalu pre album {albumName}",
    "There is no album yet!" : "Zatiaľ tu nie je žiadny album!",
    "This person could not be found" : "Túto osobu sa nepodarilo nájisť",
    "Rename person" : "Premenovať osobu",
    "Merge with different person" : "Spojiť s inou osobou",
    "Download selected photos" : "Stiahnuť vybrané fotky",
    "Favorite" : "Obľúbené",
    "Remove from favorites" : "Odstrániť z obľúbených",
    "Remove person" : "Odstrániť osobu",
    "Name of this person" : "Meno tejto osoby",
    "Save." : "Uložiť.",
    "Merge person" : "Spojiť osobu",
    "_Remove photo from person_::_Remove photos from person_" : ["Odstrániť fotky z osoby","Odstrániť fotky z osôb","Odstrániť fotky z osôb","Odstrániť fotky z osôb"],
    "This might take some time depending on the size of your photo library." : "Toto môže chvíľu trvať podľa veľkosti vašej knižnice fotiek.",
    "Recognized people will show up here" : "Rozpoznané osoby sa zobrazia tu",
    "This folder does not exist" : "Tento priečinok neexistuje",
    "Loading folders …" : "Nahrať priečinky ...",
    "No photos in here" : "Nie sú tu žiadne fotografie",
    "Cover photo for place {placeName}" : "Fotka obalu pre miesto {placeName}",
    "Cover photo for shared album {albumName}." : "Fotka obalu pre zdieľaný album {albumName}.",
    "Back to tags overview" : "Späť k prehladu štítkov",
    "No photos with this tag yet" : "Zatiaľ nie sú žiadne fotky s týmto štítkom",
    "No tags yet" : "Zatiaľ žiadne štítky",
    "Photos with tags will show up here" : "Fotografie so štítkami sa zobrazia tu",
    "Popular tags" : "Populárne štítky",
    "Add" : "Pridať",
    "Add to album" : "Pridať do albumu",
    "Delete selection" : "Zmazanie výberu",
    "No photos or videos in here" : "Nie sú tu žiadne obrázky ani videá",
    "_%n photos_::_%n photos_" : ["%n fotka","%n fotky","%n fotiek","%n fotiek"],
    "Failed to fetch faces list." : "Nepodarilo sa načítať zoznam tvárí.",
    "All your media" : "Všetky vaše médiá",
    "Tagged photos" : "Označené fotografie",
    "Failed to rename {oldName} to {faceName}." : "Chyba pri premenovávaní {oldName} na {faceName}.",
    "Failed to delete {faceName}." : "Nepodarilo sa zmazať {faceName}.",
    "Failed to delete {fileId}." : "Nepodarilo sa zmazať {fileId}.",
    "Failed to delete {fileName}." : "Nepodarilo sa zmazať {fileName}.",
    "Failed to set favorite state for {fileId}." : "Nepodarilo sa nastaviť obľúbený stav pre {fileId}.",
    "Failed to set favorite state for {fileName}." : "Nepodarilo sa nastaviť obľúbený stav pre {fileName}.",
    "Locations" : "Umiestnenie",
    "Go back to the previous view." : "Vrátiť sa na predchádzajúce zobrazenie.",
    "Go to the add collaborators view." : "Ísť na zobrazenie pre pridanie spolupracujúcich.",
    "Create the album." : "Vytvoriť album.",
    "Back to the new album form." : "Späť na formulár pre pridanie nového albumu.",
    "_Share with %n user_::_Share with %n users_" : ["Zdieľať s %n užívateľom","Zdieľať s %n užívateľmi","Zdieľať s %n užívateľmi","Zdieľať s %n užívateľmi"],
    "Search for collaborators" : "Vyhľadať spolupracovníkov",
    "Add {collaboratorLabel} to the collaborators list" : "Pridať {collaboratorLabel} na zoznam spolupracovníkov",
    "No collaborators available" : "Nie sú dostupný žiadny spolupracovníci",
    "Failed to fetch album." : "Nepodarilo sa načítať album.",
    "Add photos to the album" : "Pridať fotky do albumu",
    "Failed to fetch albums list." : "Nepodarilo sa načítať zoznam albumov.",
    "Shared albums" : "Zdieľané albumy",
    "Create a new album" : "Vytvoriť nový album",
    "Add selection to an album" : "Pridať vybrané do albumu",
    "Failed to create {albumName}." : "Zlyhalo vytváranie {albumName}.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Chyba pri premenovávaní {currentAlbumName} na {newAlbumName}."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
