OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "Sveiki, %s",
    "Hello %s," : "Sveiki, %s,",
    "Admin notifications" : "Adminu paziņojumi",
    "Notifications" : "Paziņojumi",
    "Dismiss" : "Atmest",
    "seconds ago" : "pirms mirkļa",
    "Failed to dismiss notification" : "Neizdevās atmest paziņojumu",
    "in {path}" : "{path}",
    "No notifications" : "Nav paziņojumu",
    "Never" : "Nekad",
    "1 hour" : "1 stunda",
    "3 hours" : "3 stundas",
    "Your settings have been updated." : "Jūsu uzstādījumi ir atjaunoti.",
    "You need to set up your email address before you can receive notification emails." : "Lai saņemtu paziņojumus e-pastā, jūsu profilā ir nepieciešams uzstādīt e-pasta adresi."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
