OC.L10N.register(
    "systemtags",
    {
    "Tag name is empty" : "Etiketaren izena hutsik dago",
    "Update" : "Eguneratu",
    "Create" : "Sortu",
    "Select tag …" : "Hautatu etiketa ...",
    "System tag %1$s added by the system" : "Sistemak gehitutako%1$s sistemako etiketa",
    "Added system tag {systemtag}" : "{systemtag} sistemako etiketa gehituta",
    "Added system tag %1$s" : "%1$s sistemako etiketa gehitu da",
    "%1$s added system tag %2$s" : "%1$s(e)k %2$s sistemako etiketa gehitu du",
    "{actor} added system tag {systemtag}" : "{actor}(e)k {systemtag} sistemako etiketa gehitu du",
    "System tag %1$s removed by the system" : "Sistemak kendutako %1$ssistemako etiketa",
    "Removed system tag {systemtag}" : "{systemtag} sistema etiketa kendu da",
    "Removed system tag %1$s" : "%1$s sistemako etiketa kendu da",
    "%1$s removed system tag %2$s" : "%1$s(e)k %2$s sistemaren etiketa kendu du",
    "{actor} removed system tag {systemtag}" : "{actor}(e)k {systemtag} sistemako etiketa kendu du",
    "You created system tag %1$s" : "%1$s sistemako etiketa zuk sortu duzu",
    "You created system tag {systemtag}" : "{systemtag} sistemako etiketa zuk sortu duzu",
    "%1$s created system tag %2$s" : "%1$s(e)k %2$s sistemako etiketa sortu du",
    "{actor} created system tag {systemtag}" : "{actor}(e)k {systemtag} sistemako etiketa gehitu du",
    "You deleted system tag %1$s" : "%1$s sistemako etiketa ezabatu duzu",
    "You deleted system tag {systemtag}" : "{systemtag} sistemako etiketa ezabatu duzu",
    "%1$s deleted system tag %2$s" : "%1$s(e)k %2$s sistemako etiketa ezabatu du",
    "{actor} deleted system tag {systemtag}" : "{actor}(e)k {systemtag} sistemako etiketa ezabatu du",
    "You updated system tag %2$s to %1$s" : "%2$s sistemako etiketa %1$s(e)ra eguneratu duzu",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "{oldsystemtag} sistemako etiketa {newsystemtag}(e)ra eguneratu duzu",
    "%1$s updated system tag %3$s to %2$s" : "%1$s(e)k %3$s sistemako etiketa %2$s(e)ra eguneratu du",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor}-(e)k  {oldsystemtag} sistemako etiketa eguneratu du {newsystemtag}-(e)ra",
    "System tag %2$s was added to %1$s by the system" : "Sistemak gehitu du %2$ssistemako etiketa %1$s-(e)ra ",
    "System tag {systemtag} was added to {file} by the system" : "Sistemak gehitu du {systemtag} sistemako etiketa {file}-(e)ra",
    "You added system tag %2$s to %1$s" : "%2$s sistemako etiketa gehitu duzu %1$s(e)ra",
    "You added system tag {systemtag} to {file}" : "{systemtag} sistemako etiketa gehitu duzu {file}(e)ra",
    "%1$s added system tag %3$s to %2$s" : "%1$s-(e)k gehitu du %3$ssistemako etiketa %2$s-(e)ra",
    "{actor} added system tag {systemtag} to {file}" : "{actor}(e)k {systemtag} sistemako etiketa gehitu du {file}(e)ra",
    "System tag %2$s was removed from %1$s by the system" : "Sistemak kendu du %2$ssistemako etiketa %1$s-(e)tik",
    "System tag {systemtag} was removed from {file} by the system" : "Sistemak kendu du {systemtag} sistemako etiketa {file}-(e)tik",
    "You removed system tag %2$s from %1$s" : "%2$s sistemako etiketa %1$s(e)tik kendu duzu",
    "You removed system tag {systemtag} from {file}" : "{systemtag} sistemako etiketa ezabatu duzu {file} fitxategitik",
    "%1$s removed system tag %3$s from %2$s" : "%1$s-(e)k kendu du %3$ssistemako etiketa %2$s-(e)tik",
    "{actor} removed system tag {systemtag} from {file}" : "{actor}(e)k {systemtag} sistemako etiketa kendu du {file}(e)tik",
    "%s (restricted)" : "%s (mugatua)",
    "%s (invisible)" : "%s (ikusezina)",
    "<strong>System tags</strong> for a file have been modified" : "Fitxategi baten <strong>sistema-etiketak</strong> aldatu egin dira",
    "Tags" : "Etiketak",
    "All tagged %s …" : "%sguztiak etiketatuta …",
    "tagged %s" : "%setiketatuta",
    "Collaborative tags" : "Elkarlaneko etiketak",
    "Collaborative tagging functionality which shares tags among users." : "Etiketak erabiltzaileen artean partekatzen dituen lankidetzazko etiketatze funtzionalitatea.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Etiketak erabiltzaileen artean partekatzen dituen lankidetzazko etiketatze funtzionalitatea. Bikaina taldeentzat.\n\t(Maizter anitzeko instalazioa duen hornitzailea bazara, gomendatzen da aplikazio hau desaktibatzea etiketak partekatzen dira eta.)",
    "Loading collaborative tags …" : "Elkarlaneko etiketak kargatzen ...",
    "Search or create collaborative tags" : "Bilatu edo sortu elkarlaneko etiketak",
    "Collaborative tags …" : "Elkarlaneko etiketak ...",
    "No tags to select, type to create a new tag" : "Ez dago hautatzeko etiketarik, idatzi etiketa berria sortzeko",
    "Failed to load tags" : "Etiketak kargatzeak huts egin du",
    "Failed to load selected tags" : "Hautatutako etiketa kargatzeak huts egin du",
    "Failed to select tag" : "Etiketa hautatzeak huts egin du",
    "Failed to create tag" : "Etiketa sortzeak huts egin du",
    "Failed to delete tag" : "Etiketa ezabatzeak huts egin du",
    "This file has the tag {tag}" : "Fitxategi honek {tag} etiketa dauka",
    "This file has the tags {firstTags} and {lastTag}" : "Fitxategi honek {firstTags} eta {lastTag} etiketak ditu",
    "List of tags and their associated files and folders." : "Etiketak eta atxikituta dituzten fitxategi eta karpetak.",
    "No tags found" : "Ez da etiketarik aurkitu",
    "Tags you have created will show up here." : "Sortu dituzun etiketak hemen agertuko dira.",
    "Failed to load last used tags" : "Ezin izan dira azken erabilitako etiketak kargatu",
    "Missing \"Content-Location\" header" : "\"Content-Location\" goiburua falta",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Lankidetzazko etiketak erabilgarri daude erabiltzaile guztientzat. Erabiltzaileek  etiketa murriztuak ikusgai dituzte baina ezin dituzte haiek esleitu. Etiketa ikusezinak barne erabilerarako dira, erabiltzaileek ezin baitituzte ikusi edo esleitu.",
    "Create a new tag" : "Sortu etiketa berria",
    "Tag name" : "Etiketaren izena",
    "Name" : "Izena",
    "Tag level" : "Etiketaren maila",
    "Public" : "Publikoa",
    "Restricted" : "Mugatua",
    "Invisible" : "Ikusezina",
    "Delete" : "Ezabatu",
    "Reset" : "Berrezarri",
    "No files in here" : "Ez dago fitxategirik hemen",
    "No entries found in this folder" : "Ez da sarrerarik aurkitu karpeta honetan",
    "Size" : "Tamaina",
    "Modified" : "Aldatuta",
    "Tagged files" : "Etiketatutako fitxategiak",
    "Select tags to filter by" : "Hautatu etiketak iragazteko",
    "Please select tags to filter by" : "Hautatu etiketak iragazteko",
    "No files found for the selected tags" : "Ez da fitxategirik aurkitu hautatutako etiketetarako"
},
"nplurals=2; plural=(n != 1);");
