OC.L10N.register(
    "files_versions",
    {
    "Versions" : "Versiounen",
    "Failed to revert {file} to revision {timestamp}." : "Konnt {file} net op d'Versioun {timestamp} zrécksetzen.",
    "_%n byte_::_%n bytes_" : ["%n Byte","%n Bytes"],
    "Restore" : "Zrécksetzen",
    "No other versions available" : "Keng aner Versiounen disponibel"
},
"nplurals=2; plural=(n != 1);");
