<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  22042 => 'Banjul',
  22043 => 'Bundung/Serekunda',
  2204410 => 'Brufut',
  2204412 => 'Tanji',
  2204414 => 'Sanyang',
  2204416 => 'Tujereng',
  2204417 => 'Sanyang',
  2204419 => 'Kartong',
  22044195 => 'Berending',
  220446 => 'Kotu/Senegambia',
  220447 => 'Yundum',
  2204480 => 'Bondali',
  2204481 => 'Brikama/Kanilia',
  2204482 => 'Brikama/Kanilia',
  2204483 => 'Brikama/Kanilia',
  2204484 => 'Brikama/Kanilia',
  2204485 => 'Kafuta',
  2204486 => 'Gunjur',
  2204487 => 'Faraba',
  2204488 => 'Sibanor',
  2204489 => 'Bwiam',
  220449 => 'Bakau',
  220553 => 'Soma',
  2205540 => 'Kaiaf',
  2205541 => 'Kwenella',
  2205542 => 'Nyorojattaba',
  2205543 => 'Japeneh/Soma',
  2205544 => 'Bureng',
  2205545 => 'Pakaliba',
  2205546 => 'Kudang',
  2205547 => 'Jareng',
  220566 => 'Baja Kunda/Basse/Fatoto/Gambisara/Garawol/Misera/Sambakunda/Sudowol',
  2205665 => 'Kuntaur',
  2205666 => 'Numeyel',
  220567 => 'Sotuma',
  2205674 => 'Bansang',
  2205676 => 'Georgetown',
  2205678 => 'Brikama-Ba',
  2205710 => 'Barra',
  2205714 => 'Ndugukebbe',
  2205720 => 'Kerewan',
  2205723 => 'Njabakunda',
  2205725 => 'Iliasa',
  2205735 => 'Farafenni',
  2205738 => 'Ngensanjal',
  220574 => 'Kaur',
);
