OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "הפעלת אימות TOTP דו־שלבי לחשבון שלך",
    "You disabled TOTP two-factor authentication for your account" : "השבתת אימות TOTP דו־שלבי לחשבון שלך",
    "TOTP two-factor authentication disabled by an admin" : "אימות דו־שלבי בתצורת TOTP הושבת על ידי ההנהלה",
    "TOTP (Authenticator app)" : "TOTP (יישומון אימות)",
    "Authenticate with a TOTP app" : "אימות עם יישום ה- TOTP",
    "Two-Factor TOTP Provider" : "ספק TOTP לאימות דו־שלבי",
    "TOTP two-factor provider" : "ספק אימות דו־שלבי TOTP",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "ספק אימות דו־שלבי עבור TOTP‏ (RFC 6238)",
    "Enable TOTP" : "הפעלת TOTP",
    "Could not enable TOTP" : "לא ניתן להפעיל TOTP",
    "Could not verify your key. Please try again" : "לא ניתן לוודא שהמפתח שלך תקין. נא לנסות שוב",
    "Your new TOTP secret is:" : "סוד ה־TOTP החדש שלך הוא:",
    "Authentication code" : "קוד אימות",
    "Verify" : "אימות",
    "Get the authentication code from the two-factor authentication app on your device." : "קבלת קוד אימות מיישום אימות דו-מרכיבי בהתקן שלך.",
    "Submit" : "הגשה"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
