OC.L10N.register(
    "lib",
    {
    "Other activities" : "Otres actividaes",
    "The library %s is not available." : "La biblioteca «%s» nun ta disponible.",
    "Authentication" : "Autenticación",
    "today" : "güei",
    "tomorrow" : "mañana",
    "yesterday" : "ayeri",
    "Templates" : "Plantíes",
    "Help" : "Ayuda",
    "Appearance and accessibility" : "Aspeutu ya accesibilidá",
    "Apps" : "Aplicaciones",
    "Personal settings" : "Configuración personal",
    "Settings" : "Configuración",
    "Fediverse" : "Fediversu",
    "Twitter" : "Twitter",
    "Website" : "Sitiu web",
    "Organisation" : "Organización",
    "Role" : "Rol",
    "Additional settings" : "Configuración adicional",
    "%1$s via %2$s" : "%1$s per %2$s",
    "You are not allowed to share %s" : "Nun tienes permisu pa compartir «%s»",
    "Sunday" : "Domingu",
    "Monday" : "Llunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Xueves",
    "Friday" : "Vienres",
    "Saturday" : "Sábadu",
    "Sun." : "Dom.",
    "Mon." : "Llu.",
    "Tue." : "Mar.",
    "Wed." : "Mié.",
    "Thu." : "Xue.",
    "Fri." : "Vie.",
    "Sat." : "Sáb.",
    "Su" : "Do",
    "Mo" : "Ll",
    "Tu" : "Ma",
    "We" : "Mi",
    "Th" : "Xu",
    "Fr" : "Vi",
    "Sa" : "Sá",
    "January" : "Xineru",
    "February" : "Febreru",
    "March" : "Marzu",
    "April" : "Abril",
    "May" : "Mayu",
    "June" : "Xunu",
    "July" : "Xunetu",
    "August" : "Agostu",
    "September" : "Setiembre",
    "October" : "Ochobre",
    "November" : "Payares",
    "December" : "Avientu",
    "Jan." : "Xin.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Abr.",
    "May." : "May.",
    "Jun." : "Xun.",
    "Jul." : "Xnt.",
    "Aug." : "Ago.",
    "Sep." : "Set.",
    "Oct." : "Och.",
    "Nov." : "Pay.",
    "Dec." : "Avi.",
    "a safe home for all your data" : "un llugar seguru pa los datos personales",
    "Application is not enabled" : "L'aplicación nun ta activada",
    "Please ask your server administrator to install the module." : "Pidi a l'alministración del sirvidor qu'instale'l módulu.",
    "Full name" : "Nome completu",
    "To fix this issue update your libxml2 version and restart your web server." : "Pa iguar esti problema, anueva la versión de libxml2 y reanicia'l sirvidor web.",
    "Please upgrade your database version." : "Anueva la versión de la base de datos."
},
"nplurals=2; plural=(n != 1);");
