(self.webpackChunk_nextcloud_text=self.webpackChunk_nextcloud_text||[]).push([["highlight/isbl-js-js"],{77648:(e,i,s)=>{!function e(){e.warned||(e.warned=!0,console.log('Deprecation (warning): Using file extension in specifier is deprecated, use "highlight.js/lib/languages/isbl" instead of "highlight.js/lib/languages/isbl.js"'))}(),e.exports=s(14664)}}]);
//# sourceMappingURL=isbl-js-js.js.map?v=f9f95135165010cc1e7e