<?php
namespace Aws\MainframeModernization\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWSMainframeModernization** service.
 */
class MainframeModernizationException extends AwsException {}
