<?php 
$OC_Version = array(27,1,3,2);
$OC_VersionString = '27.1.3';
$OC_Edition = '';
$OC_Channel = 'stable';
$OC_VersionCanBeUpgradedFrom = array (
  'nextcloud' => 
  array (
    '26.0' => true,
    '27.0' => true,
    '27.1' => true,
  ),
  'owncloud' => 
  array (
    '10.13' => true,
  ),
);
$OC_Build = '2023-10-26T17:25:16+00:00 565dc36226d08d071c30d8ad4fd54126dfa4be79';
$vendor = 'nextcloud';
