/* Error: Undefined variable.
 *    ,
 * 38 | $invert: luma($color-primary) > 0.6;
 *    |               ^^^^^^^^^^^^^^
 *    '
 *   apps/theming/css/theming.scss 38:15  root stylesheet */

body::before {
  font-family: "Source Code Pro", "SF Mono", Monaco, Inconsolata, "Fira Mono",
      "Droid Sans Mono", monospace, monospace;
  white-space: pre;
  display: block;
  padding: 1em;
  margin-bottom: 1em;
  border-bottom: 2px solid black;
  content: "Error: Undefined variable.\a    \2577 \a 38 \2502  $invert: luma($color-primary) > 0.6;\a    \2502                ^^^^^^^^^^^^^^\a    \2575 \a   apps/theming/css/theming.scss 38:15  root stylesheet";
}
