OC.L10N.register(
    "files",
    {
    "File could not be found" : "Невозможно найти файл",
    "Move or copy" : "Переместить или копировать",
    "Download" : "Скачать",
    "Delete" : "Удалить",
    "Tags" : "Метки",
    "Show list view" : "Просмотр списком",
    "Show grid view" : "Просмотр сеткой",
    "Home" : "Главная",
    "Close" : "Закрыть",
    "Could not create folder \"{dir}\"" : "Невозможно создать каталог «{dir}»",
    "This will stop your current uploads." : "Это действие остановит активные сеансы передачи файлов на сервер. ",
    "Upload cancelled." : "Отправка отменена.",
    "Processing files …" : "Обработка файлов…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Невозможно передать «{filename}», так как это либо каталог, либо файл нулевого размера",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Недостаточно свободного места, вы передаёте на сервер {size1}, но доступно только {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Целевой каталог «{dir}» более не существует",
    "Not enough free space" : "Недостаточно свободного места",
    "An unknown error has occurred" : "Произошла неизвестная ошибка",
    "File could not be uploaded" : "Файл не может быть загружен",
    "Uploading …" : "Передача…",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "Загрузка … ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} из {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Загрузка этого элемента не поддерживается",
    "Target folder does not exist any more" : "Каталог больше не существует",
    "Operation is blocked by access control" : "Операция не разрешена модулем контроля доступа",
    "Error when assembling chunks, status code {status}" : "Ошибка при сборке чанков, код ошибки {status}",
    "Actions" : "Действия",
    "Rename" : "Переименовать",
    "Move" : "Переместить",
    "Copy" : "Копировать",
    "Choose target folder" : "Выбор папки назначения",
    "Set reminder" : "Установить напоминание",
    "Edit locally" : "Редактировать локально",
    "Open" : "Открыть",
    "Delete file" : "Удалить файл",
    "Delete folder" : "Удалить каталог",
    "Disconnect storage" : "Отсоединить хранилище",
    "Leave this share" : "Отказаться от совместного доступа к этому ресурсу",
    "Could not load info for file \"{file}\"" : "Не удаётся загрузить информацию для файла \"{file}\"",
    "Files" : "Файлы",
    "Details" : "Подробно",
    "Please select tag(s) to add to the selection" : "Выберите метки для назначения выбранным объектам",
    "Apply tag(s) to selection" : "Назначить метки выбранным объектам",
    "Select directory \"{dirName}\"" : "Выберите каталог \"{dirName}\"",
    "Select file \"{fileName}\"" : "Выберите файл \"{fileName}\"",
    "Pending" : "Ожидается",
    "Unable to determine date" : "Невозможно определить дату",
    "This operation is forbidden" : "Операция запрещена",
    "This directory is unavailable, please check the logs or contact the administrator" : "Каталог недоступен. Проверьте журналы событий или свяжитесь с администратором",
    "Storage is temporarily not available" : "Хранилище временно недоступно",
    "Could not move \"{file}\", target exists" : "Невозможно переместить файл «{file}», он уже существует в каталоге назначения",
    "Could not move \"{file}\"" : "Невозможно переместить файл «{file}»",
    "copy" : "копия",
    "Could not copy \"{file}\", target exists" : "Невозможно скопировать файл «{file}», он уже существует в каталоге назначения",
    "Could not copy \"{file}\"" : "Невозможно скопировать файл «{file}»",
    "Copied {origin} inside {destination}" : "{origin} скопирован в {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} и {nbfiles} других файлов скопированы в {destination}",
    "Failed to redirect to client" : "Ошибка перенаправления в клиент",
    "{newName} already exists" : "«{newName}» уже существует",
    "Could not rename \"{fileName}\", it does not exist any more" : "Невозможно переименовать «{fileName}», файл больше не существует",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Имя «{targetName}» уже используется в каталоге «{dir}». Выберите другое имя.",
    "Could not rename \"{fileName}\"" : "Невозможно переименовать «{fileName}»",
    "Could not create file \"{file}\"" : "Невозможно создать файл «{file}»",
    "Could not create file \"{file}\" because it already exists" : "Невозможно создать файл «{file}», он уже существует",
    "Could not create folder \"{dir}\" because it already exists" : "Невозможно создать каталог «{dir}», он уже существует",
    "Could not fetch file details \"{file}\"" : "Не удалось получить сведения о файле «{file}»",
    "Error deleting file \"{fileName}\"." : "Ошибка удаления файла «{fileName}».",
    "No search results in other folders for {tag}{filter}{endtag}" : "Нет результатов поиска в других папках для {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Введите более двух символов для поиска в других каталогах",
    "Name" : "Имя",
    "Size" : "Размер",
    "Modified" : "Изменён",
    "_%n folder_::_%n folders_" : ["%n каталог","%n каталога","%n каталогов","%n каталогов"],
    "_%n file_::_%n files_" : ["%n файл","%n файла","%n файлов","%n файлов"],
    "{dirs} and {files}" : "{dirs} и {files}",
    "_including %n hidden_::_including %n hidden_" : ["включая %n скрытый","включая %n скрытых","включая %n скрытых","включая %n скрытых"],
    "You do not have permission to upload or create files here" : "У вас нет разрешения на загрузку или создание файлов здесь",
    "_Uploading %n file_::_Uploading %n files_" : ["Передача %n файла","Передача %n файлов","Передача %n файлов","Передача %n файлов"],
    "New" : "Новый",
    "New file/folder menu" : "Меню создания файла или папки",
    "Select file range" : "Выбор диапазона файлов",
    "{used}%" : "{used}%",
    "{used} of {quota} used" : "использовано {used} из {quota}",
    "{used} used" : "Использовано {used}",
    "\"{name}\" is an invalid file name." : "«{name}» — недопустимое имя файла.",
    "File name cannot be empty." : "Имя файла не может быть пустым.",
    "\"/\" is not allowed inside a file name." : "Символ «/» недопустим в имени файла.",
    "\"{name}\" is not an allowed filetype" : "«{name}» - недопустимый тип файла.",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Хранилище {owner} переполнено, файлы не могут быть обновлены или синхронизированы.",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Папки группы «{mountPoint}» заполнена, файлы не могут быть обновлены или синхронизированы.",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Внешнее хранилище «{mountPoint}» заполнено, файлы не могут быть обновлены или синхронизированы.",
    "Your storage is full, files cannot be updated or synced anymore!" : "Ваше хранилище заполнено, файлы не могут быть обновлены или синхронизированы.",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Хранилище пользователя {owner} почти заполнено (использовано {usedSpacePercent} %).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Папка группы «{mountPoint}» почти заполнена (использовано ({usedSpacePercent} %).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Внешнее хранилище «{mountPoint}» почти заполнено (использовано {usedSpacePercent} %).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Ваше хранилище почти заполнено (использовано {usedSpacePercent} %).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["соответствуют «{filter}»","соответствуют «{filter}»","соответствуют «{filter}»","соответствует «{filter}»"],
    "View in folder" : "Посмотреть в каталоге",
    "Direct link was copied (only works for users who have access to this file/folder)" : "Внутренняя ссылка скопирована. Она может быть использована только пользователями, у которых есть доступ к этому файлу или папке. ",
    "Path" : "Путь",
    "_%n byte_::_%n bytes_" : ["%n байт","%n байта","%n байт","%n байт"],
    "Favorited" : "Избранное",
    "Favorite" : "Добавить в избранное",
    "Copy direct link (only works for users who have access to this file/folder)" : "Копировать прямую ссылку (работает только для пользователей с правами доступа к этому файлу или каталогу)",
    "New folder" : "Новый каталог",
    "Create new folder" : "Создать папку",
    "Upload file" : "Загрузить файл",
    "Recent" : "Недавно изменённые",
    "Not favorited" : "Не избранное",
    "Remove from favorites" : "Удалить из избранных",
    "Add to favorites" : "Добавить в избранное",
    "An error occurred while trying to update the tags" : "Во время обновления тегов возникла ошибка",
    "Added to favorites" : "Добавлено в избранное",
    "Removed from favorites" : "Удалено из избранного",
    "You added {file} to your favorites" : "Вы добавили «{file}» в избранное",
    "You removed {file} from your favorites" : "Вы удалили «{file}» из избранного",
    "Favorites" : "Избранные",
    "File changes" : "Изменения файлов",
    "Created by {user}" : "Создано {user}",
    "Changed by {user}" : "Изменено {user}",
    "Deleted by {user}" : "Удалено {user}",
    "Restored by {user}" : "Восстановлено {user}",
    "Renamed by {user}" : "Переименовано {user}",
    "Moved by {user}" : "Перемещено {user}",
    "\"remote user\"" : "«пользователь с другого сервера»",
    "You created {file}" : "Вы создали «{file}»",
    "You created an encrypted file in {file}" : "Вы создали зашифрованный файл в «{file}»",
    "{user} created {file}" : "{user} создал(а) «{file}»",
    "{user} created an encrypted file in {file}" : "{user} создал(а) зашифрованный файл в «{file}»",
    "{file} was created in a public folder" : "«{file}» создан в общедоступом каталоге",
    "You changed {file}" : "Вы изменили «{file}»",
    "You changed an encrypted file in {file}" : "Вы изменили зашифрованный файл в «{file}»",
    "{user} changed {file}" : "{user} изменил(а) «{file}»",
    "{user} changed an encrypted file in {file}" : "{user} изменил(а) зашифрованный файл в «{file}»",
    "You deleted {file}" : "Вы удалили «{file}»",
    "You deleted an encrypted file in {file}" : "Вы удалили зашифрованный файл в «{file}»",
    "{user} deleted {file}" : "{user} удалил(а) «{file}»",
    "{user} deleted an encrypted file in {file}" : " {user} удалил(а) зашифрованный файл в «{file}»",
    "You restored {file}" : "Вы восстановили «{file}»",
    "{user} restored {file}" : "{user} восстановил(а) «{file}»",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Вы переименовали {oldfile} (скрытый) в {newfile} (скрытый)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Вы переименовали {oldfile} (скрытый) в {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Вы переименовали {oldfile} в {newfile} (скрытый)",
    "You renamed {oldfile} to {newfile}" : "Вы переименовали «{oldfile}» в «{newfile}»",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} переименовал(а) {oldfile} (скрытый) в {newfile} (скрытый)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} переименовал(а) {oldfile} (скрытый) в {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} переименовал(а) {oldfile} в {newfile} (скрытый)",
    "{user} renamed {oldfile} to {newfile}" : "{user} переименовал(а) «{oldfile}» в «{newfile}»",
    "You moved {oldfile} to {newfile}" : "Вы переместили «{oldfile}» в «{newfile}»",
    "{user} moved {oldfile} to {newfile}" : "{user} переместил(а) «{oldfile}» в «{newfile}»",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Файл добавлен в <strong>избранное</strong> или удалён оттуда",
    "A file or folder has been <strong>changed</strong>" : "<strong>Изменён</strong> файл или каталог",
    "A favorite file or folder has been <strong>changed</strong>" : "<strong>Изменён</strong> файл или папка отмеченные как избранное",
    "Upload (max. %s)" : "Загрузка (максимум %s)",
    "Accept" : "Принять",
    "Reject" : "Отклонить",
    "Incoming ownership transfer from {user}" : "Запрос передачи владения от пользователя {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Принять владение {path}?\n\nПримечание: процесс переноса может занять до одного часа.",
    "Ownership transfer failed" : "Не удалось передать владение",
    "Your ownership transfer of {path} to {user} failed." : "Вам не удалось передать владение «{path}» пользователю {user}.",
    "The ownership transfer of {path} from {user} failed." : "Пользователю {user} не удалось передать владение «{path}».",
    "Ownership transfer done" : "Передача владения завершена",
    "Your ownership transfer of {path} to {user} has completed." : "Завершена передача владения «{path}» от вас пользователю {user}.",
    "The ownership transfer of {path} from {user} has completed." : "Завершена передача владения «{path}» от пользователя {user}.",
    "in %s" : "в %s",
    "File Management" : "Управление файлами",
    "Reload current directory" : "Обновить текущий каталог",
    "Go to the \"{dir}\" directory" : "Перейти в каталог \"{dir}\"",
    "\"{displayName}\" action executed successfully" : "Действие «{displayName}» выполнено успешно",
    "\"{displayName}\" action failed" : "Действие «{displayName}» завершилось неудачно",
    "Select the row for {displayName}" : "Выбрать строку для {displayName}",
    "Rename file" : "Переименовать файл",
    "File name" : "Имя файла",
    "Folder name" : "Имя папки",
    "This node is unavailable" : "Этот узел недоступен",
    "Download file {name}" : "Скачать файл {name}",
    "\"{name}\" is not an allowed filetype." : "«{name}» не является допустимым типом файла.",
    "{newName} already exists." : "«{newName}» уже существует.",
    "\"{char}\" is not allowed inside a file name." : "\"{char}\" не допускается внутри имени файла.",
    "Name cannot be empty" : "Имя не может быть пустым",
    "Another entry with the same name already exists" : "Другая запись с таким названием уже существует",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Переименовано «{oldName}» в \"{newName}\"",
    "Could not rename \"{oldName}\", it does not exist any more" : "Не удалось переименовать \"{oldName}\", его больше не существует",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Имя \"{newName}\" уже используется в каталоге \"{dir}\". Выберите другое имя.",
    "Could not rename \"{oldName}\"" : "Не удалось переименовать «{oldName}»",
    "A long time ago" : "Очень давно",
    "Could not copy {file}. {message}" : "Ошибка копирования «{file}». {message}",
    "Could not move {file}. {message}" : "Ошибка перемещения «{file}». {message}",
    "Total rows summary" : "Количество строк в общем",
    "Select all" : "Выбрать всё",
    "Unselect all" : "Отменить выделение для всех",
    "\"{displayName}\" failed on some elements " : "«{displayName}» неудачно для некоторых элементов",
    "\"{displayName}\" batch action executed successfully" : "Пакетное действие \"{displayName}\" выполнено успешно",
    "List of files and folders." : "Список файлов и каталогов.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Этот список отображается не полностью из соображений производительности. Файлы будут отображаться по мере перемещения по списку.",
    "{summaryFile} and {summaryFolder}" : "{summaryFile} и {summaryFolder}",
    "File not found" : "Файл не найден",
    "_{count} file_::_{count} files_" : ["{count} файл","{count} файла","{count} файлов","{count} файлов"],
    "_{count} folder_::_{count} folders_" : ["{count} папка","{count} папки","{count} папок","{count} папок"],
    "Storage informations" : "Сведения о хранилище",
    "{usedQuotaByte} used" : "Использовано {usedQuotaByte}",
    "{relative}% used" : "Использовано {relative}%",
    "Could not refresh storage stats" : "Не удалось обновить данные об использовании хранилища",
    "Transfer ownership of a file or folder" : "Изменение владельца файла или папки",
    "Choose file or folder to transfer" : "Выберите файл или папку для передачи владения",
    "Change" : "Изменить",
    "New owner" : "Новый владелец",
    "Choose a file or folder to transfer" : "Выберите файл или папку для передачи",
    "Transfer" : "Передать",
    "Transfer {path} to {userid}" : "Передать {path} пользователю {userid}",
    "Invalid path selected" : "Указан некорректный путь",
    "Unknown error" : "Неизвестная ошибка",
    "Ownership transfer request sent" : "Запрос на передачу прав владения отправлен",
    "Cannot transfer ownership of a file or folder you do not own" : "Невозможно передать право владения на файл или каталог, которые вам не принадлежат",
    "Select file or folder to link to" : "Выберите файл или папку для создания ссылки",
    "Loading current folder" : "Загрузка текущей папки",
    "No files in here" : "Здесь нет файлов",
    "Upload some content or sync with your devices!" : "Загрузите что-нибудь или синхронизируйте со своими устройствами!",
    "Go to the previous folder" : "Перейти к предыдущей папке",
    "Go back" : "Назад",
    "Share" : "Поделиться",
    "Shared by link" : "Доступные по ссылке",
    "Shared" : "Опубликованное",
    "Switch to list view" : "Переключение в режим просмотра списка",
    "Open the files app settings" : "Открыть параметры приложения «Файлы»",
    "Files settings" : "Настройки файлов",
    "File cannot be accessed" : "Не удалось получить доступ к файлу",
    "You might not have have permissions to view it, ask the sender to share it" : "У вас отсутствуют права на просмотр файла, попросите предоставить их у владельца общего ресурса",
    "Sort favorites first" : "Сначала избранное",
    "Show hidden files" : "Показывать скрытые файлы",
    "Crop image previews" : "Обрезать пред. просмотр",
    "Additional settings" : "Дополнительные параметры",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "Копировать в буфер",
    "Use this address to access your Files via WebDAV" : "Используйте этот адрес для подключения WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Если вы используете двухфакторную аутентификацию, то нажмите здесь чтобы создать пароль приложения.",
    "Clipboard is not available" : "Буфер обмена недоступен",
    "WebDAV URL copied to clipboard" : "Ссылка CalDAV скопирована в буфер обмена",
    "Unable to change the favourite state of the file" : "Не удалось изменить состояние «избранный» этого файла.",
    "Error while loading the file data" : "Не удалось загрузить данные файла",
    "Pick a template for {name}" : "Выбрать шаблон для {name}",
    "Create" : "Создать",
    "Create a new file with the selected template" : "Создать файл на основе шаблона",
    "Creating file" : "Создание файла",
    "Blank" : "Пустой",
    "Unable to create new file from template" : "Не удалось создать файл на основе шаблона",
    "Delete permanently" : "Удалить навсегда",
    "Destination is not a folder" : "Указанное назначение не является папкой",
    "This file/folder is already in that directory" : "Файл или папка уже расположены в этой папке",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Папка или файл не могут быть перемещены во вложенную папку или в себя",
    "A file or folder with that name already exists in this folder" : "В этой папке уже есть файл или папка с этим именем",
    "The files is locked" : "Файлы заблокированы",
    "The file does not exist anymore" : "Файл больше не существует",
    "Chose destination" : "Выбор места назначения",
    "Copy to {target}" : "Скопировать в «{target}»",
    "Move to {target}" : "Переместить в «{target}»",
    "Cancelled move or copy operation" : "Копирование или перемещение отменено",
    "Open folder {displayName}" : "Открыть каталог {displayName}",
    "Open in Files" : "Открыть в Файлах",
    "Open details" : "Открыть подробности",
    "Create new templates folder" : "Создать новую папку шаблонов",
    "Templates" : "Шаблоны",
    "Unable to initialize the templates directory" : "Не удалось инициализировать каталог шаблонов",
    "Created new folder \"{name}\"" : "Создана новая папка \"{name}\"",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{count} папка","{count} папки","{count} папок","{count} папки"],
    "_{fileCount} file_::_{fileCount} files_" : ["{count} файл","{count} файла","{count} файлов","{count} файла"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["один файл и {count} папка","один файл и {count} папки","один файл и {count} папок","один файл и {count} папки"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} файл и одна папка","{fileCount} файла и одна папка","{fileCount} файлов и одна папка","{fileCount} файла и одна папка"],
    "{fileCount} files and {folderCount} folders" : "файлов: {fileCount}, папок: {folderCount}",
    "List of favorites files and folders." : "Список избранных файлов и каталогов.",
    "No favorites yet" : "В избранное ещё ничего не добавлено ",
    "Files and folders you mark as favorite will show up here" : "Здесь будут показаны файлы и каталоги, отмеченные как избранные",
    "All files" : "Все файлы",
    "List of your files and folders." : "Список ваших файлов и каталогов.",
    "List of recently modified files and folders." : "Список недавно измененных файлов и директорий.",
    "No recently modified files" : "Нет недавно измененных файлов",
    "Files and folders you recently modified will show up here." : "Здесь будут показаны недавно изменённые файлы и папки",
    "Toggle %1$s sublist" : "Переключить %1$s подсписок",
    "No entries found in this folder" : "В этом каталоге ничего не найдено",
    "Upload too large" : "Файл слишком велик",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файлы, которые вы пытаетесь передать, превышают лимит максимального размера на этом сервере.",
    "Text file" : "Текстовый файл",
    "New text file.txt" : "Новый текстовый файл.txt",
    "Storage invalid" : "Хранилище неисправно",
    "You can only favorite a single file or folder at a time" : "Одновременно можно выбрать только один файл или папку",
    "Unlimited" : "Неограничено",
    "Search users" : "Поиск пользователей",
    "Cancel" : "Отменить",
    "Set up templates folder" : "Указать папку шаблонов",
    "%s used" : "%s использовано",
    "%s%%" : "%s%%",
    "%1$s of %2$s used" : "использовано %1$s из %2$s ",
    "Toggle grid view" : "Включить или отключить режим просмотра сеткой",
    "Deleted files" : "Корзина",
    "Shares" : "Общие ресурсы",
    "Shared with others" : "Доступные для других",
    "Shared with you" : "Доступные для вас",
    "Deleted shares" : "Удалённые общие ресурсы",
    "Pending shares" : "Ожидающие общие ресурсы",
    "This file has the tag {tag}" : "Файлу назначана метка «{tag}»",
    "This file has the tags {firstTags} and {lastTag}" : "Файлу назначены метки «{firstTags}» и «{lastTag}»",
    "Open folder {name}" : "Открыть папку {name}",
    "ascending" : "восходящий",
    "descending" : "нисходящий",
    "Sort list by {column} ({direction})" : "Сортировать список по {column} ({direction})",
    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Этот список отображается не полностью из соображений производительности. Файлы будут отображаться по мере перемещения по списку.",
    "Search for an account" : "Поиск по учетной записи",
    "Choose" : "Выберите",
    "No files or folders have been deleted yet" : "Файлы или папки еще не удалены"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
