OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Info o CPU nie je dostupné",
    "Load average: {cpu} (last minute)" : "Priemerné zaťaženie:  {cpu} (za poslednú minútu)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Celkom: {memTotalBytes}/Využité: {memUsageBytes}",
    "RAM info not available" : "Informácia o RAM nie je prístupná",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Celkom: {swapTotalBytes}/Využité: {swapUsageBytes}",
    "SWAP info not available" : "Informácia o SWAPe nie je prístupná",
    "Not supported!" : "Nepodporované!",
    "Press ⌘-C to copy." : "Pre kopírovanie, stlačte ⌘-C.",
    "Press Ctrl-C to copy." : "Pre kopírovanie, stlačte Ctrl-C.",
    "System" : "Systém",
    "Monitoring" : "Sledovanie",
    "Monitoring app with useful server information" : "Monitorovacia apka s užitočnými informáciami o serveri",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Poskytuje užitočné informácie o serveri, ako napríklad vyťaženie CPU, RAM, využitie diskov, počet používateľov, atď.",
    "Operating System:" : "Operačný systém:",
    "CPU:" : "CPU:",
    "Unknown Processor" : "Neznámy procesor",
    "Memory:" : "Pamäť:",
    "Server time:" : "Čas na serveri:",
    "Uptime:" : "Doba behu:",
    "Temperature" : "Teplota",
    "Load" : "Záťaž",
    "Memory" : "Pamäť",
    "Disk" : "Disk",
    "Mount:" : "Prípojný bod:",
    "Filesystem:" : "Súborový systém:",
    "Size:" : "Veľkosť:",
    "Available:" : "Dostupné:",
    "Used:" : "Využité:",
    "Files:" : "Súbory:",
    "Storages:" : "Úložiská:",
    "Free Space:" : "Voľné miesto:",
    "Network" : "Sieť",
    "Hostname:" : "Názov servera:",
    "DNS:" : "DNS:",
    "Gateway:" : "Brána:",
    "Status:" : "Stav:",
    "Speed:" : "Rýchlosť:",
    "MAC:" : "MAC adresa:",
    "IPv4:" : "Adresa IPv4:",
    "IPv6:" : "Adresa IPv6:",
    "Active users" : "Aktívni používatelia",
    "Total users:" : "Používateľov celkom:",
    "24 hours:" : "24 hodín:",
    "1 hour:" : "1 hodina:",
    "Shares" : "Sprístupnené položky",
    "Users:" : "Používatelia:",
    "Links:" : "Odkazy:",
    "PHP" : "PHP",
    "Version:" : "Verzia:",
    "Memory limit:" : "Obmedzenie pamäte:",
    "Max execution time:" : "Maximálny čas spustenia:",
    "Upload max size:" : "Maximálna veľkosť pre nahratie:",
    "Extensions:" : "Rozšírenia:",
    "Unable to list extensions" : "Nepodarilo sa zobraziť rozšírenia",
    "Database" : "Databáza",
    "Type:" : "Typ:",
    "External monitoring tool" : "Externý sledovací nástroj",
    "You can connect an external monitoring tool by using this end point:" : "Pre pripojenie externého sledovacieho nástroja použite tento koncový bod:",
    "Copy" : "Kopírovať",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Ak na koniec adresy URL pridáte „?format = json“, získate výsledok v JSON.",
    "To use an access token, please generate one then set it using the following command:" : "Pre používanie prístupového tokenu ho vygenerujte a potom ho nastavte použitím nasledujúceho príkazu:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Pri dotazovaní na vyššie uvedenú adresu URL potom poslať token s hlavičkou „NC-Token“.",
    "You will get a notification once one of your disks is nearly full." : "Ak je niektorý z vašich diskov skoro plný, dostanete varovanie."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
