<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  38039 => 'Київстар',
  38050 => 'Vodafone Україна',
  38066 => 'Vodafone Україна',
  38067 => 'Київстар',
  38068 => 'Київстар',
  38091 => 'ТриМоб',
  38094 => 'Інтертелеком',
  38095 => 'Vodafone Україна',
  38096 => 'Київстар',
  38097 => 'Київстар',
  38098 => 'Київстар',
  38099 => 'Vodafone Україна',
);
