OC.L10N.register(
    "systemtags",
    {
    "Update" : "Opdater",
    "Create" : "Opret",
    "Select tag …" : "Vælg tag...",
    "Added system tag {systemtag}" : "Tilføjede systemtag {systemtag}",
    "Added system tag %1$s" : "Tilføjede systemtag %1$s",
    "%1$s added system tag %2$s" : "%1$s tilføjede systemtag %2$s",
    "{actor} added system tag {systemtag}" : "{actor} tilføjede systemtag {systemtag}",
    "Removed system tag {systemtag}" : "Fjernede systemtag {systemtag}",
    "Removed system tag %1$s" : " Fjernede systemmærket %1$s",
    "%1$s removed system tag %2$s" : "%1$s fjernede systemmærke %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} fjernede systemmærke {systemtag}",
    "You created system tag %1$s" : " Du oprettede systemmærke %1$s",
    "You created system tag {systemtag}" : " Du oprettede systemmærke {systemtag}",
    "%1$s created system tag %2$s" : "%1$s oprettede systemmærke %2$s",
    "{actor} created system tag {systemtag}" : "{actor} oprettede systemmærke {systemtag}",
    "You deleted system tag %1$s" : " Du slettede systemmærke %1$s",
    "You deleted system tag {systemtag}" : "Du slettede systemtag {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s fjernede systemmærket %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} slettede systemtag {systemtag}",
    "You updated system tag %2$s to %1$s" : "Du ændrede systemmærket %2$s til %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Du opdaterede {oldsystemtag} til {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s ændrede systemmærket %3$s til %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} opdaterede systemtag  {oldsystemtag} til {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Du tilføjede system tag %2$s til %1$s",
    "You added system tag {systemtag} to {file}" : "Du tilføjede system tag {systemtag} til {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s tilføjede system tag %3$s til %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} tilføjede system tag {systemtag} til {file}",
    "You removed system tag %2$s from %1$s" : "Du fjernede system tag %2$s fra %1$s",
    "You removed system tag {systemtag} from {file}" : "Du fjernede system tag {systemtag} fra {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s fjernede systemtag %3$s fra %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} fjernede system tag {systemtag} fra {file}",
    "%s (restricted)" : "%s (begrænset)",
    "%s (invisible)" : "%s (usynlig)",
    "<strong>System tags</strong> for a file have been modified" : "En fils <strong>systemmærkning</strong> er blevet ændret",
    "Tags" : "Mærker",
    "Collaborative tags" : "Kollaborativ tags",
    "Failed to load tags" : "Kunne ikke indlæse tags.",
    "This file has the tag {tag}" : "Denne fil har tagget {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Denne fil har taggene {firstTags} og {lastTag}",
    "No tags found" : "Ingen tags fundet",
    "Create a new tag" : "Opret et nyt mærkat",
    "Name" : "Navn",
    "Public" : "Offentlig",
    "Restricted" : "Begrænset",
    "Invisible" : "Usynlig",
    "Delete" : "Slet",
    "Reset" : "Reset",
    "No files in here" : "Her er ingen filer",
    "No entries found in this folder" : "Der blev ikke fundet poster i denne mappe",
    "Size" : "Størrelse",
    "Modified" : "Ændret",
    "Tagged files" : "Mærkede filer",
    "Select tags to filter by" : "Vælg de mærker, der skal filtreres efter",
    "Please select tags to filter by" : "Vælg de mærker, der skal filtreres efter",
    "No files found for the selected tags" : "Der blev ikke fundet filer, som matcher de valgte mærker"
},
"nplurals=2; plural=(n != 1);");
