OC.L10N.register(
    "logreader",
    {
    "Logging" : "Naplózás",
    "Log Reader" : "Naplóolvasó",
    "A log reader for Nextcloud" : "Egy naplóolvasó a Nextcloudhoz",
    "Log reader for Nextcloud" : "Naplóolvasó a Nextcloudhoz",
    "Log reader" : "Napló olvasó",
    "Open log reader settings" : "Napló olvasó beállításainak megnyitása",
    "Log reader settings" : "Napló olvasó beállítások",
    "Currently the log file {file} is shown" : "Jelenleg a {file} naplófájl van megjelenítve",
    "Show server log" : "Kiszolgáló naplók mutatása",
    "Live view is disabled" : "Az élő nézet ki van kapcsolva",
    "No log file" : "Nincs naplófájl",
    "Level" : "Szint",
    "App" : "Alkalmazás",
    "No app in context" : "Nincs alkalmazás a környezetben",
    "Time" : "Idő",
    "Copy raw entry" : "Nyers bejegyzés másolása",
    "Copy formatted entry" : "Formázott bejegyzés másolása",
    "Hide exception details" : "Kivétel részletek elrejtése",
    "View exception details" : "Kivétel részletek megjelenítése",
    "Raw log entry" : "Nyers napló bejegyzés",
    "Log entry successfully copied" : "Naplóbejegyzés másolása sikeres",
    "Search log entries" : "Naplóbejegyzés keresése",
    "Caused by {exception}" : "Okozta: {exception}",
    "line {line}" : "{line} sor",
    "Filter log levels" : "Naplószintek szűrése",
    "Time format" : "Időformátum",
    "Live view" : "Élő nézet",
    "Download / Upload logs" : "Naplók feltöltése/letöltése",
    "Download logs" : "Naplók letöltése",
    "Show local log file" : "Mutassa a helyi naplófájlokat",
    "Upload local log file to be displayed" : "Töltse fel a helyi naplófájlt a megjelenítéshez",
    "Raw data" : "Nyers adat",
    "Local time" : "Helyi idő",
    "UTC time" : "UTC idő",
    "Time format used for displaying the timestamp" : "Időformátum, amiben az időbélyegek megjelennek",
    "(Local log files only support the \"raw\" time format)" : "(A helyi naplófájlok csak a \"nyers\" időformátumot támogatják)",
    "Could not change date time format." : "Nem lehet módosítani a dátum és idő formátumot.",
    "Polling is disabled because server is not configured to log to file" : "A szavazás ki van kapcsolva, mert a kiszolgáló nincs konfigurálva naplózásra",
    "Polling (live view)" : "Szavazás (élő nézet)",
    "Could not change live view setting." : "Az élőnézet beállításai nem módosíthatóak.",
    "Filter logging levels" : "Naplószintek szűrése",
    "Could not set logging levels to show" : "Nem sikerült megjeleníteni a naplózási szinteket",
    "Application" : "Alkalmazás",
    "Message" : "Üzenet",
    "Log entry actions" : "Napló bejegyzés lehetőségek",
    "Loading older log entries" : "Régebbi naplóbejegyzések betöltése",
    "No older log entries available" : "Nincs régebbi naplóbejegyzés",
    "Collapse row" : "Sor bezárása",
    "Expand row" : "Sor kinyitása",
    "Show details" : "Részletek megjelenítése",
    "Debug" : "Hibakeresés",
    "Info" : "Infó",
    "Warning" : "Figyelmeztetés",
    "Error" : "Hiba",
    "Fatal" : "Végzetes",
    "Could not fetch new log entries (server unavailable)" : "Az új naplóbejegyzések nem elérhetőek (kiszolgáló nem elérhető)",
    "Could not fetch new entries" : "Nem sikerült lekérni az új bejegyzéseket",
    "Could not copy to clipboard, please copy manually:" : "Nem lehet a vágólapra másolni. Másolja át kézileg.",
    "\tfrom {address} by {user} at {time}\n" : "\terről a címről: {address} , {user} által ebben az időben: {time}\n",
    "Error parsing log" : "Napló feldolgozási hiba",
    "Caused by " : "Okozta:",
    "Copy" : "Másolás",
    "Copy raw" : "Másolás eredeti formába",
    "Copy formatted" : "Másolás formázva",
    "No server logs" : "Nincsenek kiszolgálónaplók",
    "One or more entries are hidden by the log level filter" : "Egy vagy több bejegyzés elrejtve a naplózási szint szűrő miatt",
    "Everything is working fine" : "Minden rendben működik",
    "Load log file" : "Naplófájl betöltése",
    "Invalid log file" : "Érvénytelen naplófájl",
    "Log levels" : "Naplózási szintek",
    "Log content" : "Naplótartalom",
    "Live update" : "Élő frissítés"
},
"nplurals=2; plural=(n != 1);");
