(self.webpackChunk_nextcloud_text=self.webpackChunk_nextcloud_text||[]).push([["highlight/properties"],{17546:e=>{e.exports=function(e){const n="[ \\t\\f]*",t=n+"[:=]"+n,s="[ \\t\\f]+",a="([^\\\\:= \\t\\f\\n]|\\\\.)+",i={end:"("+t+"|"+s+")",relevance:0,starts:{className:"string",end:/$/,relevance:0,contains:[{begin:"\\\\\\\\"},{begin:"\\\\\\n"}]}};return{name:".properties",disableAutodetect:!0,case_insensitive:!0,illegal:/\S/,contains:[e.COMMENT("^\\s*[!#]","$"),{returnBegin:!0,variants:[{begin:a+t},{begin:a+s}],contains:[{className:"attr",begin:a,endsParent:!0}],starts:i},{className:"attr",begin:a+n+"$"}]}}}}]);
//# sourceMappingURL=properties.js.map?v=84797cbf4ffc75a80792