OC.L10N.register(
    "lookup_server_connector",
    {
    "Lookup Server Connector" : "Łącze serwera wyszukiwania",
    "Sync public user information with the lookup server" : "Synchronizuj publiczne informacje o użytkowniku z serwerem wyszukiwania"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
