OC.L10N.register(
    "settings",
    {
    "Private" : "Pribatua",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Ikusgarri soilik mugikorrean Talk bidez telefono zenbaki integrazioarekin bat egin duten pertsonentzat",
    "Local" : "Lokala",
    "Only visible to people on this instance and guests" : "Soilik instantzia honetako erabiltzaile eta gonbidatuentzat ikusgai",
    "Federated" : "Federatua",
    "Only synchronize to trusted servers" : "Sinkronizatu zerbitzari fidagarriekin soilik",
    "Published" : "Argitaratuta",
    "Synchronize to trusted servers and the global and public address book" : "Sinkronizatu zerbitzari fidagarriekin eta helbide liburu publiko eta globalarekin",
    "Verify" : "Egiaztatu",
    "Verifying …" : "Egiaztatzen...",
    "Unable to change password" : "Ezin izan da pasahitza aldatu",
    "Very weak password" : "Pasahitz oso ahula",
    "Weak password" : "Pasahitz ahula",
    "So-so password" : "Halamoduzko pasahitza",
    "Good password" : "Pasahitz ona",
    "Strong password" : "Pasahitz sendoa",
    "Groups" : "Taldeak",
    "Group list is empty" : "Talde zerrenda hutsik dago",
    "Unable to retrieve the group list" : "Ezin izan da talde zerrenda eskuratu",
    "{actor} added you to group {group}" : "{actor} erabiltzaileak {group} taldera gehitu zaitu",
    "You added {user} to group {group}" : "{user} erabiltzailea {group} taldera gehitu duzu",
    "{actor} added {user} to group {group}" : "{actor} erabiltzaileak {user} erabiltzailea {group} taldera gehitu du",
    "An administrator added you to group {group}" : "Administratzaile batek {group} taldera gehitu zaitu",
    "An administrator added {user} to group {group}" : "Administratzaile batek {user} erabiltzailea {group} taldera gehitu du",
    "{actor} removed you from group {group}" : "{actor} erabiltzaileak {group} taldetik kendu zaitu",
    "You removed {user} from group {group}" : "{user} erabiltzailea {group} taldetik kendu duzu",
    "{actor} removed {user} from group {group}" : "{actor} erabiltzaileak {user} erabiltzailea {group} taldetik kendu du",
    "An administrator removed you from group {group}" : "Administratzaile batek {group} taldetik kendu zaitu",
    "An administrator removed {user} from group {group}" : "Administratzaile batek {user} erabiltzailea {group} taldetik kendu du",
    "Your <strong>group memberships</strong> were modified" : "Zure <strong>talde partaidetzak</strong> aldatu dira",
    "{actor} changed your password" : "{actor}-(e)k zure pasahitza aldatu du",
    "You changed your password" : "Zuk zure pasahitza aldatu duzu",
    "Your password was reset by an administrator" : "Administratzaile batek zure pasahitza berrezarri du",
    "Your password was reset" : "Zure pasahitza berezarri da",
    "{actor} changed your email address" : "{actor}-(e)k zure e-posta helbidea aldatu du",
    "You changed your email address" : "Zuk zure e-posta helbidea aldatu duzu",
    "Your email address was changed by an administrator" : "Administratzaile batek zure e-posta helbidea berrezarri du",
    "You created an app password for a session named \"{token}\"" : "\"{token}\" izeneko saio baterako aplikazio pasahitza sortu duzu",
    "An administrator created an app password for a session named \"{token}\"" : "Administratzaile batek aplikazioaren pasahitza sortu du \"{token}\" izeneko saiorako",
    "You deleted app password \"{token}\"" : "\"{token}\" aplikazio pasahitza ezabatu duzu",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "\"{token}\" aplikazio pasahitzaren izena \"{newToken}\" izatera aldatu duzu",
    "You granted filesystem access to app password \"{token}\"" : "\"{token}\" aplikazio pasahitzari fitxategi sistemarako sarbidea eman diozu",
    "You revoked filesystem access from app password \"{token}\"" : "\"{token}\" aplikazio pasahitzari fitxategi sistemarako sarbidea kendu diozu",
    "Security" : "Segurtasuna",
    "You successfully logged in using two-factor authentication (%1$s)" : "Ongi hasi duzu saioa bi urratseko egiaztapenaren bidez (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Bi urratseko egiaztapenaren bidezko saioa hasteko ahaleginak huts egin du (%1$s)",
    "Remote wipe was started on %1$s" : "Urruneko garbiketa hasi zen %1$s-ean",
    "Remote wipe has finished on %1$s" : "Urruneko garbiketa amaitu zen %1$s-ean",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Zure pasahitza edo e-posta helbidea aldatu da",
    "Apps" : "Aplikazioak",
    "Could not remove app." : "Ezin izan da kendu aplikazioa.",
    "Could not update app." : "Ezin izan da aplikazioa eguneratu.",
    "Wrong password" : "Pasahitz okerra",
    "Unable to change personal password" : "Ezin izan da pasahitz pertsonala aldatu",
    "Saved" : "Gordeta",
    "No user supplied" : "Ez da erabiltzailerik zehaztu",
    "Unable to change password. Password too long." : "Ezin izan da pasahitza aldatu. Pasahitz luzeegia.",
    "Authentication error" : "Autentifikazio errorea",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Eman berreskuratzeko administrazio  pasahitza, bestela erabiltzaile datu guztiak galduko dira",
    "Wrong admin recovery password. Please check the password and try again." : "Administratzailearen berreskuratze pasahitza ez egokia. Mesedez egiaztatu pasahitza eta saiatu berriz.",
    "Backend does not support password change, but the user's encryption key was updated." : "Backend-ek ez du onartzen pasahitza aldatzea, baina erabiltzailearen enkriptatze-gakoa eguneratu da.",
    "installing and updating apps via the App Store or Federated Cloud Sharing" : "Aplikazioak aplikazio-biltegiaren edo federatutako hodei partekatzearen bidez instalatzen edo eguneratzen",
    "Federated Cloud Sharing" : "Federatutako hodei partekatzea",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURLek zaharra gelditu den %1$s bertsioa (%2$s) darabil. Eguneratu zure sistema eragilea bestela %3$s bezalako ezaugarriek ez dute ondo funtzionatuko.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "Ezin izan da zehaztu cURLren TLS bertsioa zaharkituta dagoen edo ez, https://nextcloud.com-ekiko HTTPS eskaeran errore bat gertatu delako. Xehetasun gehiagorako, begiratu Nextcloud erregistro fitxategia.",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "PHP OPcache modulua ez da kargatu. Errendimendu hobea lortzeko, zure PHP instalazioan kargatzea gomendatzen da.",
    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "OPcache desgaituta dago. Errendimendu hobea lortzeko, zure PHP konfigurazioari <code>opcache.enable=1 </code> aplikatzea gomendatzen da.",
    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache kodea iruzkinak kentzeko konfiguratuta dago. OPcache gaituta, <code> opcache.save_comments=1 </code> ezarri behar da Nextcloud-ek funtziona dezan.",
    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud-ek ez du onartzen OPcache APIa erabiltzea. OPcache gaituta dagoela, oso gomendagarria da Nextcloud direktorio guztiak <code> opcache.restrict_api </code>-rekin sartzea edo ezarpen hau desaktibatzea OPcache API-ren murrizketak desgaitzeko, Nextcloud core edo aplikazioen berritze-lanetan akatsak saihesteko.",
    "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud-ek ez du onartzen OPcache APIa erabiltzea. Oso gomendagarria da Nextcloud-en direktorio guztiak <code>opcache.restrict_api </code>-ekin sartzea edo ezarpen hau desaktibatzea OPcache APIaren murrizketak desgaitzeko, Nextcloud core edo aplikazioen eguneratzeetan akatsak saihesteko.",
    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply <code>opcache.file_cache_only=0</code> to your PHP configuration and use the file cache as second level cache only." : "Partekatutako memorian oinarritutako OPcache desgaituta dago. Errendimendu hobea lortzeko, gomendatzen da <code> opcache.file_cache_only=0 </code> aplikatzea zure PHP konfigurazioan eta fitxategien cachea bigarren mailako cache gisa soilik erabiltzea.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "OPcache gakoen gehienezko kopurua ia gainditzen da. Script guztiak cachean gorde daitezkeela ziurtatzeko,<code>opcache.max_accelerated_files</code>zure PHP konfigurazioan <code> %s </code> baino balio handiagoarekin aplikatzea gomendatzen da.",
    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "OPcache buffer-a ia beteta dago. Script guztiak cachean gorde daitezkeela ziurtatzeko, gomendatzen da <code> opcache.memory_consumption </code> aplikatzea zure PHP konfigurazioan <code> %s </code> baino balio handiagoarekin.",
    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "OPcache barneratutako kateen buffer-a ia beteta dago. Errepikatzen diren kateak modu eraginkorrean gorde daitezkeela ziurtatzeko, gomendatzen da <code> aplikatzea opcache.interned_strings_buffer </code> zure PHP konfigurazioan <code> %s</code>baino balio handiagoarekin.",
    "Administrator documentation" : "Administratzaile dokumentazioa",
    "User documentation" : "Erabiltzailearen dokumentazioa",
    "Nextcloud help overview" : "Nextcloud laguntza ikuspegia",
    "Invalid SMTP password." : "SMTP pasahitza baliogabea",
    "Email setting test" : "E-postaren ezarpenen proba",
    "Well done, %s!" : "Ongi egina, %s!",
    "If you received this email, the email configuration seems to be correct." : "E-posta mezu hau jaso baduzu, e-postaren ezarpenak egokiak direnaren seinale.",
    "Email could not be sent. Check your mail server log" : "E-posta mezua ezin izan da bidali. Begiratu zure posta-zerbitzariaren egunkaria",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Arazo bat sortu da posta bidaltzerakoan. Berrikusi zure ezarpenak. (Error: %s)",
    "You need to set your user email before being able to send test emails. Go to %s for that." : "Zure erabiltzailearen posta elektronikoa ezarri behar duzu probako mezu elektronikoak bidali ahal izateko. Zoaz %sorrira horretarako.",
    "Users" : "Erabiltzaileak",
    "Invalid user" : "Erabiltzaile baliogabea",
    "Invalid mail address" : "Posta helbide baliogabea",
    "Settings saved" : "Ezarpenak gordeta",
    "Unable to change full name" : "Ezin izan da izena aldatu",
    "Unable to change email address" : "Ezin da helbide elektronikoa aldatu",
    "Unable to set invalid phone number" : "Ezin da telefono zenbaki baliogaberik ezarri",
    "Unable to set invalid website" : "Ezin da webgune baliogaberik ezarri",
    "Some account data was invalid" : "Kontuaren zenbait datu baliogabeak ziren",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Zure Twitter kontua egiaztatzearren, bidali hurrengo txioa Twitter-era (egiaztatu zure mezuak ez duela lerro-jauzirik):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Zure webgunea egiaztatzearren, gorde hurrengo edukia zure webgunearen sustraiko  '.well-known/CloudIdVerificationCode.txt' (egiaztatu testu osoa lerro bakarrean dagoela):",
    "%1$s changed your password on %2$s." : "%1$s-(e)k zure pasahitza aldatu du %2$s-(e)n",
    "Your password on %s was changed." : "Zure %s-(e)ko pasahitza aldatu da.",
    "Your password on %s was reset by an administrator." : "Administratzaile batek zure %s-(e)ko pasahitza berrezarri du",
    "Your password on %s was reset." : "Zure pasahitza %s(e)n berezarri egin da. ",
    "Password for %1$s changed on %2$s" : "%1$s-(r)en %2$s-(e)ko pasahitza aldatu da",
    "Password changed for %s" : "%s-(r)en pasahitza aldatu da",
    "If you did not request this, please contact an administrator." : "Zuk ez baduzu hau eskatu, jarri kontaktuan administratzailearekin.",
    "Your email address on %s was changed." : "Zure %s-(e)ko e-posta helbidea aldatu da.",
    "Your email address on %s was changed by an administrator." : "Administratzaile batek zure %s-(e)ko e-posta helbidea berrezarri du",
    "Email address for %1$s changed on %2$s" : "%1$s-(r)en %2$s-(e)ko e-posta helbidea aldatu da",
    "Email address changed for %s" : "%s-(r)en e-posta helbidea aldatu da",
    "The new email address is %s" : "E-posta helbide berria hau da: %s",
    "Your %s account was created" : "Zure %s kontua sortu da",
    "Welcome aboard" : "Ongi etorri gurera",
    "Welcome aboard %s" : "Ongi etorri gurera, %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Ongi etorri zure %s kontura, zure datuak gehitu, babestu eta parteka ditzakezu.",
    "Your username is: %s" : "Zure erabiltzailea hau da: %s",
    "Set your password" : "Ezarri zure pasahitza",
    "Go to %s" : "%s-ra joan",
    "Install Client" : "Instalatu bezeroa",
    "Logged in user must be a subadmin" : "Saioa hasitako erabiltzailea azpi-administratzailea izan behar du",
    "Settings" : "Ezarpenak",
    "Personal" : "Pertsonala",
    "Administration" : "Administrazioa",
    "Additional settings" : "Ezarpen gehiago",
    "Artificial Intelligence" : "Adimen artifiziala",
    "Administration privileges" : "Administrazio pribilegioak",
    "Groupware" : "Taldelanerako tresnak",
    "Overview" : "Ikuspegi orokorra",
    "Basic settings" : "Oinarrizko ezarpenak",
    "Sharing" : "Partekatzea",
    "Availability" : "Eskuragarritasuna",
    "Calendar" : "Egutegia",
    "Personal info" : "Informazio pertsonala",
    "Mobile & desktop" : "Mugikorra eta mahaigaina",
    "Email server" : "E-posta zerbitzaria",
    "Security & setup warnings" : "Segurtasun eta konfigurazio abisuak",
    "Background jobs" : "Atzeko planoko lanak",
    "Create" : "Sortu",
    "Change" : "Aldatu",
    "Delete" : "Ezabatu",
    "Reshare" : "Birpartekatu",
    "Unlimited" : "Mugarik gabe",
    "Verifying" : "Egiaztatzen",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Inportatutako erabiltzaile SSL ziurtagiriak egiaztatzen dituen atzeko planeko lana dago zain. Egiaztatu berriro geroago.",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Badira inportatutako zenbait erabiltzaile SSL ziurtagiri, jada erabiltzen ez direnak Nextcloud 21-ekin. Komando lerroan inportatu daitezke \"occ security: certificates: import\" komandoaren bidez. Datuen direktorioaren barruan dituzten bideak behean agertzen dira.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Zerbitzari honek ez dauka Interneteko konexiorik: hainbat amaiera-puntu ezin izan dira atzitu. Horren ondorioz, hainbat ezaugarrik ez dute funtzionatuko, hala nola, kanpoko biltegiratzeak muntatzeak, eguneraketei buruzko jakinarazpenek edo hirugarrengoen aplikazioek. Urruneko fitxategiak atzitzeak eta posta elektroniko bidezko jakinarazpenek ere ez dute funtzionatuko. Ezarri Interneterako konexioa zerbitzari honetan ezaugarri horiek izateko.",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Zerbitzariaren aldeko enkriptatze formatu zaharra gaituta dago. Hau desgaitzea gomendatzen dugu.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Irakurtzeko soilik konfigurazioa gaitu da. Honek web interfazetik konfigurazio batzuk ezartzea eragozten du. Gainera, eguneraketa bakoitzean fitxategia idazteko moduan jarri behar da eskuz.",
    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "MariaDB \"%s\" bertsioa erabiltzen da. Nextcloud 21ek eta berriagoak ez dute bertsio hau onartzen eta MariaDB 10.2 edo berriagoa behar dute.",
    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "MySQL bertsioa \"%s\" erabiltzen da. Nextcloud 21 eta berriek ez dute bertsio hau onartzen eta MySQL 8.0 edo MariaDB 10.2 edo berriagoa behar dute.",
    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "PostgreSQL \"%s\" bertsioa erabiltzen da. Nextcloud 21ek eta berriagoak ez dute bertsio hau onartzen eta PostgreSQL 9.6 edo berriagoa behar dute.",
    "Profile information" : "Profilaren informazioa",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profileko argazkia, izen osoa, helbide elektronikoa, telefono zenbakia, helbidea, webgunea, Twitter, erakundea, rola, izenburua, biografia eta zure profila gaituta dagoen ala ez",
    "Nextcloud settings" : "Nextcloud ezarpenak",
    "Machine translation" : "Makina-itzulpena",
    "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Makinen itzulpena aplikazio ezberdinek inplementatu dezakete. Hemen defini dezakezu zein den instalatu dituzun makina-itzulpeneko aplikazioen lehentasuna.",
    "Speech-To-Text" : "Ahotsetik testura",
    "Speech-To-Text can be implemented by different apps. Here you can set which app should be used." : "Ahotsetik testura aplikazio ezberdinek inplementatu dezakete. Zeintzuk aplikazio erabili daitezkeen ezarri dezakezu hemen.",
    "None of your currently installed apps provide Speech-To-Text functionality" : "Ez dago ahotsetik testurako funtzionalitatea ematen duen aplikaziorik unean.",
    "Text processing" : "Testu-prozesamendua",
    "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Testu-prozesamendu zereginak aplikazio ezberdinek inplementatu dezakete. Zeintzuk aplikazio erabili daitezkeen zein zereginerako ezarri dezakezu hemen.",
    "Task:" : "Zeregina:",
    "None of your currently installed apps provide Text processing functionality" : "Ez dago testu-prozesamendu funtzionalitatea ematen duen aplikaziorik unean.",
    "Here you can decide which group can access certain sections of the administration settings." : "Hemen administratzaile ezarpeneko hainbat sekziotan sartu daitezkeen taldeak erabaki ditzakezu.",
    "None" : "Bat ere ez",
    "Unable to modify setting" : "Ezin izan da ezarpena aldatu",
    "Two-Factor Authentication" : "Bi faktoreko autentifikazioa",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Bi faktoreko autentifikazioa erabiltzaile guztientzat edo talde batzuentzat ezarri daiteke. Ez badute bi faktoreko hornitzailerik konfiguratuta, ezingo dira sistemara sartu.",
    "Enforce two-factor authentication" : "Bi faktoreko autentikazioa erabiltzea derrigortu",
    "Limit to groups" : "Taldeetara mugatu",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Bi faktoreko autentikazioa talde batzuentzat bakarrik derrigortu daiteke.",
    "Two-factor authentication is enforced for all members of the following groups." : "Bi faktoreko autentikazioa talde hauetako kideentzat eskatuko da.",
    "Enforced groups" : "Derrigortutako taldeak",
    "Two-factor authentication is not enforced for members of the following groups." : "Bi faktoreko autentikazioa ez dago talde hauetako kideentzat derrigortuta.",
    "Excluded groups" : "Baztertu taldeak",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Taldeak aukeratuta daudenean hauxe erabiltzen da bi faktoreko autentikazioa derrigortu ala ez erabakitzeko: talderik ez badago aukeratuta, guztientzat dago derrigortuta kanpoan utzitako taldeetako kideentzat ezik. Taldeak aukeratuta badaude, beren kideentzat derrigortzen da. Erabiltzaile bat aukeratutako eta kanpoan utzitako talde bateko kide bada, aukeratutako taldekoa izatea lehenesten da eta bi faktoreko autentikazioa erabiltzera derrigortzen da.",
    "Save changes" : "Gorde aldaketak",
    "All" : "Denak",
    "Limit app usage to groups" : "Mugatu aplikazioaren erabilera taldeei",
    "No results" : "Emaitzarik ez",
    "Update to {version}" : "Eguneratu {version} bertsiora",
    "Remove" : "Ezabatu",
    "Disable" : "Ez-gaitu",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "This app has no minimum Nextcloud version assigned. This will be an error in the future.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "This app has no maximum Nextcloud version assigned. This will be an error in the future.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Aplikazioa ezin da instalatu hurrengo menpekotasunak betetzen ez direlako:",
    "View in store" : "Dendan ikusi",
    "Visit website" : "Web orria ikusi",
    "Report a bug" : "Eman akats baten berri ",
    "Admin documentation" : "Administratzailearen dokumentazioa",
    "Developer documentation" : "Garatzailearen dokumentazioa",
    "This app is supported via your current Nextcloud subscription." : "Aplikazio hau zure Nextcloud harpidetzaren bitartez ahalbidetua dago.",
    "Supported" : "Onartuta",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Nabarmendutako aplikazioak, komunitateak eta komunitatean garatutakoak dira. Funtzionalitate orokorrak eskaintzen dituzte eta produkzioan erabiltzeko prest daude.",
    "Featured" : "Nabarmendua",
    "Update to {update}" : "Eguneratu {update} bertsiora",
    "All apps are up-to-date." : "Aplikazio guztiak eguneratuta daude.",
    "Icon" : "Ikonoa",
    "Name" : "Izena",
    "Version" : "Bertsioa",
    "Level" : "Maila",
    "Actions" : "Ekintzak",
    "Results from other categories" : "Beste kategoriatako emaitzak",
    "No apps found for your version" : "Ez dira aplikaziorik aurkitu zure bertsiorako",
    "Disable all" : "Desgaitu guztia",
    "Download and enable all" : "Deskargatu eta gaitu guztia",
    "_%n app has an update available_::_%n apps have an update available_" : ["Aplikazio %nek eguneraketa dauka prest.","%n aplikaziok eguneraketa daukate prest."],
    "_Update_::_Update all_" : ["Eguneratu","Eguneratu denak"],
    "Device name" : "Gailuaren izena",
    "Marked for remote wipe" : "Urruneko garbiketarako markatuta",
    "Device settings" : "Gailuaren ezarpenak",
    "Allow filesystem access" : "Onartu fitxategi sisteman sarbidea",
    "Rename" : "Berrizendatu",
    "Revoke" : "Ezeztatu",
    "Wipe device" : "Ezabatu gailua",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Token hau baliogabetzeak zure gailua ezabatzea eragotzi dezake oraindik ezabatzen hasi ez bada.",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome Android-erako",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "{productName} iOS app" : "{productName} iOS aplikazioa",
    "{productName} Android app" : "{productName} Android aplikazioa",
    "{productName} Talk for iOS" : "{productName} Talk iOSentzat",
    "{productName} Talk for Android" : "{productName} Talk Androidentzat",
    "Sync client - {os}" : "Sinkronizatu bezeroaren - {os}",
    "This session" : "Saio hau",
    "Device" : "Gailua",
    "Last activity" : "Azken jarduerak",
    "Devices & sessions" : "Gailuak eta saioak",
    "Web, desktop and mobile clients currently logged in to your account." : "Webgunean edota mahaigaineko zein mugikorreko bezero hauetan saioa hasita duzu.",
    "Do you really want to wipe your data from this device?" : "Ziur zaude gailu honetatik zure datu guztiak ezabatu nahi dituzula?",
    "Confirm wipe" : "Berretsi garbiketa",
    "Error while creating device token" : "Errorea gailuaren tokena sortzean",
    "Error while updating device token scope" : "Errorea gailuaren tokenaren irismena eguneratzean",
    "Error while updating device token name" : "Errorea gailuaren tokenaren izena eguneratzean",
    "Error while deleting the token" : "Errorea tokena ezabatzean",
    "Error while wiping the device with the token" : "Errorea gailua tokenarekin garbitzean",
    "App name" : "Aplikazioaren izena",
    "Create new app password" : "Sortu aplikaziorako pasahitz berria",
    "Use the credentials below to configure your app or device." : "Erabili kredentzialak beheko zure aplikazioa edo gailua konfiguratzeko.",
    "For security reasons this password will only be shown once." : "Segurtasun arrazoiengatik, pasahitz hau behin soilik erakutsiko da.",
    "Username" : "Erabiltzaile izena",
    "Password" : "Pasahitza",
    "Done" : "Egina",
    "Show QR code for mobile apps" : "Erakutsi QR kodea mugikorrentzako aplikazioetan",
    "Copied!" : "Kopiatua!",
    "Copy" : "Kopiatu",
    "Could not copy app password. Please copy it manually." : "Ezin izan da aplikazioaren pasahitza kopiatu. Kopia ezazu eskuz, mesedez.",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Zerbitzariak behar bezala funtziona dezan, garrantzitsua da atzeko planoko lanak behar bezala konfiguratzea. Cron da gomendatutako ezarpena. Ikus dokumentazioa informazio gehiago lortzeko.",
    "Last job execution ran {time}. Something seems wrong." : "Azken lana exekutatu zen: {time}. Zerbait gaizki dagoela dirudi.",
    "Last job ran {relativeTime}." : "Azken lana {relativeTime}-n egin zen.",
    "Background job did not run yet!" : "Atzeko planoko lana ez da oraindik exekutatu!",
    "AJAX" : "AJAX",
    "Execute one task with each page loaded. Use case: Single user instance." : "Exekutatu zeregin bat orrialde bakoitza kargatuta. Erabilera kasua: erabiltzaile bakarreko instantzia.",
    "Webcron" : "Webcron",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php webcron zerbitzu batean erregistratuta dago HTTP bidez 5 minuturo cron.php deitzeko. Erabilera kasua: oso instantzia txikia (1-5 erabiltzaile erabileraren arabera).",
    "Cron (Recommended)" : "Cron (Gomendatuta)",
    "Use system cron service to call the cron.php file every 5 minutes." : "Sistemaren cron zerbitzua erabili cron.php-ri 5 minutuan behin deitzeko.",
    "The cron.php needs to be executed by the system user \"{user}\"." : "Cron.php sistemaren erabiltzaileak \"{user}\" exekutatu behar du.",
    "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "PHP POSIX luzapena behar da. Ikusi {linkstart}PHP dokumentazioa{linkend} xehetasun gehiagorako.",
    "Unable to update background job mode" : "Ezin izan da atzeko planoko lan-modua eguneratu",
    "Profile" : "Profila",
    "Enable or disable profile by default for new users." : "Gaitu edo desgaitu profila lehenespenez erabiltzaile berrientzat.",
    "Enable" : "Gaitu",
    "Unable to update profile default setting" : "Ezin izan da eguneratu profilaren ezarpen lehenetsia",
    "Server-side encryption" : "Zerbitzariaren aldeko zifratzea",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Zerbitzari-aldeko enkriptatzeak zerbitzarira igotzen diren fitxategiak enkriptatzea baimentzen du. Honek eraginkortasuna jaitsi dezake, beraz gaitu beharrezkoa bada soilik. ",
    "Enable server-side encryption" : "Gaitu zerbitzariaren aldeko zifratzea",
    "Please read carefully before activating server-side encryption:" : "Irakurri arretaz zerbitzariaren aldeko zifratzea gaitu aurretik mesedez:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Zifratzea gaitu ondoren zerbitzarira igotako fitxategi guztiak zifratu egingo dira . Zifratzea geroago desgaitu daiteke zifratze-modulu aktiboak funtzio hori onartzen badu eta aurrebaldintza guztiak (adibidez, berreskuratze-gako bat ezartzea) betetzen badira.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Zifratze hutsak ez du sistemaren segurtasuna bermatzen. Begiratu dokumentazioa zifratze-aplikazioak nola funtzionatzen duen jakiteko eta zein erabiltzaile-kasu onartzen den ezagutzeko.",
    "Be aware that encryption always increases the file size." : "Kontuan izan zifratzeak beti fitxategiaren tamaina handitzen duela.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Zure datuen babeskopiak sortu beharko zenituzke aldizka, eta zifratuta badaude, ziurtatu zifratze-gakoen babeskopia ere egiten dela datuekin batera.",
    "This is the final warning: Do you really want to enable encryption?" : "Azken abisua da: Benetan gaitu nahi duzu zifratzea?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Ez da zifratze-modulurik kargatu, mesedez gaitu zifratze-modulu bat app-aren menuan. ",
    "Select default encryption module:" : "Hautatu zifratze-modulu lehenetsia:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Zifratze-gakoak zifratze-sistema zaharretik (ownCloud <=8.0) sistema berrira migratu behar duzu. Gaitu mesedez \"Zifratze modulu lehenetsia\" eta {command} exekuta ezazu",
    "Unable to update server side encryption config" : "Ezin izan da zerbitzariaren aldeko zifratzearen konfigurazioa eguneratu",
    "Cancel" : "Ezeztatu",
    "Confirm" : "Berretsi",
    "Submit" : "Bidali",
    "Rename group" : "Berrizendatu taldea",
    "Remove group" : "Ezabatu taldea",
    "Current password" : "Uneko pasahitza",
    "New password" : "Pasahitz berria",
    "Change password" : "Aldatu pasahitza",
    "Your profile information" : "Zure profileko informazioa",
    "Your profile picture" : "Zure profil-irudia",
    "Upload profile picture" : "Igo profil-irudia",
    "Choose profile picture from Files" : "Aukeratu Fitxategiak-en profileko argazkia",
    "Remove profile picture" : "Kendu profil-irudia",
    "The file must be a PNG or JPG" : "Fitxategiak PNG edo JPG izan behar du",
    "Picture provided by original account" : "Irudia jatorrizko kontutik hartuta",
    "Set as profile picture" : "Ezarri profil-irudia",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Kontuan izan profil-irudia edonon eguneratzeko 24 ordu arte igaro daitezkeela.",
    "Choose your profile picture" : "Aukeratu zure profil-irudia",
    "Please select a valid png or jpg file" : "Mesedez hautatu baliozko png edo jpg fitxategi bat",
    "Error setting profile picture" : "Errorea profil-irudia ezartzean",
    "Error cropping profile picture" : "Errorea profil-irudia moztean",
    "Error saving profile picture" : "Errorea profil-irudia gordetzean",
    "Error removing profile picture" : "Errorea profil-irudia kentzean",
    "Your biography" : "Zure biografia",
    "Details" : "Xehetasunak",
    "You are a member of the following groups:" : "Honako taldeetako kide zara:",
    "You are using <strong>{usage}</strong>" : "<strong>{usage}</strong> erabiltzen ari zara",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "<strong>{usage}</strong>/<strong>{totalSpace}</strong> erabiltzen ari zara (<strong>{usageRelative}%</strong>)",
    "Your full name" : "Zure izen osoa",
    "Email options" : "Posta elektronikoaren aukerak",
    "Primary email for password reset and notifications" : "Pasahitz berrezartzeko eta jakinarazpenetarako posta elektroniko nagusia",
    "Remove primary email" : "Kendu posta elektroniko nagusia",
    "Delete email" : "Ezabatu posta elektronikoa",
    "Unset as primary email" : "Kendu posta nagusia",
    "This address is not confirmed" : "Helbide hau ez dago berretsita",
    "Set as primary email" : "Ezarri e-posta nagusi bezala",
    "Additional email address {index}" : "Posta elektroniko gehigarria {index}",
    "Unable to delete primary email address" : "Ezin izan da helbide elektroniko nagusia ezabatu",
    "Unable to update primary email address" : "Ezin izan da helbide elektroniko nagusia eguneratu",
    "Unable to add additional email address" : "Ezin izan da helbide elektroniko gehigarria gehitu",
    "Unable to update additional email address" : "Ezin izan da helbide elektroniko gehigarria eguneratu",
    "Unable to delete additional email address" : "Ezin izan da helbide elektroniko gehigarria ezabatu",
    "No email address set" : "Ez da eposta helbidea ezarri",
    "Additional emails" : "Helbide elektroniko gehigarriak",
    "Your handle" : "Zure heldulekua",
    "Your headline" : "Zure izenburua",
    "Help translate" : "Lagundu itzultzen",
    "Unable to update language" : "Ezin izan da hizkuntza eguneratu",
    "No language set" : "Ez da hizkuntzarik ezarri",
    "Week starts on {firstDayOfWeek}" : "Astea {firstDayOfWeek} egunean hasten da",
    "Unable to update locale" : "Ezin izan da lokalizazioa eguneratu",
    "No locale set" : "Ez da lokalizaziorik ezarri",
    "Your city" : "Zure hiria",
    "Your organisation" : "Zure erakundea",
    "Your phone number" : "Zure telefono zenbakia",
    "Edit your Profile visibility" : "Editatu profilaren ikusgarritasuna",
    "Enable Profile" : "Gaitu profila",
    "Unable to update profile enabled state" : "Ezin izan da profila gaitutako egoerara eguneratu",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Ikusgarritasunaren edo esparruaren ezarpen murriztaileena zure profilean errespetatzen da. Esaterako, ikusgarritasuna \"Erakutsi guztiei\" eta esparrua \"Pribatua\" gisa ezarrita badago, \"Pribatua\" errespetatzen da.",
    "Unable to update visibility of {displayId}" : "Ezin izan da {displayId}(r)en ikusgarritasuna eguneratu",
    "Your role" : "Zure rola",
    "Your Twitter handle" : "Zure Twitter erabiltzailea",
    "Your website" : "Zure web orria",
    "No {property} set" : "Ez da {property} ezarri",
    "Unable to update {property}" : "Ezin izan da {property} eguneratu",
    "Change scope level of {property}, current scope is {scope}" : "Aldatu {property}-(r)en esparru-maila, unekoa {scope} esparru-maila da",
    "Unable to update federation scope of the primary {property}" : "Ezin da eguneratu lehen mailako {property}-ren federazio-esparrua",
    "Unable to update federation scope of additional {property}" : "Ezin da eguneratu {property} gehigarriaren federazio-esparrua",
    "Add additional email" : "Gehitu e-posta gehigarria",
    "Add" : "Gehitu",
    "No users" : "Erabiltzailerik ez",
    "Loading users …" : "Erabiltzaileak kargatzen ...",
    "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list." : "Erabiltzaileen zerrenda. Zerrenda ez da guztiz errenderizatzen errendimendu arrazoiengatik. Erabiltzaileak zerrenda nabigatzen duzun heinean errenderizatuko dira.",
    "Default language" : "Hizkuntza lehenetsia",
    "Common languages" : "Hizkuntza komunak",
    "Other languages" : "Beste hizkuntza batzuk",
    "Password change is disabled because the master key is disabled" : "Pasahitza aldatzea desgaituta dago gako nagusia desaktibatuta baitago.",
    "New user" : "Erabiltzaile berria",
    "Display name" : "Erakusteko izena",
    "Either password or email is required" : "Posta elektronikoa edo pasahitza beharrezkoak dira",
    "Password (required)" : "Pasahitza (beharrezkoa)",
    "Email (required)" : "Posta elektronikoa (beharrezkoa)",
    "Email" : "E-posta",
    "Groups (required)" : "Taldeak (beharrezkoa)",
    "Set user groups" : "Ezarri erabiltzailearen taldeak",
    "Administered groups" : "Administratturiko taldeak",
    "Set user as admin for …" : "Ezarri erabiltzailea admin gisa honentzat...",
    "Quota" : "Kuota",
    "Set user quota" : "Ezarri erabiltzaie-kuota",
    "Language" : "Hizkuntza",
    "Set default language" : "Ezarri hizkuntza lehenetsia",
    "Manager" : "Zuzendaria",
    "Add new user" : "Gehitu erabiltzaile berria",
    "Set user manager" : "Ezarri erabiltzaile-kudeatzailea",
    "Username will be autogenerated" : "Erabiltzaile izena automatikoki sortuko da",
    "Username (required)" : "Erabiltzailea (beharrezkoa)",
    "Total rows summary" : "Errenkaden guztirako laburpena",
    "Scroll to load more rows" : "Mugitu pantailan behera errenkada gehiago kargatzeko",
    "_{userCount} user …_::_{userCount} users …_" : ["Erabiltzaile {userCount} …","{userCount} erabiltzaile …"],
    "_{userCount} user_::_{userCount} users_" : ["Erabiltzaile {userCount}","{userCount} erabiltzaile"],
    "Avatar" : "Avatarra",
    "Group admin for" : "Talde honen administratzailea",
    "User backend" : "Erabiltzaile jatorria",
    "Storage location" : "Biltegiratze kokapena",
    "Last login" : "Azken saioa",
    "User actions" : "Erabiltzaile-ekintzak",
    "Password or insufficient permissions message" : "Pasahitz edo baimen gutxiegiko mezua",
    "Loading user …" : "Erabiltzailea kargatzen ...",
    "Change display name" : "Aldatu erakutsiko den izena",
    "Set new password" : "Ezarri pasahitz berria",
    "You do not have permissions to see the details of this user" : "Ez duzu baimenik erabiltzaile honen xehetasunak ikusteko",
    "Set new email address" : "Ezarri helbide elektroniko berria",
    "Add user to group" : "Gehitu erabiltzailea taldera",
    "Set user as admin for" : "Ezarri erabiltzailea admin gisa",
    "Select user quota" : "Aukeratu erabiltzaile-kuota ",
    "Set the language" : "Ezarri hizkuntza",
    "{size} used" : "{size} erabilita",
    "Delete user" : "Ezabatu erabiltzailea",
    "Wipe all devices" : "Garbitu gailu guztiak",
    "Disable user" : "Desgaitu erabiltzailea",
    "Enable user" : "Gaitu erabiltzailea",
    "Resend welcome email" : "Birbidali ongi etorri mezua",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Gailua galtzen baduzu edo erakundetik irteten bazara, honek {userid} erabiltzaileari lotutako gailu guztietako Nextcloudeko datuak garbitu ditzake. Gailuak internetera konektatuta badaude bakarrik funtzionatzen du.",
    "Remote wipe of devices" : "Gailuen urruneko garbiketa",
    "Wipe {userid}'s devices" : "Garbitu {userid}-ren gailuak",
    "Wiped {userid}'s devices" : "{userid}-ren gailuak garbitu dira",
    "Failed to update user manager" : "Ezin izan da erabiltzaile kudeatzailea eguneratu",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "{userid} erabiltzailearen kontua, bere fitxategi eta aplikazioen datuak barne, guztiz ezabatu.",
    "Account deletion" : "Kontu ezabaketa",
    "Delete {userid}'s account" : "Ezabatu {userid} erabiltzailearen kontua",
    "Display name was successfully changed" : "Erakusteko izena ondo aldatu da",
    "Password was successfully changed" : "Pasahitza ondo aldatu da",
    "Email was successfully changed" : "Posta elektronikoa ondo aldatu da",
    "Welcome mail sent!" : "Ongi etorri mezua bidalita!",
    "Toggle user actions menu" : "Txandakatu erabiltzailearen ekintza menua",
    "Edit" : "Aldatu",
    "User management settings" : "Erabiltzaile kudeaketaren ezarpenak",
    "Visibility" : "Ikusgarritasuna",
    "Show language" : "Erakutsi hizkuntza",
    "Show user backend" : "Bistaratu erabiltzaile motorra",
    "Show storage path" : "Erakutsi biltegiaren bidea",
    "Show last login" : "Azken izen ematea erakutsi",
    "Send email" : "Bidali posta-mezua",
    "Send welcome email to new users" : "Bidali ongietorri eposta erabiltzaile berriei",
    "Defaults" : "Defektuzkoak",
    "Default quota" : "Kuota lehenetsia",
    "Select default quota" : "Aukeratu lehenetsitako kuota",
    "Passwordless authentication requires a secure connection." : "Pasahitzik gabeko autentifikazioak konexio segurua behar du.",
    "Add WebAuthn device" : "Gehitu WebAuthn gailua",
    "Please authorize your WebAuthn device." : "Mesedez, baimendu zure WebAuthn gailua.",
    "Name your device" : "Izendatu zure gailua",
    "Adding your device …" : "Zure gailua gehitzen ...",
    "Server error while trying to add WebAuthn device" : "Zerbitzariaren errorea WebAuthn gailua gehitzen saiatzean",
    "Server error while trying to complete WebAuthn device registration" : "Zerbitzariaren errorea WebAuthn gailuaren erregistroa osatzen saiatzean",
    "Unnamed device" : "Izen gabeko gailua",
    "Passwordless Authentication" : "Pasahitzik gabeko autentifikazioa",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Konfiguratu kontua pasahitzik gabeko autentifikaziorako FIDO2 estandarra jarraituz.",
    "No devices configured." : "Ez da gailurik konfiguratu.",
    "The following devices are configured for your account:" : "Hurrengo gailuak zure konturako konfiguratuta daude:",
    "Your browser does not support WebAuthn." : "Zure nabigatzaileak ez du WebAuthn onartzen.",
    "Your apps" : "Zure aplikazioak",
    "{license}-licensed" : "{license}-lizentziaduna",
    "Changelog" : "Aldaketak",
    "by {author}\n{license}" : "{autor}-(e)k egina\n{license}",
    "Active users" : "Erabiltzaile aktiboak",
    "Admins" : "Administratzaileak",
    "Disabled users" : "Erabiltzaile ezinduak",
    "Group name" : "Taldearen izena",
    "Not saved" : "Ez da gorde",
    "Sending…" : "Bidaltzen...",
    "Email sent" : "Eposta bidalia",
    "Location" : "Kokapena",
    "Profile picture" : "Zure irudia",
    "About" : "Honi buruz",
    "Full name" : "Izen osoa",
    "Additional email" : "Helbide elektroniko gehigarria",
    "Headline" : "Izenburua",
    "Organisation" : "Erakundea",
    "Phone number" : "Telefono zenbakia",
    "Role" : "Zeregina",
    "Twitter" : "Twitter",
    "Fediverse (e.g. Mastodon)" : "Fedibertsoa (adibidez, Mastodon)",
    "Website" : "Webgunea",
    "Profile visibility" : "Profilaren ikusgarritasuna",
    "Locale" : "Eskualdeko ezarpenak",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Ez dago eskuragarri propietate hau oinarrizko funtzionaltasunentzako beharrezkoa delako, fitxategien partekatze eta egutegien gonbidapenak barne",
    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Ez dago erabilgarri federazioa desgaitu delako zure kontuan, jarri harremanetan sistema-administratzailearekin galderarik baduzu",
    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Ez dago eskuragarri bilaketa zerbitzarira erabiltzaileen datu zehatzak argitaratzea ez dagoelako baimenduta, jarri harremanetan sistemaren administratzailearekin galderarik baduzu",
    "Active apps" : "Aplikazio aktiboak",
    "Disabled apps" : "Gaitu gabeko aplikazioak",
    "Updates" : "Eguneraketak",
    "App bundles" : "Aplikazio sortak",
    "Featured apps" : "App aipagarriak",
    "Supported apps" : "Onartutako aplikazioak",
    "Show to everyone" : "Erakutsi denei",
    "Show to logged in users only" : "Erakutsi saioa hasi duten erabiltzaileei soilik",
    "Hide" : "Ezkutatu",
    "Download and enable" : "Deskargatu eta gaitu",
    "Allow untested app" : "Baimendu probatu gabeko aplikazioa",
    "The app will be downloaded from the App Store" : "Aplikazioa aplikazio biltegitik deskargatuko da",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Aplikazio hau ez dago zure Nextcloud bertsioarekin bateragarri bezala markatuta. Jarraitzen baduzu aplikazioa instalatu egingo duzu. Kontuan izan agian aplikazioak ez duela ondo funtzionatuko.",
    "Never" : "Inoiz ez",
    "An error occurred during the request. Unable to proceed." : "Errorea gertatu da eskaeran. Ezin da jarraitu.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikazioa gaitu da baina eguneratu behar da. Eguneratze orrira joango zara 5 segundotan.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Errorea: aplikazio hau ezin da gaitu zerbitzaria ezegonkorra izatea eragiten duelako",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Eskaera gehiegi zeuden zure saretik. Saiatu beranduago edo kontaktatu zure administrailearekin hau errorea bada.",
    "Documentation" : "Dokumentazioa",
    "Forum" : "Foroa",
    "Nextcloud help resources" : "Nextcloud laguntza baliabideak",
    "Account documentation" : "Kontuen dokumentazioa",
    "Administration documentation" : "Administrazioaren dokumentazioa",
    "General documentation" : "Dokumentazio orokorra",
    "Login" : "Saio hasiera",
    "None/STARTTLS" : "Batere ez/STARTTLS",
    "SSL" : "SSL",
    "Open documentation" : "Ireki dokumentazioa",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Zerbitzaria epostak bidaltzeko gai izatea garrantzitsua da, pasahitzak berrezartzeko eta abisuentzako",
    "Send mode" : "Bidaltzeko modua",
    "Encryption" : "ZIfratzea",
    "Sendmail mode" : "Sendmail modua",
    "From address" : "Helbidetik",
    "Server address" : "Zerbitzariaren helbidea",
    "Port" : "Portua",
    "Authentication" : "Autentifikazioa",
    "Authentication required" : "Autentikazioa beharrezkoa",
    "Credentials" : "Kredentzialak",
    "SMTP Username" : "SMTP erabiltzaile-izena",
    "SMTP Password" : "SMTP pasahitza",
    "Save" : "Gorde",
    "Test and verify email settings" : "Probatu eta egiaztatu posta elektronikoaren ezarpenak",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Zure instantziaren segurtasuna eta funtzionamenduarentzat oso garrantzitsua da dena ondo konfiguratuta egotea. Horretan laguntzeko egiaztapen automatiko batzuk egiten ditu tresnak bera. Irakurri estekatutako dokumentazioa informazio gehiago lortzeko.",
    "All checks passed." : "Egiaztapen guztiak gaindituta.",
    "There are some errors regarding your setup." : "Zure ezarpenen artean errore batzuk daude.",
    "There are some warnings regarding your setup." : "Zure ezarpenei dagokienez ohartarazpen batzuk daude.",
    "Checking for system and security issues." : "Sistema eta segurtasun arazoak bilatzen.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Mesedez egiaztatu <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">instalazio gida↗</a> eta begiratu errore eta oharrak <a href=\"%2$s\">log fitxategian</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Egiaztatu zure Nextcloud instantziaren segurtasuna <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">gure segurtasun eskaneoa eginez ↗</a>.",
    "You need to enable the File sharing App." : "Fitxategi partekatze aplikazioa gaitu behar duzu.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Admin bezala partekatze portaerak zehaztasunez konfigura daitezke. Ikusi dokumentazioa informazio gehiagorako. ",
    "Allow apps to use the Share API" : "Baimendu aplikazioak partekatzeko APIa erabiltzeko",
    "Set default expiration date for shares" : "Partekatzeei iraungitze data lehenetsia ezarri",
    "Expire after" : "Iraungi honen ondoren",
    "day(s)" : "egun",
    "Enforce expiration date" : "Betearazi iraungitze-data",
    "Set default expiration date for shares to other servers" : "Ezarri beste zerbitzari batzuetarako partekatzeen iraungitze data lehenetsia",
    "Allow users to share via link and emails" : "Baimendu erabiltzaileak esteka eta e-postaren bidez partekatzea",
    "Allow public uploads" : "Baimendu igoera publikoak",
    "Always ask for a password" : "Beti eskatu pasahitza",
    "Enforce password protection" : "Betearazi pasahitzaren babesa",
    "Exclude groups from password requirements:" : "Baztertu taldeak pasahitz eskakizunetatik:",
    "Set default expiration date" : "Ezarri iraungitze-data lehenetsia",
    "Exclude groups from creating link shares:" : "Baztertu taldeak esteka partekatzeak sortzetik:",
    "Allow resharing" : "Baimendu birpartekatzea",
    "Allow sharing with groups" : "Onartu taldeekin partekatzen",
    "Restrict users to only share with users in their groups" : "Mugatu partekatzeak taldeko erabiltzaileetara",
    "Exclude groups from sharing" : "Baztertu taldeak partekatzean",
    "These groups will still be able to receive shares, but not to initiate them." : "Talde hauek oraindik jaso ahal izango dute partekatzeak, baina ezingo dute partekatu",
    "Allow username autocompletion in share dialog and allow access to the system address book" : "Baimendu erabiltzaile izena automatikoki osatzea elkarrizketa-koadroan eta baimendu sistemako helbide-liburua atzitzea",
    "Allow username autocompletion to users within the same groups and limit system address books to users in the same groups" : "Baimendu erabiltzaile izena automatikoki osatzea talde bereko erabiltzaileei eta mugatu sistemako helbide-liburuak atzitzea talde bereko erabiltzaileei",
    "Allow username autocompletion to users based on phone number integration" : "Baimendu erabiltzaile-izenen osatze automatikoa telefono zenbakien integrazioan oinarritutako erabiltzaileei",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Osatze automatikoa \"talde bera\" eta \"telefono zenbakiaren integrazioa\" gaituta badaude, bat-etortzea nahikoa da erabiltzaileari erakusteko.",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Baimendu automatikoki osatzea izen osoa edo helbide elektronikoa sartzerakoan (alde batera utziz falta den telefono-liburuarekin bat etortzea eta talde berean egotea)",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Ohar mezua igotzeko orriaren esteka publikoan erakutsi (fitxategi zerrenda ezkutatuta dagoenen bakarrik ikusten da.)",
    "This text will be shown on the public link upload page when the file list is hidden." : "Testu hau igotzeko orriaren esteka publikoan erakutsiko da fitxategi zerrenda ezkutatuta dagoenean.",
    "Default share permissions" : "Partekatze baimen lehenetsiak",
    "Reasons to use Nextcloud in your organization" : "Nextcloud zure erakundean erabiltzeko arrazoiak",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "{communityopen}Nextcloud komunitateak{linkclose} garatuta, {githubopen}iturburu kodea{linkclose}  {licenseopen}AGPL{linkclose} lizentziapean banatzen da.",
    "Like our Facebook page" : "Gure Facebook orrian Like egin",
    "Follow us on Twitter" : "Jarrai gaitzazu Twitterren",
    "Follow us on Mastodon" : "Jarraitu gaitzazu Mastodon-en",
    "Check out our blog" : "Gure bloga kontsultatu",
    "Subscribe to our newsletter" : "Izena eman gure buletinean",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Nextcloud komunitate bertsio honek ez du laguntza-zerbitzurik eta berehalako jakinarazpenak ez daude eskuragarri.",
    "Use a second factor besides your password to increase security for your account." : "Zure pasahitzaz gain bigarren faktore bat erabiltzeak zure kontua seguruago egingo du.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Hirugarrenen aplikazioak erabiltzen badituzu Nextcloud-era konektatzeko, ziurtatu bakoitzarentzako aplikazioaren pasahitza sortu eta konfiguratzen duzula bigarren faktorearen autentifikazioa gaitu aurretik.",
    "You created app password \"{token}\"" : "\"{token}\" aplikazio pasahitza sortu duzu",
    "An administrator created app password \"{token}\"" : "Administratzaile batek \"{token}\" aplikazioaren pasahitza sortu du",
    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "LDAP erabiltzaile edo taldeen UUID baliogabeak aurkitu dira. Mesedez, berrikusi zure \"Gainarazi UUID detekzioa\" ezarpenak LDAP konfigurazioaren Aditu atalean eta erabili \"occ ldap:update-uuid\" horiek eguneratzeko.",
    "Enable all" : "Gaitu denak",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Hau exekutatzeko PHP POSIX luzapena behar duzu. {linkstart}PHP dokumentazioa{linkend} ikusi informazio gehiagorako",
    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Erabili sistemaren cron zerbitzua 5 minuturo cron.php fitxategira deitzeko. Instantzia guztietarako gomendatua.",
    "You are about to remove the group {group}. The users will NOT be deleted." : "{group} taldea ezabatzera zoaz. Erabiltzaileak EZ dira ezabatuko.",
    "Please confirm the group removal " : "Mesedez, baieztatu taldearen ezabaketa",
    "Choose profile picture from files" : "Aukeratu profil-irudia fitxategietatik",
    "png or jpg, max. 20 MB" : "png edo jpg, gehienez 20MB",
    "Your email address" : "Zure e-posta",
    "Your location" : "Zure kokapena",
    "Add new password" : "Gehitu pasahitz berria",
    "Add new email address" : "Gehitu e-mail helbide berria",
    "Edit User" : "Erabiltzailea editatu",
    "Will be autogenerated" : "Automatikoki sortuko da",
    "Add a new user" : "Gehitu erabiltze berria",
    "No users in here" : "Ez dago erabiltzailerik hemen",
    "Enter group name" : "Talderan izena sartu",
    "Add group" : "Taldea gehitu",
    "Default quota:" : "Lehenetsitako kuota:",
    "Show Languages" : "Erakutsi Hizkuntzak",
    "Send email to new user" : "Bidali eposta erabiltzaile berriari",
    "Enable untested app" : "Gaitu probatu gabeko aplikazioa",
    "Plain" : "Arrunta",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Authentication method" : "Autentifikazio metodoa",
    "Allow username autocompletion in share dialog" : "Baimendu erabiltzaile-izenaren osatze automatikoa partekatze elkarrizketan",
    "Allow username autocompletion to users within the same groups" : "Baimendu erabiltzaile-izenen osatze automatikoa talde bereko erabiltzaileei",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occured. Please run it manually by calling occ dav:sync-system-addressbook." : "DAV sistemaren helbide-liburuaren sinkronizazioa oraindik ez da martxan jarri zure instantziak 1000 erabiltzaile baino gehiago dituelako edo akats bat gertatu delako. Mesedez, exekutatu eskuz occ dav:sync-system-addressbook deituz.",
    "Edit display name" : "Editatu erakutsiko den izena",
    "Select manager" : "Aukeratu kudeatzailea",
    "User's table" : "Erabiltzailearen mahaia",
    "Select user manager" : "Aukeratu erabiltzaile kudeatzailea"
},
"nplurals=2; plural=(n != 1);");
